@@ -21,8 +21,6 @@
     limitations under the License.
 */
 
-#define __STDC_FORMAT_MACROS 1
-
 #include <curl/curl.h>
 #include <map>
 #include <string>
@@ -35,8 +33,10 @@
 using namespace std;
 
 struct LookupItem {
-  LookupItem(const char *s, const char *n, const int t): pretty(s), name(n), type(t) {}
-  LookupItem(const char *s, const char *n, const char *d, const int t): pretty(s), name(n), numerator(n), denominator(d), type(t) {}
+  LookupItem(const char *s, const char *n, const int t) : pretty(s), name(n), type(t) {}
+  LookupItem(const char *s, const char *n, const char *d, const int t) : pretty(s), name(n), numerator(n), denominator(d), type(t)
+  {
+  }
   const char *pretty;
   const char *name;
   const char *numerator;
@@ -47,19 +47,21 @@ extern size_t write_data(void *ptr, size_t size, size_t nmemb, void *stream);
 extern char curl_error[CURL_ERROR_SIZE];
 extern string response;
 
-namespace constant {
-  const char global[] = "\"global\": {\n";
-  const char start[] = "\"proxy.process.";
-  const char seperator[] = "\": \"";
-  const char end[] = "\",\n";
+namespace constant
+{
+const char global[] = "\"global\": {\n";
+const char start[] = "\"proxy.process.";
+const char seperator[] = "\": \"";
+const char end[] = "\",\n";
 };
 
 
 //----------------------------------------------------------------------------
-class Stats {
+class Stats
+{
 public:
-  Stats(const string &url): _url(url) {
-
+  Stats(const string &url) : _url(url)
+  {
     if (url != "") {
       if (_url.substr(0, 4) != "http") {
         // looks like it is a host using it the old way
@@ -99,14 +101,15 @@ public:
     lookup_table.insert(make_pair("entries", LookupItem("Entries", "proxy.process.cache.direntries.used", 1)));
     lookup_table.insert(make_pair("avg_size", LookupItem("Avg Size", "disk_used", "entries", 3)));
 
-    lookup_table.insert(make_pair("dns_time", LookupItem("DNS Time", "proxy.node.dns.lookup_avg_time_ms", 2)));
-    lookup_table.insert(make_pair("dns_hits", LookupItem("DNS hits", "proxy.node.hostdb.total_hits", 2)));
-    lookup_table.insert(make_pair("dns_lookups", LookupItem("DNS lookups", "proxy.node.hostdb.total_lookups", 2)));
+    lookup_table.insert(make_pair("dns_entry", LookupItem("DNS Entry", "proxy.process.hostdb.total_entries", 1)));
+    lookup_table.insert(make_pair("dns_hits", LookupItem("DNS Hits", "proxy.process.hostdb.total_hits", 2)));
+    lookup_table.insert(make_pair("dns_lookups", LookupItem("DNS Lookups", "proxy.process.hostdb.total_lookups", 2)));
     lookup_table.insert(make_pair("client_req", LookupItem("Requests", "proxy.process.http.incoming_requests", 2)));
     lookup_table.insert(make_pair("client_conn", LookupItem("New Conn", "proxy.process.http.total_client_connections", 2)));
     lookup_table.insert(make_pair("client_req_conn", LookupItem("Req/Conn", "client_req", "client_conn", 3)));
     lookup_table.insert(make_pair("client_curr_conn", LookupItem("Curr Conn", "proxy.process.http.current_client_connections", 1)));
-    lookup_table.insert(make_pair("client_actv_conn", LookupItem("Active Con", "proxy.process.http.current_active_client_connections", 1)));
+    lookup_table.insert(
+      make_pair("client_actv_conn", LookupItem("Active Con", "proxy.process.http.current_active_client_connections", 1)));
 
     lookup_table.insert(make_pair("server_req", LookupItem("Requests", "proxy.process.http.outgoing_requests", 2)));
     lookup_table.insert(make_pair("server_conn", LookupItem("New Conn", "proxy.process.http.total_server_connections", 2)));
@@ -114,22 +117,29 @@ public:
     lookup_table.insert(make_pair("server_curr_conn", LookupItem("Curr Conn", "proxy.process.http.current_server_connections", 1)));
 
 
-    lookup_table.insert(make_pair("client_head", LookupItem("Head Bytes", "proxy.process.http.user_agent_response_header_total_size", 2)));
-    lookup_table.insert(make_pair("client_body", LookupItem("Body Bytes", "proxy.process.http.user_agent_response_document_total_size", 2)));
-    lookup_table.insert(make_pair("server_head", LookupItem("Head Bytes", "proxy.process.http.origin_server_response_header_total_size", 2)));
-    lookup_table.insert(make_pair("server_body", LookupItem("Body Bytes", "proxy.process.http.origin_server_response_document_total_size", 2)));
+    lookup_table.insert(
+      make_pair("client_head", LookupItem("Head Bytes", "proxy.process.http.user_agent_response_header_total_size", 2)));
+    lookup_table.insert(
+      make_pair("client_body", LookupItem("Body Bytes", "proxy.process.http.user_agent_response_document_total_size", 2)));
+    lookup_table.insert(
+      make_pair("server_head", LookupItem("Head Bytes", "proxy.process.http.origin_server_response_header_total_size", 2)));
+    lookup_table.insert(
+      make_pair("server_body", LookupItem("Body Bytes", "proxy.process.http.origin_server_response_document_total_size", 2)));
 
     // not used directly
     lookup_table.insert(make_pair("ram_hit", LookupItem("Ram Hit", "proxy.process.cache.ram_cache.hits", 2)));
     lookup_table.insert(make_pair("ram_miss", LookupItem("Ram Misses", "proxy.process.cache.ram_cache.misses", 2)));
-
+    lookup_table.insert(make_pair("ka_total", LookupItem("KA Total", "proxy.process.net.dynamic_keep_alive_timeout_in_total", 2)));
+    lookup_table.insert(make_pair("ka_count", LookupItem("KA Count", "proxy.process.net.dynamic_keep_alive_timeout_in_count", 2)));
 
 
     lookup_table.insert(make_pair("client_abort", LookupItem("Clnt Abort", "proxy.process.http.err_client_abort_count_stat", 2)));
     lookup_table.insert(make_pair("conn_fail", LookupItem("Conn Fail", "proxy.process.http.err_connect_fail_count_stat", 2)));
     lookup_table.insert(make_pair("abort", LookupItem("Abort", "proxy.process.http.transaction_counts.errors.aborts", 2)));
-    lookup_table.insert(make_pair("t_conn_fail", LookupItem("Conn Fail", "proxy.process.http.transaction_counts.errors.connect_failed", 2)));
+    lookup_table.insert(
+      make_pair("t_conn_fail", LookupItem("Conn Fail", "proxy.process.http.transaction_counts.errors.connect_failed", 2)));
     lookup_table.insert(make_pair("other_err", LookupItem("Other Err", "proxy.process.http.transaction_counts.errors.other", 2)));
+
     // percentage
     lookup_table.insert(make_pair("ram_ratio", LookupItem("Ram Hit", "ram_hit", "ram_hit_miss", 4)));
     lookup_table.insert(make_pair("dns_ratio", LookupItem("DNS Hit", "dns_hits", "dns_lookups", 4)));
@@ -142,12 +152,18 @@ public:
     lookup_table.insert(make_pair("not", LookupItem("Not Cache", "proxy.process.http.transaction_counts.miss_not_cacheable", 5)));
     lookup_table.insert(make_pair("no", LookupItem("No Cache", "proxy.process.http.transaction_counts.miss_client_no_cache", 5)));
 
-    lookup_table.insert(make_pair("fresh_time", LookupItem("Fresh (ms)", "proxy.process.http.transaction_totaltime.hit_fresh", "fresh", 8)));
-    lookup_table.insert(make_pair("reval_time", LookupItem("Reval (ms)", "proxy.process.http.transaction_totaltime.hit_revalidated", "reval", 8)));
-    lookup_table.insert(make_pair("cold_time", LookupItem("Cold (ms)", "proxy.process.http.transaction_totaltime.miss_cold", "cold", 8)));
-    lookup_table.insert(make_pair("changed_time", LookupItem("Chang (ms)", "proxy.process.http.transaction_totaltime.miss_changed", "changed", 8)));
-    lookup_table.insert(make_pair("not_time", LookupItem("Not (ms)", "proxy.process.http.transaction_totaltime.miss_not_cacheable", "not", 8)));
-    lookup_table.insert(make_pair("no_time", LookupItem("No (ms)", "proxy.process.http.transaction_totaltime.miss_client_no_cache", "no", 8)));
+    lookup_table.insert(
+      make_pair("fresh_time", LookupItem("Fresh (ms)", "proxy.process.http.transaction_totaltime.hit_fresh", "fresh", 8)));
+    lookup_table.insert(
+      make_pair("reval_time", LookupItem("Reval (ms)", "proxy.process.http.transaction_totaltime.hit_revalidated", "reval", 8)));
+    lookup_table.insert(
+      make_pair("cold_time", LookupItem("Cold (ms)", "proxy.process.http.transaction_totaltime.miss_cold", "cold", 8)));
+    lookup_table.insert(
+      make_pair("changed_time", LookupItem("Chang (ms)", "proxy.process.http.transaction_totaltime.miss_changed", "changed", 8)));
+    lookup_table.insert(
+      make_pair("not_time", LookupItem("Not (ms)", "proxy.process.http.transaction_totaltime.miss_not_cacheable", "not", 8)));
+    lookup_table.insert(
+      make_pair("no_time", LookupItem("No (ms)", "proxy.process.http.transaction_totaltime.miss_client_no_cache", "no", 8)));
 
     lookup_table.insert(make_pair("get", LookupItem("GET", "proxy.process.http.get_requests", 5)));
     lookup_table.insert(make_pair("head", LookupItem("HEAD", "proxy.process.http.head_requests", 5)));
@@ -219,11 +235,15 @@ public:
 
 
     lookup_table.insert(make_pair("total_time", LookupItem("Total Time", "proxy.process.http.total_transactions_time", 2)));
+
+    // ratio
     lookup_table.insert(make_pair("client_req_time", LookupItem("Resp (ms)", "total_time", "client_req", 3)));
+    lookup_table.insert(make_pair("client_dyn_ka", LookupItem("Dynamic KA", "ka_total", "ka_count", 3)));
   }
 
-  void getStats() {
-
+  void
+  getStats()
+  {
     if (_url == "") {
       int64_t value = 0;
       if (_old_stats != NULL) {
@@ -236,8 +256,7 @@ public:
       gettimeofday(&_time, NULL);
       double now = _time.tv_sec + (double)_time.tv_usec / 1000000;
 
-      for (map<string, LookupItem>::const_iterator lookup_it = lookup_table.begin();
-           lookup_it != lookup_table.end(); ++lookup_it) {
+      for (map<string, LookupItem>::const_iterator lookup_it = lookup_table.begin(); lookup_it != lookup_table.end(); ++lookup_it) {
         const LookupItem &item = lookup_it->second;
 
         if (item.type == 1 || item.type == 2 || item.type == 5 || item.type == 8) {
@@ -248,7 +267,11 @@ public:
             string key = item.name;
             (*_stats)[key] = strValue;
           } else {
-            assert(TSRecordGetInt(item.name, &value) == TS_ERR_OKAY);
+            if (TSRecordGetInt(item.name, &value) != TS_ERR_OKAY) {
+              fprintf(stderr, "Error getting stat: %s when calling TSRecordGetInt() failed: file \"%s\", line %d\n\n", item.name,
+                      __FILE__, __LINE__);
+              abort();
+            }
             string key = item.name;
             char buffer[32];
             sprintf(buffer, "%" PRId64, value);
@@ -256,7 +279,7 @@ public:
             (*_stats)[key] = foo;
           }
         }
-      } 
+      }
       _old_time = _now;
       _now = now;
       _time_diff = _now - _old_time;
@@ -297,13 +320,15 @@ public:
           abort();
         }
 
-        /* always cleanup */ 
+        /* always cleanup */
         curl_easy_cleanup(curl);
       }
     }
   }
 
-  int64_t getValue(const string &key, const map<string, string> *stats) const {
+  int64_t
+  getValue(const string &key, const map<string, string> *stats) const
+  {
     map<string, string>::const_iterator stats_it = stats->find(key);
     if (stats_it == stats->end())
       return 0;
@@ -311,18 +336,22 @@ public:
     return value;
   }
 
-  void getStat(const string &key, double &value, int overrideType = 0) {
+  void
+  getStat(const string &key, double &value, int overrideType = 0)
+  {
     string strtmp;
     int typetmp;
     getStat(key, value, strtmp, typetmp, overrideType);
   }
 
 
-  void getStat(const string &key, string &value) {
+  void
+  getStat(const string &key, string &value)
+  {
     map<string, LookupItem>::const_iterator lookup_it = lookup_table.find(key);
     assert(lookup_it != lookup_table.end());
     const LookupItem &item = lookup_it->second;
-    
+
     map<string, string>::const_iterator stats_it = _stats->find(item.name);
     if (stats_it == _stats->end())
       value = "";
@@ -330,7 +359,9 @@ public:
       value = stats_it->second.c_str();
   }
 
-  void getStat(const string &key, double &value, string &prettyName, int &type, int overrideType = 0) {
+  void
+  getStat(const string &key, double &value, string &prettyName, int &type, int overrideType = 0)
+  {
     map<string, LookupItem>::const_iterator lookup_it = lookup_table.find(key);
     assert(lookup_it != lookup_table.end());
     const LookupItem &item = lookup_it->second;
@@ -394,7 +425,9 @@ public:
     }
   }
 
-  bool toggleAbsolute() {
+  bool
+  toggleAbsolute()
+  {
     if (_absolute == true)
       _absolute = false;
     else
@@ -403,7 +436,9 @@ public:
     return _absolute;
   }
 
-  void parseResponse(const string &response) {
+  void
+  parseResponse(const string &response)
+  {
     // move past global
     size_t pos = response.find(constant::global);
     pos += sizeof(constant::global) - 1;
@@ -413,27 +448,33 @@ public:
       size_t start = response.find(constant::start, pos);
       size_t seperator = response.find(constant::seperator, pos);
       size_t end = response.find(constant::end, pos);
-  
+
       if (start == string::npos || seperator == string::npos || end == string::npos)
         return;
 
-      //cout << constant::start << " " << start << endl;
-      //cout << constant::seperator << " " << seperator << endl;
-      //cout << constant::end << " " << end << endl;
+      // cout << constant::start << " " << start << endl;
+      // cout << constant::seperator << " " << seperator << endl;
+      // cout << constant::end << " " << end << endl;
 
       string key = response.substr(start + 1, seperator - start - 1);
-      string value = response.substr(seperator + sizeof(constant::seperator) - 1, end - seperator - sizeof(constant::seperator) + 1);
+      string value =
+        response.substr(seperator + sizeof(constant::seperator) - 1, end - seperator - sizeof(constant::seperator) + 1);
 
       (*_stats)[key] = value;
-      //cout << "key " << key << " " << "value " << value << endl;
+      // cout << "key " << key << " " << "value " << value << endl;
       pos = end + sizeof(constant::end) - 1;
-      //cout << "pos: " << pos << endl;
+      // cout << "pos: " << pos << endl;
     }
   }
 
-  const string& getHost() const { return _host; }
+  const string &
+  getHost() const
+  {
+    return _host;
+  }
 
-  ~Stats() {
+  ~Stats()
+  {
     if (_stats != NULL) {
       delete _stats;
     }
