@@ -41,7 +41,10 @@
 /* MAX_SERVER_NAME_LENGTH + MAX_FILE_NAME_LENGTH + strlen("\n\n") */
 #define MAX_REQUEST_LENGTH 2050
 
-#define set_handler(_d, _s) {_d = _s;}
+#define set_handler(_d, _s) \
+  {                         \
+    _d = _s;                \
+  }
 
 
 #endif /* PROTOCOL_H */
