@@ -72,7 +72,7 @@ TSCacheKey CacheKeyCreate(char *file_name);
 int
 main_handler(TSCont contp, TSEvent event, void *data)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
   TxnSMHandler q_current_handler = txn_sm->q_current_handler;
 
   TSDebug("protocol", "main_handler (contp %p event %d)", contp, event);
@@ -90,7 +90,7 @@ main_handler(TSCont contp, TSEvent event, void *data)
 
   TSDebug("protocol", "current_handler (%p)", q_current_handler);
 
-  return (*q_current_handler) (contp, event, data);
+  return (*q_current_handler)(contp, event, data);
 }
 
 /* Create the Txn data structure and the continuation for the Txn. */
@@ -100,7 +100,7 @@ TxnSMCreate(TSMutex pmutex, TSVConn client_vc, int server_port)
   TSCont contp;
   TxnSM *txn_sm;
 
-  txn_sm = (TxnSM *) TSmalloc(sizeof(TxnSM));
+  txn_sm = (TxnSM *)TSmalloc(sizeof(TxnSM));
 
   txn_sm->q_mutex = pmutex;
   txn_sm->q_pending_action = NULL;
@@ -126,7 +126,7 @@ TxnSMCreate(TSMutex pmutex, TSVConn client_vc, int server_port)
   txn_sm->q_server_request_buffer_reader = NULL;
 
   /* Char buffers to store client request and server response. */
-  txn_sm->q_client_request = (char *) TSmalloc(sizeof(char) * (MAX_REQUEST_LENGTH + 1));
+  txn_sm->q_client_request = (char *)TSmalloc(sizeof(char) * (MAX_REQUEST_LENGTH + 1));
   memset(txn_sm->q_client_request, '\0', (sizeof(char) * (MAX_REQUEST_LENGTH + 1)));
   txn_sm->q_server_response = NULL;
   txn_sm->q_server_response_length = 0;
@@ -136,8 +136,8 @@ TxnSMCreate(TSMutex pmutex, TSVConn client_vc, int server_port)
   txn_sm->q_cache_read_buffer = NULL;
   txn_sm->q_cache_read_buffer_reader = NULL;
 
-  txn_sm->q_server_name = (char *) TSmalloc(sizeof(char) * (MAX_SERVER_NAME_LENGTH + 1));
-  txn_sm->q_file_name = (char *) TSmalloc(sizeof(char) * (MAX_FILE_NAME_LENGTH + 1));
+  txn_sm->q_server_name = (char *)TSmalloc(sizeof(char) * (MAX_SERVER_NAME_LENGTH + 1));
+  txn_sm->q_file_name = (char *)TSmalloc(sizeof(char) * (MAX_FILE_NAME_LENGTH + 1));
 
   txn_sm->q_key = NULL;
   txn_sm->q_magic = TXN_SM_ALIVE;
@@ -154,7 +154,7 @@ TxnSMCreate(TSMutex pmutex, TSVConn client_vc, int server_port)
 int
 state_start(TSCont contp, TSEvent event ATS_UNUSED, void *data ATS_UNUSED)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   if (!txn_sm->q_client_vc) {
     return prepare_to_die(contp);
@@ -173,7 +173,7 @@ state_start(TSCont contp, TSEvent event ATS_UNUSED, void *data ATS_UNUSED)
      INT64_MAX, so that we will always get TS_EVENT_VCONN_READ_READY
      event, but never TS_EVENT_VCONN_READ_COMPLETE event. */
   set_handler(txn_sm->q_current_handler, (TxnSMHandler)&state_interface_with_client);
-  txn_sm->q_client_read_vio = TSVConnRead(txn_sm->q_client_vc, (TSCont) contp, txn_sm->q_client_request_buffer, INT64_MAX);
+  txn_sm->q_client_read_vio = TSVConnRead(txn_sm->q_client_vc, (TSCont)contp, txn_sm->q_client_request_buffer, INT64_MAX);
 
   return TS_SUCCESS;
 }
@@ -188,7 +188,7 @@ state_start(TSCont contp, TSEvent event ATS_UNUSED, void *data ATS_UNUSED)
 int
 state_interface_with_client(TSCont contp, TSEvent event, TSVIO vio)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   TSDebug("protocol", "enter state_interface_with_client");
 
@@ -209,7 +209,7 @@ state_read_request_from_client(TSCont contp, TSEvent event, TSVIO vio ATS_UNUSED
   int bytes_read, parse_result;
   char *temp_buf;
 
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   TSDebug("protocol", "enter state_read_request_from_client");
 
@@ -218,13 +218,13 @@ state_read_request_from_client(TSCont contp, TSEvent event, TSVIO vio ATS_UNUSED
     bytes_read = TSIOBufferReaderAvail(txn_sm->q_client_request_buffer_reader);
 
     if (bytes_read > 0) {
-      temp_buf = (char *) get_info_from_buffer(txn_sm->q_client_request_buffer_reader);
+      temp_buf = (char *)get_info_from_buffer(txn_sm->q_client_request_buffer_reader);
       TSstrlcat(txn_sm->q_client_request, temp_buf, MAX_REQUEST_LENGTH + 1);
       TSfree(temp_buf);
 
       /* Check if the request is fully read, if so, do cache lookup. */
       if (strstr(txn_sm->q_client_request, "\r\n\r\n") != NULL) {
-        temp_buf = (char *) TSmalloc(sizeof(char) * (strlen(txn_sm->q_client_request) + 1));
+        temp_buf = (char *)TSmalloc(sizeof(char) * (strlen(txn_sm->q_client_request) + 1));
         memcpy(temp_buf, txn_sm->q_client_request, strlen(txn_sm->q_client_request));
         temp_buf[strlen(txn_sm->q_client_request)] = '\0';
         parse_result = parse_request(temp_buf, txn_sm->q_server_name, txn_sm->q_file_name);
@@ -248,9 +248,8 @@ state_read_request_from_client(TSCont contp, TSEvent event, TSVIO vio ATS_UNUSED
     TSVIOReenable(txn_sm->q_client_read_vio);
     break;
 
-  default:                     /* Shouldn't get here, prepare to die. */
+  default: /* Shouldn't get here, prepare to die. */
     return prepare_to_die(contp);
-
   }
   return TS_SUCCESS;
 }
@@ -261,7 +260,7 @@ state_read_request_from_client(TSCont contp, TSEvent event, TSVIO vio ATS_UNUSED
 int
 state_handle_cache_lookup(TSCont contp, TSEvent event, TSVConn vc)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
   int64_t response_size;
   int ret_val;
 
@@ -289,9 +288,8 @@ state_handle_cache_lookup(TSCont contp, TSEvent event, TSVConn vc)
     txn_sm->q_cache_read_buffer = TSIOBufferCreate();
     txn_sm->q_cache_read_buffer_reader = TSIOBufferReaderAlloc(txn_sm->q_cache_read_buffer);
 
-    if (!txn_sm->q_client_response_buffer ||
-        !txn_sm->q_client_response_buffer_reader ||
-        !txn_sm->q_cache_read_buffer || !txn_sm->q_cache_read_buffer_reader) {
+    if (!txn_sm->q_client_response_buffer || !txn_sm->q_client_response_buffer_reader || !txn_sm->q_cache_read_buffer ||
+        !txn_sm->q_cache_read_buffer_reader) {
       return prepare_to_die(contp);
     }
 
@@ -323,7 +321,7 @@ state_handle_cache_lookup(TSCont contp, TSEvent event, TSVConn vc)
 }
 
 static void
-load_buffer_cache_data(TxnSM * txn_sm)
+load_buffer_cache_data(TxnSM *txn_sm)
 {
   /* transfer the data from the cache buffer (which must
      fully be consumed on a VCONN_READY event, to the
@@ -335,9 +333,9 @@ load_buffer_cache_data(TxnSM * txn_sm)
 
   TSAssert(rdr_avail > 0);
 
-  TSIOBufferCopy(txn_sm->q_client_response_buffer,     /* (cache response buffer) */
-                  txn_sm->q_cache_read_buffer_reader,   /* (transient buffer)      */
-                  rdr_avail, 0);
+  TSIOBufferCopy(txn_sm->q_client_response_buffer,   /* (cache response buffer) */
+                 txn_sm->q_cache_read_buffer_reader, /* (transient buffer)      */
+                 rdr_avail, 0);
 
   TSIOBufferReaderConsume(txn_sm->q_cache_read_buffer_reader, rdr_avail);
 }
@@ -350,7 +348,7 @@ load_buffer_cache_data(TxnSM * txn_sm)
 int
 state_handle_cache_read_response(TSCont contp, TSEvent event, TSVIO vio ATS_UNUSED)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   TSDebug("protocol", "enter state_handle_cache_read_response");
 
@@ -390,7 +388,6 @@ state_handle_cache_read_response(TSCont contp, TSEvent event, TSVIO vio ATS_UNUS
     TSAssert(txn_sm->q_pending_action == NULL);
     txn_sm->q_pending_action = TSCacheWrite(contp, txn_sm->q_key);
     break;
-
   }
   return TS_SUCCESS;
 }
@@ -401,7 +398,7 @@ state_handle_cache_read_response(TSCont contp, TSEvent event, TSVIO vio ATS_UNUS
 int
 state_handle_cache_prepare_for_write(TSCont contp, TSEvent event, TSVConn vc)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   TSDebug("protocol", "enter state_handle_cache_prepare_for_write");
 
@@ -425,7 +422,7 @@ state_handle_cache_prepare_for_write(TSCont contp, TSEvent event, TSVConn vc)
 int
 state_build_and_send_request(TSCont contp, TSEvent event ATS_UNUSED, void *data ATS_UNUSED)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   TSDebug("protocol", "enter state_build_and_send_request");
 
@@ -437,9 +434,8 @@ state_build_and_send_request(TSCont contp, TSEvent event ATS_UNUSED, void *data
   txn_sm->q_server_response_buffer = TSIOBufferCreate();
   txn_sm->q_cache_response_buffer_reader = TSIOBufferReaderAlloc(txn_sm->q_server_response_buffer);
 
-  if (!txn_sm->q_server_request_buffer ||
-      !txn_sm->q_server_request_buffer_reader ||
-      !txn_sm->q_server_response_buffer || !txn_sm->q_cache_response_buffer_reader) {
+  if (!txn_sm->q_server_request_buffer || !txn_sm->q_server_request_buffer_reader || !txn_sm->q_server_response_buffer ||
+      !txn_sm->q_cache_response_buffer_reader) {
     return prepare_to_die(contp);
   }
 
@@ -461,8 +457,8 @@ state_build_and_send_request(TSCont contp, TSEvent event ATS_UNUSED, void *data
 int
 state_dns_lookup(TSCont contp, TSEvent event, TSHostLookupResult host_info)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
-  struct sockaddr const* q_server_addr;
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
+  struct sockaddr const *q_server_addr;
   struct sockaddr_in ip_addr;
 
   TSDebug("protocol", "enter state_dns_lookup");
@@ -483,7 +479,7 @@ state_dns_lookup(TSCont contp, TSEvent event, TSHostLookupResult host_info)
 
   memcpy(&ip_addr, q_server_addr, sizeof(ip_addr));
   ip_addr.sin_port = txn_sm->q_server_port;
-  txn_sm->q_pending_action = TSNetConnect(contp, (struct sockaddr const*)&ip_addr);
+  txn_sm->q_pending_action = TSNetConnect(contp, (struct sockaddr const *)&ip_addr);
 
   return TS_SUCCESS;
 }
@@ -496,7 +492,7 @@ state_dns_lookup(TSCont contp, TSEvent event, TSHostLookupResult host_info)
 int
 state_connect_to_server(TSCont contp, TSEvent event, TSVConn vc)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   TSDebug("protocol", "enter state_connect_to_server");
 
@@ -512,8 +508,8 @@ state_connect_to_server(TSCont contp, TSEvent event, TSVConn vc)
   set_handler(txn_sm->q_current_handler, (TxnSMHandler)&state_send_request_to_server);
 
   /* Actively write the request to the net_vc. */
-  txn_sm->q_server_write_vio = TSVConnWrite(txn_sm->q_server_vc, contp,
-                                             txn_sm->q_server_request_buffer_reader, strlen(txn_sm->q_client_request));
+  txn_sm->q_server_write_vio =
+    TSVConnWrite(txn_sm->q_server_vc, contp, txn_sm->q_server_request_buffer_reader, strlen(txn_sm->q_client_request));
   return TS_SUCCESS;
 }
 
@@ -522,7 +518,7 @@ state_connect_to_server(TSCont contp, TSEvent event, TSVConn vc)
 int
 state_send_request_to_server(TSCont contp, TSEvent event, TSVIO vio)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   TSDebug("protocol", "enter state_send_request_to_server");
 
@@ -538,7 +534,7 @@ state_send_request_to_server(TSCont contp, TSEvent event, TSVIO vio)
     txn_sm->q_server_read_vio = TSVConnRead(txn_sm->q_server_vc, contp, txn_sm->q_server_response_buffer, INT64_MAX);
     break;
 
-    /* it could be failure of TSNetConnect */
+  /* it could be failure of TSNetConnect */
   default:
     return prepare_to_die(contp);
   }
@@ -549,25 +545,25 @@ state_send_request_to_server(TSCont contp, TSEvent event, TSVIO vio)
 int
 state_interface_with_server(TSCont contp, TSEvent event, TSVIO vio)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   TSDebug("protocol", "enter state_interface_with_server");
 
   txn_sm->q_pending_action = NULL;
 
   switch (event) {
-    /* This is returned from cache_vc. */
+  /* This is returned from cache_vc. */
   case TS_EVENT_VCONN_WRITE_READY:
   case TS_EVENT_VCONN_WRITE_COMPLETE:
     return state_write_to_cache(contp, event, vio);
-    /* Otherwise, handle events from server. */
+  /* Otherwise, handle events from server. */
   case TS_EVENT_VCONN_READ_READY:
-    /* Actually, we shouldn't get READ_COMPLETE because we set bytes
-       count to be INT64_MAX. */
+  /* Actually, we shouldn't get READ_COMPLETE because we set bytes
+     count to be INT64_MAX. */
   case TS_EVENT_VCONN_READ_COMPLETE:
     return state_read_response_from_server(contp, event, vio);
 
-    /* all data of the response come in. */
+  /* all data of the response come in. */
   case TS_EVENT_VCONN_EOS:
     TSDebug("protocol", "get server eos");
     /* There is no more use of server_vc, close it. */
@@ -607,10 +603,10 @@ state_interface_with_server(TSCont contp, TSEvent event, TSVIO vio)
       /* Open cache_vc to read data and send to client. */
       set_handler(txn_sm->q_current_handler, (TxnSMHandler)&state_handle_cache_lookup);
       txn_sm->q_pending_action = TSCacheRead(contp, txn_sm->q_key);
-    } else {                    /* not done with writing into cache */
+    } else { /* not done with writing into cache */
 
       TSDebug("protocol", "cache_response_length is %d, server response length is %d", txn_sm->q_cache_response_length,
-               txn_sm->q_server_response_length);
+              txn_sm->q_server_response_length);
       TSVIOReenable(txn_sm->q_cache_write_vio);
     }
 
@@ -630,7 +626,7 @@ state_interface_with_server(TSCont contp, TSEvent event, TSVIO vio)
 int
 state_read_response_from_server(TSCont contp, TSEvent event ATS_UNUSED, TSVIO vio ATS_UNUSED)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
   int bytes_read = 0;
 
   TSDebug("protocol", "enter state_read_response_from_server");
@@ -641,18 +637,17 @@ state_read_response_from_server(TSCont contp, TSEvent event ATS_UNUSED, TSVIO vi
     /* If this is the first write, do TSVConnWrite, otherwise, simply
        reenable q_cache_write_vio. */
     if (txn_sm->q_server_response_length == 0) {
-      txn_sm->q_cache_write_vio = TSVConnWrite(txn_sm->q_cache_vc,
-                                                contp, txn_sm->q_cache_response_buffer_reader, bytes_read);
+      txn_sm->q_cache_write_vio = TSVConnWrite(txn_sm->q_cache_vc, contp, txn_sm->q_cache_response_buffer_reader, bytes_read);
     } else {
       TSAssert(txn_sm->q_server_response_length > 0);
       TSVIOReenable(txn_sm->q_cache_write_vio);
       txn_sm->q_block_bytes_read = bytes_read;
-/*
-	    txn_sm->q_cache_write_vio = TSVConnWrite (txn_sm->q_cache_vc,
-						       contp,
-						       txn_sm->q_cache_response_buffer_reader,
-						       bytes_read);
-						       */
+      /*
+                  txn_sm->q_cache_write_vio = TSVConnWrite (txn_sm->q_cache_vc,
+                                                             contp,
+                                                             txn_sm->q_cache_response_buffer_reader,
+                                                             bytes_read);
+                                                             */
     }
   }
 
@@ -667,7 +662,7 @@ state_read_response_from_server(TSCont contp, TSEvent event ATS_UNUSED, TSVIO vi
 int
 state_write_to_cache(TSCont contp, TSEvent event, TSVIO vio)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   TSDebug("protocol", "enter state_write_to_cache");
 
@@ -695,7 +690,7 @@ state_write_to_cache(TSCont contp, TSEvent event, TSVIO vio)
     if (txn_sm->q_cache_response_length >= txn_sm->q_server_response_length) {
       /* Write is complete, close the cache_vc. */
       TSDebug("protocol", "close cache_vc, cache_response_length is %d, server_response_lenght is %d",
-               txn_sm->q_cache_response_length, txn_sm->q_server_response_length);
+              txn_sm->q_cache_response_length, txn_sm->q_server_response_length);
       TSVConnClose(txn_sm->q_cache_vc);
       txn_sm->q_cache_vc = NULL;
       txn_sm->q_cache_write_vio = NULL;
@@ -704,7 +699,7 @@ state_write_to_cache(TSCont contp, TSEvent event, TSVIO vio)
       /* Open cache_vc to read data and send to client. */
       set_handler(txn_sm->q_current_handler, (TxnSMHandler)&state_handle_cache_lookup);
       txn_sm->q_pending_action = TSCacheRead(contp, txn_sm->q_key);
-    } else {                    /* not done with writing into cache */
+    } else { /* not done with writing into cache */
 
       TSDebug("protocol", "re-enable cache_write_vio");
       TSVIOReenable(txn_sm->q_cache_write_vio);
@@ -724,14 +719,14 @@ state_write_to_cache(TSCont contp, TSEvent event, TSVIO vio)
 int
 state_send_response_to_client(TSCont contp, TSEvent event, TSVIO vio)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   TSDebug("protocol", "enter state_send_response_to_client");
 
   switch (event) {
   case TS_EVENT_VCONN_WRITE_READY:
     TSDebug("protocol", " . wr ready");
-    TSDebug("protocol", "write_ready: nbytes %" PRId64", ndone %" PRId64, TSVIONBytesGet(vio), TSVIONDoneGet(vio));
+    TSDebug("protocol", "write_ready: nbytes %" PRId64 ", ndone %" PRId64, TSVIONBytesGet(vio), TSVIONDoneGet(vio));
     TSVIOReenable(txn_sm->q_client_write_vio);
     break;
 
@@ -751,7 +746,6 @@ state_send_response_to_client(TSCont contp, TSEvent event, TSVIO vio)
   default:
     TSDebug("protocol", " . default handler");
     return prepare_to_die(contp);
-
   }
 
   TSDebug("protocol", "leaving send_response_to_client");
@@ -765,7 +759,7 @@ state_send_response_to_client(TSCont contp, TSEvent event, TSVIO vio)
 int
 prepare_to_die(TSCont contp)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   TSDebug("protocol", "enter prepare_to_die");
   if (txn_sm->q_client_vc) {
@@ -795,7 +789,7 @@ prepare_to_die(TSCont contp)
 int
 state_done(TSCont contp, TSEvent event ATS_UNUSED, TSVIO vio ATS_UNUSED)
 {
-  TxnSM *txn_sm = (TxnSM *) TSContDataGet(contp);
+  TxnSM *txn_sm = (TxnSM *)TSContDataGet(contp);
 
   TSDebug("protocol", "enter state_done");
 
@@ -887,14 +881,14 @@ send_response_to_client(TSCont contp)
 
   TSDebug("protocol", "enter send_response_to_client");
 
-  txn_sm = (TxnSM *) TSContDataGet(contp);
+  txn_sm = (TxnSM *)TSContDataGet(contp);
   response_len = TSIOBufferReaderAvail(txn_sm->q_client_response_buffer_reader);
 
   TSDebug("protocol", " . resp_len is %d", response_len);
 
   set_handler(txn_sm->q_current_handler, (TxnSMHandler)&state_interface_with_client);
-  txn_sm->q_client_write_vio = TSVConnWrite(txn_sm->q_client_vc, (TSCont) contp,
-                                             txn_sm->q_client_response_buffer_reader, response_len);
+  txn_sm->q_client_write_vio =
+    TSVConnWrite(txn_sm->q_client_vc, (TSCont)contp, txn_sm->q_client_response_buffer_reader, response_len);
   return TS_SUCCESS;
 }
 
@@ -914,7 +908,7 @@ get_info_from_buffer(TSIOBufferReader the_reader)
 
   read_avail = TSIOBufferReaderAvail(the_reader);
 
-  info = (char *) TSmalloc(sizeof(char) * read_avail);
+  info = (char *)TSmalloc(sizeof(char) * read_avail);
   if (info == NULL)
     return NULL;
   info_start = info;
@@ -922,7 +916,7 @@ get_info_from_buffer(TSIOBufferReader the_reader)
   /* Read the data out of the reader */
   while (read_avail > 0) {
     blk = TSIOBufferReaderStart(the_reader);
-    buf = (char *) TSIOBufferBlockReadStart(blk, the_reader, &read_done);
+    buf = (char *)TSIOBufferBlockReadStart(blk, the_reader, &read_done);
     memcpy(info, buf, read_done);
     if (read_done > 0) {
       TSIOBufferReaderConsume(the_reader, read_done);
@@ -948,13 +942,15 @@ is_request_end(char *buf)
 int
 parse_request(char *request, char *server_name, char *file_name)
 {
-  char *temp = strtok(request, " ");
+  char *saveptr = NULL;
+  char *temp = strtok_r(request, " ", &saveptr);
+
   if (temp != NULL)
     TSstrlcpy(server_name, temp, MAX_SERVER_NAME_LENGTH + 1);
   else
     return 0;
 
-  temp = strtok(NULL, " ");
+  temp = strtok_r(NULL, " ", &saveptr);
   if (temp != NULL)
     TSstrlcpy(file_name, temp, MAX_FILE_NAME_LENGTH + 1);
   else
