@@ -28,7 +28,7 @@
 
 
  ****************************************************************************/
-#if !defined (_I_AIO_h_)
+#if !defined(_I_AIO_h_)
 #define _I_AIO_h_
 
 #include "libts.h"
@@ -37,25 +37,21 @@
 
 #define AIO_MODULE_MAJOR_VERSION 1
 #define AIO_MODULE_MINOR_VERSION 0
-#define AIO_MODULE_VERSION       makeModuleVersion(AIO_MODULE_MAJOR_VERSION,\
-						   AIO_MODULE_MINOR_VERSION,\
-						   PUBLIC_MODULE_HEADER)
+#define AIO_MODULE_VERSION makeModuleVersion(AIO_MODULE_MAJOR_VERSION, AIO_MODULE_MINOR_VERSION, PUBLIC_MODULE_HEADER)
 
-#define AIO_EVENT_DONE           (AIO_EVENT_EVENTS_START+0)
+#define AIO_EVENT_DONE (AIO_EVENT_EVENTS_START + 0)
 
-#define AIO_MODE_AIO             0
-#define AIO_MODE_SYNC            1
-#define AIO_MODE_THREAD          2
-#define AIO_MODE_NATIVE          3
+#define AIO_MODE_THREAD 0
+#define AIO_MODE_NATIVE 1
 
 #if TS_USE_LINUX_NATIVE_AIO
-#define AIO_MODE                 AIO_MODE_NATIVE
+#define AIO_MODE AIO_MODE_NATIVE
 #else
-#define AIO_MODE                 AIO_MODE_THREAD
+#define AIO_MODE AIO_MODE_THREAD
 #endif
 
-#define LIO_READ        0x1
-#define LIO_WRITE       0x2
+#define LIO_READ 0x1
+#define LIO_WRITE 0x2
 
 #if AIO_MODE == AIO_MODE_NATIVE
 
@@ -67,23 +63,22 @@ typedef struct iocb ink_aiocb_t;
 typedef struct io_event ink_io_event_t;
 
 // XXX hokey old-school compatibility with ink_aiocb.h ...
-#define aio_nbytes  u.c.nbytes
-#define aio_offset  u.c.offset
-#define aio_buf     u.c.buf
+#define aio_nbytes u.c.nbytes
+#define aio_offset u.c.offset
+#define aio_buf u.c.buf
 
 #else
 
-typedef struct ink_aiocb
-{
+typedef struct ink_aiocb {
   int aio_fildes;
-  volatile void *aio_buf;       /* buffer location */
-  size_t aio_nbytes;            /* length of transfer */
-  off_t aio_offset;             /* file offset */
+  volatile void *aio_buf; /* buffer location */
+  size_t aio_nbytes;      /* length of transfer */
+  off_t aio_offset;       /* file offset */
 
-  int aio_reqprio;              /* request priority offset */
-  int aio_lio_opcode;           /* listio operation */
-  int aio_state;                /* state flag for List I/O */
-  int aio__pad[1];              /* extension padding */
+  int aio_reqprio;    /* request priority offset */
+  int aio_lio_opcode; /* listio operation */
+  int aio_state;      /* state flag for List I/O */
+  int aio__pad[1];    /* extension padding */
 } ink_aiocb_t;
 
 bool ink_aio_thread_num_set(int thread_num);
@@ -91,14 +86,13 @@ bool ink_aio_thread_num_set(int thread_num);
 #endif
 
 // AIOCallback::thread special values
-#define AIO_CALLBACK_THREAD_ANY ((EThread*)0) // any regular event thread
-#define AIO_CALLBACK_THREAD_AIO ((EThread*)-1)
+#define AIO_CALLBACK_THREAD_ANY ((EThread *)0) // any regular event thread
+#define AIO_CALLBACK_THREAD_AIO ((EThread *)-1)
 
-#define AIO_LOWEST_PRIORITY      0
-#define AIO_DEFAULT_PRIORITY     AIO_LOWEST_PRIORITY
+#define AIO_LOWEST_PRIORITY 0
+#define AIO_DEFAULT_PRIORITY AIO_LOWEST_PRIORITY
 
-struct AIOCallback: public Continuation
-{
+struct AIOCallback : public Continuation {
   // set before calling aio_read/aio_write
   ink_aiocb_t aiocb;
   Action action;
@@ -108,21 +102,18 @@ struct AIOCallback: public Continuation
   int64_t aio_result;
 
   int ok();
-  AIOCallback() : thread(AIO_CALLBACK_THREAD_ANY), then(0) {
-    aiocb.aio_reqprio = AIO_DEFAULT_PRIORITY;
-  }
+  AIOCallback() : thread(AIO_CALLBACK_THREAD_ANY), then(0) { aiocb.aio_reqprio = AIO_DEFAULT_PRIORITY; }
 };
 
 #if AIO_MODE == AIO_MODE_NATIVE
 
-struct AIOVec: public Continuation
-{
+struct AIOVec : public Continuation {
   Action action;
   int size;
   int completed;
   AIOCallback *first;
 
-  AIOVec(int sz, AIOCallback *c): Continuation(new_ProxyMutex()), size(sz), completed(0), first(c)
+  AIOVec(int sz, AIOCallback *c) : Continuation(new_ProxyMutex()), size(sz), completed(0), first(c)
   {
     action = c->action;
     SET_HANDLER(&AIOVec::mainEvent);
@@ -131,8 +122,7 @@ struct AIOVec: public Continuation
   int mainEvent(int event, Event *e);
 };
 
-struct DiskHandler: public Continuation
-{
+struct DiskHandler : public Continuation {
   Event *trigger_event;
   io_context_t ctx;
   ink_io_event_t events[MAX_AIO_EVENTS];
@@ -140,12 +130,13 @@ struct DiskHandler: public Continuation
   Que(AIOCallback, link) complete_list;
   int startAIOEvent(int event, Event *e);
   int mainAIOEvent(int event, Event *e);
-  DiskHandler() {
+  DiskHandler()
+  {
     SET_HANDLER(&DiskHandler::startAIOEvent);
     memset(&ctx, 0, sizeof(ctx));
     int ret = io_setup(MAX_AIO_EVENTS, &ctx);
     if (ret < 0) {
-      perror("io_setup error");
+      Debug("aio", "io_setup error: %s (%d)", strerror(-ret), -ret);
     }
   }
 };
@@ -153,11 +144,13 @@ struct DiskHandler: public Continuation
 
 void ink_aio_init(ModuleVersion version);
 int ink_aio_start();
-void ink_aio_set_callback(Continuation * error_callback);
+void ink_aio_set_callback(Continuation *error_callback);
 
-int ink_aio_read(AIOCallback *op, int fromAPI = 0);   // fromAPI is a boolean to indicate if this is from a API call such as upload proxy feature
+int ink_aio_read(AIOCallback *op,
+                 int fromAPI = 0); // fromAPI is a boolean to indicate if this is from a API call such as upload proxy feature
 int ink_aio_write(AIOCallback *op, int fromAPI = 0);
-int ink_aio_readv(AIOCallback *op, int fromAPI = 0);   // fromAPI is a boolean to indicate if this is from a API call such as upload proxy feature
+int ink_aio_readv(AIOCallback *op,
+                  int fromAPI = 0); // fromAPI is a boolean to indicate if this is from a API call such as upload proxy feature
 int ink_aio_writev(AIOCallback *op, int fromAPI = 0);
 AIOCallback *new_AIOCallback(void);
 #endif
