@@ -26,31 +26,21 @@
 
 extern int gndisks;
 
-matcher_tags CacheHosting_tags = {
-  "hostname", "domain"
-};
-
-
-bool alarmAlready = false;
+matcher_tags CacheHosting_tags = {"hostname", "domain"};
 
 /*************************************************************
  *   Begin class HostMatcher
  *************************************************************/
 
-CacheHostMatcher::CacheHostMatcher(const char * name, CacheType typ):
-data_array(NULL),
-array_len(-1),
-num_el(-1),
-type(typ)
+CacheHostMatcher::CacheHostMatcher(const char *name, CacheType typ) : data_array(NULL), array_len(-1), num_el(-1), type(typ)
 {
   host_lookup = new HostLookup(name);
 }
 
 CacheHostMatcher::~CacheHostMatcher()
 {
-
   delete host_lookup;
-  delete[]data_array;
+  delete[] data_array;
 }
 
 //
@@ -62,7 +52,6 @@ CacheHostMatcher::~CacheHostMatcher()
 void
 CacheHostMatcher::Print()
 {
-
   printf("\tHost/Domain Matcher with %d elements\n", num_el);
   host_lookup->Print(PrintFunc);
 }
@@ -76,7 +65,7 @@ CacheHostMatcher::Print()
 void
 CacheHostMatcher::PrintFunc(void *opaque_data)
 {
-  CacheHostRecord *d = (CacheHostRecord *) opaque_data;
+  CacheHostRecord *d = (CacheHostRecord *)opaque_data;
   d->Print();
 }
 
@@ -104,9 +93,8 @@ CacheHostMatcher::AllocateSpace(int num_entries)
 //    arg hostname
 //
 void
-CacheHostMatcher::Match(char *rdata, int rlen, CacheHostResult * result)
+CacheHostMatcher::Match(char const *rdata, int rlen, CacheHostResult *result)
 {
-
   void *opaque_ptr;
   CacheHostRecord *data_ptr;
   bool r;
@@ -128,7 +116,7 @@ CacheHostMatcher::Match(char *rdata, int rlen, CacheHostResult * result)
 
   while (r == true) {
     ink_assert(opaque_ptr != NULL);
-    data_ptr = (CacheHostRecord *) opaque_ptr;
+    data_ptr = (CacheHostRecord *)opaque_ptr;
     data_ptr->UpdateMatch(result, data);
 
     r = host_lookup->MatchNext(&s, &opaque_ptr);
@@ -144,9 +132,8 @@ CacheHostMatcher::Match(char *rdata, int rlen, CacheHostResult * result)
 //
 
 void
-CacheHostMatcher::NewEntry(matcher_line * line_info)
+CacheHostMatcher::NewEntry(matcher_line *line_info)
 {
-
   CacheHostRecord *cur_d;
   int errNo;
   char *match_data;
@@ -190,16 +177,17 @@ CacheHostMatcher::NewEntry(matcher_line * line_info)
  *   End class HostMatcher
  *************************************************************/
 
-CacheHostTable::CacheHostTable(Cache * c, CacheType typ)
+CacheHostTable::CacheHostTable(Cache *c, CacheType typ)
 {
-  xptr<char> config_path;
+  ats_scoped_str config_path;
 
   config_tags = &CacheHosting_tags;
   ink_assert(config_tags != NULL);
 
   type = typ;
   cache = c;
-  matcher_name = "[CacheHosting]";;
+  matcher_name = "[CacheHosting]";
+  ;
   hostMatch = NULL;
 
   config_path = RecConfigReadConfigPath("proxy.config.cache.hosting_filename");
@@ -210,7 +198,6 @@ CacheHostTable::CacheHostTable(Cache * c, CacheType typ)
 
 CacheHostTable::~CacheHostTable()
 {
-
   if (hostMatch != NULL) {
     delete hostMatch;
   }
@@ -236,9 +223,8 @@ CacheHostTable::Print()
 //   Queries each table for the Result*
 //
 void
-CacheHostTable::Match(char *rdata, int rlen, CacheHostResult * result)
+CacheHostTable::Match(char const *rdata, int rlen, CacheHostResult *result)
 {
-
   hostMatch->Match(rdata, rlen, result);
 }
 
@@ -246,7 +232,7 @@ int
 CacheHostTable::config_callback(const char * /* name ATS_UNUSED */, RecDataT /* data_type ATS_UNUSED */,
                                 RecData /* data ATS_UNUSED */, void *cookie)
 {
-  CacheHostTable **ppt = (CacheHostTable **) cookie;
+  CacheHostTable **ppt = (CacheHostTable **)cookie;
   eventProcessor.schedule_imm(new CacheHostTableConfig(ppt));
   return 0;
 }
@@ -259,7 +245,7 @@ int fstat_wrapper(int fd, struct stat *s);
 //      from it
 //
 int
-CacheHostTable::BuildTableFromString(const char * config_file_path, char *file_buf)
+CacheHostTable::BuildTableFromString(const char *config_file_path, char *file_buf)
 {
   // Table build locals
   Tokenizer bufTok("\n");
@@ -271,7 +257,6 @@ CacheHostTable::BuildTableFromString(const char * config_file_path, char *file_b
   int line_num = 0;
   int second_pass = 0;
   int numEntries = 0;
-  char errBuf[1024];
   const char *errPtr = NULL;
 
   // type counts
@@ -288,7 +273,6 @@ CacheHostTable::BuildTableFromString(const char * config_file_path, char *file_b
   // First get the number of entries
   tmp = bufTok.iterFirst(&i_state);
   while (tmp != NULL) {
-
     line_num++;
 
     // skip all blank spaces at beginning of line
@@ -297,17 +281,14 @@ CacheHostTable::BuildTableFromString(const char * config_file_path, char *file_b
     }
 
     if (*tmp != '#' && *tmp != '\0') {
-
       current = (matcher_line *)ats_malloc(sizeof(matcher_line));
-      errPtr = parseConfigLine((char *) tmp, current, config_tags);
+      errPtr = parseConfigLine((char *)tmp, current, config_tags);
 
       if (errPtr != NULL) {
-        snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry at line %d : %s",
-                 matcher_name, config_file_path, line_num, errPtr);
-        REC_SignalError(errBuf, alarmAlready);
+        RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "%s discarding %s entry at line %d : %s", matcher_name, config_file_path,
+                         line_num, errPtr);
         ats_free(current);
       } else {
-
         // Line parsed ok.  Figure out what the destination
         //  type is and link it into our list
         numEntries++;
@@ -360,7 +341,6 @@ CacheHostTable::BuildTableFromString(const char * config_file_path, char *file_b
   while (current != NULL) {
     second_pass++;
     if ((current->type == MATCH_DOMAIN) || (current->type == MATCH_HOST)) {
-
       char *match_data = current->line[1][current->dest_entry];
       ink_assert(match_data != NULL);
 
@@ -385,9 +365,8 @@ CacheHostTable::BuildTableFromString(const char * config_file_path, char *file_b
         hostMatch->NewEntry(current);
       }
     } else {
-      snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry with unknown type at line %d",
-               matcher_name, config_file_path, current->line_num);
-      REC_SignalError(errBuf, alarmAlready);
+      RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "%s discarding %s entry with unknown type at line %d", matcher_name,
+                       config_file_path, current->line_num);
     }
 
     // Deallocate the parsing structure
@@ -398,10 +377,9 @@ CacheHostTable::BuildTableFromString(const char * config_file_path, char *file_b
 
   if (!generic_rec_initd) {
     const char *cache_type = (type == CACHE_HTTP_TYPE) ? "http" : "mixt";
-    snprintf(errBuf, sizeof(errBuf),
-             "No Volumes specified for Generic Hostnames for %s documents: %s cache will be disabled", cache_type,
-             cache_type);
-    REC_SignalError(errBuf, alarmAlready);
+    RecSignalWarning(REC_SIGNAL_CONFIG_ERROR,
+                     "No Volumes specified for Generic Hostnames for %s documents: %s cache will be disabled", cache_type,
+                     cache_type);
   }
 
   ink_assert(second_pass == numEntries);
@@ -413,7 +391,7 @@ CacheHostTable::BuildTableFromString(const char * config_file_path, char *file_b
 }
 
 int
-CacheHostTable::BuildTable(const char * config_file_path)
+CacheHostTable::BuildTable(const char *config_file_path)
 {
   char *file_buf;
   int ret;
@@ -434,13 +412,10 @@ CacheHostTable::BuildTable(const char * config_file_path)
 int
 CacheHostRecord::Init(CacheType typ)
 {
-
   int i, j;
   extern Queue<CacheVol> cp_list;
   extern int cp_list_len;
-  char err[1024];
 
-  err[0] = 0;
   num_vols = 0;
   type = typ;
   cp = (CacheVol **)ats_malloc(cp_list_len * sizeof(CacheVol *));
@@ -456,8 +431,7 @@ CacheHostRecord::Init(CacheType typ)
     }
   }
   if (!num_cachevols) {
-    snprintf(err, 1024, "error: No volumes found for Cache Type %d\n", type);
-    REC_SignalError(err, alarmAlready);
+    RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "error: No volumes found for Cache Type %d", type);
     return -1;
   }
   vols = (Vol **)ats_malloc(num_vols * sizeof(Vol *));
@@ -475,12 +449,10 @@ CacheHostRecord::Init(CacheType typ)
 }
 
 int
-CacheHostRecord::Init(matcher_line * line_info, CacheType typ)
+CacheHostRecord::Init(matcher_line *line_info, CacheType typ)
 {
   int i, j;
   extern Queue<CacheVol> cp_list;
-  char err[1024];
-  err[0] = 0;
   int is_vol_present = 0;
   char config_file[PATH_NAME_MAX];
 
@@ -507,21 +479,17 @@ CacheHostRecord::Init(matcher_line * line_info, CacheType typ)
           s++;
           if (!(*s)) {
             const char *errptr = "A volume number expected";
-            snprintf(err, 1024,
-                         "%s discarding %s entry at line %d :%s",
-                         "[CacheHosting]", config_file, line_info->line_num, errptr);
-            REC_SignalError(err, alarmAlready);
+            RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "%s discarding %s entry at line %d :%s", "[CacheHosting]", config_file,
+                             line_info->line_num, errptr);
             if (val != NULL) {
               ats_free(val);
             }
             return -1;
           }
         }
-        if ((*s<'0') || (*s> '9')) {
-          snprintf(err, 1024,
-                       "%s discarding %s entry at line %d : bad token [%c]",
-                       "[CacheHosting]", config_file, line_info->line_num, *s);
-          REC_SignalError(err, alarmAlready);
+        if ((*s < '0') || (*s > '9')) {
+          RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "%s discarding %s entry at line %d : bad token [%c]", "[CacheHosting]",
+                           config_file, line_info->line_num, *s);
           if (val != NULL) {
             ats_free(val);
           }
@@ -545,9 +513,8 @@ CacheHostRecord::Init(matcher_line * line_info, CacheType typ)
             if (cachep->vol_number == volume_number) {
               is_vol_present = 1;
               if (cachep->scheme == type) {
-                Debug("cache_hosting",
-                      "Host Record: %p, Volume: %d, size: %ld",
-                      this, volume_number, (long)(cachep->size * STORE_BLOCK_SIZE));
+                Debug("cache_hosting", "Host Record: %p, Volume: %d, size: %ld", this, volume_number,
+                      (long)(cachep->size * STORE_BLOCK_SIZE));
                 cp[num_cachevols] = cachep;
                 num_cachevols++;
                 num_vols += cachep->num_vols;
@@ -556,10 +523,8 @@ CacheHostRecord::Init(matcher_line * line_info, CacheType typ)
             }
           }
           if (!is_vol_present) {
-            snprintf(err, 1024,
-                         "%s discarding %s entry at line %d : bad volume number [%d]",
-                         "[CacheHosting]", config_file, line_info->line_num, volume_number);
-            REC_SignalError(err, alarmAlready);
+            RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "%s discarding %s entry at line %d : bad volume number [%d]",
+                             "[CacheHosting]", config_file, line_info->line_num, volume_number);
             if (val != NULL) {
               ats_free(val);
             }
@@ -577,18 +542,14 @@ CacheHostRecord::Init(matcher_line * line_info, CacheType typ)
       break;
     }
 
-    snprintf(err, 1024,
-                 "%s discarding %s entry at line %d : bad token [%s]",
-                 "[CacheHosting]", config_file, line_info->line_num, label);
-    REC_SignalError(err, alarmAlready);
+    RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "%s discarding %s entry at line %d : bad token [%s]", "[CacheHosting]", config_file,
+                     line_info->line_num, label);
     return -1;
   }
 
   if (i == MATCHER_MAX_TOKENS) {
-    snprintf(err, 1024,
-                 "%s discarding %s entry at line %d : No volumes specified",
-                 "[CacheHosting]", config_file, line_info->line_num);
-    REC_SignalError(err, alarmAlready);
+    RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "%s discarding %s entry at line %d : No volumes specified", "[CacheHosting]",
+                     config_file, line_info->line_num);
     return -1;
   }
 
@@ -610,7 +571,7 @@ CacheHostRecord::Init(matcher_line * line_info, CacheType typ)
 }
 
 void
-CacheHostRecord::UpdateMatch(CacheHostResult * r, char * /* rd ATS_UNUSED */)
+CacheHostRecord::UpdateMatch(CacheHostResult *r, char * /* rd ATS_UNUSED */)
 {
   r->record = this;
 }
@@ -621,11 +582,10 @@ CacheHostRecord::Print()
 }
 
 
-
 void
 ConfigVolumes::read_config_file()
 {
-  xptr<char> config_path;
+  ats_scoped_str config_path;
   char *file_buf;
 
   config_path = RecConfigReadConfigPath("proxy.config.cache.volume_filename");
@@ -645,27 +605,24 @@ ConfigVolumes::read_config_file()
 void
 ConfigVolumes::BuildListFromString(char *config_file_path, char *file_buf)
 {
-
 #define PAIR_ZERO 0
 #define PAIR_ONE 1
 #define PAIR_TWO 2
 #define DONE 3
 #define INK_ERROR -1
 
-#define INK_ERROR_VOLUME -2  //added by YTS Team, yamsat for bug id 59632
-// Table build locals
+#define INK_ERROR_VOLUME -2 // added by YTS Team, yamsat for bug id 59632
+  // Table build locals
   Tokenizer bufTok("\n");
   tok_iter_state i_state;
   const char *tmp;
   char *end;
   char *line_end = NULL;
   int line_num = 0;
-  int total = 0;                //added by YTS Team, yamsat for bug id 59632
-  char errBuf[1024];
+  int total = 0; // added by YTS Team, yamsat for bug id 59632
 
   char volume_seen[256];
-  int state = 0;                //changed by YTS Team, yamsat for bug id 59632
-  int manager_alarmed = false;
+  int state = 0; // changed by YTS Team, yamsat for bug id 59632
   int volume_number = 0;
   CacheType scheme = CACHE_NONE_TYPE;
   int size = 0;
@@ -714,8 +671,7 @@ ConfigVolumes::BuildListFromString(char *config_file_path, char *file_buf)
           num_http_volumes++;
         else
           num_stream_volumes++;
-        Debug("cache_hosting",
-              "added volume=%d, scheme=%d, size=%d percent=%d\n", volume_number, scheme, size, in_percent);
+        Debug("cache_hosting", "added volume=%d, scheme=%d, size=%d percent=%d\n", volume_number, scheme, size, in_percent);
         break;
       }
 
@@ -724,15 +680,13 @@ ConfigVolumes::BuildListFromString(char *config_file_path, char *file_buf)
           break;
       } else {
         if (!(*tmp)) {
-          snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry at line %d : Unexpected end of line",
-                   matcher_name, config_file_path, line_num);
-          REC_SignalError(errBuf, manager_alarmed);
-
+          RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "%s discarding %s entry at line %d : Unexpected end of line", matcher_name,
+                           config_file_path, line_num);
           break;
         }
       }
 
-      end = (char *) tmp;
+      end = (char *)tmp;
       while (*end && !isspace(*end))
         end++;
 
@@ -744,7 +698,7 @@ ConfigVolumes::BuildListFromString(char *config_file_path, char *file_buf)
       }
       char *eq_sign;
 
-      eq_sign = (char *) strchr(tmp, '=');
+      eq_sign = (char *)strchr(tmp, '=');
       if (!eq_sign) {
         state = INK_ERROR;
       } else
@@ -756,21 +710,20 @@ ConfigVolumes::BuildListFromString(char *config_file_path, char *file_buf)
           state = INK_ERROR;
           break;
         }
-        tmp += 7;              //size of string volume including null
+        tmp += 7; // size of string volume including null
         volume_number = atoi(tmp);
 
-        if (volume_number<1 || volume_number> 255 || volume_seen[volume_number]) {
+        if (volume_number < 1 || volume_number > 255 || volume_seen[volume_number]) {
           const char *err;
 
-          if (volume_number<1 || volume_number> 255) {
+          if (volume_number < 1 || volume_number > 255) {
             err = "Bad Volume Number";
           } else {
             err = "Volume Already Specified";
           }
 
-          snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry at line %d : %s [%d]",
-                   matcher_name, config_file_path, line_num, err, volume_number);
-          REC_SignalError(errBuf, manager_alarmed);
+          RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "%s discarding %s entry at line %d : %s [%d]", matcher_name, config_file_path,
+                           line_num, err, volume_number);
           state = INK_ERROR;
           break;
         }
@@ -786,7 +739,7 @@ ConfigVolumes::BuildListFromString(char *config_file_path, char *file_buf)
           state = INK_ERROR;
           break;
         }
-        tmp += 7;               //size of string scheme including null
+        tmp += 7; // size of string scheme including null
 
         if (!strcasecmp(tmp, "http")) {
           tmp += 4;
@@ -815,38 +768,30 @@ ConfigVolumes::BuildListFromString(char *config_file_path, char *file_buf)
           tmp++;
 
         if (*tmp == '%') {
-          //added by YTS Team, yamsat for bug id 59632
+          // added by YTS Team, yamsat for bug id 59632
           total += size;
           if (size > 100 || total > 100) {
             state = INK_ERROR_VOLUME;
-            if (state == INK_ERROR_VOLUME || *tmp) {
-              snprintf(errBuf, sizeof(errBuf),
-                       "Total volume size added upto more than 100 percent,No volumes created");
-              REC_SignalError(errBuf, manager_alarmed);
-              break;
-            }
+            RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "Total volume size added upto more than 100 percent, No volumes created");
+            break;
           }
-          //ends here
+          // ends here
           in_percent = 1;
           tmp++;
         } else
           in_percent = 0;
         state = DONE;
         break;
-
       }
 
       if (state == INK_ERROR || *tmp) {
-        snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry at line %d : Invalid token [%s]",
-                 matcher_name, config_file_path, line_num, tmp);
-        REC_SignalError(errBuf, manager_alarmed);
-
+        RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "%s discarding %s entry at line %d : Invalid token [%s]", matcher_name,
+                         config_file_path, line_num, tmp);
         break;
       }
-      //added by YTS Team, yamsat for bug id 59632
+      // added by YTS Team, yamsat for bug id 59632
       if (state == INK_ERROR_VOLUME || *tmp) {
-        snprintf(errBuf, sizeof(errBuf), "Total volume size added upto more than 100 percent,No volumes created");
-        REC_SignalError(errBuf, manager_alarmed);
+        RecSignalWarning(REC_SIGNAL_CONFIG_ERROR, "Total volume size added upto more than 100 percent,No volumes created");
         break;
       }
       // ends here
@@ -860,10 +805,9 @@ ConfigVolumes::BuildListFromString(char *config_file_path, char *file_buf)
 }
 
 
-
 /* Test the cache volumeing with different configurations */
 #define MEGS_128 (128 * 1024 * 1024)
-#define ROUND_TO_VOL_SIZE(_x) (((_x) + (MEGS_128 - 1)) &~ (MEGS_128 - 1))
+#define ROUND_TO_VOL_SIZE(_x) (((_x) + (MEGS_128 - 1)) & ~(MEGS_128 - 1))
 extern CacheDisk **gdisks;
 extern Queue<CacheVol> cp_list;
 extern int cp_list_len;
@@ -879,14 +823,15 @@ int saved_cp_list_len;
 ConfigVolumes saved_config_volumes;
 int saved_gnvol;
 
-int ClearConfigVol(ConfigVolumes * configp);
+int ClearConfigVol(ConfigVolumes *configp);
 int ClearCacheVolList(Queue<CacheVol> *cpl, int len);
-int create_config(RegressionTest * t, int i);
-int execute_and_verify(RegressionTest * t);
+int create_config(RegressionTest *t, int i);
+int execute_and_verify(RegressionTest *t);
 void save_state();
 void restore_state();
 
-EXCLUSIVE_REGRESSION_TEST(Cache_vol) (RegressionTest * t, int /* atype ATS_UNUSED */, int *status) {
+EXCLUSIVE_REGRESSION_TEST(Cache_vol)(RegressionTest *t, int /* atype ATS_UNUSED */, int *status)
+{
   save_state();
   srand48(time(NULL));
   *status = REGRESSION_TEST_PASSED;
@@ -902,7 +847,7 @@ EXCLUSIVE_REGRESSION_TEST(Cache_vol) (RegressionTest * t, int /* atype ATS_UNUSE
 }
 
 int
-create_config(RegressionTest * t, int num)
+create_config(RegressionTest *t, int num)
 {
   int i = 0;
   int vol_num = 1;
@@ -931,117 +876,110 @@ create_config(RegressionTest * t, int num)
         config_volumes.num_volumes++;
         config_volumes.num_http_volumes++;
       }
-
     }
     rprintf(t, "%d 128 Megabyte Volumes\n", vol_num - 1);
     break;
 
-  case 1:
-    {
-      for (i = 0; i < gndisks; i++) {
-        gdisks[i]->delete_all_volumes();
-      }
-
-      // calculate the total free space
-      off_t total_space = 0;
-      for (i = 0; i < gndisks; i++) {
-        off_t vol_blocks = gdisks[i]->num_usable_blocks;
-        /* round down the blocks to the nearest
-           multiple of STORE_BLOCKS_PER_VOL */
-        vol_blocks = (vol_blocks / STORE_BLOCKS_PER_VOL)
-          * STORE_BLOCKS_PER_VOL;
-        total_space += vol_blocks;
-      }
-
-      // make sure we have atleast 1280 M bytes
-      if (total_space<(10 << 27)>> STORE_BLOCK_SHIFT) {
-        rprintf(t, "Not enough space for 10 volume\n");
-        return 0;
-      }
-
-      vol_num = 1;
-      rprintf(t, "Cleared  disk\n");
-      for (i = 0; i < 10; i++) {
-        ConfigVol *cp = new ConfigVol();
-        cp->number = vol_num++;
-        cp->scheme = CACHE_HTTP_TYPE;
-        cp->size = 10;
-        cp->percent = 10;
-        cp->in_percent = 1;
-        cp->cachep = 0;
-        config_volumes.cp_queue.enqueue(cp);
-        config_volumes.num_volumes++;
-        config_volumes.num_http_volumes++;
-      }
-      rprintf(t, "10 volume, 10 percent each\n");
+  case 1: {
+    for (i = 0; i < gndisks; i++) {
+      gdisks[i]->delete_all_volumes();
     }
-    break;
+
+    // calculate the total free space
+    off_t total_space = 0;
+    for (i = 0; i < gndisks; i++) {
+      off_t vol_blocks = gdisks[i]->num_usable_blocks;
+      /* round down the blocks to the nearest
+         multiple of STORE_BLOCKS_PER_VOL */
+      vol_blocks = (vol_blocks / STORE_BLOCKS_PER_VOL) * STORE_BLOCKS_PER_VOL;
+      total_space += vol_blocks;
+    }
+
+    // make sure we have atleast 1280 M bytes
+    if (total_space<(10 << 27)>> STORE_BLOCK_SHIFT) {
+      rprintf(t, "Not enough space for 10 volume\n");
+      return 0;
+    }
+
+    vol_num = 1;
+    rprintf(t, "Cleared  disk\n");
+    for (i = 0; i < 10; i++) {
+      ConfigVol *cp = new ConfigVol();
+      cp->number = vol_num++;
+      cp->scheme = CACHE_HTTP_TYPE;
+      cp->size = 10;
+      cp->percent = 10;
+      cp->in_percent = 1;
+      cp->cachep = 0;
+      config_volumes.cp_queue.enqueue(cp);
+      config_volumes.num_volumes++;
+      config_volumes.num_http_volumes++;
+    }
+    rprintf(t, "10 volume, 10 percent each\n");
+  } break;
 
   case 2:
   case 3:
 
-    {
-      /* calculate the total disk space */
-      InkRand *gen = &this_ethread()->generator;
-      off_t total_space = 0;
-      vol_num = 1;
+  {
+    /* calculate the total disk space */
+    InkRand *gen = &this_ethread()->generator;
+    off_t total_space = 0;
+    vol_num = 1;
+    if (num == 2) {
+      rprintf(t, "Random Volumes after clearing the disks\n");
+    } else {
+      rprintf(t, "Random Volumes without clearing the disks\n");
+    }
+
+    for (i = 0; i < gndisks; i++) {
+      off_t vol_blocks = gdisks[i]->num_usable_blocks;
+      /* round down the blocks to the nearest
+         multiple of STORE_BLOCKS_PER_VOL */
+      vol_blocks = (vol_blocks / STORE_BLOCKS_PER_VOL) * STORE_BLOCKS_PER_VOL;
+      total_space += vol_blocks;
+
       if (num == 2) {
-        rprintf(t, "Random Volumes after clearing the disks\n");
+        gdisks[i]->delete_all_volumes();
       } else {
-        rprintf(t, "Random Volumes without clearing the disks\n");
-      }
-
-      for (i = 0; i < gndisks; i++) {
-        off_t vol_blocks = gdisks[i]->num_usable_blocks;
-        /* round down the blocks to the nearest
-           multiple of STORE_BLOCKS_PER_VOL */
-        vol_blocks = (vol_blocks / STORE_BLOCKS_PER_VOL)
-          * STORE_BLOCKS_PER_VOL;
-        total_space += vol_blocks;
-
-        if (num == 2) {
-          gdisks[i]->delete_all_volumes();
-        } else {
-          gdisks[i]->cleared = 0;
-        }
-      }
-      while (total_space > 0) {
-        if (vol_num > 255)
-          break;
-        off_t modu = MAX_VOL_SIZE;
-        if (total_space<(MAX_VOL_SIZE>> STORE_BLOCK_SHIFT)) {
-          modu = total_space * STORE_BLOCK_SIZE;
-        }
-
-        off_t random_size = (gen->random() % modu) + 1;
-        /* convert to 128 megs multiple */
-        CacheType scheme = (random_size % 2) ? CACHE_HTTP_TYPE : CACHE_RTSP_TYPE;
-        random_size = ROUND_TO_VOL_SIZE(random_size);
-        off_t blocks = random_size / STORE_BLOCK_SIZE;
-        ink_assert(blocks <= (int) total_space);
-        total_space -= blocks;
-
-        ConfigVol *cp = new ConfigVol();
-
-        cp->number = vol_num++;
-        cp->scheme = scheme;
-        cp->size = random_size >> 20;
-        cp->percent = 0;
-        cp->in_percent = 0;
-        cp->cachep = 0;
-        config_volumes.cp_queue.enqueue(cp);
-        config_volumes.num_volumes++;
-        if (cp->scheme == CACHE_HTTP_TYPE) {
-          config_volumes.num_http_volumes++;
-          rprintf(t, "volume=%d scheme=http size=%d\n", cp->number, cp->size);
-        } else {
-          config_volumes.num_stream_volumes++;
-          rprintf(t, "volume=%d scheme=rtsp size=%d\n", cp->number, cp->size);
-
-        }
+        gdisks[i]->cleared = 0;
       }
     }
-    break;
+    while (total_space > 0) {
+      if (vol_num > 255)
+        break;
+      off_t modu = MAX_VOL_SIZE;
+      if (total_space < (MAX_VOL_SIZE >> STORE_BLOCK_SHIFT)) {
+        modu = total_space * STORE_BLOCK_SIZE;
+      }
+
+      off_t random_size = (gen->random() % modu) + 1;
+      /* convert to 128 megs multiple */
+      CacheType scheme = (random_size % 2) ? CACHE_HTTP_TYPE : CACHE_RTSP_TYPE;
+      random_size = ROUND_TO_VOL_SIZE(random_size);
+      off_t blocks = random_size / STORE_BLOCK_SIZE;
+      ink_assert(blocks <= (int)total_space);
+      total_space -= blocks;
+
+      ConfigVol *cp = new ConfigVol();
+
+      cp->number = vol_num++;
+      cp->scheme = scheme;
+      cp->size = random_size >> 20;
+      cp->percent = 0;
+      cp->in_percent = 0;
+      cp->cachep = 0;
+      config_volumes.cp_queue.enqueue(cp);
+      config_volumes.num_volumes++;
+      if (cp->scheme == CACHE_HTTP_TYPE) {
+        config_volumes.num_http_volumes++;
+        rprintf(t, "volume=%d scheme=http size=%d\n", cp->number, cp->size);
+      } else {
+        config_volumes.num_stream_volumes++;
+        rprintf(t, "volume=%d scheme=rtsp size=%d\n", cp->number, cp->size);
+      }
+    }
+  } break;
 
   default:
     return 1;
@@ -1050,7 +988,7 @@ create_config(RegressionTest * t, int num)
 }
 
 int
-execute_and_verify(RegressionTest * t)
+execute_and_verify(RegressionTest *t)
 {
   cplist_init();
   cplist_reconfigure();
@@ -1069,8 +1007,7 @@ execute_and_verify(RegressionTest * t)
     cachep = cp_list.head;
     while (cachep) {
       if (cachep->vol_number == cp->number) {
-        if ((cachep->scheme != cp->scheme) ||
-            (cachep->size != (cp->size << (20 - STORE_BLOCK_SHIFT))) || (cachep != cp->cachep)) {
+        if ((cachep->scheme != cp->scheme) || (cachep->size != (cp->size << (20 - STORE_BLOCK_SHIFT))) || (cachep != cp->cachep)) {
           rprintf(t, "Configuration and Actual volumes don't match\n");
           return REGRESSION_TEST_FAILED;
         }
@@ -1123,16 +1060,13 @@ execute_and_verify(RegressionTest * t)
   for (int i = 0; i < gndisks; i++) {
     CacheDisk *d = gdisks[i];
     if (is_debug_tag_set("cache_hosting")) {
-
-      Debug("cache_hosting", "Disk: %d: Vol Blocks: %u: Free space: %" PRIu64,
-            i, d->header->num_diskvol_blks, d->free_space);
-      for (int j = 0; j < (int) d->header->num_volumes; j++) {
-
+      Debug("cache_hosting", "Disk: %d: Vol Blocks: %u: Free space: %" PRIu64, i, d->header->num_diskvol_blks, d->free_space);
+      for (int j = 0; j < (int)d->header->num_volumes; j++) {
         Debug("cache_hosting", "\tVol: %d Size: %" PRIu64, d->disk_vols[j]->vol_number, d->disk_vols[j]->size);
       }
-      for (int j = 0; j < (int) d->header->num_diskvol_blks; j++) {
-        Debug("cache_hosting", "\tBlock No: %d Size: %" PRIu64" Free: %u",
-              d->header->vol_info[j].number, d->header->vol_info[j].len, d->header->vol_info[j].free);
+      for (int j = 0; j < (int)d->header->num_diskvol_blks; j++) {
+        Debug("cache_hosting", "\tBlock No: %d Size: %" PRIu64 " Free: %u", d->header->vol_info[j].number,
+              d->header->vol_info[j].len, d->header->vol_info[j].free);
       }
     }
   }
@@ -1140,9 +1074,8 @@ execute_and_verify(RegressionTest * t)
 }
 
 int
-ClearConfigVol(ConfigVolumes * configp)
+ClearConfigVol(ConfigVolumes *configp)
 {
-
   int i = 0;
   ConfigVol *cp = NULL;
   while ((cp = configp->cp_queue.dequeue())) {
@@ -1162,13 +1095,12 @@ ClearConfigVol(ConfigVolumes * configp)
 int
 ClearCacheVolList(Queue<CacheVol> *cpl, int len)
 {
-
   int i = 0;
   CacheVol *cp = NULL;
   while ((cp = cpl->dequeue())) {
     ats_free(cp->disk_vols);
     ats_free(cp->vols);
-    delete(cp);
+    delete (cp);
     i++;
   }
 
