@@ -22,14 +22,13 @@
  */
 
 
-
 #include "P_Cache.h"
 
-#define SCAN_BUF_SIZE      RECOVERY_SIZE
+#define SCAN_BUF_SIZE RECOVERY_SIZE
 #define SCAN_WRITER_LOCK_MAX_RETRY 5
 
 Action *
-Cache::scan(Continuation * cont, char *hostname, int host_len, int KB_per_second)
+Cache::scan(Continuation *cont, char *hostname, int host_len, int KB_per_second)
 {
   Debug("cache_scan_truss", "inside scan");
   if (!CacheProcessor::IsCacheReady(CACHE_FRAG_TYPE_HTTP)) {
@@ -93,20 +92,22 @@ Ldone:
  * d - Vol
  * vol_map - precalculated map
  * offset - offset to start looking at (and data at this location has not been read yet). */
-static off_t next_in_map(Vol *d, char *vol_map, off_t offset)
+static off_t
+next_in_map(Vol *d, char *vol_map, off_t offset)
 {
   off_t start_offset = vol_offset_to_offset(d, 0);
   off_t new_off = (offset - start_offset);
   off_t vol_len = vol_relative_length(d, start_offset);
 
-  while (new_off < vol_len && !vol_map[new_off / SCAN_BUF_SIZE]) new_off += SCAN_BUF_SIZE;
-  if (new_off >= vol_len) return vol_len + start_offset;
+  while (new_off < vol_len && !vol_map[new_off / SCAN_BUF_SIZE])
+    new_off += SCAN_BUF_SIZE;
+  if (new_off >= vol_len)
+    return vol_len + start_offset;
   return new_off + start_offset;
 }
 
 // Function in CacheDir.cc that we need for make_vol_map().
-int
-dir_bucket_loop_fix(Dir *start_dir, int s, Vol *d);
+int dir_bucket_loop_fix(Dir *start_dir, int s, Vol *d);
 
 // TODO: If we used a bit vector, we could make a smaller map structure.
 // TODO: If we saved a high water mark we could have a smaller buf, and avoid searching it
@@ -114,7 +115,8 @@ dir_bucket_loop_fix(Dir *start_dir, int s, Vol *d);
 /* Make map of what blocks in partition are used.
  *
  * d - Vol to make a map of. */
-static char *make_vol_map(Vol *d)
+static char *
+make_vol_map(Vol *d)
 {
   // Map will be one byte for each SCAN_BUF_SIZE bytes.
   off_t start_offset = vol_offset_to_offset(d, 0);
@@ -134,9 +136,10 @@ static char *make_vol_map(Vol *d)
         break;
       }
       while (e) {
-        if (dir_offset(e)) {
-            off_t offset = vol_offset(d, e) - start_offset;
-            if (offset <= vol_len) vol_map[offset / SCAN_BUF_SIZE] = 1;
+        if (dir_offset(e) && dir_valid(d, e) && dir_agg_valid(d, e) && dir_head(e)) {
+          off_t offset = vol_offset(d, e) - start_offset;
+          if (offset <= vol_len)
+            vol_map[offset / SCAN_BUF_SIZE] = 1;
         }
         e = next_dir(e, seg);
         if (!e)
@@ -168,18 +171,18 @@ CacheVC::scanObject(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
     return free_CacheVC(this);
 
   CACHE_TRY_LOCK(lock, vol->mutex, mutex->thread_holding);
-  if (!lock) {
+  if (!lock.is_locked()) {
     Debug("cache_scan_truss", "delay %p:scanObject", this);
     mutex->thread_holding->schedule_in_local(this, HRTIME_MSECONDS(cache_config_mutex_retry_delay));
     return EVENT_CONT;
   }
 
-  if (!fragment) {               // initialize for first read
+  if (!fragment) { // initialize for first read
     fragment = 1;
     scan_vol_map = make_vol_map(vol);
     io.aiocb.aio_offset = next_in_map(vol, scan_vol_map, vol_offset_to_offset(vol, 0));
     if (io.aiocb.aio_offset >= (off_t)(vol->skip + vol->len))
-      goto Ldone;
+      goto Lnext_vol;
     io.aiocb.aio_nbytes = SCAN_BUF_SIZE;
     io.aiocb.aio_buf = buf->data();
     io.action = this;
@@ -188,12 +191,12 @@ CacheVC::scanObject(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
     goto Lread;
   }
 
-  if ((size_t)io.aio_result != (size_t) io.aiocb.aio_nbytes) {
-    result = (void *) -ECACHE_READ_FAIL;
+  if ((size_t)io.aio_result != (size_t)io.aiocb.aio_nbytes) {
+    result = (void *)-ECACHE_READ_FAIL;
     goto Ldone;
   }
 
-  doc = (Doc *) (buf->data() + offset);
+  doc = (Doc *)(buf->data() + offset);
   // If there is data in the buffer before the start that is from a partial object read previously
   // Fix things as if we read it this time.
   if (scan_fix_buffer_offset) {
@@ -203,9 +206,9 @@ CacheVC::scanObject(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
     io.aiocb.aio_buf = (char *)io.aiocb.aio_buf - scan_fix_buffer_offset;
     scan_fix_buffer_offset = 0;
   }
-  while ((off_t)((char *) doc - buf->data()) + next_object_len < (off_t)io.aiocb.aio_nbytes) {
+  while ((off_t)((char *)doc - buf->data()) + next_object_len < (off_t)io.aiocb.aio_nbytes) {
     might_need_overlap_read = false;
-    doc = (Doc *) ((char *) doc + next_object_len);
+    doc = (Doc *)((char *)doc + next_object_len);
     next_object_len = vol->round_to_approx_size(doc->len);
 #ifdef HTTP_CACHE
     int i;
@@ -216,8 +219,8 @@ CacheVC::scanObject(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
       Debug("cache_scan_truss", "blockskip %p:scanObject", this);
       continue;
     }
-      
-    if (doc->ftype != CACHE_FRAG_TYPE_HTTP || !doc->hlen)
+
+    if (doc->doc_type != CACHE_FRAG_TYPE_HTTP || !doc->hlen)
       goto Lskip;
 
     last_collision = NULL;
@@ -225,11 +228,11 @@ CacheVC::scanObject(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
       if (!dir_probe(&doc->first_key, vol, &dir, &last_collision))
         goto Lskip;
       if (!dir_agg_valid(vol, &dir) || !dir_head(&dir) ||
-          (vol_offset(vol, &dir) != io.aiocb.aio_offset + ((char *) doc - buf->data())))
+          (vol_offset(vol, &dir) != io.aiocb.aio_offset + ((char *)doc - buf->data())))
         continue;
       break;
     }
-    if (doc->data() - buf->data() > (int) io.aiocb.aio_nbytes) {
+    if (doc->data() - buf->data() > (int)io.aiocb.aio_nbytes) {
       might_need_overlap_read = true;
       goto Lskip;
     }
@@ -246,7 +249,7 @@ CacheVC::scanObject(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
         tmp += r;
       }
     }
-    if (vector.get_handles(doc->hdr(), doc->hlen) != doc->hlen)
+    if (this->load_http_info(&vector, doc) != doc->hlen)
       goto Lskip;
     changed = false;
     hostinfo_copied = 0;
@@ -301,10 +304,10 @@ CacheVC::scanObject(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
         ink_assert(hostinfo_copied);
         SET_HANDLER(&CacheVC::scanRemoveDone);
         // force remove even if there is a writer
-        cacheProcessor.remove(this, &doc->first_key, true, CACHE_FRAG_TYPE_HTTP, true, false, (char *) hname, hlen);
+        cacheProcessor.remove(this, &doc->first_key, true, CACHE_FRAG_TYPE_HTTP, true, false, (char *)hname, hlen);
         return EVENT_CONT;
       } else {
-        offset = (char *) doc - buf->data();
+        offset = (char *)doc - buf->data();
         write_len = 0;
         frag_type = CACHE_FRAG_TYPE_HTTP;
         f.use_first_key = 1;
@@ -318,16 +321,16 @@ CacheVC::scanObject(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
       }
     }
     continue;
-  Lskip:;
+  Lskip:
+    ;
 #endif
   }
 #ifdef HTTP_CACHE
   vector.clear();
 #endif
-    // If we had an object that went past the end of the buffer, and it is small enough to fix,
-    // fix it.
-  if (might_need_overlap_read &&
-      ((off_t)((char *) doc - buf->data()) + next_object_len > (off_t)io.aiocb.aio_nbytes) &&
+  // If we had an object that went past the end of the buffer, and it is small enough to fix,
+  // fix it.
+  if (might_need_overlap_read && ((off_t)((char *)doc - buf->data()) + next_object_len > (off_t)io.aiocb.aio_nbytes) &&
       next_object_len > 0) {
     off_t partial_object_len = io.aiocb.aio_nbytes - ((char *)doc - buf->data());
     // Copy partial object to beginning of the buffer.
@@ -347,6 +350,7 @@ CacheVC::scanObject(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
   }
 
   if (io.aiocb.aio_offset >= vol->skip + vol->len) {
+  Lnext_vol:
     SET_HANDLER(&CacheVC::scanVol);
     eventProcessor.schedule_in(this, HRTIME_MSECONDS(scan_msec_delay));
     return EVENT_CONT;
@@ -358,12 +362,11 @@ Lread:
     io.aiocb.aio_nbytes = vol->skip + vol->len - io.aiocb.aio_offset;
   offset = 0;
   ink_assert(ink_aio_read(&io) >= 0);
-  Debug("cache_scan_truss", "read %p:scanObject %" PRId64 " %zu", this,
-        (int64_t)io.aiocb.aio_offset, (size_t)io.aiocb.aio_nbytes);
+  Debug("cache_scan_truss", "read %p:scanObject %" PRId64 " %zu", this, (int64_t)io.aiocb.aio_offset, (size_t)io.aiocb.aio_nbytes);
   return EVENT_CONT;
 
 Ldone:
-   Debug("cache_scan_truss", "done %p:scanObject", this);
+  Debug("cache_scan_truss", "done %p:scanObject", this);
   _action.continuation->handleEvent(CACHE_EVENT_SCAN_DONE, result);
 #ifdef HTTP_CACHE
 Lcancel:
@@ -404,7 +407,7 @@ CacheVC::scanOpenWrite(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
   int ret = 0;
   {
     CACHE_TRY_LOCK(lock, vol->mutex, mutex->thread_holding);
-    if (!lock) {
+    if (!lock.is_locked()) {
       Debug("cache_scan", "vol->mutex %p:scanOpenWrite", this);
       VC_SCHED_LOCK_RETRY();
     }
@@ -430,15 +433,15 @@ CacheVC::scanOpenWrite(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
     Debug("cache_scan", "got writer lock");
     Dir *l = NULL;
     Dir d;
-    Doc *doc = (Doc *) (buf->data() + offset);
-    offset = (char *) doc - buf->data() + vol->round_to_approx_size(doc->len);
+    Doc *doc = (Doc *)(buf->data() + offset);
+    offset = (char *)doc - buf->data() + vol->round_to_approx_size(doc->len);
     // if the doc contains some data, then we need to create
     // a new directory entry for this fragment. Remember the
     // offset and the key in earliest_key
     dir_assign(&od->first_dir, &dir);
     if (doc->total_len) {
       dir_assign(&od->single_doc_dir, &dir);
-      dir_set_tag(&od->single_doc_dir, doc->key.word(2));
+      dir_set_tag(&od->single_doc_dir, doc->key.slice32(2));
       od->single_doc_key = doc->key;
       od->move_resident_alt = 1;
     }
@@ -477,7 +480,7 @@ CacheVC::scanUpdateDone(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
   cancel_trigger();
   // get volume lock
   CACHE_TRY_LOCK(lock, vol->mutex, mutex->thread_holding);
-  if (lock) {
+  if (lock.is_locked()) {
     // insert a directory entry for the previous fragment
     dir_overwrite(&first_key, vol, &dir, &od->first_dir, false);
     if (od->move_resident_alt) {
@@ -493,4 +496,3 @@ CacheVC::scanUpdateDone(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
     return EVENT_CONT;
   }
 }
-
