@@ -25,7 +25,7 @@
 #define __P_CACHE_HOSTING_H__
 #include "P_Cache.h"
 
-#define CACHE_MEM_FREE_TIMEOUT     HRTIME_SECONDS(1)
+#define CACHE_MEM_FREE_TIMEOUT HRTIME_SECONDS(1)
 
 struct Vol;
 struct CacheVol;
@@ -33,8 +33,7 @@ struct CacheVol;
 struct CacheHostResult;
 struct Cache;
 
-struct CacheHostRecord
-{
+struct CacheHostRecord {
   int Init(CacheType typ);
   int Init(matcher_line *line_info, CacheType typ);
   void UpdateMatch(CacheHostResult *r, char *rd);
@@ -55,46 +54,55 @@ struct CacheHostRecord
   CacheVol **cp;
   int num_cachevols;
 
-  CacheHostRecord():
-    type(CACHE_NONE_TYPE), vols(NULL), good_num_vols(0), num_vols(0),
-    num_initialized(0), vol_hash_table(0), cp(NULL), num_cachevols(0)
-  { }
-
+  CacheHostRecord()
+    : type(CACHE_NONE_TYPE), vols(NULL), good_num_vols(0), num_vols(0), num_initialized(0), vol_hash_table(0), cp(NULL),
+      num_cachevols(0)
+  {
+  }
 };
 
 void build_vol_hash_table(CacheHostRecord *cp);
 
-struct CacheHostResult
-{
+struct CacheHostResult {
   CacheHostRecord *record;
 
-  CacheHostResult()
-    : record(NULL)
-  { }
+  CacheHostResult() : record(NULL) {}
 };
 
 
 class CacheHostMatcher
 {
 public:
-  CacheHostMatcher(const char * name, CacheType typ);
+  CacheHostMatcher(const char *name, CacheType typ);
   ~CacheHostMatcher();
 
-  void Match(char *rdata, int rlen, CacheHostResult *result);
+  void Match(char const *rdata, int rlen, CacheHostResult *result);
   void AllocateSpace(int num_entries);
   void NewEntry(matcher_line *line_info);
   void Print();
 
-  int getNumElements() const { return num_el; }
-  CacheHostRecord *getDataArray() const { return data_array; }
-  HostLookup *getHLookup() const { return host_lookup; }
+  int
+  getNumElements() const
+  {
+    return num_el;
+  }
+  CacheHostRecord *
+  getDataArray() const
+  {
+    return data_array;
+  }
+  HostLookup *
+  getHLookup() const
+  {
+    return host_lookup;
+  }
 
 private:
   static void PrintFunc(void *opaque_data);
-  HostLookup *host_lookup;      // Data structure to do the lookups
-  CacheHostRecord *data_array;  // array of all data items
-  int array_len;                // the length of the arrays
-  int num_el;                   // the number of itmems in the tree
+  HostLookup *host_lookup;     // Data structure to do the lookups
+  CacheHostRecord *data_array; // array of all data items
+  int array_len;               // the length of the arrays
+  int num_el;                  // the number of itmems in the tree
   CacheType type;
 };
 
@@ -104,20 +112,29 @@ public:
   // Parameter name must not be deallocated before this
   //  object is
   CacheHostTable(Cache *c, CacheType typ);
-   ~CacheHostTable();
-  int BuildTable(const char * config_file_path);
-  int BuildTableFromString(const char * config_file_path, char *str);
-  void Match(char *rdata, int rlen, CacheHostResult *result);
+  ~CacheHostTable();
+  int BuildTable(const char *config_file_path);
+  int BuildTableFromString(const char *config_file_path, char *str);
+  void Match(char const *rdata, int rlen, CacheHostResult *result);
   void Print();
 
-  int getEntryCount() const { return m_numEntries; }
-  CacheHostMatcher *getHostMatcher() const { return hostMatch; }
+  int
+  getEntryCount() const
+  {
+    return m_numEntries;
+  }
+  CacheHostMatcher *
+  getHostMatcher() const
+  {
+    return hostMatch;
+  }
 
   static int config_callback(const char *, RecDataT, RecData, void *);
 
-  void register_config_callback(CacheHostTable ** p)
+  void
+  register_config_callback(CacheHostTable **p)
   {
-    REC_RegisterConfigUpdateFunc("proxy.config.cache.hosting_filename", CacheHostTable::config_callback, (void *) p);
+    REC_RegisterConfigUpdateFunc("proxy.config.cache.hosting_filename", CacheHostTable::config_callback, (void *)p);
   }
 
   CacheType type;
@@ -128,26 +145,25 @@ public:
 private:
   CacheHostMatcher *hostMatch;
   const matcher_tags *config_tags;
-  const char *matcher_name;     // Used for Debug/Warning/Error messages
+  const char *matcher_name; // Used for Debug/Warning/Error messages
 };
 
 struct CacheHostTableConfig;
-typedef int (CacheHostTableConfig::*CacheHostTabHandler) (int, void *);
-struct CacheHostTableConfig: public Continuation
-{
+typedef int (CacheHostTableConfig::*CacheHostTabHandler)(int, void *);
+struct CacheHostTableConfig : public Continuation {
   CacheHostTable **ppt;
-  CacheHostTableConfig(CacheHostTable ** appt)
-    : Continuation(NULL), ppt(appt)
+  CacheHostTableConfig(CacheHostTable **appt) : Continuation(NULL), ppt(appt)
   {
-    SET_HANDLER((CacheHostTabHandler) & CacheHostTableConfig::mainEvent);
+    SET_HANDLER((CacheHostTabHandler)&CacheHostTableConfig::mainEvent);
   }
 
-  int mainEvent(int event, Event *e)
+  int
+  mainEvent(int event, Event *e)
   {
-    (void) e;
-    (void) event;
+    (void)e;
+    (void)event;
     CacheHostTable *t = new CacheHostTable((*ppt)->cache, (*ppt)->type);
-    CacheHostTable *old = (CacheHostTable *) ink_atomic_swap(&t, *ppt);
+    CacheHostTable *old = (CacheHostTable *)ink_atomic_swap(&t, *ppt);
     new_Deleter(old, CACHE_MEM_FREE_TIMEOUT);
     return EVENT_DONE;
   }
@@ -155,8 +171,7 @@ struct CacheHostTableConfig: public Continuation
 
 
 /* list of volumes in the volume.config file */
-struct ConfigVol
-{
+struct ConfigVol {
   int number;
   CacheType scheme;
   off_t size;
@@ -166,8 +181,7 @@ struct ConfigVol
   LINK(ConfigVol, link);
 };
 
-struct ConfigVolumes
-{
+struct ConfigVolumes {
   int num_volumes;
   int num_http_volumes;
   int num_stream_volumes;
@@ -175,7 +189,8 @@ struct ConfigVolumes
   void read_config_file();
   void BuildListFromString(char *config_file_path, char *file_buf);
 
-  void clear_all(void)
+  void
+  clear_all(void)
   {
     // remove all the volumes from the queue
     for (int i = 0; i < num_volumes; i++) {
