@@ -31,25 +31,21 @@
 #define PINNED_DOC_TABLE_SIZE 16
 #define PINNED_DOC_TABLES 246
 
-struct PinnedDocEntry
-{
+struct PinnedDocEntry {
   CacheKey key;
   ink_time_t time;
   LINK(PinnedDocEntry, link);
 };
 
-struct PinnedDocTable: public Continuation
-{
+struct PinnedDocTable : public Continuation {
   Queue<PinnedDocEntry> bucket[PINNED_DOC_TABLE_SIZE];
 
-  void insert(CacheKey * key, ink_time_t time, int update);
-  int probe(CacheKey * key);
-  int remove(CacheKey * key);
-  int cleanup(int event, Event * e);
+  void insert(CacheKey *key, ink_time_t time, int update);
+  int probe(CacheKey *key);
+  int remove(CacheKey *key);
+  int cleanup(int event, Event *e);
 
-  PinnedDocTable():Continuation(new_ProxyMutex()) {
-    memset(bucket, 0, sizeof(Queue<PinnedDocEntry>) * PINNED_DOC_TABLE_SIZE);
-  }
+  PinnedDocTable() : Continuation(new_ProxyMutex()) { memset(bucket, 0, sizeof(Queue<PinnedDocEntry>) * PINNED_DOC_TABLE_SIZE); }
 };
 
 struct CacheTestHost {
@@ -58,8 +54,7 @@ struct CacheTestHost {
   double xprev_host_prob;
   double xnext_host_prob;
 
-  CacheTestHost():name(NULL), xlast_cachable_id(0),
-                  xprev_host_prob(0), xnext_host_prob(0) {}
+  CacheTestHost() : name(NULL), xlast_cachable_id(0), xprev_host_prob(0), xnext_host_prob(0) {}
 };
 
 struct CacheTestHeader {
@@ -96,7 +91,9 @@ struct CacheTestSM : public RegressionSM {
   int check_result(int event);
   int complete(int event);
   int event_handler(int event, void *edata);
-  void make_request() {
+  void
+  make_request()
+  {
     start_time = ink_get_hrtime();
     make_request_internal();
   }
@@ -104,13 +101,21 @@ struct CacheTestSM : public RegressionSM {
   virtual int open_read_callout();
   virtual int open_write_callout();
 
-  void cancel_timeout() {
-    if (timeout) timeout->cancel();
+  void
+  cancel_timeout()
+  {
+    if (timeout)
+      timeout->cancel();
     timeout = 0;
   }
 
   // RegressionSM API
-  void run() { MUTEX_LOCK(lock, mutex, this_ethread()); timeout = eventProcessor.schedule_imm(this); }
+  void
+  run()
+  {
+    MUTEX_LOCK(lock, mutex, this_ethread());
+    timeout = eventProcessor.schedule_imm(this);
+  }
   virtual RegressionSM *clone() = 0;
 
   CacheTestSM(RegressionTest *t);
@@ -119,13 +124,20 @@ struct CacheTestSM : public RegressionSM {
 };
 
 // It is 2010 and C++ STILL doesn't have closures, a technology of the 1950s, unbelievable
-#define CACHE_SM(_t, _sm, _f)                \
-  struct CacheTestSM__##_sm : public CacheTestSM { \
-    void make_request_internal() _f \
-    CacheTestSM__##_sm(RegressionTest *t) : CacheTestSM(t) {} \
+#define CACHE_SM(_t, _sm, _f)                                               \
+  struct CacheTestSM__##_sm : public CacheTestSM {                          \
+    void                                                                    \
+    make_request_internal() _f CacheTestSM__##_sm(RegressionTest *t)        \
+      : CacheTestSM(t)                                                      \
+    {                                                                       \
+    }                                                                       \
     CacheTestSM__##_sm(const CacheTestSM__##_sm &xsm) : CacheTestSM(xsm) {} \
-    RegressionSM *clone() { return new CacheTestSM__##_sm(*this); } \
-} _sm(_t);
+    RegressionSM *                                                          \
+    clone()                                                                 \
+    {                                                                       \
+      return new CacheTestSM__##_sm(*this);                                 \
+    }                                                                       \
+  } _sm(_t);
 
 void force_link_CacheTest();
 
