@@ -25,69 +25,67 @@
 #ifndef _P_CACHE_VOL_H__
 #define _P_CACHE_VOL_H__
 
-#define CACHE_BLOCK_SHIFT               9
-#define CACHE_BLOCK_SIZE                (1<<CACHE_BLOCK_SHIFT) // 512, smallest sector size
-#define ROUND_TO_STORE_BLOCK(_x)        INK_ALIGN((_x), STORE_BLOCK_SIZE)
-#define ROUND_TO_CACHE_BLOCK(_x)        INK_ALIGN((_x), CACHE_BLOCK_SIZE)
-#define ROUND_TO_SECTOR(_p, _x)         INK_ALIGN((_x), _p->sector_size)
-#define ROUND_TO(_x, _y)                INK_ALIGN((_x), (_y))
+#define CACHE_BLOCK_SHIFT 9
+#define CACHE_BLOCK_SIZE (1 << CACHE_BLOCK_SHIFT) // 512, smallest sector size
+#define ROUND_TO_STORE_BLOCK(_x) INK_ALIGN((_x), STORE_BLOCK_SIZE)
+#define ROUND_TO_CACHE_BLOCK(_x) INK_ALIGN((_x), CACHE_BLOCK_SIZE)
+#define ROUND_TO_SECTOR(_p, _x) INK_ALIGN((_x), _p->sector_size)
+#define ROUND_TO(_x, _y) INK_ALIGN((_x), (_y))
 
 // Vol (volumes)
-#define VOL_MAGIC                      0xF1D0F00D
-#define START_BLOCKS                    16      // 8k, STORE_BLOCK_SIZE
-#define START_POS                       ((off_t)START_BLOCKS * CACHE_BLOCK_SIZE)
-#define AGG_SIZE                        (4 * 1024 * 1024) // 4MB
-#define AGG_HIGH_WATER                  (AGG_SIZE / 2) // 2MB
-#define EVACUATION_SIZE                 (2 * AGG_SIZE)  // 8MB
-#define MAX_VOL_SIZE                   ((off_t)512 * 1024 * 1024 * 1024 * 1024)
-#define STORE_BLOCKS_PER_CACHE_BLOCK    (STORE_BLOCK_SIZE / CACHE_BLOCK_SIZE)
-#define MAX_VOL_BLOCKS                 (MAX_VOL_SIZE / CACHE_BLOCK_SIZE)
-#define MAX_FRAG_SIZE                   (AGG_SIZE - sizeofDoc) // true max
-#define LEAVE_FREE                      DEFAULT_MAX_BUFFER_SIZE
-#define PIN_SCAN_EVERY                  16      // scan every 1/16 of disk
-#define VOL_HASH_TABLE_SIZE             32707
-#define VOL_HASH_EMPTY                 0xFFFF
-#define VOL_HASH_ALLOC_SIZE             (8 * 1024 * 1024)  // one chance per this unit
-#define LOOKASIDE_SIZE                  256
-#define EVACUATION_BUCKET_SIZE          (2 * EVACUATION_SIZE) // 16MB
-#define RECOVERY_SIZE                   EVACUATION_SIZE // 8MB
-#define AIO_NOT_IN_PROGRESS             0
-#define AIO_AGG_WRITE_IN_PROGRESS       -1
-#define AUTO_SIZE_RAM_CACHE             -1      // 1-1 with directory size
-#define DEFAULT_TARGET_FRAGMENT_SIZE    (1048576 - sizeofDoc) // 1MB
+#define VOL_MAGIC 0xF1D0F00D
+#define START_BLOCKS 16 // 8k, STORE_BLOCK_SIZE
+#define START_POS ((off_t)START_BLOCKS * CACHE_BLOCK_SIZE)
+#define AGG_SIZE (4 * 1024 * 1024)     // 4MB
+#define AGG_HIGH_WATER (AGG_SIZE / 2)  // 2MB
+#define EVACUATION_SIZE (2 * AGG_SIZE) // 8MB
+#define MAX_VOL_SIZE ((off_t)512 * 1024 * 1024 * 1024 * 1024)
+#define STORE_BLOCKS_PER_CACHE_BLOCK (STORE_BLOCK_SIZE / CACHE_BLOCK_SIZE)
+#define MAX_VOL_BLOCKS (MAX_VOL_SIZE / CACHE_BLOCK_SIZE)
+#define MAX_FRAG_SIZE (AGG_SIZE - sizeofDoc) // true max
+#define LEAVE_FREE DEFAULT_MAX_BUFFER_SIZE
+#define PIN_SCAN_EVERY 16 // scan every 1/16 of disk
+#define VOL_HASH_TABLE_SIZE 32707
+#define VOL_HASH_EMPTY 0xFFFF
+#define VOL_HASH_ALLOC_SIZE (8 * 1024 * 1024) // one chance per this unit
+#define LOOKASIDE_SIZE 256
+#define EVACUATION_BUCKET_SIZE (2 * EVACUATION_SIZE) // 16MB
+#define RECOVERY_SIZE EVACUATION_SIZE                // 8MB
+#define AIO_NOT_IN_PROGRESS 0
+#define AIO_AGG_WRITE_IN_PROGRESS -1
+#define AUTO_SIZE_RAM_CACHE -1                             // 1-1 with directory size
+#define DEFAULT_TARGET_FRAGMENT_SIZE (1048576 - sizeofDoc) // 1MB
 
 
-#define dir_offset_evac_bucket(_o) \
-  (_o / (EVACUATION_BUCKET_SIZE / CACHE_BLOCK_SIZE))
+#define dir_offset_evac_bucket(_o) (_o / (EVACUATION_BUCKET_SIZE / CACHE_BLOCK_SIZE))
 #define dir_evac_bucket(_e) dir_offset_evac_bucket(dir_offset(_e))
 #define offset_evac_bucket(_d, _o) \
   dir_offset_evac_bucket((offset_to_vol_offset(_d, _o)
 
 // Documents
 
-#define DOC_MAGIC                       ((uint32_t)0x5F129B13)
-#define DOC_CORRUPT                     ((uint32_t)0xDEADBABE)
-#define DOC_NO_CHECKSUM                 ((uint32_t)0xA0B0C0D0)
+#define DOC_MAGIC ((uint32_t)0x5F129B13)
+#define DOC_CORRUPT ((uint32_t)0xDEADBABE)
+#define DOC_NO_CHECKSUM ((uint32_t)0xA0B0C0D0)
 
-#define sizeofDoc (((uint32_t)(uintptr_t)&((Doc*)0)->checksum)+(uint32_t)sizeof(uint32_t))
+#define sizeofDoc (((uint32_t)(uintptr_t) & ((Doc *)0)->checksum) + (uint32_t)sizeof(uint32_t))
 
 #if TS_USE_INTERIM_CACHE == 1
-struct InterimVolHeaderFooter
-{
+struct InterimVolHeaderFooter {
   unsigned int magic;
   VersionNumber version;
   time_t create_time;
   off_t write_pos;
   off_t last_write_pos;
   off_t agg_pos;
-  uint32_t generation;            // token generation (vary), this cannot be 0
+  uint32_t generation; // token generation (vary), this cannot be 0
   uint32_t phase;
   uint32_t cycle;
   uint32_t sync_serial;
   uint32_t write_serial;
   uint32_t dirty;
   uint32_t sector_size;
-  int32_t unused;                // pad out to 8 byte boundary
+  int32_t unused; // pad out to 8 byte boundary
 };
 #endif
 
@@ -98,22 +96,21 @@ struct VolInitInfo;
 struct DiskVol;
 struct CacheVol;
 
-struct VolHeaderFooter
-{
+struct VolHeaderFooter {
   unsigned int magic;
   VersionNumber version;
   time_t create_time;
   off_t write_pos;
   off_t last_write_pos;
   off_t agg_pos;
-  uint32_t generation;            // token generation (vary), this cannot be 0
+  uint32_t generation; // token generation (vary), this cannot be 0
   uint32_t phase;
   uint32_t cycle;
   uint32_t sync_serial;
   uint32_t write_serial;
   uint32_t dirty;
   uint32_t sector_size;
-  uint32_t unused;                // pad out to 8 byte boundary
+  uint32_t unused; // pad out to 8 byte boundary
 #if TS_USE_INTERIM_CACHE == 1
   InterimVolHeaderFooter interim_header[8];
 #endif
@@ -121,24 +118,20 @@ struct VolHeaderFooter
 };
 
 // Key and Earliest key for each fragment that needs to be evacuated
-struct EvacuationKey
-{
+struct EvacuationKey {
   SLink<EvacuationKey> link;
-  INK_MD5 key;
-  INK_MD5 earliest_key;
+  CryptoHash key;
+  CryptoHash earliest_key;
 };
 
-struct EvacuationBlock
-{
-  union
-  {
+struct EvacuationBlock {
+  union {
     unsigned int init;
-    struct
-    {
-      unsigned int done:1;              // has been evacuated
-      unsigned int pinned:1;            // check pinning timeout
-      unsigned int evacuate_head:1;     // check pinning timeout
-      unsigned int unused:29;
+    struct {
+      unsigned int done : 1;          // has been evacuated
+      unsigned int pinned : 1;        // check pinning timeout
+      unsigned int evacuate_head : 1; // check pinning timeout
+      unsigned int unused : 29;
     } f;
   };
 
@@ -152,7 +145,7 @@ struct EvacuationBlock
 };
 
 #if TS_USE_INTERIM_CACHE == 1
-#define MIGRATE_BUCKETS                 1021
+#define MIGRATE_BUCKETS 1021
 extern int migrate_threshold;
 extern int good_interim_disks;
 
@@ -160,11 +153,11 @@ extern int good_interim_disks;
 union AccessEntry {
   uintptr_t v[2];
   struct {
-    uint32_t  next;
-    uint32_t  prev;
-    uint32_t  index;
-    uint16_t  tag;
-    int16_t  count;
+    uint32_t next;
+    uint32_t prev;
+    uint32_t index;
+    uint16_t tag;
+    int16_t count;
   } item;
 };
 
@@ -177,31 +170,37 @@ struct AccessHistory {
 
   AccessEntry *freelist;
 
-  void freeEntry(AccessEntry *entry) {
-    entry->v[0] = (uintptr_t) freelist;
+  void
+  freeEntry(AccessEntry *entry)
+  {
+    entry->v[0] = (uintptr_t)freelist;
     entry->v[1] = 0xABCD1234U;
     freelist = entry;
   }
 
-  void init(int size, int hash_size) {
+  void
+  init(int size, int hash_size)
+  {
     this->size = size;
     this->hash_size = hash_size;
     freelist = NULL;
 
-    base = (AccessEntry *) malloc(sizeof(AccessEntry) * size);
-    hash = (uint32_t *) malloc (sizeof(uint32_t) * hash_size);
+    base = (AccessEntry *)malloc(sizeof(AccessEntry) * size);
+    hash = (uint32_t *)malloc(sizeof(uint32_t) * hash_size);
 
     memset(hash, 0, sizeof(uint32_t) * hash_size);
 
     base[0].item.next = base[0].item.prev = 0;
     base[0].v[1] = 0xABCD1234UL;
     for (int i = size; --i > 0;)
-     freeEntry(&base[i]);
+      freeEntry(&base[i]);
 
     return;
   }
 
-  void remove(AccessEntry *entry) {
+  void
+  remove(AccessEntry *entry)
+  {
     if (entry == &(base[base[0].item.prev])) { // head
       base[0].item.prev = entry->item.next;
     } else {
@@ -212,12 +211,14 @@ struct AccessHistory {
     } else {
       base[entry->item.next].item.prev = entry->item.prev;
     }
-    uint32_t hash_index = (uint32_t) (entry->item.index % hash_size);
+    uint32_t hash_index = (uint32_t)(entry->item.index % hash_size);
     hash[hash_index] = 0;
   }
 
-  void enqueue(AccessEntry *entry) {
-    uint32_t hash_index = (uint32_t) (entry->item.index % hash_size);
+  void
+  enqueue(AccessEntry *entry)
+  {
+    uint32_t hash_index = (uint32_t)(entry->item.index % hash_size);
     hash[hash_index] = entry - base;
 
     entry->item.prev = 0;
@@ -228,7 +229,9 @@ struct AccessHistory {
       base[0].item.next = entry - base;
   }
 
-  AccessEntry* dequeue() {
+  AccessEntry *
+  dequeue()
+  {
     AccessEntry *tail = &base[base[0].item.next];
     if (tail != base)
       remove(tail);
@@ -236,10 +239,12 @@ struct AccessHistory {
     return tail;
   }
 
-  void set_in_progress(INK_MD5 *key) {
-    uint32_t key_index = key->word(3);
-    uint16_t tag = (uint16_t) key->word(1);
-    unsigned int hash_index = (uint32_t) (key_index % hash_size);
+  void
+  set_in_progress(CryptoHash *key)
+  {
+    uint32_t key_index = key->slice32(3);
+    uint16_t tag = static_cast<uint16_t>(key->slice32(1));
+    unsigned int hash_index = (uint32_t)(key_index % hash_size);
 
     uint32_t index = hash[hash_index];
     AccessEntry *entry = &base[index];
@@ -248,10 +253,12 @@ struct AccessHistory {
     }
   }
 
-  void set_not_in_progress(INK_MD5 *key) {
-    uint32_t key_index = key->word(3);
-    uint16_t tag = (uint16_t) key->word(1);
-    unsigned int hash_index = (uint32_t) (key_index % hash_size);
+  void
+  set_not_in_progress(CryptoHash *key)
+  {
+    uint32_t key_index = key->slice32(3);
+    uint16_t tag = static_cast<uint16_t>(key->slice32(1));
+    unsigned int hash_index = (uint32_t)(key_index % hash_size);
 
     uint32_t index = hash[hash_index];
     AccessEntry *entry = &base[index];
@@ -260,10 +267,12 @@ struct AccessHistory {
     }
   }
 
-  void put_key(INK_MD5 *key) {
-    uint32_t key_index = key->word(3);
-    uint16_t tag = (uint16_t) key->word(1);
-    unsigned int hash_index = (uint32_t) (key_index % hash_size);
+  void
+  put_key(CryptoHash *key)
+  {
+    uint32_t key_index = key->slice32(3);
+    uint16_t tag = static_cast<uint16_t>(key->slice32(1));
+    unsigned int hash_index = (uint32_t)(key_index % hash_size);
 
     uint32_t index = hash[hash_index];
     AccessEntry *entry = &base[index];
@@ -280,7 +289,7 @@ struct AccessHistory {
           }
         } else {
           entry = freelist;
-          freelist = (AccessEntry *) entry->v[0];
+          freelist = (AccessEntry *)entry->v[0];
         }
       } else { // collation
         remove(entry);
@@ -292,11 +301,13 @@ struct AccessHistory {
     }
   }
 
-  bool remove_key(INK_MD5 *key) {
-    unsigned int hash_index = (uint32_t) (key->word(3) % hash_size);
+  bool
+  remove_key(CryptoHash *key)
+  {
+    unsigned int hash_index = static_cast<uint32_t>(key->slice32(3) % hash_size);
     uint32_t index = hash[hash_index];
     AccessEntry *entry = &base[index];
-    if (index != 0 && entry->item.tag == (uint16_t)key->word(1) && entry->item.index == key->word(3)) {
+    if (index != 0 && entry->item.tag == static_cast<uint16_t>(key->slice32(1)) && entry->item.index == key->slice32(3)) {
       remove(entry);
       freeEntry(entry);
       return true;
@@ -304,27 +315,27 @@ struct AccessHistory {
     return false;
   }
 
-  bool is_hot(INK_MD5 *key) {
-    uint32_t key_index = key->word(3);
-    uint16_t tag = (uint16_t) key->word(1);
-    unsigned int hash_index = (uint32_t) (key_index % hash_size);
+  bool
+  is_hot(CryptoHash *key)
+  {
+    uint32_t key_index = key->slice32(3);
+    uint16_t tag = (uint16_t)key->slice32(1);
+    unsigned int hash_index = (uint32_t)(key_index % hash_size);
 
     uint32_t index = hash[hash_index];
     AccessEntry *entry = &base[index];
 
-    return (index != 0 && entry->item.tag == tag && entry->item.index == key_index
-        && entry->item.count >= migrate_threshold);
+    return (index != 0 && entry->item.tag == tag && entry->item.index == key_index && entry->item.count >= migrate_threshold);
   }
 };
 
 struct InterimCacheVol;
 
-struct MigrateToInterimCache
-{
-  MigrateToInterimCache() { }
+struct MigrateToInterimCache {
+  MigrateToInterimCache() {}
   Ptr<IOBufferData> buf;
   uint32_t agg_len;
-  CacheKey  key;
+  CacheKey key;
   Dir dir;
   InterimCacheVol *interim_vol;
   CacheVC *vc;
@@ -335,9 +346,8 @@ struct MigrateToInterimCache
   LINK(MigrateToInterimCache, hash_link);
 };
 
-struct InterimCacheVol: public Continuation
-{
-  char *hash_id;
+struct InterimCacheVol : public Continuation {
+  ats_scoped_str hash_text;
   InterimVolHeaderFooter *header;
 
   off_t recover_pos;
@@ -347,7 +357,7 @@ struct InterimCacheVol: public Continuation
   bool recover_wrapped;
 
   off_t scan_pos;
-  off_t skip; // start of headers
+  off_t skip;  // start of headers
   off_t start; // start of data
   off_t len;
   off_t data_blocks;
@@ -362,28 +372,39 @@ struct InterimCacheVol: public Continuation
   Queue<MigrateToInterimCache, MigrateToInterimCache::Link_link> agg;
   int64_t transistor_range_threshold;
   bool sync;
-  bool is_io_in_progress() {
+  bool
+  is_io_in_progress()
+  {
     return io.aiocb.aio_fildes != AIO_NOT_IN_PROGRESS;
   }
 
   int recover_data();
   int handle_recover_from_data(int event, void *data);
 
-  void set_io_not_in_progress() {
+  void
+  set_io_not_in_progress()
+  {
     io.aiocb.aio_fildes = AIO_NOT_IN_PROGRESS;
   }
 
   int aggWrite(int event, void *e);
   int aggWriteDone(int event, void *e);
-  uint32_t round_to_approx_size (uint32_t l) {
+  uint32_t
+  round_to_approx_size(uint32_t l)
+  {
     uint32_t ll = round_to_approx_dir_size(l);
     return INK_ALIGN(ll, disk->hw_sector_size);
   }
 
-  void init(off_t s, off_t l, CacheDisk *interim, Vol *v, InterimVolHeaderFooter *hptr) {
-    const size_t hash_id_size = strlen(interim->path) + 32;
-    hash_id = (char *)ats_malloc(hash_id_size);
-    snprintf(hash_id, hash_id_size, "%s %" PRIu64 ":%" PRIu64 "", interim->path, s, l);
+  void
+  init(off_t s, off_t l, CacheDisk *interim, Vol *v, InterimVolHeaderFooter *hptr)
+  {
+    char *seed_str = interim->hash_base_string ? interim->hash_base_string : interim->path;
+    const size_t hash_seed_size = strlen(seed_str);
+    const size_t hash_text_size = hash_seed_size + 32;
+
+    hash_text = static_cast<char *>(ats_malloc(hash_text_size));
+    snprintf(hash_text, hash_text_size, "%s %" PRIu64 ":%" PRIu64 "", seed_str, s, l);
 
     skip = start = s;
     len = l;
@@ -398,7 +419,7 @@ struct InterimCacheVol: public Continuation
     agg_todo_size = 0;
     agg_buf_pos = 0;
 
-    agg_buffer = (char *) ats_memalign(sysconf(_SC_PAGESIZE), AGG_SIZE);
+    agg_buffer = (char *)ats_memalign(sysconf(_SC_PAGESIZE), AGG_SIZE);
     memset(agg_buffer, 0, AGG_SIZE);
     this->mutex = ((Continuation *)vol)->mutex;
   }
@@ -411,11 +432,10 @@ void dir_clean_interimvol(InterimCacheVol *d);
 
 #endif
 
-struct Vol: public Continuation
-{
+struct Vol : public Continuation {
   char *path;
-  char *hash_id;
-  INK_MD5 hash_id_md5;
+  ats_scoped_str hash_text;
+  CryptoHash hash_id;
   int fd;
 
   char *raw_dir;
@@ -427,8 +447,8 @@ struct Vol: public Continuation
   off_t recover_pos;
   off_t prev_recover_pos;
   off_t scan_pos;
-  off_t skip;               // start of headers
-  off_t start;              // start of data
+  off_t skip;  // start of headers
+  off_t start; // start of data
   off_t len;
   off_t data_blocks;
   int hit_evacuate_window;
@@ -476,8 +496,10 @@ struct Vol: public Continuation
   volatile int interim_done;
 
 
-  bool migrate_probe(CacheKey *key, MigrateToInterimCache **result) {
-    uint32_t indx = key->word(3) % MIGRATE_BUCKETS;
+  bool
+  migrate_probe(CacheKey *key, MigrateToInterimCache **result)
+  {
+    uint32_t indx = key->slice32(3) % MIGRATE_BUCKETS;
     MigrateToInterimCache *m = mig_hash[indx].head;
     while (m != NULL && !(m->key == *key)) {
       m = mig_hash[indx].next(m);
@@ -487,18 +509,24 @@ struct Vol: public Continuation
     return m != NULL;
   }
 
-  void set_migrate_in_progress(MigrateToInterimCache *m) {
-    uint32_t indx = m->key.word(3) % MIGRATE_BUCKETS;
+  void
+  set_migrate_in_progress(MigrateToInterimCache *m)
+  {
+    uint32_t indx = m->key.slice32(3) % MIGRATE_BUCKETS;
     mig_hash[indx].enqueue(m);
   }
 
-  void set_migrate_failed(MigrateToInterimCache *m) {
-    uint32_t indx = m->key.word(3) % MIGRATE_BUCKETS;
+  void
+  set_migrate_failed(MigrateToInterimCache *m)
+  {
+    uint32_t indx = m->key.slice32(3) % MIGRATE_BUCKETS;
     mig_hash[indx].remove(m);
   }
 
-  void set_migrate_done(MigrateToInterimCache *m) {
-    uint32_t indx = m->key.word(3) % MIGRATE_BUCKETS;
+  void
+  set_migrate_done(MigrateToInterimCache *m)
+  {
+    uint32_t indx = m->key.slice32(3) % MIGRATE_BUCKETS;
     mig_hash[indx].remove(m);
     history.remove_key(&m->key);
   }
@@ -516,8 +544,8 @@ struct Vol: public Continuation
   int begin_read_lock(CacheVC *cont);
   // unused read-write interlock code
   // currently http handles a write-lock failure by retrying the read
-  OpenDirEntry *open_read(INK_MD5 *key);
-  OpenDirEntry *open_read_lock(INK_MD5 *key, EThread *t);
+  OpenDirEntry *open_read(CryptoHash *key);
+  OpenDirEntry *open_read_lock(CryptoHash *key, EThread *t);
   int close_read(CacheVC *cont);
   int close_read_lock(CacheVC *cont);
 
@@ -540,11 +568,13 @@ struct Vol: public Continuation
   int dir_check(bool fix);
   int db_check(bool fix);
 
-  int is_io_in_progress()
+  int
+  is_io_in_progress()
   {
     return io.aiocb.aio_fildes != AIO_NOT_IN_PROGRESS;
   }
-  int increment_generation()
+  int
+  increment_generation()
   {
     // this is stored in the offset field of the directory (!=0)
     ink_assert(mutex->thread_holding == this_ethread());
@@ -553,11 +583,12 @@ struct Vol: public Continuation
       header->generation++;
     return header->generation;
   }
-  void set_io_not_in_progress()
+  void
+  set_io_not_in_progress()
   {
     io.aiocb.aio_fildes = AIO_NOT_IN_PROGRESS;
   }
-  
+
   int aggWriteDone(int event, Event *e);
   int aggWrite(int event, void *e);
   void agg_wrap();
@@ -576,33 +607,27 @@ struct Vol: public Continuation
   uint32_t round_to_approx_size(uint32_t l);
 
   Vol()
-    : Continuation(new_ProxyMutex()), path(NULL), fd(-1),
-      dir(0), buckets(0), recover_pos(0), prev_recover_pos(0), scan_pos(0), skip(0), start(0),
-      len(0), data_blocks(0), hit_evacuate_window(0), agg_todo_size(0), agg_buf_pos(0), trigger(0),
-      evacuate_size(0), disk(NULL), last_sync_serial(0), last_write_serial(0), recover_wrapped(false),
-      dir_sync_waiting(0), dir_sync_in_progress(0), writing_end_marker(0) {
+    : Continuation(new_ProxyMutex()), path(NULL), fd(-1), dir(0), buckets(0), recover_pos(0), prev_recover_pos(0), scan_pos(0),
+      skip(0), start(0), len(0), data_blocks(0), hit_evacuate_window(0), agg_todo_size(0), agg_buf_pos(0), trigger(0),
+      evacuate_size(0), disk(NULL), last_sync_serial(0), last_write_serial(0), recover_wrapped(false), dir_sync_waiting(0),
+      dir_sync_in_progress(0), writing_end_marker(0)
+  {
     open_dir.mutex = mutex;
     agg_buffer = (char *)ats_memalign(ats_pagesize(), AGG_SIZE);
     memset(agg_buffer, 0, AGG_SIZE);
     SET_HANDLER(&Vol::aggWrite);
   }
 
-  ~Vol() {
-    ats_memalign_free(agg_buffer);
-  }
+  ~Vol() { ats_memalign_free(agg_buffer); }
 };
 
-struct AIO_Callback_handler: public Continuation
-{
+struct AIO_Callback_handler : public Continuation {
   int handle_disk_failure(int event, void *data);
 
-  AIO_Callback_handler():Continuation(new_ProxyMutex()) {
-    SET_HANDLER(&AIO_Callback_handler::handle_disk_failure);
-  }
+  AIO_Callback_handler() : Continuation(new_ProxyMutex()) { SET_HANDLER(&AIO_Callback_handler::handle_disk_failure); }
 };
 
-struct CacheVol
-{
+struct CacheVol {
   int vol_number;
   int scheme;
   off_t size;
@@ -613,26 +638,25 @@ struct CacheVol
   // per volume stats
   RecRawStatBlock *vol_rsb;
 
-  CacheVol()
-    : vol_number(-1), scheme(0), size(0), num_vols(0), vols(NULL), disk_vols(0), vol_rsb(0)
-  { }
+  CacheVol() : vol_number(-1), scheme(0), size(0), num_vols(0), vols(NULL), disk_vols(0), vol_rsb(0) {}
 };
 
 // Note : hdr() needs to be 8 byte aligned.
 // If you change this, change sizeofDoc above
-struct Doc
-{
-  uint32_t magic;         // DOC_MAGIC
-  uint32_t len;           // length of this segment (including hlen, flen & sizeof(Doc), unrounded)
-  uint64_t total_len;     // total length of document
-  INK_MD5 first_key;    // first key in document (http: vector)
-  INK_MD5 key;
-  uint32_t hlen;          // header length
-  uint32_t ftype:8;       // fragment type CACHE_FRAG_TYPE_XX
-  uint32_t _flen:24;       // fragment table length [amc] NOT USED
+struct Doc {
+  uint32_t magic;        // DOC_MAGIC
+  uint32_t len;          // length of this fragment (including hlen & sizeof(Doc), unrounded)
+  uint64_t total_len;    // total length of document
+  CryptoHash first_key;  ///< first key in object.
+  CryptoHash key;        ///< Key for this doc.
+  uint32_t hlen;         ///< Length of this header.
+  uint32_t doc_type : 8; ///< Doc type - indicates the format of this structure and its content.
+  uint32_t v_major : 8;  ///< Major version number.
+  uint32_t v_minor : 8;  ///< Minor version number.
+  uint32_t unused : 8;   ///< Unused, forced to zero.
   uint32_t sync_serial;
   uint32_t write_serial;
-  uint32_t pinned;        // pinned until
+  uint32_t pinned; // pinned until
   uint32_t checksum;
 
   uint32_t data_len();
@@ -655,16 +679,16 @@ extern unsigned short *vol_hash_table;
 // inline Functions
 
 TS_INLINE int
-vol_headerlen(Vol *d) {
-  return ROUND_TO_STORE_BLOCK(sizeof(VolHeaderFooter) + sizeof(uint16_t) * (d->segments-1));
+vol_headerlen(Vol *d)
+{
+  return ROUND_TO_STORE_BLOCK(sizeof(VolHeaderFooter) + sizeof(uint16_t) * (d->segments - 1));
 }
 
 TS_INLINE size_t
 vol_dirlen(Vol *d)
 {
-  return vol_headerlen(d) + 
-    ROUND_TO_STORE_BLOCK(((size_t)d->buckets) * DIR_DEPTH * d->segments * SIZEOF_DIR) +
-    ROUND_TO_STORE_BLOCK(sizeof(VolHeaderFooter));
+  return vol_headerlen(d) + ROUND_TO_STORE_BLOCK(((size_t)d->buckets) * DIR_DEPTH * d->segments * SIZEOF_DIR) +
+         ROUND_TO_STORE_BLOCK(sizeof(VolHeaderFooter));
 }
 
 TS_INLINE int
@@ -674,39 +698,31 @@ vol_direntries(Vol *d)
 }
 
 #if TS_USE_INTERIM_CACHE == 1
-#define vol_out_of_phase_valid(d, e)            \
-    (dir_offset(e) - 1 >= ((d->header->agg_pos - d->start) / CACHE_BLOCK_SIZE))
+#define vol_out_of_phase_valid(d, e) (dir_offset(e) - 1 >= ((d->header->agg_pos - d->start) / CACHE_BLOCK_SIZE))
 
-#define vol_out_of_phase_agg_valid(d, e)        \
-    (dir_offset(e) - 1 >= ((d->header->agg_pos - d->start + AGG_SIZE) / CACHE_BLOCK_SIZE))
+#define vol_out_of_phase_agg_valid(d, e) (dir_offset(e) - 1 >= ((d->header->agg_pos - d->start + AGG_SIZE) / CACHE_BLOCK_SIZE))
 
-#define vol_out_of_phase_write_valid(d, e)      \
-    (dir_offset(e) - 1 >= ((d->header->agg_pos - d->start + AGG_SIZE) / CACHE_BLOCK_SIZE))
+#define vol_out_of_phase_write_valid(d, e) (dir_offset(e) - 1 >= ((d->header->agg_pos - d->start + AGG_SIZE) / CACHE_BLOCK_SIZE))
 
-#define vol_in_phase_valid(d, e)                \
-    (dir_offset(e) - 1 < ((d->header->write_pos + d->agg_buf_pos - d->start) / CACHE_BLOCK_SIZE))
+#define vol_in_phase_valid(d, e) (dir_offset(e) - 1 < ((d->header->write_pos + d->agg_buf_pos - d->start) / CACHE_BLOCK_SIZE))
 
-#define vol_offset_to_offset(d, pos)            \
-    (d->start + pos * CACHE_BLOCK_SIZE - CACHE_BLOCK_SIZE)
+#define vol_offset_to_offset(d, pos) (d->start + pos * CACHE_BLOCK_SIZE - CACHE_BLOCK_SIZE)
 
-#define vol_dir_segment(d, s)                   \
-    (Dir *) (((char *) d->dir) + (s * d->buckets) * DIR_DEPTH * SIZEOF_DIR)
+#define vol_dir_segment(d, s) (Dir *)(((char *)d->dir) + (s * d->buckets) * DIR_DEPTH * SIZEOF_DIR)
 
-#define offset_to_vol_offset(d, pos)            \
-    ((pos - d->start + CACHE_BLOCK_SIZE) / CACHE_BLOCK_SIZE)
+#define offset_to_vol_offset(d, pos) ((pos - d->start + CACHE_BLOCK_SIZE) / CACHE_BLOCK_SIZE)
 
-#define vol_offset(d, e)                        \
-    ((d)->start + (off_t) ((off_t)dir_offset(e) * CACHE_BLOCK_SIZE) - CACHE_BLOCK_SIZE)
+#define vol_offset(d, e) ((d)->start + (off_t)((off_t)dir_offset(e) * CACHE_BLOCK_SIZE) - CACHE_BLOCK_SIZE)
 
-#define vol_in_phase_agg_buf_valid(d, e)        \
-    ((vol_offset(d, e) >= d->header->write_pos) && vol_offset(d, e) < (d->header->write_pos + d->agg_buf_pos))
+#define vol_in_phase_agg_buf_valid(d, e) \
+  ((vol_offset(d, e) >= d->header->write_pos) && vol_offset(d, e) < (d->header->write_pos + d->agg_buf_pos))
 
-#define vol_transistor_range_valid(d, e)    \
-  ((d->header->agg_pos + d->transistor_range_threshold < d->start + d->len) ? \
-      (vol_out_of_phase_write_valid(d, e) && \
-      (dir_offset(e) <= ((d->header->agg_pos - d->start + d->transistor_range_threshold) / CACHE_BLOCK_SIZE))) : \
-      ((dir_offset(e) <= ((d->header->agg_pos - d->start + d->transistor_range_threshold - d->len) / CACHE_BLOCK_SIZE)) || \
-          (dir_offset(e) > ((d->header->agg_pos - d->start) / CACHE_BLOCK_SIZE))))
+#define vol_transistor_range_valid(d, e)                                                                                  \
+  ((d->header->agg_pos + d->transistor_range_threshold < d->start + d->len) ?                                             \
+     (vol_out_of_phase_write_valid(d, e) &&                                                                               \
+      (dir_offset(e) <= ((d->header->agg_pos - d->start + d->transistor_range_threshold) / CACHE_BLOCK_SIZE))) :          \
+     ((dir_offset(e) <= ((d->header->agg_pos - d->start + d->transistor_range_threshold - d->len) / CACHE_BLOCK_SIZE)) || \
+      (dir_offset(e) > ((d->header->agg_pos - d->start) / CACHE_BLOCK_SIZE))))
 
 
 #else
@@ -737,7 +753,7 @@ vol_in_phase_valid(Vol *d, Dir *e)
 TS_INLINE off_t
 vol_offset(Vol *d, Dir *e)
 {
-  return d->start + (off_t) dir_offset(e) * CACHE_BLOCK_SIZE - CACHE_BLOCK_SIZE;
+  return d->start + (off_t)dir_offset(e) * CACHE_BLOCK_SIZE - CACHE_BLOCK_SIZE;
 }
 
 TS_INLINE off_t
@@ -755,7 +771,7 @@ vol_offset_to_offset(Vol *d, off_t pos)
 TS_INLINE Dir *
 vol_dir_segment(Vol *d, int s)
 {
-  return (Dir *) (((char *) d->dir) + (s * d->buckets) * DIR_DEPTH * SIZEOF_DIR);
+  return (Dir *)(((char *)d->dir) + (s * d->buckets) * DIR_DEPTH * SIZEOF_DIR);
 }
 
 TS_INLINE int
@@ -768,37 +784,37 @@ vol_in_phase_agg_buf_valid(Vol *d, Dir *e)
 TS_INLINE off_t
 vol_relative_length(Vol *v, off_t start_offset)
 {
-   return (v->len + v->skip) - start_offset;
+  return (v->len + v->skip) - start_offset;
 }
 
 TS_INLINE uint32_t
 Doc::prefix_len()
 {
-  return sizeofDoc + hlen + _flen;
+  return sizeofDoc + hlen;
 }
 
 TS_INLINE uint32_t
 Doc::data_len()
 {
-  return len - sizeofDoc - hlen - _flen;
+  return len - sizeofDoc - hlen;
 }
 
 TS_INLINE int
 Doc::single_fragment()
 {
-  return (data_len() == total_len);
+  return data_len() == total_len;
 }
 
 TS_INLINE char *
 Doc::hdr()
 {
-  return ((char *) this) + sizeofDoc + _flen;
+  return reinterpret_cast<char *>(this) + sizeofDoc;
 }
 
 TS_INLINE char *
 Doc::data()
 {
-  return ((char *) this) + sizeofDoc + _flen + hlen;
+  return this->hdr() + hlen;
 }
 
 int vol_dir_clear(Vol *d);
@@ -849,7 +865,7 @@ free_EvacuationBlock(EvacuationBlock *b, EThread *t)
 }
 
 TS_INLINE OpenDirEntry *
-Vol::open_read(INK_MD5 *key)
+Vol::open_read(CryptoHash *key)
 {
   return open_dir.open_read(key);
 }
@@ -867,64 +883,67 @@ Vol::within_hit_evacuate_window(Dir *xdir)
 }
 
 TS_INLINE uint32_t
-Vol::round_to_approx_size(uint32_t l) {
+Vol::round_to_approx_size(uint32_t l)
+{
   uint32_t ll = round_to_approx_dir_size(l);
   return ROUND_TO_SECTOR(this, ll);
 }
 
 #if TS_USE_INTERIM_CACHE == 1
 inline bool
-dir_valid(Vol *_d, Dir *_e) {
+dir_valid(Vol *_d, Dir *_e)
+{
   if (!dir_ininterim(_e))
-    return _d->header->phase == dir_phase(_e) ? vol_in_phase_valid(_d, _e) :
-        vol_out_of_phase_valid(_d, _e);
+    return _d->header->phase == dir_phase(_e) ? vol_in_phase_valid(_d, _e) : vol_out_of_phase_valid(_d, _e);
   else {
     int idx = dir_get_index(_e);
-    if (good_interim_disks <= 0 || idx >= _d->num_interim_vols) return false;
+    if (good_interim_disks <= 0 || idx >= _d->num_interim_vols)
+      return false;
     InterimCacheVol *sv = &(_d->interim_vols[idx]);
-    return !DISK_BAD(sv->disk) ? (sv->header->phase == dir_phase(_e) ? vol_in_phase_valid(sv, _e) :
-        vol_out_of_phase_valid(sv, _e)) : false;
+    return !DISK_BAD(sv->disk) ?
+             (sv->header->phase == dir_phase(_e) ? vol_in_phase_valid(sv, _e) : vol_out_of_phase_valid(sv, _e)) :
+             false;
   }
 }
 
 inline bool
-dir_valid(InterimCacheVol *_d, Dir *_e) {
+dir_valid(InterimCacheVol *_d, Dir *_e)
+{
   if (!dir_ininterim(_e))
     return true;
   InterimCacheVol *sv = &(_d->vol->interim_vols[dir_get_index(_e)]);
   if (_d != sv)
     return true;
-  return !DISK_BAD(sv->disk) ? (sv->header->phase == dir_phase(_e) ? vol_in_phase_valid(sv, _e) :
-      vol_out_of_phase_valid(sv, _e)) : false;
-
+  return !DISK_BAD(sv->disk) ? (sv->header->phase == dir_phase(_e) ? vol_in_phase_valid(sv, _e) : vol_out_of_phase_valid(sv, _e)) :
+                               false;
 }
 
 inline bool
-dir_agg_valid(Vol *_d, Dir *_e) {
+dir_agg_valid(Vol *_d, Dir *_e)
+{
   if (!dir_ininterim(_e))
-    return _d->header->phase == dir_phase(_e) ? vol_in_phase_valid(_d, _e) :
-        vol_out_of_phase_agg_valid(_d, _e);
+    return _d->header->phase == dir_phase(_e) ? vol_in_phase_valid(_d, _e) : vol_out_of_phase_agg_valid(_d, _e);
   else {
     int idx = dir_get_index(_e);
-    if(good_interim_disks <= 0 || idx >= _d->num_interim_vols) return false;
+    if (good_interim_disks <= 0 || idx >= _d->num_interim_vols)
+      return false;
     InterimCacheVol *sv = &(_d->interim_vols[idx]);
-    return sv->header->phase == dir_phase(_e) ? vol_in_phase_valid(sv, _e) :
-        vol_out_of_phase_agg_valid(sv, _e);
+    return sv->header->phase == dir_phase(_e) ? vol_in_phase_valid(sv, _e) : vol_out_of_phase_agg_valid(sv, _e);
   }
 }
 inline bool
-dir_write_valid(Vol *_d, Dir *_e) {
+dir_write_valid(Vol *_d, Dir *_e)
+{
   if (!dir_ininterim(_e))
-    return _d->header->phase == dir_phase(_e) ? vol_in_phase_valid(_d, _e) :
-        vol_out_of_phase_write_valid(_d, _e);
+    return _d->header->phase == dir_phase(_e) ? vol_in_phase_valid(_d, _e) : vol_out_of_phase_write_valid(_d, _e);
   else {
     InterimCacheVol *sv = &(_d->interim_vols[dir_get_index(_e)]);
-    return sv->header->phase == dir_phase(_e) ? vol_in_phase_valid(sv, _e) :
-        vol_out_of_phase_write_valid(sv, _e);
+    return sv->header->phase == dir_phase(_e) ? vol_in_phase_valid(sv, _e) : vol_out_of_phase_write_valid(sv, _e);
   }
 }
 inline bool
-dir_agg_buf_valid(Vol *_d, Dir *_e) {
+dir_agg_buf_valid(Vol *_d, Dir *_e)
+{
   if (!dir_ininterim(_e))
     return _d->header->phase == dir_phase(_e) && vol_in_phase_agg_buf_valid(_d, _e);
   else {
@@ -934,7 +953,8 @@ dir_agg_buf_valid(Vol *_d, Dir *_e) {
 }
 
 inline bool
-dir_agg_buf_valid(InterimCacheVol *_d, Dir *_e) {
+dir_agg_buf_valid(InterimCacheVol *_d, Dir *_e)
+{
   return _d->header->phase == dir_phase(_e) && vol_in_phase_agg_buf_valid(_d, _e);
 }
 
