@@ -25,73 +25,67 @@
 #include "P_Cache.h"
 #include "I_Layout.h"
 
-#if HAVE_SYS_PARAM_H
-#include <sys/param.h>
+#if HAVE_LINUX_MAJOR_H
+#include <linux/major.h>
 #endif
 
-#if HAVE_SYS_DISK_H
-#include <sys/disk.h>
-#endif
-
-#if HAVE_SYS_DISKLABEL_H
-#include <sys/disklabel.h>
-#endif
-
-// Global
-Store theStore;
-
-int Store::getVolume(char* line) {
-  int v = 0;
-  if(!line) return 0;
-  char* str = strstr(line, vol_str);
-  char* vol_start = str;
-  if(!str) return 0;
-  while (*str && !ParseRules::is_digit(*str))
-    str++;
-  v = ink_atoi(str);
-
-  while (*str && ParseRules::is_digit(*str))
-    str++;
-  while(*str) {
-    *vol_start = *str;
-    vol_start++;
-    str++;
-  }
-  *vol_start = 0;
-  Debug("cache_init", "returning %d and '%s'", v, line);
-
-  if(v < 0) return 0;
-  return v;
-}
-
-
 //
 // Store
 //
-Ptr<ProxyMutex> tmp_p;
-Store::Store():n_disks(0), disk(NULL),
-#if TS_USE_INTERIM_CACHE == 1
-  n_interim_disks(0), interim_disk(NULL),
-#endif
-  vol_str("volume=")
+
+char const Store::VOLUME_KEY[] = "volume";
+char const Store::HASH_BASE_STRING_KEY[] = "id";
+
+static span_error_t
+make_span_error(int error)
 {
+  switch (error) {
+  case ENOENT:
+    return SPAN_ERROR_NOT_FOUND;
+  case EPERM: /* fallthru */
+  case EACCES:
+    return SPAN_ERROR_NO_ACCESS;
+  default:
+    return SPAN_ERROR_UNKNOWN;
+  }
 }
 
-int
-initialize_store()
+static const char *
+span_file_typename(mode_t st_mode)
+{
+  switch (st_mode & S_IFMT) {
+  case S_IFBLK:
+    return "block device";
+  case S_IFCHR:
+    return "character device";
+  case S_IFDIR:
+    return "directory";
+  case S_IFREG:
+    return "file";
+  default:
+    return "<unsupported>";
+  }
+}
+
+Ptr<ProxyMutex> tmp_p;
+Store::Store()
+  : n_disks(0), disk(NULL)
+#if TS_USE_INTERIM_CACHE == 1
+    ,
+    n_interim_disks(0), interim_disk(NULL)
+#endif
 {
-  return theStore.read_config()? -1 : 0;
 }
 
 void
-Store::add(Span * ds)
+Store::add(Span *ds)
 {
   extend(n_disks + 1);
   disk[n_disks - 1] = ds;
 }
 
 void
-Store::add(Store & s)
+Store::add(Store &s)
 {
   // assume on different disks
   for (unsigned i = 0; i < s.n_disks; i++) {
@@ -102,17 +96,16 @@ Store::add(Store & s)
 }
 
 
-
 // should be changed to handle offset in more general
 // case (where this is not a free of a "just" allocated
 // store
 void
-Store::free(Store & s)
+Store::free(Store &s)
 {
   for (unsigned i = 0; i < s.n_disks; i++) {
-    for (Span * sd = s.disk[i]; sd; sd = sd->link.next) {
+    for (Span *sd = s.disk[i]; sd; sd = sd->link.next) {
       for (unsigned j = 0; j < n_disks; j++)
-        for (Span * d = disk[j]; d; d = d->link.next)
+        for (Span *d = disk[j]; d; d = d->link.next)
           if (!strcmp(sd->pathname, d->pathname)) {
             if (sd->offset < d->offset)
               d->offset = sd->offset;
@@ -120,7 +113,8 @@ Store::free(Store & s)
             goto Lfound;
           }
       ink_release_assert(!"Store::free failed");
-    Lfound:;
+    Lfound:
+      ;
     }
   }
 }
@@ -128,7 +122,7 @@ Store::free(Store & s)
 void
 Store::sort()
 {
-  Span **vec = (Span **) alloca(sizeof(Span *) * n_disks);
+  Span **vec = (Span **)alloca(sizeof(Span *) * n_disks);
   memset(vec, 0, sizeof(Span *) * n_disks);
   for (unsigned i = 0; i < n_disks; i++) {
     vec[i] = disk[i];
@@ -139,7 +133,7 @@ Store::sort()
 
   unsigned n = 0;
   for (unsigned i = 0; i < n_disks; i++) {
-    for (Span * sd = vec[i]; sd; sd = vec[i]) {
+    for (Span *sd = vec[i]; sd; sd = vec[i]) {
       vec[i] = vec[i]->link.next;
       for (unsigned d = 0; d < n; d++) {
         if (sd->disk_id == disk[d]->disk_id) {
@@ -149,7 +143,8 @@ Store::sort()
         }
       }
       disk[n++] = sd;
-    Ldone:;
+    Ldone:
+      ;
     }
   }
   n_disks = n;
@@ -158,12 +153,11 @@ Store::sort()
 
   for (unsigned i = 0; i < n_disks; i++) {
   Lagain:
-    Span * prev = 0;
-    for (Span * sd = disk[i]; sd;) {
+    Span *prev = 0;
+    for (Span *sd = disk[i]; sd;) {
       Span *next = sd->link.next;
       if (next &&
-          ((strcmp(sd->pathname, next->pathname) < 0) ||
-           (!strcmp(sd->pathname, next->pathname) && sd->offset > next->offset))) {
+          ((strcmp(sd->pathname, next->pathname) < 0) || (!strcmp(sd->pathname, next->pathname) && sd->offset > next->offset))) {
         if (!prev) {
           disk[i] = next;
           sd->link.next = next->link.next;
@@ -183,7 +177,7 @@ Store::sort()
   // merge adjacent spans
 
   for (unsigned i = 0; i < n_disks; i++) {
-    for (Span * sd = disk[i]; sd;) {
+    for (Span *sd = disk[i]; sd;) {
       Span *next = sd->link.next;
       if (next && !strcmp(sd->pathname, next->pathname)) {
         if (!sd->file_pathname) {
@@ -204,8 +198,30 @@ Store::sort()
   }
 }
 
+const char *
+Span::errorstr(span_error_t serr)
+{
+  switch (serr) {
+  case SPAN_ERROR_OK:
+    return "no error";
+  case SPAN_ERROR_NOT_FOUND:
+    return "file not found";
+  case SPAN_ERROR_NO_ACCESS:
+    return "unable to access file";
+  case SPAN_ERROR_MISSING_SIZE:
+    return "missing size specification";
+  case SPAN_ERROR_UNSUPPORTED_DEVTYPE:
+    return "unsupported cache file type";
+  case SPAN_ERROR_MEDIA_PROBE:
+    return "failed to probe device geometry";
+  case SPAN_ERROR_UNKNOWN: /* fallthru */
+  default:
+    return "unknown error";
+  }
+}
+
 int
-Span::path(char *filename, int64_t * aoffset, char *buf, int buflen)
+Span::path(char *filename, int64_t *aoffset, char *buf, int buflen)
 {
   ink_assert(!aoffset);
   Span *ds = this;
@@ -221,6 +237,18 @@ Span::path(char *filename, int64_t * aoffset, char *buf, int buflen)
   return strlen(buf);
 }
 
+void
+Span::hash_base_string_set(char const *s)
+{
+  hash_base_string = s ? ats_strdup(s) : NULL;
+}
+
+void
+Span::volume_number_set(int n)
+{
+  forced_volume_num = n;
+}
+
 void
 Store::delete_all()
 {
@@ -240,15 +268,14 @@ Store::~Store()
 
 Span::~Span()
 {
-  ats_free(pathname);
   if (link.next)
     delete link.next;
 }
 
-inline int
-get_int64(int fd, int64_t & data)
+static int
+get_int64(int fd, int64_t &data)
 {
-  char buf[PATH_NAME_MAX + 1];
+  char buf[PATH_NAME_MAX];
   if (ink_file_fd_readline(fd, PATH_NAME_MAX, buf) <= 0)
     return (-1);
   // the above line will guarantee buf to be no longer than PATH_NAME_MAX
@@ -267,7 +294,7 @@ Store::remove(char *n)
 Lagain:
   for (unsigned i = 0; i < n_disks; i++) {
     Span *p = NULL;
-    for (Span * sd = disk[i]; sd; sd = sd->link.next) {
+    for (Span *sd = disk[i]; sd; sd = sd->link.next) {
       if (!strcmp(n, sd->pathname)) {
         found = true;
         if (p)
@@ -285,73 +312,83 @@ Lagain:
 }
 
 const char *
-Store::read_config(int fd)
+Store::read_config()
 {
   int n_dsstore = 0;
   int ln = 0;
+  int i = 0;
   const char *err = NULL;
   Span *sd = NULL, *cur = NULL;
   Span *ns;
+  ats_scoped_fd fd;
+  ats_scoped_str storage_path(RecConfigReadConfigPath("proxy.config.cache.storage_filename", "storage.config"));
 
-  // Get pathname if not checking file
-
+  Debug("cache_init", "Store::read_config, fd = -1, \"%s\"", (const char *)storage_path);
+  fd = ::open(storage_path, O_RDONLY);
   if (fd < 0) {
-    xptr<char> storage_path(RecConfigReadConfigPath("proxy.config.cache.storage_filename", "storage.config"));
-
-    Debug("cache_init", "Store::read_config, fd = -1, \"%s\"", (const char *)storage_path);
-    fd =::open(storage_path, O_RDONLY);
-    if (fd < 0) {
-      err = "error on open";
-      goto Lfail;
-    }
+    err = "error on open";
+    goto Lfail;
   }
+
   // For each line
 
-  char line[256];
-  while (ink_file_fd_readline(fd, sizeof(line) - 1, line) > 0) {
+  char line[1024];
+  int len;
+  while ((len = ink_file_fd_readline(fd, sizeof(line), line)) > 0) {
+    char const *path;
+    char const *seed = 0;
     // update lines
 
-    line[sizeof(line) - 1] = 0;
-    ln++;
+    ++ln;
+
+    // Because the SimpleTokenizer is a bit too simple, we have to normalize whitespace.
+    for (char *spot = line, *limit = line + len; spot < limit; ++spot)
+      if (ParseRules::is_space(*spot))
+        *spot = ' '; // force whitespace to literal space.
+
+    SimpleTokenizer tokens(line, ' ', SimpleTokenizer::OVERWRITE_INPUT_STRING);
 
     // skip comments and blank lines
-
-    if (*line == '#')
+    path = tokens.getNext();
+    if (0 == path || '#' == path[0])
       continue;
-    char *n = line;
-    n += strspn(n, " \t\n");
-    if (!*n)
-      continue;
-
-   int volume_id = getVolume(n);
 
     // parse
-    Debug("cache_init", "Store::read_config: \"%s\"", n);
+    Debug("cache_init", "Store::read_config: \"%s\"", path);
 
-    char *e = strpbrk(n, " \t\n");
-    int len = e ? e - n : strlen(n);
-    (void) len;
     int64_t size = -1;
-    while (e && *e && !ParseRules::is_digit(*e))
-      e++;
-    if (e && *e) {
-      if ((size = ink_atoi64(e)) <= 0) {
-        err = "error parsing size";
-        goto Lfail;
+    int volume_num = -1;
+    char const *e;
+    while (0 != (e = tokens.getNext())) {
+      if (ParseRules::is_digit(*e)) {
+        if ((size = ink_atoi64(e)) <= 0) {
+          err = "error parsing size";
+          goto Lfail;
+        }
+      } else if (0 == strncasecmp(HASH_BASE_STRING_KEY, e, sizeof(HASH_BASE_STRING_KEY) - 1)) {
+        e += sizeof(HASH_BASE_STRING_KEY) - 1;
+        if ('=' == *e)
+          ++e;
+        if (*e && !ParseRules::is_space(*e))
+          seed = e;
+      } else if (0 == strncasecmp(VOLUME_KEY, e, sizeof(VOLUME_KEY) - 1)) {
+        e += sizeof(VOLUME_KEY) - 1;
+        if ('=' == *e)
+          ++e;
+        if (!*e || !ParseRules::is_digit(*e) || 0 >= (volume_num = ink_atoi(e))) {
+          err = "error parsing volume number";
+          goto Lfail;
+        }
       }
     }
 
-    n[len] = 0;
-    char *pp = Layout::get()->relative(n);
+    char *pp = Layout::get()->relative(path);
     ns = new Span;
-    ns->vol_num = volume_id;
-    Debug("cache_init", "Store::read_config - ns = new Span; ns->init(\"%s\",%" PRId64 "), ns->vol_num=%d",
-      pp, size, ns->vol_num);
+    Debug("cache_init", "Store::read_config - ns = new Span; ns->init(\"%s\",%" PRId64 "), forced volume=%d%s%s", pp, size,
+          volume_num, seed ? " id=" : "", seed ? seed : "");
     if ((err = ns->init(pp, size))) {
-      char buf[4096];
-      snprintf(buf, sizeof(buf), "could not initialize storage \"%s\" [%s]", pp, err);
-      REC_SignalWarning(REC_SIGNAL_SYSTEM_ERROR, buf);
-      Debug("cache_init", "Store::read_config - %s", buf);
+      RecSignalWarning(REC_SIGNAL_SYSTEM_ERROR, "could not initialize storage \"%s\" [%s]", pp, err);
+      Debug("cache_init", "Store::read_config - could not initialize storage \"%s\" [%s]", pp, err);
       delete ns;
       ats_free(pp);
       continue;
@@ -359,6 +396,12 @@ Store::read_config(int fd)
     ats_free(pp);
     n_dsstore++;
 
+    // Set side values if present.
+    if (seed)
+      ns->hash_base_string_set(seed);
+    if (volume_num > 0)
+      ns->volume_number_set(volume_num);
+
     // new Span
     {
       Span *prev = cur;
@@ -370,32 +413,32 @@ Store::read_config(int fd)
     }
   }
 
-  ::close(fd);
   // count the number of disks
-
-  {
-    extend(n_dsstore);
-    cur = sd;
-    Span *next = cur;
-    int i = 0;
-    while (cur) {
-      next = cur->link.next;
-      cur->link.next = NULL;
-      disk[i++] = cur;
-      cur = next;
-    }
-    sort();
+  extend(n_dsstore);
+  cur = sd;
+  while (cur) {
+    Span *next = cur->link.next;
+    cur->link.next = NULL;
+    disk[i++] = cur;
+    cur = next;
   }
-
-Lfail:;
+  sd = 0; // these are all used.
+  sort();
   return NULL;
+
+Lfail:
+  // Do clean up.
+  if (sd)
+    delete sd;
+
   return err;
 }
 
 #if TS_USE_INTERIM_CACHE == 1
 const char *
-Store::read_interim_config() {
-  char p[PATH_NAME_MAX + 1];
+Store::read_interim_config()
+{
+  char p[PATH_NAME_MAX];
   Span *sd = NULL;
   Span *ns;
   int interim_store = 0;
@@ -411,11 +454,8 @@ Store::read_interim_config() {
     n[len] = '\0';
     ns = new Span;
     if ((err = ns->init(n, -1))) {
-      char buf[4096];
-      snprintf(buf, sizeof(buf), "could not initialize storage \"%s\" [%s]", n,
-          err);
-      REC_SignalWarning(REC_SIGNAL_SYSTEM_ERROR, buf);
-      Debug("cache_init", "Store::read_interim_config - %s", buf);
+      RecSignalWarning(REC_SIGNAL_SYSTEM_ERROR, "could not initialize storage \"%s\" [%s]", n, err);
+      Debug("cache_init", "Store::read_interim_config - could not initialize storage \"%s\" [%s]", n, err);
       delete ns;
       continue;
     }
@@ -425,7 +465,7 @@ Store::read_interim_config() {
   }
 
   n_interim_disks = interim_store;
-  interim_disk = (Span **) ats_malloc(interim_store * sizeof(Span *));
+  interim_disk = (Span **)ats_malloc(interim_store * sizeof(Span *));
   {
     int i = 0;
     while (sd) {
@@ -440,391 +480,156 @@ Store::read_interim_config() {
 #endif
 
 int
-Store::write_config_data(int fd)
+Store::write_config_data(int fd) const
 {
   for (unsigned i = 0; i < n_disks; i++)
-    for (Span * sd = disk[i]; sd; sd = sd->link.next) {
+    for (Span *sd = disk[i]; sd; sd = sd->link.next) {
       char buf[PATH_NAME_MAX + 64];
-      snprintf(buf, sizeof(buf), "%s %" PRId64 "\n", sd->pathname, (int64_t) sd->blocks * (int64_t) STORE_BLOCK_SIZE);
+      snprintf(buf, sizeof(buf), "%s %" PRId64 "\n", sd->pathname.get(), (int64_t)sd->blocks * (int64_t)STORE_BLOCK_SIZE);
       if (ink_file_fd_writestring(fd, buf) == -1)
         return (-1);
     }
   return 0;
 }
 
-#if defined(freebsd) || defined(darwin) || defined(openbsd)
-
 const char *
-Span::init(char *an, int64_t size)
+Span::init(const char *path, int64_t size)
 {
-  int devnum = 0;
-  const char *err = NULL;
-  int ret = 0;
+  struct stat sbuf;
+  struct statvfs vbuf;
+  span_error_t serr;
+  ink_device_geometry geometry;
 
-  is_mmapable_internal = true;
+  ats_scoped_fd fd(socketManager.open(path, O_RDONLY));
+  if (fd < 0) {
+    serr = make_span_error(errno);
+    Warning("unable to open '%s': %s", path, strerror(errno));
+    goto fail;
+  }
 
-  // handle symlinks
+  if (fstat(fd, &sbuf) == -1) {
+    serr = make_span_error(errno);
+    Warning("unable to stat '%s': %s (%d)", path, strerror(errno), errno);
+    goto fail;
+  }
 
-  char *n = NULL;
-  int n_len = 0;
-  char real_n[PATH_NAME_MAX];
+  if (fstatvfs(fd, &vbuf) == -1) {
+    serr = make_span_error(errno);
+    Warning("unable to statvfs '%s': %s (%d)", path, strerror(errno), errno);
+    goto fail;
+  }
 
-  if ((n_len = readlink(an, real_n, sizeof(real_n) - 1)) > 0) {
-    real_n[n_len] = 0;
-    if (*real_n != '/') {
-      char *rs = strrchr(an, '/');
-      int l = 2;
-      const char *ann = "./";
-
-      if (rs) {
-        ann = an;
-        l = (rs - an) + 1;
-      }
-      memmove(real_n + l, real_n, strlen(real_n) + 1);
-      memcpy(real_n, ann, l);
+  // Directories require an explicit size parameter. For device nodes and files, we use
+  // the existing size.
+  if (S_ISDIR(sbuf.st_mode)) {
+    if (size <= 0) {
+      Warning("cache %s '%s' requires a size > 0", span_file_typename(sbuf.st_mode), path);
+      serr = SPAN_ERROR_MISSING_SIZE;
+      goto fail;
     }
-    n = real_n;
-  } else {
-    n = an;
   }
 
-  // stat the file system
-
-  struct stat s;
-  if ((ret = stat(n, &s)) < 0) {
-    Warning("unable to stat '%s': %d %d, %s", n, ret, errno, strerror(errno));
-    return "error stat of file";
-  }
-
-  xfd fd(socketManager.open(n, O_RDONLY));
-  if (!fd) {
-    Warning("unable to open '%s': %s", n, strerror(errno));
-    return "unable to open";
-  }
-
-  struct statvfs fs;
-  if ((ret = fstatvfs(fd, &fs)) < 0) {
-    Warning("unable to statvfs '%s': %d %d, %s", n, ret, errno, strerror(errno));
-    return "unable to statvfs";
-  }
-
-  hw_sector_size = fs.f_bsize;
-  int64_t fsize = (int64_t) fs.f_blocks * (int64_t) fs.f_bsize;
-
-  switch ((s.st_mode & S_IFMT)) {
-
-  case S_IFBLK:{
-  case S_IFCHR:
-    // These IOCTLs are standard across the BSD family; Darwin has a different set though.
-#if defined(DIOCGMEDIASIZE) && defined(DIOCGSECTORSIZE)
-      if (ioctl(fd, DIOCGMEDIASIZE, &size) < 0) {
-        Warning("unable to get disk information for '%s': %s", n, strerror(errno));
-        err = "unable to get label information";
-        goto Lfail;
-      }
-      if (ioctl(fd, DIOCGSECTORSIZE, &hw_sector_size) < 0) {
-        Warning("unable to get disk information for '%s': %s", n, strerror(errno));
-        err = "unable to get label information";
-        goto Lfail;
-      }
-      devnum = s.st_rdev;
-      break;
-#else
-      Warning("unable to get disk information for '%s': %s", n, strerror(errno));
-      err = "no raw disk support on this platform";
-      goto Lfail;
-#endif
-    }
-  case S_IFDIR:
-  case S_IFREG:
-    if (size <= 0 || size > fsize) {
-      Warning("bad or missing size for '%s': size %" PRId64 " fsize %" PRId64 "", n, (int64_t) size, fsize);
-      err = "bad or missing size";
-      goto Lfail;
-    }
-    devnum = s.st_dev;
-    break;
-
-  default:
-    Warning("unknown file type '%s': %d", n, s.st_mode);
-    return "unknown file type";
-    break;
-  }
-
-  disk_id = devnum;
-
-  pathname = ats_strdup(an);
-  // igalic: blocks = size / hw_sector_size; was wrong TS-1707
-  // This code needs refactoring to unify the code-paths which are equal across platforms.
-  blocks = size / STORE_BLOCK_SIZE;
-  file_pathname = !((s.st_mode & S_IFMT) == S_IFDIR);
-
-  // This is so FreeBSD admins don't worry about our malicious code creating boot sector viruses:
-  if (((s.st_mode & S_IFMT) == S_IFBLK) || ((s.st_mode & S_IFMT) == S_IFCHR)) {
-    blocks--;
-    offset = 1;
-  }
-
-  Debug("cache_init", "Span::init - %s hw_sector_size = %d  size = %" PRId64 ", blocks = %" PRId64 ", disk_id = %d, file_pathname = %d", pathname, hw_sector_size, size, blocks, disk_id, file_pathname);
-
-Lfail:
-  return err;
-}
-
-#endif
-
-#if defined(solaris)
-
-const char *
-Span::init(char *filename, int64_t size)
-{
-  int devnum = 0;
-  const char *err = NULL;
-  int ret = 0;
-
-  //
-  // All file types on Solaris can be mmaped
-  //
-  is_mmapable_internal = true;
-
-  xfd fd(socketManager.open(filename, O_RDONLY));
-  if (!fd) {
-    Warning("unable to open '%s': %s", filename, strerror(errno));
-    return "unable to open";
-  }
-
-  // stat the file system
-  struct stat s;
-  if ((ret = fstat(fd, &s)) < 0) {
-    Warning("unable to fstat '%s': %d %d, %s", filename, ret, errno, strerror(errno));
-    err = "unable to fstat";
-    goto Lfail;
-  }
-
-
-  switch ((s.st_mode & S_IFMT)) {
+  // Should regular files use the IO size (vbuf.f_bsize), or the
+  // fundamental filesystem block size (vbuf.f_frsize)? That depends
+  // on whether we are using that block size for performance or for
+  // reliability.
 
+  switch (sbuf.st_mode & S_IFMT) {
   case S_IFBLK:
   case S_IFCHR:
-    devnum = s.st_rdev;
-    // maybe we should use lseek(fd, 0, SEEK_END) here (it is portable)
-    size = (int64_t) s.st_size;
-    hw_sector_size = s.st_blksize;
-    break;
-  case S_IFDIR:
-  case S_IFREG:
-    int64_t fsize;
-    struct statvfs fs;
-    if ((ret = fstatvfs(fd, &fs)) < 0) {
-      Warning("unable to statvfs '%s': %d %d, %s", filename, ret, errno, strerror(errno));
-      err = "unable to statvfs";
-      goto Lfail;
-    }
-
-    hw_sector_size = fs.f_bsize;
-    fsize = (int64_t) fs.f_blocks * (int64_t) hw_sector_size;
-
-    if (size <= 0 || size > fsize) {
-      Warning("bad or missing size for '%s': size %" PRId64 " fsize %" PRId64 "", filename, (int64_t) size, fsize);
-      err = "bad or missing size";
-      goto Lfail;
-    }
-
-    devnum = s.st_dev;
-    break;
-
-  default:
-    Warning("unknown file type '%s': %" PRId64 "", filename, (int64_t)(s.st_mode));
-    err = "unknown file type";
-    goto Lfail;
-  }
-
-  // estimate the disk SOLARIS specific
-  if ((devnum >> 16) == 0x80) {
-    disk_id = (devnum >> 3) & 0x3F;
-  } else {
-    disk_id = devnum;
-  }
-
-  pathname = ats_strdup(filename);
-  // is this right Seems like this should be size / hw_sector_size
-  // igalic: No. See TS-1707
-  blocks = size / STORE_BLOCK_SIZE;
-  file_pathname = !((s.st_mode & S_IFMT) == S_IFDIR);
-
-  Debug("cache_init", "Span::init - %s hw_sector_size = %d  size = %" PRId64 ", blocks = %" PRId64 ", disk_id = %d, file_pathname = %d", filename, hw_sector_size, size, blocks, disk_id, file_pathname);
-
-Lfail:
-  return err;
-}
-#endif
 
 #if defined(linux)
-#include <unistd.h>             /* for close() */
-#include <sys/ioctl.h>
-#include <linux/hdreg.h>        /* for struct hd_geometry */
-#include <linux/fs.h>           /* for BLKGETSIZE.  sys/mount.h is another candidate */
-
-
-const char *
-Span::init(char *filename, int64_t size)
-{
-  int devnum = 0, arg = 0;
-  int ret = 0, is_disk = 0;
-  u_int64_t heads, sectors, cylinders, adjusted_sec;
-  xfd fd;
-
-  /* Fetch file type */
-  struct stat stat_buf;
-  Debug("cache_init", "Span::init(\"%s\",%" PRId64 ")", filename, size);
-  if ((ret = stat(filename, &stat_buf)) < 0) {
-    Warning("unable to stat '%s': %d %d, %s", filename, ret, errno, strerror(errno));
-    return "cannot stat file";
-  }
-  switch (stat_buf.st_mode & S_IFMT) {
-  case S_IFBLK:
-  case S_IFCHR:
-    devnum = stat_buf.st_rdev;
-    Debug("cache_init", "Span::init - %s - devnum = %d",
-          ((stat_buf.st_mode & S_IFMT) == S_IFBLK) ? "S_IFBLK" : "S_IFCHR", devnum);
-    break;
-  case S_IFDIR:
-    devnum = stat_buf.st_dev;
-    file_pathname = 0;
-    Debug("cache_init", "Span::init - S_IFDIR - devnum = %d", devnum);
-    break;
-  case S_IFREG:
-    devnum = stat_buf.st_dev;
-    file_pathname = 1;
-    size = stat_buf.st_size;
-    Debug("cache_init", "Span::init - S_IFREG - devnum = %d", devnum);
-    break;
-  default:
-    break;
-  }
-
-  fd = socketManager.open(filename, O_RDONLY);
-  if (!fd) {
-    Warning("unable to open '%s': %s", filename, strerror(errno));
-    return "unable to open";
-  }
-  Debug("cache_init", "Span::init - socketManager.open(\"%s\", O_RDONLY) = %d", filename, (int)fd);
-
-  adjusted_sec = 1;
-#ifdef BLKPBSZGET
-  if (ioctl(fd, BLKPBSZGET, &arg) == 0)
-#else
-  if (ioctl(fd, BLKSSZGET, &arg) == 0)
-#endif
-  {
-    hw_sector_size = arg;
-    is_disk = 1;
-    adjusted_sec = hw_sector_size / 512;
-    Debug("cache_init", "Span::init - %s hw_sector_size=%d is_disk=%d adjusted_sec=%" PRId64,
-          filename, hw_sector_size, is_disk, adjusted_sec);
-  }
-
-  alignment = 0;
-#ifdef BLKALIGNOFF
-  if (ioctl(fd, BLKALIGNOFF, &arg) == 0) {
-    alignment = arg;
-    Debug("cache_init", "Span::init - %s alignment = %d", filename, alignment);
-  }
+    if (major(sbuf.st_rdev) == RAW_MAJOR && minor(sbuf.st_rdev) == 0) {
+      Warning("cache %s '%s' is the raw device control interface", span_file_typename(sbuf.st_mode), path);
+      serr = SPAN_ERROR_UNSUPPORTED_DEVTYPE;
+      goto fail;
+    }
 #endif
 
-  if (is_disk) {
-    u_int32_t ioctl_sectors = 0;
-    u_int64_t ioctl_bytes = 0;
-    u_int64_t physsectors = 0;
+    if (!ink_file_get_geometry(fd, geometry)) {
+      serr = make_span_error(errno);
 
-    /* Disks cannot be mmapped */
-    is_mmapable_internal = false;
-
-    if (!ioctl(fd, BLKGETSIZE64, &ioctl_bytes)) {
-      heads = 1;
-      cylinders = 1;
-      physsectors = ioctl_bytes / hw_sector_size;
-      sectors = physsectors;
-    } else if (!ioctl(fd, BLKGETSIZE, &ioctl_sectors)) {
-      heads = 1;
-      cylinders = 1;
-      physsectors = ioctl_sectors;
-      sectors = physsectors / adjusted_sec;
-    } else {
-      struct hd_geometry geometry;
-      if (!ioctl(fd, HDIO_GETGEO, &geometry)) {
-        heads = geometry.heads;
-        sectors = geometry.sectors;
-        cylinders = geometry.cylinders;
-        cylinders /= adjusted_sec;      /* do not round up */
+      if (errno == ENOTSUP) {
+        Warning("failed to query disk geometry for '%s', no raw device support", path);
       } else {
-        /* Almost certainly something other than a disk device. */
-        Warning("unable to get geometry '%s': %d %s", filename, errno, strerror(errno));
-        return ("unable to get geometry");
+        Warning("failed to query disk geometry for '%s', %s (%d)", path, strerror(errno), errno);
+      }
+
+      goto fail;
+    }
+
+    this->disk_id[0] = 0;
+    this->disk_id[1] = sbuf.st_rdev;
+    this->file_pathname = true;
+    this->hw_sector_size = geometry.blocksz;
+    this->alignment = geometry.alignsz;
+    this->blocks = geometry.totalsz / STORE_BLOCK_SIZE;
+
+    break;
+
+  case S_IFDIR:
+    if ((int64_t)(vbuf.f_frsize * vbuf.f_bavail) < size) {
+      Warning("not enough free space for cache %s '%s'", span_file_typename(sbuf.st_mode), path);
+      // Just warn for now; let the cache open fail later.
+    }
+
+    // The cache initialization code in Cache.cc takes care of creating the actual cache file, naming it and making
+    // it the right size based on the "file_pathname" flag. That's something that we should clean up in the future.
+    this->file_pathname = false;
+
+    this->disk_id[0] = sbuf.st_dev;
+    this->disk_id[1] = sbuf.st_ino;
+    this->hw_sector_size = vbuf.f_bsize;
+    this->alignment = 0;
+    this->blocks = size / STORE_BLOCK_SIZE;
+    break;
+
+  case S_IFREG:
+    if (size > 0 && sbuf.st_size < size) {
+      int64_t needed = size - sbuf.st_size;
+      if ((int64_t)(vbuf.f_frsize * vbuf.f_bavail) < needed) {
+        Warning("not enough free space for cache %s '%s'", span_file_typename(sbuf.st_mode), path);
+        // Just warn for now; let the cache open fail later.
       }
     }
 
-    blocks = heads * sectors * cylinders;
+    this->disk_id[0] = sbuf.st_dev;
+    this->disk_id[1] = sbuf.st_ino;
+    this->file_pathname = true;
+    this->hw_sector_size = vbuf.f_bsize;
+    this->alignment = 0;
+    this->blocks = sbuf.st_size / STORE_BLOCK_SIZE;
 
-    if (size > 0 && blocks * hw_sector_size != size) {
-      Warning("Warning: you specified a size of %" PRId64 " for %s,\n", size, filename);
-      Warning("but the device size is %" PRId64 ". Using minimum of the two.\n", (int64_t)blocks * (int64_t)hw_sector_size);
-      if ((int64_t)blocks * (int64_t)hw_sector_size < size)
-        size = (int64_t)blocks * (int64_t)hw_sector_size;
-    } else {
-      size = (int64_t)blocks * (int64_t)hw_sector_size;
-    }
+    break;
 
-    /* I don't know why I'm redefining blocks to be something that is quite
-     * possibly something other than the actual number of blocks, but the
-     * code for other arches seems to.  Revisit this, perhaps. */
-    // igalic: No. See TS-1707
-    blocks = size / STORE_BLOCK_SIZE;
-
-    Debug("cache_init", "Span::init physical sectors %" PRId64 " total size %" PRId64 " geometry size %" PRId64 " store blocks %" PRId64 "",
-          physsectors, hw_sector_size * physsectors, size, blocks);
-
-    pathname = ats_strdup(filename);
-    file_pathname = 1;
-  } else {
-    Debug("cache_init", "Span::init - is_disk = %d, raw device = %s", is_disk, (major(devnum) == 162) ? "yes" : "no");
-    if (major(devnum) == 162) {
-      /* Oh, a raw device, how cute. */
-
-      if (minor(devnum) == 0)
-        return "The raw device control file (usually /dev/raw; major 162, minor 0) is not a valid cache location.\n";
-
-      is_disk = 1;
-      is_mmapable_internal = false;     /* I -think- */
-      file_pathname = 1;
-      pathname = ats_strdup(filename);
-      isRaw = 1;
-
-      if (size <= 0)
-        return "When using raw devices for cache storage, you must specify a size\n";
-    } else {
-      /* Files can be mmapped */
-      is_mmapable_internal = true;
-
-      /* The code for other arches seems to want to dereference symlinks, but I
-       * don't particularly understand that behaviour, so I'll just ignore it.
-       * :) */
-
-      pathname = ats_strdup(filename);
-      if (!file_pathname)
-        if (size <= 0)
-          return "When using directories for cache storage, you must specify a size\n";
-      Debug("cache_init", "Span::init - mapped file \"%s\", %" PRId64 "", pathname, size);
-    }
-    blocks = size / STORE_BLOCK_SIZE;
+  default:
+    serr = SPAN_ERROR_UNSUPPORTED_DEVTYPE;
+    goto fail;
   }
 
-  disk_id = devnum;
+  // The actual size of a span always trumps the configured size.
+  if (size > 0 && this->size() != size) {
+    int64_t newsz = MIN(size, this->size());
+
+    Note("cache %s '%s' is %" PRId64 " bytes, but the configured size is %" PRId64 " bytes, using the minimum",
+         span_file_typename(sbuf.st_mode), path, this->size(), size);
+
+    this->blocks = newsz / STORE_BLOCK_SIZE;
+  }
+
+  // A directory span means we will end up with a file, otherwise, we get what we asked for.
+  this->set_mmapable(ink_file_is_mmappable(S_ISDIR(sbuf.st_mode) ? (mode_t)S_IFREG : sbuf.st_mode));
+  this->pathname = ats_strdup(path);
+
+  Debug("cache_init", "initialized span '%s'", this->pathname.get());
+  Debug("cache_init", "hw_sector_size=%d, size=%" PRId64 ", blocks=%" PRId64 ", disk_id=%" PRId64 "/%" PRId64 ", file_pathname=%d",
+        this->hw_sector_size, this->size(), this->blocks, this->disk_id[0], this->disk_id[1], this->file_pathname);
 
   return NULL;
-}
-#endif
 
+fail:
+  return Span::errorstr(serr);
+}
 
 
 void
@@ -839,23 +644,20 @@ Store::normalize()
 }
 
 static unsigned int
-try_alloc(Store & target, Span * source, unsigned int start_blocks, bool one_only = false)
+try_alloc(Store &target, Span *source, unsigned int start_blocks, bool one_only = false)
 {
   unsigned int blocks = start_blocks;
   Span *ds = NULL;
   while (source && blocks) {
     if (source->blocks) {
-      unsigned int a;           // allocated
+      unsigned int a; // allocated
       if (blocks > source->blocks)
         a = source->blocks;
       else
         a = blocks;
       Span *d = new Span(*source);
 
-      d->pathname = ats_strdup(source->pathname);
       d->blocks = a;
-      d->file_pathname = source->file_pathname;
-      d->offset = source->offset;
       d->link.next = ds;
 
       if (d->file_pathname)
@@ -874,7 +676,7 @@ try_alloc(Store & target, Span * source, unsigned int start_blocks, bool one_onl
 }
 
 void
-Store::spread_alloc(Store & s, unsigned int blocks, bool mmapable)
+Store::spread_alloc(Store &s, unsigned int blocks, bool mmapable)
 {
   //
   // Count the eligable disks..
@@ -897,7 +699,7 @@ Store::spread_alloc(Store & s, unsigned int blocks, bool mmapable)
 
   int disks_left = spread_over;
 
-  for (unsigned i = 0; blocks && i < n_disks; i++) {
+  for (unsigned i = 0; blocks && disks_left && i < n_disks; i++) {
     if (!(mmapable && !disk[i]->is_mmapable())) {
       unsigned int target = blocks / disks_left;
       if (blocks - target > total_blocks(i + 1))
@@ -909,13 +711,13 @@ Store::spread_alloc(Store & s, unsigned int blocks, bool mmapable)
 }
 
 void
-Store::try_realloc(Store & s, Store & diff)
+Store::try_realloc(Store &s, Store &diff)
 {
   for (unsigned i = 0; i < s.n_disks; i++) {
     Span *prev = 0;
-    for (Span * sd = s.disk[i]; sd;) {
+    for (Span *sd = s.disk[i]; sd;) {
       for (unsigned j = 0; j < n_disks; j++)
-        for (Span * d = disk[j]; d; d = d->link.next)
+        for (Span *d = disk[j]; d; d = d->link.next)
           if (!strcmp(sd->pathname, d->pathname)) {
             if (sd->offset >= d->offset && (sd->end() <= d->end())) {
               if (!sd->file_pathname || (sd->end() == d->end())) {
@@ -927,7 +729,6 @@ Store::try_realloc(Store & s, Store & diff)
                 goto Lfound;
               } else {
                 Span *x = new Span(*d);
-                x->pathname = ats_strdup(x->pathname);
                 // d will be the first vol
                 d->blocks = sd->offset - d->offset;
                 d->link.next = x;
@@ -949,7 +750,8 @@ Store::try_realloc(Store & s, Store & diff)
         sd = prev ? prev->link.next : s.disk[i];
         continue;
       }
-    Lfound:;
+    Lfound:
+      ;
       prev = sd;
       sd = sd->link.next;
     }
@@ -963,7 +765,7 @@ Store::try_realloc(Store & s, Store & diff)
 // Stupid grab first availabled space allocator
 //
 void
-Store::alloc(Store & s, unsigned int blocks, bool one_only, bool mmapable)
+Store::alloc(Store &s, unsigned int blocks, bool one_only, bool mmapable)
 {
   unsigned int oblocks = blocks;
   for (unsigned i = 0; blocks && i < n_disks; i++) {
@@ -976,11 +778,11 @@ Store::alloc(Store & s, unsigned int blocks, bool one_only, bool mmapable)
 }
 
 int
-Span::write(int fd)
+Span::write(int fd) const
 {
   char buf[32];
 
-  if (ink_file_fd_writestring(fd, (char *) (pathname ? pathname : ")")) == -1)
+  if (ink_file_fd_writestring(fd, (pathname ? pathname.get() : ")")) == -1)
     return (-1);
   if (ink_file_fd_writestring(fd, "\n") == -1)
     return (-1);
@@ -997,7 +799,7 @@ Span::write(int fd)
   if (ink_file_fd_writestring(fd, buf) == -1)
     return (-1);
 
-  snprintf(buf, sizeof(buf), "%d\n", (int) is_mmapable());
+  snprintf(buf, sizeof(buf), "%d\n", (int)is_mmapable());
   if (ink_file_fd_writestring(fd, buf) == -1)
     return (-1);
 
@@ -1005,7 +807,7 @@ Span::write(int fd)
 }
 
 int
-Store::write(int fd, char *name)
+Store::write(int fd, const char *name) const
 {
   char buf[32];
 
@@ -1040,7 +842,7 @@ Store::write(int fd, char *name)
 int
 Span::read(int fd)
 {
-  char buf[PATH_NAME_MAX + 1], p[PATH_NAME_MAX + 1];
+  char buf[PATH_NAME_MAX], p[PATH_NAME_MAX];
 
   if (ink_file_fd_readline(fd, PATH_NAME_MAX, buf) <= 0)
     return (-1);
@@ -1086,8 +888,8 @@ int
 Store::read(int fd, char *aname)
 {
   char *name = aname;
-  char tname[PATH_NAME_MAX + 1];
-  char buf[PATH_NAME_MAX + 1];
+  char tname[PATH_NAME_MAX];
+  char buf[PATH_NAME_MAX];
   if (!aname)
     name = tname;
 
@@ -1148,14 +950,13 @@ Span *
 Span::dup()
 {
   Span *ds = new Span(*this);
-  ds->pathname = ats_strdup(pathname);
-  if (ds->link.next)
-    ds->link.next = ds->link.next->dup();
+  if (this->link.next)
+    ds->link.next = this->link.next->dup();
   return ds;
 }
 
 void
-Store::dup(Store & s)
+Store::dup(Store &s)
 {
   s.n_disks = n_disks;
   s.disk = (Span **)ats_malloc(sizeof(Span *) * n_disks);
@@ -1171,15 +972,15 @@ Store::clear(char *filename, bool clear_dirs)
   memset(z, 0, STORE_BLOCK_SIZE);
   for (unsigned i = 0; i < n_disks; i++) {
     Span *ds = disk[i];
-    for (int j = 0; j < disk[i]->paths(); j++) {
-      char path[PATH_NAME_MAX + 1];
+    for (unsigned j = 0; j < disk[i]->paths(); j++) {
+      char path[PATH_NAME_MAX];
       Span *d = ds->nth(j);
       if (!clear_dirs && !d->file_pathname)
         continue;
       int r = d->path(filename, NULL, path, PATH_NAME_MAX);
       if (r < 0)
         return -1;
-      int fd =::open(path, O_RDWR | O_CREAT, 0644);
+      int fd = ::open(path, O_RDWR | O_CREAT, 0644);
       if (fd < 0)
         return -1;
       for (int b = 0; d->blocks; b++)
