@@ -35,7 +35,7 @@
 // scheduling only occurs after they move into the data_bucket.
 //
 void
-cluster_schedule(ClusterHandler * ch, ClusterVConnection * vc, ClusterVConnState * ns)
+cluster_schedule(ClusterHandler *ch, ClusterVConnection *vc, ClusterVConnState *ns)
 {
   //
   // actually schedule into new bucket
@@ -52,7 +52,7 @@ cluster_schedule(ClusterHandler * ch, ClusterVConnection * vc, ClusterVConnState
 }
 
 void
-cluster_reschedule_offset(ClusterHandler * ch, ClusterVConnection * vc, ClusterVConnState * ns, int offset)
+cluster_reschedule_offset(ClusterHandler *ch, ClusterVConnection *vc, ClusterVConnState *ns, int offset)
 {
   if (ns == &vc->read) {
     if (vc->read.queue)
@@ -64,27 +64,6 @@ cluster_reschedule_offset(ClusterHandler * ch, ClusterVConnection * vc, ClusterV
     ClusterVC_enqueue_write(ch->write_vcs[(ch->cur_vcs + offset) % CLUSTER_BUCKETS], vc);
   }
 }
-
-//
-//  iov_memcpy() -- struct iov based memcpy()
-//
-int
-iov_memcpy(IOVec * iov, int n_iov, int did, char *bb_arg)
-{
-  char *bb = bb_arg;
-  for (int i = 0; i < n_iov; i++) {
-    int len = iov[i].iov_len;
-    did -= len;
-    if (did < 0) {
-      // fprintf(stderr,"iov_memcpy %X %d\n",iov[i].iov_base+(len+did),-did);
-      memcpy(bb, (char *) iov[i].iov_base + (len + did), -did);
-      bb += -did;
-      did = 0;
-    }
-  }
-  return bb - bb_arg;
-}
-
 /*************************************************************************/
 // ClusterVCToken member functions (Public Class)
 /*************************************************************************/
@@ -100,7 +79,7 @@ ClusterVCToken::alloc()
 #else
   ip_created = this_cluster_machine()->ip;
 #endif
-  sequence_number = ink_atomic_increment((int *) &cluster_sequence_number, 1);
+  sequence_number = ink_atomic_increment((int *)&cluster_sequence_number, 1);
 }
 
 ///////////////////////////////////////////
@@ -108,7 +87,7 @@ ClusterVCToken::alloc()
 ///////////////////////////////////////////
 
 IOBufferBlock *
-clone_IOBufferBlockList(IOBufferBlock * b, int start_off, int n, IOBufferBlock ** b_tail)
+clone_IOBufferBlockList(IOBufferBlock *b, int start_off, int n, IOBufferBlock **b_tail)
 {
   ////////////////////////////////////////////////////////////////
   // Create a clone list of IOBufferBlock(s) where the sum
@@ -133,7 +112,6 @@ clone_IOBufferBlockList(IOBufferBlock * b, int start_off, int n, IOBufferBlock *
       bclone->next = bsrc->clone();
       bclone = bclone->next;
     } else {
-
       // Skip bytes already processed
       if (bytes_to_skip) {
         bytes_to_skip -= bsrc->read_avail();
@@ -170,7 +148,7 @@ clone_IOBufferBlockList(IOBufferBlock * b, int start_off, int n, IOBufferBlock *
 }
 
 IOBufferBlock *
-consume_IOBufferBlockList(IOBufferBlock * b, int64_t n)
+consume_IOBufferBlockList(IOBufferBlock *b, int64_t n)
 {
   IOBufferBlock *b_remainder = 0;
   int64_t nbytes = n;
@@ -181,8 +159,8 @@ consume_IOBufferBlockList(IOBufferBlock * b, int64_t n)
       if (nbytes < 0) {
         // Consumed a partial block, clone remainder
         b_remainder = b->clone();
-        b->fill(nbytes);        // make read_avail match nbytes
-        b_remainder->consume(b->read_avail());  // clone for remaining bytes
+        b->fill(nbytes);                       // make read_avail match nbytes
+        b_remainder->consume(b->read_avail()); // clone for remaining bytes
         b_remainder->next = b->next;
         b->next = 0;
         nbytes = 0;
@@ -198,13 +176,14 @@ consume_IOBufferBlockList(IOBufferBlock * b, int64_t n)
     }
   }
   ink_release_assert(nbytes == 0);
-  return b_remainder;           // return remaining blocks
+  return b_remainder; // return remaining blocks
 }
 
 int64_t
-bytes_IOBufferBlockList(IOBufferBlock * b, int64_t read_avail_bytes)
+bytes_IOBufferBlockList(IOBufferBlock *b, int64_t read_avail_bytes)
 {
-  int64_t n = 0;;
+  int64_t n = 0;
+  ;
 
   while (b) {
     if (read_avail_bytes) {
@@ -226,19 +205,19 @@ bytes_IOBufferBlockList(IOBufferBlock * b, int64_t read_avail_bytes)
 // Test code which mimic the network slowdown
 //
 int
-partial_readv(int fd, IOVec * iov, int n_iov, int seq)
+partial_readv(int fd, IOVec *iov, int n_iov, int seq)
 {
   IOVec tiov[16];
   for (int i = 0; i < n_iov; i++)
     tiov[i] = iov[i];
   int tn_iov = n_iov;
   int rnd = seq;
-  int element = rand_r((unsigned int *) &rnd);
+  int element = rand_r((unsigned int *)&rnd);
   element = element % n_iov;
-  int byte = rand_r((unsigned int *) &rnd);
+  int byte = rand_r((unsigned int *)&rnd);
   byte = byte % iov[element].iov_len;
-  int stop = rand_r((unsigned int *) &rnd);
-  if (!(stop % 3)) {            // 33% chance
+  int stop = rand_r((unsigned int *)&rnd);
+  if (!(stop % 3)) { // 33% chance
     tn_iov = element + 1;
     tiov[element].iov_len = byte;
     if (!byte)
@@ -258,32 +237,32 @@ partial_readv(int fd, IOVec * iov, int n_iov, int seq)
 // Test code which mimic the network backing up (too little buffering)
 //
 int
-partial_writev(int fd, IOVec * iov, int n_iov, int seq)
+partial_writev(int fd, IOVec *iov, int n_iov, int seq)
 {
   int rnd = seq;
   int sum = 0;
   int i = 0;
-    for (i = 0; i < n_iov; i++) {
-      int l = iov[i].iov_len;
-      int r = rand_r((unsigned int *) &rnd);
-      if ((r >> 4) & 1) {
-        l = ((unsigned int) rand_r((unsigned int *) &rnd)) % iov[i].iov_len;
-        if (!l) {
-          l = iov[i].iov_len;
-        }
-      }
-      ink_assert(l <= iov[i].iov_len);
-      fprintf(stderr, "writing %d: [%d] &%X %d of %d\n", seq, i, iov[i].iov_base, l, iov[i].iov_len);
-      int res = socketManager.write(fd, iov[i].iov_base, l);
-      if (res < 0) {
-        return res;
-      }
-      sum += res;
-      if (res != iov[i].iov_len) {
-        return sum;
+  for (i = 0; i < n_iov; i++) {
+    int l = iov[i].iov_len;
+    int r = rand_r((unsigned int *)&rnd);
+    if ((r >> 4) & 1) {
+      l = ((unsigned int)rand_r((unsigned int *)&rnd)) % iov[i].iov_len;
+      if (!l) {
+        l = iov[i].iov_len;
       }
     }
-    return sum;
+    ink_assert(l <= iov[i].iov_len);
+    fprintf(stderr, "writing %d: [%d] &%X %d of %d\n", seq, i, iov[i].iov_base, l, iov[i].iov_len);
+    int res = socketManager.write(fd, iov[i].iov_base, l);
+    if (res < 0) {
+      return res;
+    }
+    sum += res;
+    if (res != iov[i].iov_len) {
+      return sum;
+    }
+  }
+  return sum;
 }
 #endif // TEST_PARTIAL_WRITES
 
@@ -337,9 +316,9 @@ dump_time_buckets()
 #endif // ENABLE_TIME_TRACE
 }
 
-GlobalClusterPeriodicEvent::GlobalClusterPeriodicEvent():Continuation(new_ProxyMutex())
+GlobalClusterPeriodicEvent::GlobalClusterPeriodicEvent() : Continuation(new_ProxyMutex())
 {
-  SET_HANDLER((GClusterPEHandler) & GlobalClusterPeriodicEvent::calloutEvent);
+  SET_HANDLER((GClusterPEHandler)&GlobalClusterPeriodicEvent::calloutEvent);
 }
 
 GlobalClusterPeriodicEvent::~GlobalClusterPeriodicEvent()
