@@ -32,7 +32,7 @@ ClassAllocator<ClusterVConnection> clusterVCAllocator("clusterVCAllocator");
 ClassAllocator<ByteBankDescriptor> byteBankAllocator("byteBankAllocator");
 
 ByteBankDescriptor *
-ByteBankDescriptor::ByteBankDescriptor_alloc(IOBufferBlock * iob)
+ByteBankDescriptor::ByteBankDescriptor_alloc(IOBufferBlock *iob)
 {
   ByteBankDescriptor *b = byteBankAllocator.alloc();
   b->block = iob;
@@ -40,14 +40,14 @@ ByteBankDescriptor::ByteBankDescriptor_alloc(IOBufferBlock * iob)
 }
 
 void
-ByteBankDescriptor::ByteBankDescriptor_free(ByteBankDescriptor * b)
+ByteBankDescriptor::ByteBankDescriptor_free(ByteBankDescriptor *b)
 {
   b->block = 0;
   byteBankAllocator.free(b);
 }
 
 void
-clusterVCAllocator_free(ClusterVConnection * vc)
+clusterVCAllocator_free(ClusterVConnection *vc)
 {
   vc->mutex = 0;
   vc->action_ = 0;
@@ -59,22 +59,21 @@ clusterVCAllocator_free(ClusterVConnection * vc)
   clusterVCAllocator.free(vc);
 }
 
-ClusterVConnState::ClusterVConnState():enabled(0), priority(1), vio(VIO::NONE), queue(0), ifd(-1), delay_timeout(NULL)
+ClusterVConnState::ClusterVConnState() : enabled(0), priority(1), vio(VIO::NONE), queue(0), ifd(-1), delay_timeout(NULL)
 {
 }
 
-ClusterVConnectionBase::ClusterVConnectionBase():
-thread(0), closed(0), inactivity_timeout_in(0), active_timeout_in(0), inactivity_timeout(NULL), active_timeout(NULL)
+ClusterVConnectionBase::ClusterVConnectionBase()
+  : thread(0), closed(0), inactivity_timeout_in(0), active_timeout_in(0), inactivity_timeout(NULL), active_timeout(NULL)
 {
 }
 
 #ifdef DEBUG
-int
-  ClusterVConnectionBase::enable_debug_trace = 0;
+int ClusterVConnectionBase::enable_debug_trace = 0;
 #endif
 
 VIO *
-ClusterVConnectionBase::do_io_read(Continuation * acont, int64_t anbytes, MIOBuffer * abuffer)
+ClusterVConnectionBase::do_io_read(Continuation *acont, int64_t anbytes, MIOBuffer *abuffer)
 {
   ink_assert(!closed);
   read.vio.buffer.writer_for(abuffer);
@@ -82,10 +81,10 @@ ClusterVConnectionBase::do_io_read(Continuation * acont, int64_t anbytes, MIOBuf
   read.vio.set_continuation(acont);
   read.vio.nbytes = anbytes;
   read.vio.ndone = 0;
-  read.vio.vc_server = (VConnection *) this;
+  read.vio.vc_server = (VConnection *)this;
   read.enabled = 1;
 
-  ClusterVConnection *cvc = (ClusterVConnection *) this;
+  ClusterVConnection *cvc = (ClusterVConnection *)this;
   Debug("cluster_vc_xfer", "do_io_read [%s] chan %d", "", cvc->channel);
   return &read.vio;
 }
@@ -119,7 +118,7 @@ ClusterVConnection::get_single_data(void ** /* ptr ATS_UNUSED */, int * /* len A
 }
 
 VIO *
-ClusterVConnectionBase::do_io_write(Continuation * acont, int64_t anbytes, IOBufferReader * abuffer, bool owner)
+ClusterVConnectionBase::do_io_write(Continuation *acont, int64_t anbytes, IOBufferReader *abuffer, bool owner)
 {
   ink_assert(!closed);
   ink_assert(!owner);
@@ -128,7 +127,7 @@ ClusterVConnectionBase::do_io_write(Continuation * acont, int64_t anbytes, IOBuf
   write.vio.set_continuation(acont);
   write.vio.nbytes = anbytes;
   write.vio.ndone = 0;
-  write.vio.vc_server = (VConnection *) this;
+  write.vio.vc_server = (VConnection *)this;
   write.enabled = 1;
 
   return &write.vio;
@@ -162,7 +161,7 @@ ClusterVConnection::reenable(VIO *vio)
 }
 
 void
-ClusterVConnectionBase::reenable(VIO * vio)
+ClusterVConnectionBase::reenable(VIO *vio)
 {
   ink_assert(!closed);
   if (vio == &read.vio) {
@@ -183,45 +182,23 @@ ClusterVConnectionBase::reenable(VIO * vio)
 }
 
 void
-ClusterVConnectionBase::reenable_re(VIO * vio)
+ClusterVConnectionBase::reenable_re(VIO *vio)
 {
   reenable(vio);
 }
 
 ClusterVConnection::ClusterVConnection(int is_new_connect_read)
-  :  ch(NULL),
-     new_connect_read(is_new_connect_read),
-     remote_free(0),
-     last_local_free(0),
-     channel(0),
-     close_disabled(0),
-     remote_closed(0),
-     remote_close_disabled(1),
-     remote_lerrno(0),
-     in_vcs(0),
-     type(0),
-     start_time(0),
-     last_activity_time(0),
-     n_set_data_msgs(0),
-     n_recv_set_data_msgs(0),
-     pending_remote_fill(0),
-     remote_ram_cache_hit(0),
-     have_all_data(0),
-     initial_data_bytes(0),
-     current_cont(0),
-     iov_map(CLUSTER_IOV_NOT_OPEN),
-     write_list_tail(0),
-     write_list_bytes(0),
-     write_bytes_in_transit(0),
-     alternate(),
-     time_pin(0),
-     disk_io_priority(0)
+  : ch(NULL), new_connect_read(is_new_connect_read), remote_free(0), last_local_free(0), channel(0), close_disabled(0),
+    remote_closed(0), remote_close_disabled(1), remote_lerrno(0), in_vcs(0), type(0), start_time(0), last_activity_time(0),
+    n_set_data_msgs(0), n_recv_set_data_msgs(0), pending_remote_fill(0), remote_ram_cache_hit(0), have_all_data(0),
+    initial_data_bytes(0), current_cont(0), iov_map(CLUSTER_IOV_NOT_OPEN), write_list_tail(0), write_list_bytes(0),
+    write_bytes_in_transit(0), alternate(), time_pin(0), disk_io_priority(0)
 {
 #ifdef DEBUG
   read.vio.buffer.name = "ClusterVConnection.read";
   write.vio.buffer.name = "ClusterVConnection.write";
 #endif
-  SET_HANDLER((ClusterVConnHandler) & ClusterVConnection::startEvent);
+  SET_HANDLER((ClusterVConnHandler)&ClusterVConnection::startEvent);
 }
 
 ClusterVConnection::~ClusterVConnection()
@@ -249,7 +226,7 @@ ClusterVConnection::free()
 }
 
 VIO *
-ClusterVConnection::do_io_read(Continuation * c, int64_t nbytes, MIOBuffer * buf)
+ClusterVConnection::do_io_read(Continuation *c, int64_t nbytes, MIOBuffer *buf)
 {
   if (type == VC_CLUSTER)
     type = VC_CLUSTER_READ;
@@ -259,7 +236,7 @@ ClusterVConnection::do_io_read(Continuation * c, int64_t nbytes, MIOBuffer * buf
 }
 
 VIO *
-ClusterVConnection::do_io_write(Continuation * c, int64_t nbytes, IOBufferReader * buf, bool owner)
+ClusterVConnection::do_io_write(Continuation *c, int64_t nbytes, IOBufferReader *buf, bool owner)
 {
   if (type == VC_CLUSTER)
     type = VC_CLUSTER_WRITE;
@@ -283,27 +260,27 @@ ClusterVConnection::do_io_close(int alerrno)
 }
 
 int
-ClusterVConnection::startEvent(int event, Event * e)
+ClusterVConnection::startEvent(int event, Event *e)
 {
   //
   // Safe to call with e == NULL from the same thread.
   //
-  (void) event;
-  start(e ? e->ethread : (EThread *) NULL);
+  (void)event;
+  start(e ? e->ethread : (EThread *)NULL);
   return EVENT_DONE;
 }
 
 int
-ClusterVConnection::mainEvent(int event, Event * e)
+ClusterVConnection::mainEvent(int event, Event *e)
 {
-  (void) event;
-  (void) e;
+  (void)event;
+  (void)e;
   ink_assert(!"unexpected event");
   return EVENT_DONE;
 }
 
 int
-ClusterVConnection::start(EThread * t)
+ClusterVConnection::start(EThread *t)
 {
   //
   //  New channel connect protocol.  Establish VC locally and send the
@@ -346,13 +323,13 @@ ClusterVConnection::start(EThread * t)
 
     // Establish the local side of the VC connection
     MUTEX_TRY_LOCK(lock, m, t);
-    if (!lock) {
+    if (!lock.is_locked()) {
       t->schedule_in(this, CLUSTER_CONNECT_RETRY);
       return EVENT_DONE;
     }
     if (!ch) {
       if (action_.continuation) {
-        action_.continuation->handleEvent(CLUSTER_EVENT_OPEN_FAILED, (void *) -ECLUSTER_NO_MACHINE);
+        action_.continuation->handleEvent(CLUSTER_EVENT_OPEN_FAILED, (void *)-ECLUSTER_NO_MACHINE);
         clusterVCAllocator_free(this);
         return EVENT_DONE;
       } else {
@@ -365,7 +342,7 @@ ClusterVConnection::start(EThread * t)
     channel = ch->alloc_channel(this);
     if (channel < 0) {
       if (action_.continuation) {
-        action_.continuation->handleEvent(CLUSTER_EVENT_OPEN_FAILED, (void *) -ECLUSTER_NOMORE_CHANNELS);
+        action_.continuation->handleEvent(CLUSTER_EVENT_OPEN_FAILED, (void *)-ECLUSTER_NOMORE_CHANNELS);
         clusterVCAllocator_free(this);
         return EVENT_DONE;
       } else {
@@ -385,7 +362,7 @@ ClusterVConnection::start(EThread * t)
     if ((status = ch->alloc_channel(this, channel)) < 0) {
       Debug(CL_TRACE, "VC start alloc remote failed chan=%d VC=%p", channel, this);
       clusterVCAllocator_free(this);
-      return status;            // Channel active or no more channels
+      return status; // Channel active or no more channels
     } else {
       Debug(CL_TRACE, "VC start alloc remote chan=%d VC=%p", channel, this);
       if (new_connect_read)
@@ -435,7 +412,8 @@ ClusterVConnection::allow_remote_close()
   remote_close_disabled = 0;
 }
 
-bool ClusterVConnection::schedule_write()
+bool
+ClusterVConnection::schedule_write()
 {
   //
   // Schedule write if we have all data or current write data is
@@ -476,27 +454,25 @@ ClusterVConnection::set_type(int options)
 }
 
 // Overide functions in base class VConnection.
-bool ClusterVConnection::get_data(int id, void * /* data ATS_UNUSED */)
+bool
+ClusterVConnection::get_data(int id, void * /* data ATS_UNUSED */)
 {
   switch (id) {
-  case CACHE_DATA_HTTP_INFO:
-    {
-      ink_release_assert(!"ClusterVConnection::get_data CACHE_DATA_HTTP_INFO not supported");
-    }
-  case CACHE_DATA_KEY:
-    {
-      ink_release_assert(!"ClusterVConnection::get_data CACHE_DATA_KEY not supported");
-    }
-  default:
-    {
-      ink_release_assert(!"ClusterVConnection::get_data invalid id");
-    }
+  case CACHE_DATA_HTTP_INFO: {
+    ink_release_assert(!"ClusterVConnection::get_data CACHE_DATA_HTTP_INFO not supported");
+  }
+  case CACHE_DATA_KEY: {
+    ink_release_assert(!"ClusterVConnection::get_data CACHE_DATA_KEY not supported");
+  }
+  default: {
+    ink_release_assert(!"ClusterVConnection::get_data invalid id");
+  }
   }
   return false;
 }
 
 void
-ClusterVConnection::get_http_info(CacheHTTPInfo ** info)
+ClusterVConnection::get_http_info(CacheHTTPInfo **info)
 {
   *info = &alternate;
 }
@@ -514,7 +490,7 @@ ClusterVConnection::is_pread_capable()
 }
 
 void
-ClusterVConnection::set_http_info(CacheHTTPInfo * d)
+ClusterVConnection::set_http_info(CacheHTTPInfo *d)
 {
   int flen, len;
   void *data;
@@ -529,9 +505,9 @@ ClusterVConnection::set_http_info(CacheHTTPInfo * d)
   // Cache semantics dictate that set_http_info() be established prior
   // to transferring any data on the ClusterVConnection.
   //
-  ink_release_assert(this->write.vio.op == VIO::NONE);  // not true if do_io()
+  ink_release_assert(this->write.vio.op == VIO::NONE); // not true if do_io()
   //   already done
-  ink_release_assert(this->read.vio.op == VIO::NONE);   // should always be true
+  ink_release_assert(this->read.vio.op == VIO::NONE); // should always be true
 
   int vers = SetChanDataMessage::protoToVersion(ch->machine->msg_proto_major);
   if (vers == SetChanDataMessage::SET_CHANNEL_DATA_MESSAGE_VERSION) {
@@ -547,12 +523,12 @@ ClusterVConnection::set_http_info(CacheHTTPInfo * d)
 
   CacheHTTPInfo *r = d;
   len = r->marshal_length();
-  data = (void *) ALLOCA_DOUBLE(flen + len);
-  memcpy((char *) data, (char *) &msg, sizeof(msg));
-  m = (SetChanDataMessage *) data;
+  data = (void *)ALLOCA_DOUBLE(flen + len);
+  memcpy((char *)data, (char *)&msg, sizeof(msg));
+  m = (SetChanDataMessage *)data;
   m->data_type = CACHE_DATA_HTTP_INFO;
 
-  char *p = (char *) m + flen;
+  char *p = (char *)m + flen;
   res = r->marshal(p, len);
   if (res < 0) {
     r->destroy();
@@ -569,7 +545,8 @@ ClusterVConnection::set_http_info(CacheHTTPInfo * d)
   clusterProcessor.invoke_remote(ch, SET_CHANNEL_DATA_CLUSTER_FUNCTION, data, flen + len);
 }
 
-bool ClusterVConnection::set_pin_in_cache(time_t t)
+bool
+ClusterVConnection::set_pin_in_cache(time_t t)
 {
   SetChanPinMessage msg;
 
@@ -578,9 +555,9 @@ bool ClusterVConnection::set_pin_in_cache(time_t t)
   // open_write() ClusterVConnection.  It is only allowed after a
   // successful open_write() and prior to issuing the do_io(VIO::WRITE).
   //
-  ink_release_assert(this->write.vio.op == VIO::NONE);  // not true if do_io()
+  ink_release_assert(this->write.vio.op == VIO::NONE); // not true if do_io()
   //   already done
-  ink_release_assert(this->read.vio.op == VIO::NONE);   // should always be true
+  ink_release_assert(this->read.vio.op == VIO::NONE); // should always be true
   time_pin = t;
 
   int vers = SetChanPinMessage::protoToVersion(ch->machine->msg_proto_major);
@@ -591,7 +568,8 @@ bool ClusterVConnection::set_pin_in_cache(time_t t)
     //////////////////////////////////////////////////////////////
     // Create the specified down rev version of this message
     //////////////////////////////////////////////////////////////
-    ink_release_assert(!"ClusterVConnection::set_pin_in_cache() bad msg " "version");
+    ink_release_assert(!"ClusterVConnection::set_pin_in_cache() bad msg "
+                        "version");
   }
   msg.channel = channel;
   msg.sequence_number = token.sequence_number;
@@ -600,16 +578,18 @@ bool ClusterVConnection::set_pin_in_cache(time_t t)
   // note pending set_data() msgs on VC.
   ink_atomic_increment(&n_set_data_msgs, 1);
 
-  clusterProcessor.invoke_remote(ch, SET_CHANNEL_PIN_CLUSTER_FUNCTION, (char *) &msg, sizeof(msg));
+  clusterProcessor.invoke_remote(ch, SET_CHANNEL_PIN_CLUSTER_FUNCTION, (char *)&msg, sizeof(msg));
   return true;
 }
 
-time_t ClusterVConnection::get_pin_in_cache()
+time_t
+ClusterVConnection::get_pin_in_cache()
 {
   return time_pin;
 }
 
-bool ClusterVConnection::set_disk_io_priority(int priority)
+bool
+ClusterVConnection::set_disk_io_priority(int priority)
 {
   SetChanPriorityMessage msg;
 
@@ -618,9 +598,9 @@ bool ClusterVConnection::set_disk_io_priority(int priority)
   // open_write() ClusterVConnection.  It is only allowed after a
   // successful open_write() and prior to issuing the do_io(VIO::WRITE).
   //
-  ink_release_assert(this->write.vio.op == VIO::NONE);  // not true if do_io()
+  ink_release_assert(this->write.vio.op == VIO::NONE); // not true if do_io()
   //   already done
-  ink_release_assert(this->read.vio.op == VIO::NONE);   // should always be true
+  ink_release_assert(this->read.vio.op == VIO::NONE); // should always be true
   disk_io_priority = priority;
 
   int vers = SetChanPriorityMessage::protoToVersion(ch->machine->msg_proto_major);
@@ -631,7 +611,8 @@ bool ClusterVConnection::set_disk_io_priority(int priority)
     //////////////////////////////////////////////////////////////
     // Create the specified down rev version of this message
     //////////////////////////////////////////////////////////////
-    ink_release_assert(!"ClusterVConnection::set_disk_io_priority() bad msg " "version");
+    ink_release_assert(!"ClusterVConnection::set_disk_io_priority() bad msg "
+                        "version");
   }
   msg.channel = channel;
   msg.sequence_number = token.sequence_number;
@@ -640,7 +621,7 @@ bool ClusterVConnection::set_disk_io_priority(int priority)
   // note pending set_data() msgs on VC.
   ink_atomic_increment(&n_set_data_msgs, 1);
 
-  clusterProcessor.invoke_remote(ch, SET_CHANNEL_PRIORITY_CLUSTER_FUNCTION, (char *) &msg, sizeof(msg));
+  clusterProcessor.invoke_remote(ch, SET_CHANNEL_PRIORITY_CLUSTER_FUNCTION, (char *)&msg, sizeof(msg));
   return true;
 }
 
