@@ -34,45 +34,45 @@
 class ClusterLoadMonitor;
 
 struct ClusterCalloutContinuation;
-typedef int (ClusterCalloutContinuation::*ClstCoutContHandler) (int, void *);
+typedef int (ClusterCalloutContinuation::*ClstCoutContHandler)(int, void *);
 
-struct ClusterCalloutContinuation:public Continuation
-{
+struct ClusterCalloutContinuation : public Continuation {
   struct ClusterHandler *_ch;
 
-  int CalloutHandler(int event, Event * e);
-    ClusterCalloutContinuation(struct ClusterHandler *ch);
-   ~ClusterCalloutContinuation();
+  int CalloutHandler(int event, Event *e);
+  ClusterCalloutContinuation(struct ClusterHandler *ch);
+  ~ClusterCalloutContinuation();
 };
 
-struct ClusterControl: public Continuation
-{
+struct ClusterControl : public Continuation {
   int len; // TODO: Should this be 64-bit ?
   char size_index;
   int64_t *real_data;
   char *data;
-  void (*free_proc) (void *);
+  void (*free_proc)(void *);
   void *free_proc_arg;
-    Ptr<IOBufferBlock> iob_block;
+  Ptr<IOBufferBlock> iob_block;
 
-  IOBufferBlock *get_block()
+  IOBufferBlock *
+  get_block()
   {
     return iob_block;
   }
-  bool fast_data()
+  bool
+  fast_data()
   {
     return (len <= MAX_FAST_CONTROL_MESSAGE);
   }
-  bool valid_alloc_data()
+  bool
+  valid_alloc_data()
   {
     return iob_block && real_data && data;
   }
 
-  enum
-  {
+  enum {
     // DATA_HDR = size_index (1 byte) + magicno (1 byte) + sizeof(this)
 
-    DATA_HDR = (sizeof(int64_t) * 2)      // must be multiple of sizeof(int64_t)
+    DATA_HDR = (sizeof(int64_t) * 2) // must be multiple of sizeof(int64_t)
   };
 
   ClusterControl();
@@ -81,19 +81,21 @@ struct ClusterControl: public Continuation
   virtual void freeall() = 0;
 };
 
-struct OutgoingControl: public ClusterControl
-{
+struct OutgoingControl : public ClusterControl {
   ClusterHandler *ch;
   ink_hrtime submit_time;
 
   static OutgoingControl *alloc();
 
-    OutgoingControl();
-  void alloc_data(bool align_int32_on_non_int64_boundary = true) {
-    real_alloc_data(1, align_int32_on_non_int64_boundary);      /* read access */
+  OutgoingControl();
+  void
+  alloc_data(bool align_int32_on_non_int64_boundary = true)
+  {
+    real_alloc_data(1, align_int32_on_non_int64_boundary); /* read access */
   }
 
-  void set_data(char *adata, int alen)
+  void
+  set_data(char *adata, int alen)
   {
     data = adata;
     len = alen;
@@ -108,31 +110,33 @@ struct OutgoingControl: public ClusterControl
     iob_block->_buf_end = iob_block->end();
   }
 
-  void set_data(IOBufferBlock * buf, void (*free_data_proc) (void *), void *free_data_arg)
+  void
+  set_data(IOBufferBlock *buf, void (*free_data_proc)(void *), void *free_data_arg)
   {
     data = buf->data->data();
-    len = bytes_IOBufferBlockList(buf, 1);      // read avail bytes
+    len = bytes_IOBufferBlockList(buf, 1); // read avail bytes
     free_proc = free_data_proc;
     free_proc_arg = free_data_arg;
     real_data = 0;
     iob_block = buf;
   }
-  int startEvent(int event, Event * e);
+  int startEvent(int event, Event *e);
   virtual void freeall();
 };
 
 //
 // incoming control messsage are received by this machine
 //
-struct IncomingControl: public ClusterControl
-{
+struct IncomingControl : public ClusterControl {
   ink_hrtime recognized_time;
 
   static IncomingControl *alloc();
 
-    IncomingControl();
-  void alloc_data(bool align_int32_on_non_int64_boundary = true) {
-    real_alloc_data(0, align_int32_on_non_int64_boundary);      /* write access */
+  IncomingControl();
+  void
+  alloc_data(bool align_int32_on_non_int64_boundary = true)
+  {
+    real_alloc_data(0, align_int32_on_non_int64_boundary); /* write access */
   }
   virtual void freeall();
 };
@@ -140,21 +144,17 @@ struct IncomingControl: public ClusterControl
 //
 // Interface structure for internal_invoke_remote()
 //
-struct invoke_remote_data_args
-{
+struct invoke_remote_data_args {
   int32_t magicno;
   OutgoingControl *msg_oc;
   OutgoingControl *data_oc;
   int dest_channel;
   ClusterVCToken token;
 
-  enum
-  {
-    MagicNo = 0x04141998
+  enum {
+    MagicNo = 0x04141998,
   };
-    invoke_remote_data_args():magicno(MagicNo), msg_oc(NULL), data_oc(NULL), dest_channel(0)
-  {
-  }
+  invoke_remote_data_args() : magicno(MagicNo), msg_oc(NULL), data_oc(NULL), dest_channel(0) {}
 };
 
 //
@@ -163,27 +163,26 @@ struct invoke_remote_data_args
 //
 
 // type
-#define CLUSTER_SEND_FREE   0
-#define CLUSTER_SEND_DATA   1
-#define CLUSTER_SEQUENCE_NUMBER(_x) (((unsigned int)_x)&0xFFFF)
+#define CLUSTER_SEND_FREE 0
+#define CLUSTER_SEND_DATA 1
+#define CLUSTER_SEQUENCE_NUMBER(_x) (((unsigned int)_x) & 0xFFFF)
 
-struct Descriptor
-{                               // Note: Over the Wire structure
-  uint32_t type:1;
-  uint32_t channel:15;
-  uint16_t sequence_number;       // lower 16 bits of the ClusterVCToken.seq
+struct Descriptor { // Note: Over the Wire structure
+  uint32_t type : 1;
+  uint32_t channel : 15;
+  uint16_t sequence_number; // lower 16 bits of the ClusterVCToken.seq
   uint32_t length;
 
-  inline void SwapBytes()
+  inline void
+  SwapBytes()
   {
-    ats_swap16((uint16_t *) this);    // Hack
-    ats_swap16((uint16_t *) & sequence_number);
-    ats_swap32((uint32_t *) & length);
+    ats_swap16((uint16_t *)this); // Hack
+    ats_swap16((uint16_t *)&sequence_number);
+    ats_swap32((uint32_t *)&length);
   }
 };
 
-struct ClusterMsgHeader
-{                               // Note: Over the Wire structure
+struct ClusterMsgHeader { // Note: Over the Wire structure
   uint16_t count;
   uint16_t descriptor_cksum;
   uint16_t control_bytes_cksum;
@@ -191,7 +190,8 @@ struct ClusterMsgHeader
   uint32_t control_bytes;
   uint32_t count_check;
 
-  void clear()
+  void
+  clear()
   {
     count = 0;
     descriptor_cksum = 0;
@@ -200,34 +200,32 @@ struct ClusterMsgHeader
     control_bytes = 0;
     count_check = 0;
   }
-  ClusterMsgHeader():count(0), descriptor_cksum(0), control_bytes_cksum(0), unused(0), control_bytes(0), count_check(0)
+  ClusterMsgHeader() : count(0), descriptor_cksum(0), control_bytes_cksum(0), unused(0), control_bytes(0), count_check(0) {}
+  inline void
+  SwapBytes()
   {
-  }
-  inline void SwapBytes()
-  {
-    ats_swap16((uint16_t *) & count);
-    ats_swap16((uint16_t *) & descriptor_cksum);
-    ats_swap16((uint16_t *) & control_bytes_cksum);
-    ats_swap16((uint16_t *) & unused);
-    ats_swap32((uint32_t *) & control_bytes);
-    ats_swap32((uint32_t *) & count_check);
+    ats_swap16((uint16_t *)&count);
+    ats_swap16((uint16_t *)&descriptor_cksum);
+    ats_swap16((uint16_t *)&control_bytes_cksum);
+    ats_swap16((uint16_t *)&unused);
+    ats_swap32((uint32_t *)&control_bytes);
+    ats_swap32((uint32_t *)&count_check);
   }
 };
 
-struct ClusterMsg
-{
+struct ClusterMsg {
   Descriptor *descriptor;
-    Ptr<IOBufferBlock> iob_descriptor_block;
+  Ptr<IOBufferBlock> iob_descriptor_block;
   int count;
   int control_bytes;
   int descriptor_cksum;
   int control_bytes_cksum;
   int unused;
-  int state;                    // Only used by read to denote
-  //   read phase (count, descriptor, data)
-    Queue<OutgoingControl> outgoing_control;
-    Queue<OutgoingControl> outgoing_small_control;
-    Queue<OutgoingControl> outgoing_callout; // compound msg callbacks
+  int state; // Only used by read to denote
+             //   read phase (count, descriptor, data)
+  Queue<OutgoingControl> outgoing_control;
+  Queue<OutgoingControl> outgoing_small_control;
+  Queue<OutgoingControl> outgoing_callout; // compound msg callbacks
 
   // read processing usage.
   int control_data_offset;
@@ -237,22 +235,24 @@ struct ClusterMsg
   int did_large_control_msgs;
   int did_freespace_msgs;
 
-  ClusterMsgHeader *hdr()
+  ClusterMsgHeader *
+  hdr()
   {
-    return (ClusterMsgHeader *) (((char *) descriptor)
-                                 - sizeof(ClusterMsgHeader));
+    return (ClusterMsgHeader *)(((char *)descriptor) - sizeof(ClusterMsgHeader));
   }
 
-  IOBufferBlock *get_block()
+  IOBufferBlock *
+  get_block()
   {
     return iob_descriptor_block;
   }
 
-  IOBufferBlock *get_block_header()
+  IOBufferBlock *
+  get_block_header()
   {
     int start_offset;
 
-    start_offset = (char *) hdr() - iob_descriptor_block->buf();
+    start_offset = (char *)hdr() - iob_descriptor_block->buf();
     iob_descriptor_block->reset();
     iob_descriptor_block->next = 0;
     iob_descriptor_block->fill(start_offset);
@@ -260,12 +260,12 @@ struct ClusterMsg
     return iob_descriptor_block;
   }
 
-  IOBufferBlock *get_block_descriptor()
+  IOBufferBlock *
+  get_block_descriptor()
   {
     int start_offset;
 
-    start_offset = ((char *) hdr() + sizeof(ClusterMsgHeader))
-      - iob_descriptor_block->buf();
+    start_offset = ((char *)hdr() + sizeof(ClusterMsgHeader)) - iob_descriptor_block->buf();
     iob_descriptor_block->reset();
     iob_descriptor_block->next = 0;
     iob_descriptor_block->fill(start_offset);
@@ -273,7 +273,8 @@ struct ClusterMsg
     return iob_descriptor_block;
   }
 
-  void clear()
+  void
+  clear()
   {
     hdr()->clear();
     count = 0;
@@ -291,10 +292,11 @@ struct ClusterMsg
     did_large_control_msgs = 0;
     did_freespace_msgs = 0;
   }
-  uint16_t calc_control_bytes_cksum()
+  uint16_t
+  calc_control_bytes_cksum()
   {
     uint16_t cksum = 0;
-    char *p = (char *) &descriptor[count];
+    char *p = (char *)&descriptor[count];
     char *endp = p + control_bytes;
     while (p < endp) {
       cksum += *p;
@@ -302,56 +304,53 @@ struct ClusterMsg
     }
     return cksum;
   }
-  uint16_t calc_descriptor_cksum()
+  uint16_t
+  calc_descriptor_cksum()
   {
     uint16_t cksum = 0;
-    char *p = (char *) &descriptor[0];
-    char *endp = (char *) &descriptor[count];
+    char *p = (char *)&descriptor[0];
+    char *endp = (char *)&descriptor[count];
     while (p < endp) {
       cksum += *p;
       ++p;
     }
     return cksum;
   }
-ClusterMsg():descriptor(NULL), iob_descriptor_block(NULL), count(0),
-    control_bytes(0),
-    descriptor_cksum(0), control_bytes_cksum(0),
-    unused(0), state(0),
-    control_data_offset(0),
-    did_small_control_set_data(0),
-    did_large_control_set_data(0), did_small_control_msgs(0), did_large_control_msgs(0), did_freespace_msgs(0) {
+  ClusterMsg()
+    : descriptor(NULL), iob_descriptor_block(NULL), count(0), control_bytes(0), descriptor_cksum(0), control_bytes_cksum(0),
+      unused(0), state(0), control_data_offset(0), did_small_control_set_data(0), did_large_control_set_data(0),
+      did_small_control_msgs(0), did_large_control_msgs(0), did_freespace_msgs(0)
+  {
   }
-
 };
 
 //
 // State for a particular (read/write) direction of a cluster link
 //
 struct ClusterHandler;
-struct ClusterState: public Continuation
-{
+struct ClusterState : public Continuation {
   ClusterHandler *ch;
   bool read_channel;
-  bool do_iodone_event;         // schedule_imm() on i/o complete
+  bool do_iodone_event; // schedule_imm() on i/o complete
   int n_descriptors;
   ClusterMsg msg;
   unsigned int sequence_number;
-  int to_do;                    // # of bytes to transact
-  int did;                      // # of bytes transacted
-  int n_iov;                    // defined iov(s) in this operation
-  int io_complete;              // current i/o complete
-  int io_complete_event;        // current i/o complete event
-  VIO *v;                       // VIO associated with current op
-  int bytes_xfered;             // bytes xfered at last callback
-  int last_ndone;               // last do_io ndone
+  int to_do;             // # of bytes to transact
+  int did;               // # of bytes transacted
+  int n_iov;             // defined iov(s) in this operation
+  int io_complete;       // current i/o complete
+  int io_complete_event; // current i/o complete event
+  VIO *v;                // VIO associated with current op
+  int bytes_xfered;      // bytes xfered at last callback
+  int last_ndone;        // last do_io ndone
   int total_bytes_xfered;
-  IOVec *iov;                   // io vector for readv, writev
+  IOVec *iov; // io vector for readv, writev
   Ptr<IOBufferData> iob_iov;
 
   // Write byte bank structures
-  char *byte_bank;              // bytes buffered for transit
-  int n_byte_bank;              // number of bytes buffered for transit
-  int byte_bank_size;           // allocated size of byte bank
+  char *byte_bank;    // bytes buffered for transit
+  int n_byte_bank;    // number of bytes buffered for transit
+  int byte_bank_size; // allocated size of byte bank
 
   int missed;
   bool missed_msg;
@@ -360,11 +359,10 @@ struct ClusterState: public Continuation
 
   Ptr<IOBufferBlock> block[MAX_TCOUNT];
   class MIOBuffer *mbuf;
-  int state;                    // See enum defs below
+  int state; // See enum defs below
 
 
-  enum
-  {
+  enum {
     READ_START = 1,
     READ_HEADER,
     READ_AWAIT_HEADER,
@@ -378,14 +376,13 @@ struct ClusterState: public Continuation
     READ_COMPLETE
   } read_state_t;
 
-  enum
-  {
+  enum {
     WRITE_START = 1,
     WRITE_SETUP,
     WRITE_INITIATE,
     WRITE_AWAIT_COMPLETION,
     WRITE_POST_COMPLETE,
-    WRITE_COMPLETE
+    WRITE_COMPLETE,
   } write_state_t;
 
   ClusterState(ClusterHandler *, bool);
@@ -402,8 +399,7 @@ struct ClusterState: public Continuation
 // ClusterHandlerBase superclass for processors with
 // bi-directional VConnections.
 //
-struct ClusterHandlerBase: public Continuation
-{
+struct ClusterHandlerBase : public Continuation {
   //
   // Private
   //
@@ -413,13 +409,10 @@ struct ClusterHandlerBase: public Continuation
   int min_priority;
   Event *trigger_event;
 
-  ClusterHandlerBase():Continuation(NULL), read_vcs(NULL), write_vcs(NULL), cur_vcs(0), min_priority(1)
-  {
-  }
+  ClusterHandlerBase() : Continuation(NULL), read_vcs(NULL), write_vcs(NULL), cur_vcs(0), min_priority(1) {}
 };
 
-struct ClusterHandler:public ClusterHandlerBase
-{
+struct ClusterHandler : public ClusterHandlerBase {
 #ifdef MSG_TRACE
   FILE *t_fd;
 #endif
@@ -434,11 +427,10 @@ struct ClusterHandler:public ClusterHandlerBase
   bool dead;
   bool downing;
 
-  int32_t active;                 // handler currently running
+  int32_t active; // handler currently running
   bool on_stolen_thread;
 
-  struct ChannelData
-  {
+  struct ChannelData {
     int channel_number;
     LINK(ChannelData, link);
   };
@@ -449,16 +441,15 @@ struct ClusterHandler:public ClusterHandlerBase
   Queue<ChannelData> free_local_channels;
 
   bool connector;
-  int cluster_connect_state;    // see clcon_state_t enum
+  int cluster_connect_state; // see clcon_state_t enum
   ClusterHelloMessage clusteringVersion;
   ClusterHelloMessage nodeClusteringVersion;
   bool needByteSwap;
   int configLookupFails;
 
-#define CONFIG_LOOKUP_RETRIES	10
+#define CONFIG_LOOKUP_RETRIES 10
 
-  enum
-  {
+  enum {
     CLCON_INITIAL = 1,
     CLCON_SEND_MSG,
     CLCON_SEND_MSG_COMPLETE,
@@ -475,7 +466,7 @@ struct ClusterHandler:public ClusterHandlerBase
   InkAtomicList outgoing_control_al[CLUSTER_CMSG_QUEUES];
   InkAtomicList external_incoming_control;
   InkAtomicList external_incoming_open_local;
-  ClusterCalloutContinuation * callout_cont[MAX_COMPLETION_CALLBACK_EVENTS];
+  ClusterCalloutContinuation *callout_cont[MAX_COMPLETION_CALLBACK_EVENTS];
   Event *callout_events[MAX_COMPLETION_CALLBACK_EVENTS];
   Event *cluster_periodic_event;
   Queue<OutgoingControl> outgoing_control[CLUSTER_CMSG_QUEUES];
@@ -505,7 +496,7 @@ struct ClusterHandler:public ClusterHandlerBase
   bool control_message_write;
 
 #ifdef CLUSTER_STATS
-    Ptr<IOBufferBlock> message_blk;
+  Ptr<IOBufferBlock> message_blk;
 
   int64_t _vc_writes;
   int64_t _vc_write_bytes;
@@ -542,7 +533,8 @@ struct ClusterHandler:public ClusterHandlerBase
   int _n_write_post_complete;
   int _n_write_complete;
 
-  void clear_cluster_stats()
+  void
+  clear_cluster_stats()
   {
     _vc_writes = 0;
     _vc_write_bytes = 0;
@@ -579,30 +571,31 @@ struct ClusterHandler:public ClusterHandlerBase
     _n_write_post_complete = 0;
     _n_write_complete = 0;
   }
-#endif                          // CLUSTER_STATS
+#endif // CLUSTER_STATS
 
   ClusterHandler();
   ~ClusterHandler();
   bool check_channel(int c);
-  int alloc_channel(ClusterVConnection * vc, int requested_channel = 0);
-  void free_channel(ClusterVConnection * vc);
-//
-//  local_channel()
-//  - Initiator node-node TCP socket  &&  Odd channel  => Local Channel
-//  - !Initiator node-node TCP socket &&  Even channel => Local Channel
-  inline bool local_channel(int i)
+  int alloc_channel(ClusterVConnection *vc, int requested_channel = 0);
+  void free_channel(ClusterVConnection *vc);
+  //
+  //  local_channel()
+  //  - Initiator node-node TCP socket  &&  Odd channel  => Local Channel
+  //  - !Initiator node-node TCP socket &&  Even channel => Local Channel
+  inline bool
+  local_channel(int i)
   {
     return !connector == !(i & 1);
   }
 
   void close_ClusterVConnection(ClusterVConnection *);
-  int cluster_signal_and_update(int event, ClusterVConnection * vc, ClusterVConnState * s);
-  int cluster_signal_and_update_locked(int event, ClusterVConnection * vc, ClusterVConnState * s);
-  int cluster_signal_error_and_update(ClusterVConnection * vc, ClusterVConnState * s, int lerrno);
+  int cluster_signal_and_update(int event, ClusterVConnection *vc, ClusterVConnState *s);
+  int cluster_signal_and_update_locked(int event, ClusterVConnection *vc, ClusterVConnState *s);
+  int cluster_signal_error_and_update(ClusterVConnection *vc, ClusterVConnState *s, int lerrno);
   void close_free_lock(ClusterVConnection *, ClusterVConnState *);
 
-#define CLUSTER_READ       true
-#define CLUSTER_WRITE      false
+#define CLUSTER_READ true
+#define CLUSTER_WRITE false
 
   bool build_data_vector(char *, int, bool);
   bool build_initial_vector(bool);
@@ -615,7 +608,7 @@ struct ClusterHandler:public ClusterHandlerBase
   void process_small_control_msgs();
   void process_large_control_msgs();
   void process_freespace_msgs();
-  bool complete_channel_read(int, ClusterVConnection * vc);
+  bool complete_channel_read(int, ClusterVConnection *vc);
   void finish_delayed_reads();
   // returns: false if the channel was closed
 
@@ -625,27 +618,27 @@ struct ClusterHandler:public ClusterHandlerBase
   int build_freespace_descriptors();
   int build_controlmsg_descriptors();
   int add_small_controlmsg_descriptors();
-  int valid_for_data_write(ClusterVConnection * vc);
-  int valid_for_freespace_write(ClusterVConnection * vc);
+  int valid_for_data_write(ClusterVConnection *vc);
+  int valid_for_freespace_write(ClusterVConnection *vc);
 
   int machine_down();
-  int remote_close(ClusterVConnection * vc, ClusterVConnState * ns);
-  void steal_thread(EThread * t);
+  int remote_close(ClusterVConnection *vc, ClusterVConnState *ns);
+  void steal_thread(EThread *t);
 
 #define CLUSTER_FREE_ALL_LOCKS -1
   void free_locks(bool read_flag, int i = CLUSTER_FREE_ALL_LOCKS);
   bool get_read_locks();
   bool get_write_locks();
-  int zombify(Event * e = NULL);        // optional event to use
+  int zombify(Event *e = NULL); // optional event to use
 
-  int connectClusterEvent(int event, Event * e);
-  int startClusterEvent(int event, Event * e);
-  int mainClusterEvent(int event, Event * e);
-  int beginClusterEvent(int event, Event * e);
-  int zombieClusterEvent(int event, Event * e);
-  int protoZombieEvent(int event, Event * e);
+  int connectClusterEvent(int event, Event *e);
+  int startClusterEvent(int event, Event *e);
+  int mainClusterEvent(int event, Event *e);
+  int beginClusterEvent(int event, Event *e);
+  int zombieClusterEvent(int event, Event *e);
+  int protoZombieEvent(int event, Event *e);
 
-  void vcs_push(ClusterVConnection * vc, int type);
+  void vcs_push(ClusterVConnection *vc, int type);
   bool vc_ok_read(ClusterVConnection *);
   bool vc_ok_write(ClusterVConnection *);
   int do_open_local_requests();
@@ -664,7 +657,7 @@ struct ClusterHandler:public ClusterHandlerBase
 };
 
 // Valid (ClusterVConnection *) in ClusterHandler.channels[]
-#define VALID_CHANNEL(vc) (vc && !(((uintptr_t) vc) & 1))
+#define VALID_CHANNEL(vc) (vc && !(((uintptr_t)vc) & 1))
 
 // outgoing control continuations
 extern ClassAllocator<OutgoingControl> outControlAllocator;
