@@ -26,12 +26,12 @@
 
 #include "SRV.h"
 
-#define  MAX_DNS_PACKET_LEN         8192
-#define  DNS_MAX_ALIASES              35
-#define  DNS_MAX_ADDRS                35
-#define  DNS_HOSTBUF_SIZE           8192
-#define  DOMAIN_SERVICE_PORT          53
-#define  DEFAULT_DOMAIN_NAME_SERVER    0        // use the default server
+#define MAX_DNS_PACKET_LEN 8192
+#define DNS_MAX_ALIASES 35
+#define DNS_MAX_ADDRS 35
+#define DNS_HOSTBUF_SIZE 8192
+#define DOMAIN_SERVICE_PORT 53
+#define DEFAULT_DOMAIN_NAME_SERVER 0 // use the default server
 
 
 /**
@@ -53,9 +53,10 @@ struct HostEnt : RefCountObj {
 
   virtual void free();
 
-  HostEnt() { 
-    size_t base = sizeof(force_VFPT_to_top);  // preserve VFPT
-    memset(((char*)this) + base, 0, sizeof(*this) - base); 
+  HostEnt()
+  {
+    size_t base = sizeof(force_VFPT_to_top); // preserve VFPT
+    memset(((char *)this) + base, 0, sizeof(*this) - base);
   }
 };
 
@@ -63,8 +64,7 @@ extern EventType ET_DNS;
 
 struct DNSHandler;
 
-struct DNSProcessor: public Processor
-{
+struct DNSProcessor : public Processor {
   // Public Interface
   //
 
@@ -74,7 +74,7 @@ struct DNSProcessor: public Processor
 
     /// Query handler to use.
     /// Default: single threaded handler.
-    DNSHandler* handler;
+    DNSHandler *handler;
     /// Query timeout value.
     /// Default: @c DEFAULT_DNS_TIMEOUT (or as set in records.config)
     int timeout; ///< Timeout value for request.
@@ -87,19 +87,19 @@ struct DNSProcessor: public Processor
 
     /// Set @a handler option.
     /// @return This object.
-    self& setHandler(DNSHandler* handler);
+    self &setHandler(DNSHandler *handler);
 
     /// Set @a timeout option.
     /// @return This object.
-    self& setTimeout(int timeout);
+    self &setTimeout(int timeout);
 
     /// Set host query @a style option.
     /// @return This object.
-    self& setHostResStyle(HostResStyle style);
+    self &setHostResStyle(HostResStyle style);
 
     /// Reset to default constructed values.
     /// @return This object.
-    self& reset();
+    self &reset();
   };
 
   // DNS lookup
@@ -108,21 +108,21 @@ struct DNSProcessor: public Processor
   // NOTE: the HostEnt *block is freed when the function returns
   //
 
-  Action *gethostbyname(Continuation *cont, const char *name, Options const& opt);
-  Action *getSRVbyname(Continuation *cont, const char *name, Options const& opt);
-  Action *gethostbyname(Continuation *cont, const char *name, int len, Options const& opt);
-  Action *gethostbyaddr(Continuation *cont, IpAddr const* ip, Options const& opt);
+  Action *gethostbyname(Continuation *cont, const char *name, Options const &opt);
+  Action *getSRVbyname(Continuation *cont, const char *name, Options const &opt);
+  Action *gethostbyname(Continuation *cont, const char *name, int len, Options const &opt);
+  Action *gethostbyaddr(Continuation *cont, IpAddr const *ip, Options const &opt);
 
 
   // Processor API
   //
   /* currently dns system uses event threads
    * dont pass any value to the call */
-  int start(int no_of_extra_dns_threads=0, size_t stacksize=DEFAULT_STACKSIZE);
+  int start(int no_of_extra_dns_threads = 0, size_t stacksize = DEFAULT_STACKSIZE);
 
   // Open/close a link to a 'named' (done in start())
   //
-  void open(sockaddr const* ns = 0, int options = _res.options);
+  void open(sockaddr const *ns = 0);
 
   DNSProcessor();
 
@@ -141,7 +141,7 @@ struct DNSProcessor: public Processor
       For address resolution ( @a type is @c T_PTR ), @a x should be a
       @c sockaddr cast to  @c char @c const* .
    */
-  Action *getby(const char *x, int len, int type, Continuation *cont, Options const& opt);
+  Action *getby(const char *x, int len, int type, Continuation *cont, Options const &opt);
 
   void dns_init();
 };
@@ -157,58 +157,55 @@ extern DNSProcessor dnsProcessor;
 //
 
 inline Action *
-DNSProcessor::getSRVbyname(Continuation *cont, const char *name, Options const& opt)
+DNSProcessor::getSRVbyname(Continuation *cont, const char *name, Options const &opt)
 {
   return getby(name, 0, T_SRV, cont, opt);
 }
 
 inline Action *
-DNSProcessor::gethostbyname(Continuation *cont, const char *name, Options const& opt)
+DNSProcessor::gethostbyname(Continuation *cont, const char *name, Options const &opt)
 {
   return getby(name, 0, T_A, cont, opt);
 }
 
 inline Action *
-DNSProcessor::gethostbyname(Continuation *cont, const char *name, int len, Options const& opt)
+DNSProcessor::gethostbyname(Continuation *cont, const char *name, int len, Options const &opt)
 {
   return getby(name, len, T_A, cont, opt);
 }
 
 inline Action *
-DNSProcessor::gethostbyaddr(Continuation *cont, IpAddr const* addr, Options const& opt)
+DNSProcessor::gethostbyaddr(Continuation *cont, IpAddr const *addr, Options const &opt)
 {
-  return getby(reinterpret_cast<char const*>(addr), 0, T_PTR, cont, opt);
+  return getby(reinterpret_cast<char const *>(addr), 0, T_PTR, cont, opt);
 }
 
-inline DNSProcessor::Options::Options()
-                    : handler(0)
-                    , timeout(0)
-                    , host_res_style(HOST_RES_IPV4)
+inline DNSProcessor::Options::Options() : handler(0), timeout(0), host_res_style(HOST_RES_IPV4)
 {
 }
 
-inline DNSProcessor::Options&
-DNSProcessor::Options::setHandler(DNSHandler* h)
+inline DNSProcessor::Options &
+DNSProcessor::Options::setHandler(DNSHandler *h)
 {
   handler = h;
   return *this;
 }
 
-inline DNSProcessor::Options&
+inline DNSProcessor::Options &
 DNSProcessor::Options::setTimeout(int t)
 {
   timeout = t;
   return *this;
 }
 
-inline DNSProcessor::Options&
+inline DNSProcessor::Options &
 DNSProcessor::Options::setHostResStyle(HostResStyle style)
 {
   host_res_style = style;
   return *this;
 }
 
-inline DNSProcessor::Options&
+inline DNSProcessor::Options &
 DNSProcessor::Options::reset()
 {
   *this = Options();
