@@ -21,7 +21,7 @@
   limitations under the License.
  */
 
-#if !defined (_P_DNSProcessor_h_)
+#if !defined(_P_DNSProcessor_h_)
 #define _P_DNSProcessor_h_
 
 /*
@@ -33,19 +33,19 @@
 */
 #include "I_EventSystem.h"
 
-#define MAX_NAMED                           32
-#define DEFAULT_DNS_RETRIES                 5
-#define MAX_DNS_RETRIES                     9
-#define DEFAULT_DNS_TIMEOUT                 30
-#define MAX_DNS_IN_FLIGHT                   2048
-#define DEFAULT_FAILOVER_NUMBER             (DEFAULT_DNS_RETRIES + 1)
-#define DEFAULT_FAILOVER_PERIOD             (DEFAULT_DNS_TIMEOUT + 30)
+#define MAX_NAMED 32
+#define DEFAULT_DNS_RETRIES 5
+#define MAX_DNS_RETRIES 9
+#define DEFAULT_DNS_TIMEOUT 30
+#define MAX_DNS_IN_FLIGHT 2048
+#define DEFAULT_FAILOVER_NUMBER (DEFAULT_DNS_RETRIES + 1)
+#define DEFAULT_FAILOVER_PERIOD (DEFAULT_DNS_TIMEOUT + 30)
 // how many seconds before FAILOVER_PERIOD to try the primary with
 // a well known address
-#define DEFAULT_FAILOVER_TRY_PERIOD         (DEFAULT_DNS_TIMEOUT + 1)
-#define DEFAULT_DNS_SEARCH           1
-#define FAILOVER_SOON_RETRY          5
-#define NO_NAMESERVER_SELECTED       -1
+#define DEFAULT_FAILOVER_TRY_PERIOD (DEFAULT_DNS_TIMEOUT + 1)
+#define DEFAULT_DNS_SEARCH 1
+#define FAILOVER_SOON_RETRY 5
+#define NO_NAMESERVER_SELECTED -1
 
 //
 // Config
@@ -63,13 +63,13 @@ extern unsigned int dns_sequence_number;
 // Constants
 //
 
-#define DNS_PERIOD                          HRTIME_MSECONDS(-100)
-#define DNS_DELAY_PERIOD                    HRTIME_MSECONDS(10)
-#define DNS_SEQUENCE_NUMBER_RESTART_OFFSET  4000
-#define DNS_PRIMARY_RETRY_PERIOD            HRTIME_SECONDS(5)
-#define DNS_PRIMARY_REOPEN_PERIOD           HRTIME_SECONDS(60)
-#define BAD_DNS_RESULT                      ((HostEnt*)(uintptr_t)-1)
-#define DEFAULT_NUM_TRY_SERVER              8
+#define DNS_PERIOD HRTIME_MSECONDS(-100)
+#define DNS_DELAY_PERIOD HRTIME_MSECONDS(10)
+#define DNS_SEQUENCE_NUMBER_RESTART_OFFSET 4000
+#define DNS_PRIMARY_RETRY_PERIOD HRTIME_SECONDS(5)
+#define DNS_PRIMARY_REOPEN_PERIOD HRTIME_SECONDS(60)
+#define BAD_DNS_RESULT ((HostEnt *)(uintptr_t)-1)
+#define DEFAULT_NUM_TRY_SERVER 8
 
 // these are from nameser.h
 #ifndef HFIXEDSZ
@@ -82,16 +82,15 @@ extern unsigned int dns_sequence_number;
 
 // Events
 
-#define DNS_EVENT_LOOKUP             DNS_EVENT_EVENTS_START
+#define DNS_EVENT_LOOKUP DNS_EVENT_EVENTS_START
 
 extern int dns_fd;
 
 void *dns_udp_receiver(void *arg);
 
 
-//Stats
-enum DNS_Stats
-{
+// Stats
+enum DNS_Stats {
   dns_total_lookups_stat,
   dns_response_time_stat,
   dns_success_time_stat,
@@ -113,31 +112,25 @@ extern RecRawStatBlock *dns_rsb;
 
 // Stat Macros
 
-#define DNS_DEBUG_COUNT_DYN_STAT(_x, _y)                            \
-  RecIncrRawStatCount(dns_rsb, mutex->thread_holding, (int)_x, _y)
+#define DNS_DEBUG_COUNT_DYN_STAT(_x, _y) RecIncrRawStatCount(dns_rsb, mutex->thread_holding, (int)_x, _y)
 
-#define DNS_INCREMENT_DYN_STAT(_x)                              \
-  RecIncrRawStatSum(dns_rsb, mutex->thread_holding, (int)_x, 1)
+#define DNS_INCREMENT_DYN_STAT(_x) RecIncrRawStatSum(dns_rsb, mutex->thread_holding, (int)_x, 1)
 
-#define DNS_DECREMENT_DYN_STAT(_x)                                \
-  RecIncrRawStatSum(dns_rsb, mutex->thread_holding, (int)_x, -1)
+#define DNS_DECREMENT_DYN_STAT(_x) RecIncrRawStatSum(dns_rsb, mutex->thread_holding, (int)_x, -1)
 
-#define DNS_SUM_DYN_STAT(_x, _r)                                  \
-  RecIncrRawStatSum(dns_rsb, mutex->thread_holding, (int)_x, _r)
+#define DNS_SUM_DYN_STAT(_x, _r) RecIncrRawStatSum(dns_rsb, mutex->thread_holding, (int)_x, _r)
 
-#define DNS_READ_DYN_STAT(_x, _count, _sum) do {    \
-    RecGetRawStatSum(dns_rsb, (int)_x, &_sum);      \
-    RecGetRawStatCount(dns_rsb, (int)_x, &_count);  \
+#define DNS_READ_DYN_STAT(_x, _count, _sum)        \
+  do {                                             \
+    RecGetRawStatSum(dns_rsb, (int)_x, &_sum);     \
+    RecGetRawStatCount(dns_rsb, (int)_x, &_count); \
   } while (0)
 
-#define DNS_SET_DYN_COUNT(_x, _count)           \
-  RecSetRawStatCount(dns_rsb, _x, _count);
+#define DNS_SET_DYN_COUNT(_x, _count) RecSetRawStatCount(dns_rsb, _x, _count);
 
-#define DNS_INCREMENT_THREAD_DYN_STAT(_s, _t)   \
-  RecIncrRawStatSum(dns_rsb, _t, (int) _s, 1);
+#define DNS_INCREMENT_THREAD_DYN_STAT(_s, _t) RecIncrRawStatSum(dns_rsb, _t, (int)_s, 1);
 
-#define DNS_DECREMENT_THREAD_DYN_STAT(_s, _t)   \
-  RecIncrRawStatSum(dns_rsb, _t, (int) _s, -1);
+#define DNS_DECREMENT_THREAD_DYN_STAT(_s, _t) RecIncrRawStatSum(dns_rsb, _t, (int)_s, -1);
 
 /**
   One DNSEntry is allocated per outstanding request. This continuation
@@ -145,10 +138,9 @@ extern RecRawStatBlock *dns_rsb;
   information about the request and its status.
 
 */
-struct DNSEntry: public Continuation
-{
+struct DNSEntry : public Continuation {
   int id[MAX_DNS_RETRIES];
-  int qtype; ///< Type of query to send.
+  int qtype;                   ///< Type of query to send.
   HostResStyle host_res_style; ///< Preferred IP address family.
   int retries;
   int which_ns;
@@ -173,16 +165,12 @@ struct DNSEntry: public Continuation
   int delayEvent(int event, Event *e);
   int post(DNSHandler *h, HostEnt *ent);
   int postEvent(int event, Event *e);
-  void init(const char *x, int len, int qtype_arg, Continuation *acont, DNSProcessor::Options const& opt);
+  void init(const char *x, int len, int qtype_arg, Continuation *acont, DNSProcessor::Options const &opt);
 
-   DNSEntry()
-     : Continuation(NULL),
-       qtype(0),
-       host_res_style(HOST_RES_NONE),
-       retries(DEFAULT_DNS_RETRIES),
-       which_ns(NO_NAMESERVER_SELECTED), submit_time(0), send_time(0), qname_len(0),
-       orig_qname_len(0), domains(0), timeout(0), result_ent(0), dnsH(0), written_flag(false),
-       once_written_flag(false), last(false)
+  DNSEntry()
+    : Continuation(NULL), qtype(0), host_res_style(HOST_RES_NONE), retries(DEFAULT_DNS_RETRIES), which_ns(NO_NAMESERVER_SELECTED),
+      submit_time(0), send_time(0), qname_len(0), orig_qname_len(0), domains(0), timeout(0), result_ent(0), dnsH(0),
+      written_flag(false), once_written_flag(false), last(false)
   {
     for (int i = 0; i < MAX_DNS_RETRIES; i++)
       id[i] = -1;
@@ -191,7 +179,7 @@ struct DNSEntry: public Continuation
 };
 
 
-typedef int (DNSEntry::*DNSEntryHandler) (int, void *);
+typedef int (DNSEntry::*DNSEntryHandler)(int, void *);
 
 struct DNSEntry;
 
@@ -200,8 +188,7 @@ struct DNSEntry;
   UDP port.
 
 */
-struct DNSHandler: public Continuation
-{
+struct DNSHandler : public Continuation {
   /// This is used as the target if round robin isn't set.
   IpEndpoint ip;
   IpEndpoint local_ipv6; ///< Local V6 address if set.
@@ -209,7 +196,6 @@ struct DNSHandler: public Continuation
   int ifd[MAX_NAMED];
   int n_con;
   DNSConnection con[MAX_NAMED];
-  int options;
   Queue<DNSEntry> entries;
   Queue<DNSConnection> triggered;
   int in_flight;
@@ -229,14 +215,16 @@ struct DNSHandler: public Continuation
 
   InkRand generator;
   // bitmap of query ids in use
-  uint64_t qid_in_flight[(USHRT_MAX+1)/64];
+  uint64_t qid_in_flight[(USHRT_MAX + 1) / 64];
 
-  void received_one(int i)
+  void
+  received_one(int i)
   {
     failover_number[i] = failover_soon_number[i] = crossed_failover_number[i] = 0;
   }
 
-  void sent_one()
+  void
+  sent_one()
   {
     ++failover_number[name_server];
     Debug("dns", "sent_one: failover_number for resolver %d is %d", name_server, failover_number[name_server]);
@@ -244,18 +232,20 @@ struct DNSHandler: public Continuation
       crossed_failover_number[name_server] = ink_get_hrtime();
   }
 
-  bool failover_now(int i)
+  bool
+  failover_now(int i)
   {
     if (is_debug_tag_set("dns")) {
       Debug("dns", "failover_now: Considering immediate failover, target time is %" PRId64 "",
             (ink_hrtime)HRTIME_SECONDS(dns_failover_period));
       Debug("dns", "\tdelta time is %" PRId64 "", (ink_get_hrtime() - crossed_failover_number[i]));
     }
-    return (crossed_failover_number[i] &&
-            ((ink_get_hrtime() - crossed_failover_number[i]) > HRTIME_SECONDS(dns_failover_period)));
+    return (crossed_failover_number[i] && ((ink_get_hrtime() - crossed_failover_number[i]) > HRTIME_SECONDS(dns_failover_period)));
   }
 
-  bool failover_soon(int i) {
+  bool
+  failover_soon(int i)
+  {
     return (crossed_failover_number[i] &&
             ((ink_get_hrtime() - crossed_failover_number[i]) >
              (HRTIME_SECONDS(dns_failover_try_period + failover_soon_number[i] * FAILOVER_SOON_RETRY))));
@@ -266,7 +256,7 @@ struct DNSHandler: public Continuation
   int startEvent_sdns(int event, Event *e);
   int mainEvent(int event, Event *e);
 
-  void open_con(sockaddr const* addr, bool failed = false, int icon = 0);
+  void open_con(sockaddr const *addr, bool failed = false, int icon = 0);
   void failover();
   void rr_failure(int ndx);
   void recover();
@@ -275,16 +265,22 @@ struct DNSHandler: public Continuation
   void switch_named(int ndx);
   uint16_t get_query_id();
 
-  void release_query_id(uint16_t qid) {
-    qid_in_flight[qid >> 6] &= (uint64_t)~(0x1ULL << (qid & 0x3F));
+  void
+  release_query_id(uint16_t qid)
+  {
+    qid_in_flight[qid >> 6] &= (uint64_t) ~(0x1ULL << (qid & 0x3F));
   };
 
-  void set_query_id_in_use(uint16_t qid) {
+  void
+  set_query_id_in_use(uint16_t qid)
+  {
     qid_in_flight[qid >> 6] |= (uint64_t)(0x1ULL << (qid & 0x3F));
   };
 
-  bool query_id_in_use(uint16_t qid) {
-    return (qid_in_flight[(uint16_t)(qid) >> 6] & (uint64_t)(0x1ULL << ((uint16_t)(qid) & 0x3F))) != 0;
+  bool
+  query_id_in_use(uint16_t qid)
+  {
+    return (qid_in_flight[(uint16_t)(qid) >> 6] & (uint64_t)(0x1ULL << ((uint16_t)(qid)&0x3F))) != 0;
   };
 
   DNSHandler();
@@ -299,8 +295,7 @@ private:
 
    A record for an single server
    -------------------------------------------------------------- */
-struct DNSServer
-{
+struct DNSServer {
   IpEndpoint x_server_ip[MAXNS];
   char x_dns_ip_line[MAXDNAME * 2];
 
@@ -309,8 +304,7 @@ struct DNSServer
 
   DNSHandler *x_dnsH;
 
-  DNSServer()
-  : x_dnsH(NULL)
+  DNSServer() : x_dnsH(NULL)
   {
     memset(x_server_ip, 0, sizeof(x_server_ip));
 
@@ -321,10 +315,10 @@ struct DNSServer
 };
 
 
-TS_INLINE DNSHandler::DNSHandler()
- : Continuation(NULL), n_con(0), options(0), in_flight(0), name_server(0), in_write_dns(0),
-  hostent_cache(0), last_primary_retry(0), last_primary_reopen(0),
-  m_res(0), txn_lookup_timeout(0), generator((uint32_t)((uintptr_t)time(NULL) ^ (uintptr_t)this))
+TS_INLINE
+DNSHandler::DNSHandler()
+  : Continuation(NULL), n_con(0), in_flight(0), name_server(0), in_write_dns(0), hostent_cache(0), last_primary_retry(0),
+    last_primary_reopen(0), m_res(0), txn_lookup_timeout(0), generator((uint32_t)((uintptr_t)time(NULL) ^ (uintptr_t) this))
 {
   ats_ip_invalidate(&ip);
   for (int i = 0; i < MAX_NAMED; i++) {
@@ -335,13 +329,12 @@ TS_INLINE DNSHandler::DNSHandler()
     ns_down[i] = 1;
     con[i].handler = this;
   }
-  memset(&qid_in_flight, 0, sizeof(qid_in_flight));  
+  memset(&qid_in_flight, 0, sizeof(qid_in_flight));
   SET_HANDLER(&DNSHandler::startEvent);
   Debug("net_epoll", "inline DNSHandler::DNSHandler()");
 }
 
-#define DOT_SEPARATED(_x)                                   \
-  ((unsigned char*)&(_x))[0], ((unsigned char*)&(_x))[1],   \
-    ((unsigned char*)&(_x))[2], ((unsigned char*)&(_x))[3]
+#define DOT_SEPARATED(_x) \
+  ((unsigned char *)&(_x))[0], ((unsigned char *)&(_x))[1], ((unsigned char *)&(_x))[2], ((unsigned char *)&(_x))[3]
 
 #endif
