@@ -25,6 +25,7 @@
   UIOBuffer.cc
 
 **************************************************************************/
+#include "ink_defs.h"
 #include "P_EventSystem.h"
 
 //
@@ -45,6 +46,11 @@ void
 init_buffer_allocators()
 {
   char *name;
+  int advice = 0;
+
+#ifdef MADV_DONTDUMP // This should only exist on Linux 3.4 and higher.
+  advice = MADV_DONTDUMP;
+#endif
 
   for (int i = 0; i < DEFAULT_BUFFER_SIZES; i++) {
     int64_t s = DEFAULT_BUFFER_BASE_SIZE * (((int64_t)1) << i);
@@ -55,12 +61,12 @@ init_buffer_allocators()
 
     name = new char[64];
     snprintf(name, 64, "ioBufAllocator[%d]", i);
-    ioBufAllocator[i].re_init(name, s, n, a);
+    ioBufAllocator[i].re_init(name, s, n, a, advice);
   }
 }
 
 int64_t
-MIOBuffer::remove_append(IOBufferReader * r)
+MIOBuffer::remove_append(IOBufferReader *r)
 {
   int64_t l = 0;
   while (r->block) {
@@ -82,7 +88,7 @@ MIOBuffer::remove_append(IOBufferReader * r)
 int64_t
 MIOBuffer::write(const void *abuf, int64_t alen)
 {
-  const char *buf = (const char*)abuf;
+  const char *buf = (const char *)abuf;
   int64_t len = alen;
   while (len) {
     if (!_writer)
@@ -107,14 +113,14 @@ MIOBuffer::write(const void *abuf, int64_t alen)
 
 
 #ifdef WRITE_AND_TRANSFER
-  /*
-   * Same functionality as write but for the one small difference.
-   * The space available in the last block is taken from the original
-   * and this space becomes available to the copy.
-   *
-   */
+/*
+ * Same functionality as write but for the one small difference.
+ * The space available in the last block is taken from the original
+ * and this space becomes available to the copy.
+ *
+ */
 int64_t
-MIOBuffer::write_and_transfer_left_over_space(IOBufferReader * r, int64_t alen, int64_t offset)
+MIOBuffer::write_and_transfer_left_over_space(IOBufferReader *r, int64_t alen, int64_t offset)
 {
   int64_t rval = write(r, alen, offset);
   // reset the end markers of the original so that it cannot
@@ -133,7 +139,7 @@ MIOBuffer::write_and_transfer_left_over_space(IOBufferReader * r, int64_t alen,
 
 
 int64_t
-MIOBuffer::write(IOBufferReader * r, int64_t alen, int64_t offset)
+MIOBuffer::write(IOBufferReader *r, int64_t alen, int64_t offset)
 {
   int64_t len = alen;
   IOBufferBlock *b = r->block;
@@ -148,7 +154,7 @@ MIOBuffer::write(IOBufferReader * r, int64_t alen, int64_t offset)
       continue;
     }
     int64_t bytes;
-    if (len<0 || len>= max_bytes)
+    if (len < 0 || len >= max_bytes)
       bytes = max_bytes;
     else
       bytes = len;
@@ -172,8 +178,8 @@ MIOBuffer::puts(char *s, int64_t len)
     if (len-- <= 0)
       return -1;
     if (!*pb || *pb == '\n') {
-      int64_t n = (int64_t) (pb - s);
-      memcpy(end(), s, n + 1);  // Upto and including '\n'
+      int64_t n = (int64_t)(pb - s);
+      memcpy(end(), s, n + 1); // Upto and including '\n'
       end()[n + 1] = 0;
       fill(n + 1);
       return n + 1;
@@ -187,7 +193,7 @@ MIOBuffer::puts(char *s, int64_t len)
 int64_t
 IOBufferReader::read(void *ab, int64_t len)
 {
-  char *b = (char*)ab;
+  char *b = (char *)ab;
   int64_t max_bytes = read_avail();
   int64_t bytes = len <= max_bytes ? len : max_bytes;
   int64_t n = bytes;
@@ -221,14 +227,14 @@ IOBufferReader::memchr(char c, int64_t len, int64_t offset)
       continue;
     }
     int64_t bytes;
-    if (len<0 || len>= max_bytes)
+    if (len < 0 || len >= max_bytes)
       bytes = max_bytes;
     else
       bytes = len;
     char *s = b->start() + offset;
-    char *p = (char *) ::memchr(s, c, bytes);
+    char *p = (char *)::memchr(s, c, bytes);
     if (p)
-      return (int64_t) (o - start_offset + p - s);
+      return (int64_t)(o - start_offset + p - s);
     o += bytes;
     len -= bytes;
     b = b->next;
@@ -241,7 +247,7 @@ IOBufferReader::memchr(char c, int64_t len, int64_t offset)
 char *
 IOBufferReader::memcpy(const void *ap, int64_t len, int64_t offset)
 {
-  char *p = (char*)ap;
+  char *p = (char *)ap;
   IOBufferBlock *b = block;
   offset += start_offset;
 
@@ -254,7 +260,7 @@ IOBufferReader::memcpy(const void *ap, int64_t len, int64_t offset)
       continue;
     }
     int64_t bytes;
-    if (len<0 || len>= max_bytes)
+    if (len < 0 || len >= max_bytes)
       bytes = max_bytes;
     else
       bytes = len;
