@@ -27,16 +27,134 @@
 #include "libts.h"
 #include "I_Thread.h"
 
-#define MAX_LOCK_TIME	HRTIME_MSECONDS(200)
-#define THREAD_MUTEX_THREAD_HOLDING	(-1024*1024)
+#define MAX_LOCK_TIME HRTIME_MSECONDS(200)
+#define THREAD_MUTEX_THREAD_HOLDING (-1024 * 1024)
+
+/*------------------------------------------------------*\
+|  Macros                                                |
+\*------------------------------------------------------*/
+
+/**
+  Blocks until the lock to the ProxyMutex is acquired.
+
+  This macro performs a blocking call until the lock to the ProxyMutex
+  is acquired. This call allocates a special object that holds the
+  lock to the ProxyMutex only for the scope of the function or
+  region. It is a good practice to delimit such scope explicitly
+  with '&#123;' and '&#125;'.
+
+  @param _l Arbitrary name for the lock to use in this call
+  @param _m A pointer to (or address of) a ProxyMutex object
+  @param _t The current EThread executing your code.
+
+*/
+#ifdef DEBUG
+#define MUTEX_LOCK(_l, _m, _t) MutexLock _l(DiagsMakeLocation(), NULL, _m, _t)
+#else
+#define MUTEX_LOCK(_l, _m, _t) MutexLock _l(_m, _t)
+#endif // DEBUG
+
+#ifdef DEBUG
+/**
+  Attempts to acquire the lock to the ProxyMutex.
+
+  This macro attempts to acquire the lock to the specified ProxyMutex
+  object in a non-blocking manner. After using the macro you can
+  see if it was successful by comparing the lock variable with true
+  or false (the variable name passed in the _l parameter).
+
+  @param _l Arbitrary name for the lock to use in this call (lock variable)
+  @param _m A pointer to (or address of) a ProxyMutex object
+  @param _t The current EThread executing your code.
+
+*/
+#define MUTEX_TRY_LOCK(_l, _m, _t) MutexTryLock _l(DiagsMakeLocation(), (char *)NULL, _m, _t)
+
+/**
+  Attempts to acquire the lock to the ProxyMutex.
+
+  This macro performs up to the specified number of attempts to
+  acquire the lock on the ProxyMutex object. It does so by running
+  a busy loop (busy wait) '_sc' times. You should use it with care
+  since it blocks the thread during that time and wastes CPU time.
+
+  @param _l Arbitrary name for the lock to use in this call (lock variable)
+  @param _m A pointer to (or address of) a ProxyMutex object
+  @param _t The current EThread executing your code.
+  @param _sc The number of attempts or spin count. It must be a positive value.
+
+*/
+#define MUTEX_TRY_LOCK_SPIN(_l, _m, _t, _sc) MutexTryLock _l(DiagsMakeLocation(), (char *)NULL, _m, _t, _sc)
+
+/**
+  Attempts to acquire the lock to the ProxyMutex.
+
+  This macro attempts to acquire the lock to the specified ProxyMutex
+  object in a non-blocking manner. After using the macro you can
+  see if it was successful by comparing the lock variable with true
+  or false (the variable name passed in the _l parameter).
+
+  @param _l Arbitrary name for the lock to use in this call (lock variable)
+  @param _m A pointer to (or address of) a ProxyMutex object
+  @param _t The current EThread executing your code.
+  @param _c Continuation whose mutex will be attempted to lock.
+
+*/
+
+#define MUTEX_TRY_LOCK_FOR(_l, _m, _t, _c) MutexTryLock _l(DiagsMakeLocation(), NULL, _m, _t)
+#else // DEBUG
+#define MUTEX_TRY_LOCK(_l, _m, _t) MutexTryLock _l(_m, _t)
+#define MUTEX_TRY_LOCK_SPIN(_l, _m, _t, _sc) MutexTryLock _l(_m, _t, _sc)
+#define MUTEX_TRY_LOCK_FOR(_l, _m, _t, _c) MutexTryLock _l(_m, _t)
+#endif // DEBUG
+
+/**
+  Releases the lock on a ProxyMutex.
+
+  This macro releases the lock on the ProxyMutex, provided it is
+  currently held. The lock must have been successfully acquired
+  with one of the MUTEX macros.
+
+  @param _l Arbitrary name for the lock to use in this call (lock
+    variable) It must be the same name as the one used to acquire the
+    lock.
+
+*/
+#define MUTEX_RELEASE(_l) (_l).release()
+
+/////////////////////////////////////
+// DEPRECATED DEPRECATED DEPRECATED
+#ifdef DEBUG
+#define MUTEX_TAKE_TRY_LOCK(_m, _t) Mutex_trylock(DiagsMakeLocation(), (char *)NULL, _m, _t)
+#define MUTEX_TAKE_TRY_LOCK_FOR(_m, _t, _c) Mutex_trylock(DiagsMakeLocation(), (char *)NULL, _m, _t)
+#define MUTEX_TAKE_TRY_LOCK_FOR_SPIN(_m, _t, _c, _sc) Mutex_trylock_spin(DiagsMakeLocation(), NULL, _m, _t, _sc)
+#else
+#define MUTEX_TAKE_TRY_LOCK(_m, _t) Mutex_trylock(_m, _t)
+#define MUTEX_TAKE_TRY_LOCK_FOR(_m, _t, _c) Mutex_trylock(_m, _t)
+#define MUTEX_TAKE_TRY_LOCK_FOR_SPIN(_m, _t, _c, _sc) Mutex_trylock_spin(_m, _t, _sc)
+#endif
+
+#ifdef DEBUG
+#define MUTEX_TAKE_LOCK(_m, _t) Mutex_lock(DiagsMakeLocation(), (char *)NULL, _m, _t)
+#define MUTEX_TAKE_LOCK_FOR(_m, _t, _c) Mutex_lock(DiagsMakeLocation(), NULL, _m, _t)
+#else
+#define MUTEX_TAKE_LOCK(_m, _t) Mutex_lock(_m, _t)
+#define MUTEX_TAKE_LOCK_FOR(_m, _t, _c) Mutex_lock(_m, _t)
+#endif // DEBUG
+
+#define MUTEX_UNTAKE_LOCK(_m, _t) Mutex_unlock(_m, _t)
+// DEPRECATED DEPRECATED DEPRECATED
+/////////////////////////////////////
 
 class EThread;
 typedef EThread *EThreadPtr;
 typedef volatile EThreadPtr VolatileEThreadPtr;
 
-inkcoreapi extern void lock_waiting(const char *file, int line, const char *handler);
-inkcoreapi extern void lock_holding(const char *file, int line, const char *handler);
-extern void lock_taken(const char *file, int line, const char *handler);
+#if DEBUG
+inkcoreapi extern void lock_waiting(const SrcLoc &, const char *handler);
+inkcoreapi extern void lock_holding(const SrcLoc &, const char *handler);
+inkcoreapi extern void lock_taken(const SrcLoc &, const char *handler);
+#endif
 
 /**
   Lock object used in continuations and threads.
@@ -64,7 +182,7 @@ extern void lock_taken(const char *file, int line, const char *handler);
   allow you to lock/unlock the underlying mutex object.
 
 */
-class ProxyMutex: public RefCountObj
+class ProxyMutex : public RefCountObj
 {
 public:
   /**
@@ -85,25 +203,23 @@ public:
 
   */
   volatile EThreadPtr thread_holding;
-  
+
   int nthread_holding;
 
 #ifdef DEBUG
   ink_hrtime hold_time;
-  const char *file;
-  int line;
+  SrcLoc srcloc;
   const char *handler;
 
-#  ifdef MAX_LOCK_TAKEN
+#ifdef MAX_LOCK_TAKEN
   int taken;
-#  endif                        //MAX_LOCK_TAKEN
+#endif // MAX_LOCK_TAKEN
 
-#  ifdef LOCK_CONTENTION_PROFILING
-  int total_acquires, blocking_acquires,
-    nonblocking_acquires, successful_nonblocking_acquires, unsuccessful_nonblocking_acquires;
+#ifdef LOCK_CONTENTION_PROFILING
+  int total_acquires, blocking_acquires, nonblocking_acquires, successful_nonblocking_acquires, unsuccessful_nonblocking_acquires;
   void print_lock_stats(int flag);
-#  endif                        //LOCK_CONTENTION_PROFILING
-#endif                          //DEBUG
+#endif // LOCK_CONTENTION_PROFILING
+#endif // DEBUG
   void free();
 
   /**
@@ -117,25 +233,26 @@ public:
 
   */
   ProxyMutex()
+#ifdef DEBUG
+    : srcloc(NULL, NULL, 0)
+#endif
   {
     thread_holding = NULL;
     nthread_holding = 0;
 #ifdef DEBUG
     hold_time = 0;
-    file = NULL;
-    line = 0;
     handler = NULL;
-#  ifdef MAX_LOCK_TAKEN
+#ifdef MAX_LOCK_TAKEN
     taken = 0;
-#  endif                        //MAX_LOCK_TAKEN
-#  ifdef LOCK_CONTENTION_PROFILING
+#endif // MAX_LOCK_TAKEN
+#ifdef LOCK_CONTENTION_PROFILING
     total_acquires = 0;
     blocking_acquires = 0;
     nonblocking_acquires = 0;
     successful_nonblocking_acquires = 0;
     unsuccessful_nonblocking_acquires = 0;
-#  endif                        //LOCK_CONTENTION_PROFILING
-#endif                          //DEBUG
+#endif // LOCK_CONTENTION_PROFILING
+#endif // DEBUG
     // coverity[uninit_member]
   }
 
@@ -149,7 +266,9 @@ public:
       on the given platform.
 
   */
-  void init(const char *name = "UnnamedMutex") {
+  void
+  init(const char *name = "UnnamedMutex")
+  {
     ink_mutex_init(&the_mutex, name);
   }
 };
@@ -160,36 +279,34 @@ extern inkcoreapi ClassAllocator<ProxyMutex> mutexAllocator;
 inline bool
 Mutex_trylock(
 #ifdef DEBUG
-               const char *afile, int aline, const char *ahandler,
+  const SrcLoc &location, const char *ahandler,
 #endif
-               ProxyMutex * m, EThread * t)
+  ProxyMutex *m, EThread *t)
 {
-
   ink_assert(t != 0);
-  ink_assert(t == (EThread*)this_thread());
+  ink_assert(t == (EThread *)this_thread());
   if (m->thread_holding != t) {
     if (!ink_mutex_try_acquire(&m->the_mutex)) {
 #ifdef DEBUG
-      lock_waiting(m->file, m->line, m->handler);
+      lock_waiting(m->srcloc, m->handler);
 #ifdef LOCK_CONTENTION_PROFILING
       m->unsuccessful_nonblocking_acquires++;
       m->nonblocking_acquires++;
       m->total_acquires++;
       m->print_lock_stats(0);
-#endif //LOCK_CONTENTION_PROFILING
-#endif //DEBUG
+#endif // LOCK_CONTENTION_PROFILING
+#endif // DEBUG
       return false;
     }
-    ink_assert(m->thread_holding = t);
+    m->thread_holding = t;
 #ifdef DEBUG
-    m->file = afile;
-    m->line = aline;
+    m->srcloc = location;
     m->handler = ahandler;
     m->hold_time = ink_get_hrtime();
 #ifdef MAX_LOCK_TAKEN
     m->taken++;
-#endif //MAX_LOCK_TAKEN
-#endif //DEBUG
+#endif // MAX_LOCK_TAKEN
+#endif // DEBUG
   }
 #ifdef DEBUG
 #ifdef LOCK_CONTENTION_PROFILING
@@ -197,8 +314,8 @@ Mutex_trylock(
   m->nonblocking_acquires++;
   m->total_acquires++;
   m->print_lock_stats(0);
-#endif //LOCK_CONTENTION_PROFILING
-#endif //DEBUG
+#endif // LOCK_CONTENTION_PROFILING
+#endif // DEBUG
   m->nthread_holding++;
   return true;
 }
@@ -206,11 +323,10 @@ Mutex_trylock(
 inline bool
 Mutex_trylock_spin(
 #ifdef DEBUG
-                    const char *afile, int aline, const char *ahandler,
+  const SrcLoc &location, const char *ahandler,
 #endif
-                    ProxyMutex * m, EThread * t, int spincnt = 1)
+  ProxyMutex *m, EThread *t, int spincnt = 1)
 {
-
   ink_assert(t != 0);
   if (m->thread_holding != t) {
     int locked;
@@ -220,27 +336,26 @@ Mutex_trylock_spin(
     } while (--spincnt);
     if (!locked) {
 #ifdef DEBUG
-      lock_waiting(m->file, m->line, m->handler);
+      lock_waiting(m->srcloc, m->handler);
 #ifdef LOCK_CONTENTION_PROFILING
       m->unsuccessful_nonblocking_acquires++;
       m->nonblocking_acquires++;
       m->total_acquires++;
       m->print_lock_stats(0);
-#endif //LOCK_CONTENTION_PROFILING
-#endif //DEBUG
+#endif // LOCK_CONTENTION_PROFILING
+#endif // DEBUG
       return false;
     }
     m->thread_holding = t;
     ink_assert(m->thread_holding);
 #ifdef DEBUG
-    m->file = afile;
-    m->line = aline;
+    m->srcloc = location;
     m->handler = ahandler;
     m->hold_time = ink_get_hrtime();
 #ifdef MAX_LOCK_TAKEN
     m->taken++;
-#endif //MAX_LOCK_TAKEN
-#endif //DEBUG
+#endif // MAX_LOCK_TAKEN
+#endif // DEBUG
   }
 #ifdef DEBUG
 #ifdef LOCK_CONTENTION_PROFILING
@@ -248,8 +363,8 @@ Mutex_trylock_spin(
   m->nonblocking_acquires++;
   m->total_acquires++;
   m->print_lock_stats(0);
-#endif //LOCK_CONTENTION_PROFILING
-#endif //DEBUG
+#endif // LOCK_CONTENTION_PROFILING
+#endif // DEBUG
   m->nthread_holding++;
   return true;
 }
@@ -257,25 +372,23 @@ Mutex_trylock_spin(
 inline int
 Mutex_lock(
 #ifdef DEBUG
-            const char *afile, int aline, const char *ahandler,
+  const SrcLoc &location, const char *ahandler,
 #endif
-            ProxyMutex * m, EThread * t)
+  ProxyMutex *m, EThread *t)
 {
-
   ink_assert(t != 0);
   if (m->thread_holding != t) {
     ink_mutex_acquire(&m->the_mutex);
     m->thread_holding = t;
     ink_assert(m->thread_holding);
 #ifdef DEBUG
-    m->file = afile;
-    m->line = aline;
+    m->srcloc = location;
     m->handler = ahandler;
     m->hold_time = ink_get_hrtime();
 #ifdef MAX_LOCK_TAKEN
     m->taken++;
-#endif //MAX_LOCK_TAKEN
-#endif //DEBUG
+#endif // MAX_LOCK_TAKEN
+#endif // DEBUG
   }
 #ifdef DEBUG
 #ifdef LOCK_CONTENTION_PROFILING
@@ -283,13 +396,13 @@ Mutex_lock(
   m->total_acquires++;
   m->print_lock_stats(0);
 #endif // LOCK_CONTENTION_PROFILING
-#endif //DEBUG
+#endif // DEBUG
   m->nthread_holding++;
   return true;
 }
 
 inline void
-Mutex_unlock(ProxyMutex * m, EThread * t)
+Mutex_unlock(ProxyMutex *m, EThread *t)
 {
   if (m->nthread_holding) {
     ink_assert(t == m->thread_holding);
@@ -297,15 +410,14 @@ Mutex_unlock(ProxyMutex * m, EThread * t)
     if (!m->nthread_holding) {
 #ifdef DEBUG
       if (ink_get_hrtime() - m->hold_time > MAX_LOCK_TIME)
-        lock_holding(m->file, m->line, m->handler);
+        lock_holding(m->srcloc, m->handler);
 #ifdef MAX_LOCK_TAKEN
       if (m->taken > MAX_LOCK_TAKEN)
-        lock_taken(m->file, m->line, m->handler);
-#endif //MAX_LOCK_TAKEN
-      m->file = NULL;
-      m->line = 0;
+        lock_taken(m->srcloc, m->handler);
+#endif // MAX_LOCK_TAKEN
+      m->srcloc = SrcLoc(NULL, NULL, 0);
       m->handler = NULL;
-#endif //DEBUG
+#endif // DEBUG
       ink_assert(m->thread_holding);
       m->thread_holding = 0;
       ink_mutex_release(&m->the_mutex);
@@ -313,112 +425,103 @@ Mutex_unlock(ProxyMutex * m, EThread * t)
   }
 }
 
-struct MutexLock
+/** Scoped lock class for ProxyMutex
+ */
+class MutexLock
 {
+private:
   Ptr<ProxyMutex> m;
 
-  MutexLock():m(NULL)
-  {
-  };
-
+public:
   MutexLock(
 #ifdef DEBUG
-             const char *afile, int aline, const char *ahandler,
-#endif                          //DEBUG
-             ProxyMutex * am, EThread * t):m(am)
+    const SrcLoc &location, const char *ahandler,
+#endif // DEBUG
+    ProxyMutex *am, EThread *t)
+    : m(am)
   {
-
     Mutex_lock(
 #ifdef DEBUG
-                afile, aline, ahandler,
-#endif //DEBUG
-                m, t);
+      location, ahandler,
+#endif // DEBUG
+      m, t);
   }
 
-  void set_and_take(
-#ifdef DEBUG
-                     const char *afile, int aline, const char *ahandler,
-#endif                          //DEBUG
-                     ProxyMutex * am, EThread * t)
-  {
-
-    m = am;
-    Mutex_lock(
-#ifdef DEBUG
-                afile, aline, ahandler,
-#endif //DEBUG
-                m, t);
-  }
-
-  void release()
-  {
-    if (m)
-      Mutex_unlock(m, m->thread_holding);
-    m.clear();
-  }
-
-  ~MutexLock()
-  {
-    if (m)
-      Mutex_unlock(m, m->thread_holding);
-  }
-
-  int operator!() const { return false; }
-  operator bool() { return true; }
+  ~MutexLock() { Mutex_unlock(m, m->thread_holding); }
 };
 
-struct MutexTryLock
+/** Scoped try lock class for ProxyMutex
+ */
+class MutexTryLock
 {
+private:
   Ptr<ProxyMutex> m;
-  volatile bool lock_acquired;
+  bool lock_acquired;
 
+public:
   MutexTryLock(
 #ifdef DEBUG
-                  const char *afile, int aline, const char *ahandler,
-#endif                          //DEBUG
-                  ProxyMutex * am, EThread * t)
+    const SrcLoc &location, const char *ahandler,
+#endif // DEBUG
+    ProxyMutex *am, EThread *t)
+    : m(am)
   {
-      lock_acquired = Mutex_trylock(
+    lock_acquired = Mutex_trylock(
 #ifdef DEBUG
-                                     afile, aline, ahandler,
-#endif //DEBUG
-                                     am, t);
-      if (lock_acquired)
-        m = am;
+      location, ahandler,
+#endif // DEBUG
+      m, t);
   }
 
   MutexTryLock(
 #ifdef DEBUG
-                const char *afile, int aline, const char *ahandler,
-#endif                          //DEBUG
-                ProxyMutex * am, EThread * t, int sp)
+    const SrcLoc &location, const char *ahandler,
+#endif // DEBUG
+    ProxyMutex *am, EThread *t, int sp)
+    : m(am)
   {
-      lock_acquired = Mutex_trylock_spin(
+    lock_acquired = Mutex_trylock_spin(
 #ifdef DEBUG
-                                          afile, aline, ahandler,
-#endif //DEBUG
-                                          am, t, sp);
-      if (lock_acquired)
-        m = am;
+      location, ahandler,
+#endif // DEBUG
+      m, t, sp);
   }
 
   ~MutexTryLock()
   {
-    if (m.m_ptr)
+    if (lock_acquired)
       Mutex_unlock(m.m_ptr, m.m_ptr->thread_holding);
   }
 
-  void release()
+  /** Spin till lock is acquired
+   */
+  void
+  acquire(EThread *t)
   {
-    if (m.m_ptr) {
+    MUTEX_TAKE_LOCK(m.m_ptr, t);
+    lock_acquired = true;
+  }
+
+  void
+  release()
+  {
+    ink_assert(lock_acquired); // generate a warning because it shouldn't be done.
+    if (lock_acquired) {
       Mutex_unlock(m.m_ptr, m.m_ptr->thread_holding);
-      m.clear();
     }
     lock_acquired = false;
   }
 
-  int operator!() const { return !lock_acquired; }
-  operator bool() const { return lock_acquired; }
+  bool
+  is_locked() const
+  {
+    return lock_acquired;
+  }
+  const ProxyMutex *
+  get_mutex()
+  {
+    return m.m_ptr;
+  }
 };
 
 inline void
@@ -453,133 +556,4 @@ new_ProxyMutex()
   return m;
 }
 
-/*------------------------------------------------------*\
-|  Macros                                                |
-\*------------------------------------------------------*/
-
-/**
-  Blocks until the lock to the ProxyMutex is acquired.
-
-  This macro performs a blocking call until the lock to the ProxyMutex
-  is acquired. This call allocates a special object that holds the
-  lock to the ProxyMutex only for the scope of the function or
-  region. It is a good practice to delimit such scope explicitly
-  with '&#123;' and '&#125;'.
-
-  @param _l Arbitrary name for the lock to use in this call
-  @param _m A pointer to (or address of) a ProxyMutex object
-  @param _t The current EThread executing your code.
-
-*/
-#  ifdef DEBUG
-#    define MUTEX_LOCK(_l,_m,_t) MutexLock _l(__FILE__,__LINE__,NULL,_m,_t)
-#  else
-#    define MUTEX_LOCK(_l,_m,_t) MutexLock _l(_m,_t)
-#  endif //DEBUG
-
-#  ifdef DEBUG
-/**
-  Attempts to acquire the lock to the ProxyMutex.
-
-  This macro attempts to acquire the lock to the specified ProxyMutex
-  object in a non-blocking manner. After using the macro you can
-  see if it was successful by comparing the lock variable with true
-  or false (the variable name passed in the _l parameter).
-
-  @param _l Arbitrary name for the lock to use in this call (lock variable)
-  @param _m A pointer to (or address of) a ProxyMutex object
-  @param _t The current EThread executing your code.
-
-*/
-#    define MUTEX_TRY_LOCK(_l,_m,_t) \
-MutexTryLock _l(__FILE__,__LINE__,(char*)NULL,_m,_t)
-
-/**
-  Attempts to acquire the lock to the ProxyMutex.
-
-  This macro performs up to the specified number of attempts to
-  acquire the lock on the ProxyMutex object. It does so by running
-  a busy loop (busy wait) '_sc' times. You should use it with care
-  since it blocks the thread during that time and wastes CPU time.
-
-  @param _l Arbitrary name for the lock to use in this call (lock variable)
-  @param _m A pointer to (or address of) a ProxyMutex object
-  @param _t The current EThread executing your code.
-  @param _sc The number of attempts or spin count. It must be a positive value.
-
-*/
-#    define MUTEX_TRY_LOCK_SPIN(_l,_m,_t,_sc) \
-MutexTryLock _l(__FILE__,__LINE__,(char*)NULL,_m,_t,_sc)
-
-
-/**
-  Attempts to acquire the lock to the ProxyMutex.
-
-  This macro attempts to acquire the lock to the specified ProxyMutex
-  object in a non-blocking manner. After using the macro you can
-  see if it was successful by comparing the lock variable with true
-  or false (the variable name passed in the _l parameter).
-
-  @param _l Arbitrary name for the lock to use in this call (lock variable)
-  @param _m A pointer to (or address of) a ProxyMutex object
-  @param _t The current EThread executing your code.
-  @param _c Continuation whose mutex will be attempted to lock.
-
-*/
-
-#    define MUTEX_TRY_LOCK_FOR(_l,_m,_t,_c) \
-MutexTryLock _l(__FILE__,__LINE__,NULL,_m,_t)
-#  else //DEBUG
-#    define MUTEX_TRY_LOCK(_l,_m,_t) MutexTryLock _l(_m,_t)
-#    define MUTEX_TRY_LOCK_SPIN(_l,_m,_t,_sc) MutexTryLock _l(_m,_t,_sc)
-#    define MUTEX_TRY_LOCK_FOR(_l,_m,_t,_c) MutexTryLock _l(_m,_t)
-#  endif //DEBUG
-
-/**
-  Releases the lock on a ProxyMutex.
-
-  This macro releases the lock on the ProxyMutex, provided it is
-  currently held. The lock must have been successfully acquired
-  with one of the MUTEX macros.
-
-  @param _l Arbitrary name for the lock to use in this call (lock
-    variable) It must be the same name as the one used to acquire the
-    lock.
-
-*/
-#  define MUTEX_RELEASE(_l) (_l).release()
-
-/////////////////////////////////////
-// DEPRECATED DEPRECATED DEPRECATED
-#ifdef DEBUG
-#  define MUTEX_TAKE_TRY_LOCK(_m,_t) \
-Mutex_trylock(__FILE__,__LINE__,(char*)NULL,_m,_t)
-#  define MUTEX_TAKE_TRY_LOCK_FOR(_m,_t,_c) \
-Mutex_trylock(__FILE__,__LINE__,(char*)NULL,_m,_t)
-#  define MUTEX_TAKE_TRY_LOCK_FOR_SPIN(_m,_t,_c,_sc) \
-Mutex_trylock_spin(__FILE__,__LINE__,NULL,_m,_t,_sc)
-#else
-#  define MUTEX_TAKE_TRY_LOCK(_m,_t) Mutex_trylock(_m,_t)
-#  define MUTEX_TAKE_TRY_LOCK_FOR(_m,_t,_c) Mutex_trylock(_m,_t)
-#  define MUTEX_TAKE_TRY_LOCK_FOR_SPIN(_m,_t,_c,_sc) \
-Mutex_trylock_spin(_m,_t,_sc)
-#endif
-
-#ifdef DEBUG
-#  define MUTEX_TAKE_LOCK(_m,_t)\
-Mutex_lock(__FILE__,__LINE__,(char*)NULL,_m,_t)
-#  define MUTEX_SET_AND_TAKE_LOCK(_s,_m,_t)\
-_s.set_and_take(__FILE__,__LINE__,(char*)NULL,_m,_t)
-#  define MUTEX_TAKE_LOCK_FOR(_m,_t,_c) \
-Mutex_lock(__FILE__,__LINE__,NULL,_m,_t)
-#else
-#  define MUTEX_TAKE_LOCK(_m,_t) Mutex_lock(_m,_t)
-#  define MUTEX_SET_AND_TAKE_LOCK(_s,_m,_t)_s.set_and_take(_m,_t)
-#  define MUTEX_TAKE_LOCK_FOR(_m,_t,_c) Mutex_lock(_m,_t)
-#endif //DEBUG
-
-#define MUTEX_UNTAKE_LOCK(_m,_t) Mutex_unlock(_m,_t)
-// DEPRECATED DEPRECATED DEPRECATED
-/////////////////////////////////////
-
 #endif // _Lock_h_
