@@ -31,75 +31,68 @@
 // NUMA socket affinity. We'll potentially return these on an arbitarily
 // selected processor/socket.
 
-template<class C> struct DeleterContinuation: public Continuation
-{
-public:                        // Needed by WinNT compiler (compiler bug)
-  C * p;
-  int dieEvent(int event, void *e)
+template <class C> struct DeleterContinuation : public Continuation {
+public: // Needed by WinNT compiler (compiler bug)
+  C *p;
+  int
+  dieEvent(int event, void *e)
   {
-    (void) event;
-    (void) e;
+    (void)event;
+    (void)e;
     if (p)
       delete p;
     delete this;
-      return EVENT_DONE;
-  }
-  DeleterContinuation(C * ap):Continuation(new_ProxyMutex()), p(ap)
-  {
-    SET_HANDLER(&DeleterContinuation::dieEvent);
+    return EVENT_DONE;
   }
+  DeleterContinuation(C *ap) : Continuation(new_ProxyMutex()), p(ap) { SET_HANDLER(&DeleterContinuation::dieEvent); }
 };
 
-template<class C> TS_INLINE void
-new_Deleter(C * ap, ink_hrtime t)
+template <class C>
+TS_INLINE void
+new_Deleter(C *ap, ink_hrtime t)
 {
-  eventProcessor.schedule_in(new DeleterContinuation<C> (ap), t, ET_TASK);
+  eventProcessor.schedule_in(new DeleterContinuation<C>(ap), t, ET_TASK);
 }
 
-template<class C> struct FreeCallContinuation: public Continuation
-{
-public:                        // Needed by WinNT compiler (compiler bug)
-  C * p;
-  int dieEvent(int event, void *e)
+template <class C> struct FreeCallContinuation : public Continuation {
+public: // Needed by WinNT compiler (compiler bug)
+  C *p;
+  int
+  dieEvent(int event, void *e)
   {
-    (void) event;
-    (void) e;
+    (void)event;
+    (void)e;
     p->free();
     delete this;
-      return EVENT_DONE;
-  }
-  FreeCallContinuation(C * ap):Continuation(NULL), p(ap)
-  {
-    SET_HANDLER(&FreeCallContinuation::dieEvent);
+    return EVENT_DONE;
   }
+  FreeCallContinuation(C *ap) : Continuation(NULL), p(ap) { SET_HANDLER(&FreeCallContinuation::dieEvent); }
 };
 
-template<class C> TS_INLINE void
-new_FreeCaller(C * ap, ink_hrtime t)
+template <class C>
+TS_INLINE void
+new_FreeCaller(C *ap, ink_hrtime t)
 {
-  eventProcessor.schedule_in(new FreeCallContinuation<C> (ap), t, ET_TASK);
+  eventProcessor.schedule_in(new FreeCallContinuation<C>(ap), t, ET_TASK);
 }
 
 struct FreerContinuation;
-typedef int (FreerContinuation::*FreerContHandler) (int, void *);
+typedef int (FreerContinuation::*FreerContHandler)(int, void *);
 
-struct FreerContinuation: public Continuation
-{
+struct FreerContinuation : public Continuation {
   void *p;
 
-  int dieEvent(int event, Event * e)
+  int
+  dieEvent(int event, Event *e)
   {
-    (void) event;
-    (void) e;
+    (void)event;
+    (void)e;
     ats_free(p);
     delete this;
     return EVENT_DONE;
   }
 
-  FreerContinuation(void *ap):Continuation(NULL), p(ap)
-  {
-    SET_HANDLER((FreerContHandler) & FreerContinuation::dieEvent);
-  }
+  FreerContinuation(void *ap) : Continuation(NULL), p(ap) { SET_HANDLER((FreerContHandler)&FreerContinuation::dieEvent); }
 };
 
 TS_INLINE void
@@ -108,11 +101,11 @@ new_Freer(void *ap, ink_hrtime t)
   eventProcessor.schedule_in(new FreerContinuation(ap), t, ET_TASK);
 }
 
-template<class C> struct DereferContinuation: public Continuation
-{
+template <class C> struct DereferContinuation : public Continuation {
   C *p;
 
-  int dieEvent(int, Event *)
+  int
+  dieEvent(int, Event *)
   {
     p->refcount_dec();
     if (REF_COUNT_OBJ_REFCOUNT_DEC(p) == 0) {
@@ -123,16 +116,14 @@ template<class C> struct DereferContinuation: public Continuation
     return EVENT_DONE;
   }
 
-  DereferContinuation(C * ap):Continuation(NULL), p(ap)
-  {
-    SET_HANDLER(&DereferContinuation::dieEvent);
-  }
+  DereferContinuation(C *ap) : Continuation(NULL), p(ap) { SET_HANDLER(&DereferContinuation::dieEvent); }
 };
 
-template<class C> TS_INLINE void
-new_Derefer(C * ap, ink_hrtime t)
+template <class C>
+TS_INLINE void
+new_Derefer(C *ap, ink_hrtime t)
 {
-  eventProcessor.schedule_in(new DereferContinuation<C> (ap), t, ET_TASK);
+  eventProcessor.schedule_in(new DereferContinuation<C>(ap), t, ET_TASK);
 }
 
 #endif /* _Freer_h_ */
