@@ -47,32 +47,30 @@
 
 #define NET_SYSTEM_MODULE_MAJOR_VERSION 1
 #define NET_SYSTEM_MODULE_MINOR_VERSION 0
-#define NET_SYSTEM_MODULE_VERSION makeModuleVersion(                 \
-                                    NET_SYSTEM_MODULE_MAJOR_VERSION, \
-                                    NET_SYSTEM_MODULE_MINOR_VERSION, \
-                                    PUBLIC_MODULE_HEADER)
+#define NET_SYSTEM_MODULE_VERSION \
+  makeModuleVersion(NET_SYSTEM_MODULE_MAJOR_VERSION, NET_SYSTEM_MODULE_MINOR_VERSION, PUBLIC_MODULE_HEADER)
 
 static int const NO_FD = -1;
 
 extern int net_config_poll_timeout;
 
-#define NET_EVENT_OPEN                    (NET_EVENT_EVENTS_START)
-#define NET_EVENT_OPEN_FAILED             (NET_EVENT_EVENTS_START+1)
-#define NET_EVENT_ACCEPT                  (NET_EVENT_EVENTS_START+2)
-#define NET_EVENT_ACCEPT_SUCCEED          (NET_EVENT_EVENTS_START+3)
-#define NET_EVENT_ACCEPT_FAILED           (NET_EVENT_EVENTS_START+4)
-#define NET_EVENT_CANCEL                  (NET_EVENT_EVENTS_START+5)
-#define NET_EVENT_DATAGRAM_READ_COMPLETE  (NET_EVENT_EVENTS_START+6)
-#define NET_EVENT_DATAGRAM_READ_ERROR     (NET_EVENT_EVENTS_START+7)
-#define NET_EVENT_DATAGRAM_WRITE_COMPLETE (NET_EVENT_EVENTS_START+8)
-#define NET_EVENT_DATAGRAM_WRITE_ERROR    (NET_EVENT_EVENTS_START+9)
-#define NET_EVENT_DATAGRAM_READ_READY     (NET_EVENT_EVENTS_START+10)
-#define NET_EVENT_DATAGRAM_OPEN           (NET_EVENT_EVENTS_START+11)
-#define NET_EVENT_DATAGRAM_ERROR          (NET_EVENT_EVENTS_START+12)
-#define NET_EVENT_ACCEPT_INTERNAL         (NET_EVENT_EVENTS_START+22)
-#define NET_EVENT_CONNECT_INTERNAL        (NET_EVENT_EVENTS_START+23)
+#define NET_EVENT_OPEN (NET_EVENT_EVENTS_START)
+#define NET_EVENT_OPEN_FAILED (NET_EVENT_EVENTS_START + 1)
+#define NET_EVENT_ACCEPT (NET_EVENT_EVENTS_START + 2)
+#define NET_EVENT_ACCEPT_SUCCEED (NET_EVENT_EVENTS_START + 3)
+#define NET_EVENT_ACCEPT_FAILED (NET_EVENT_EVENTS_START + 4)
+#define NET_EVENT_CANCEL (NET_EVENT_EVENTS_START + 5)
+#define NET_EVENT_DATAGRAM_READ_COMPLETE (NET_EVENT_EVENTS_START + 6)
+#define NET_EVENT_DATAGRAM_READ_ERROR (NET_EVENT_EVENTS_START + 7)
+#define NET_EVENT_DATAGRAM_WRITE_COMPLETE (NET_EVENT_EVENTS_START + 8)
+#define NET_EVENT_DATAGRAM_WRITE_ERROR (NET_EVENT_EVENTS_START + 9)
+#define NET_EVENT_DATAGRAM_READ_READY (NET_EVENT_EVENTS_START + 10)
+#define NET_EVENT_DATAGRAM_OPEN (NET_EVENT_EVENTS_START + 11)
+#define NET_EVENT_DATAGRAM_ERROR (NET_EVENT_EVENTS_START + 12)
+#define NET_EVENT_ACCEPT_INTERNAL (NET_EVENT_EVENTS_START + 22)
+#define NET_EVENT_CONNECT_INTERNAL (NET_EVENT_EVENTS_START + 23)
 
-#define MAIN_ACCEPT_PORT                  -1
+#define MAIN_ACCEPT_PORT -1
 
 /*
  * Net system uses event threads
