@@ -27,24 +27,17 @@
 #include "I_Net.h"
 #include "I_VConnection.h"
 
-class SessionAccept: public Continuation
+class SessionAccept : public Continuation
 {
 public:
-  SessionAccept(ProxyMutex *amutex);
-  ~SessionAccept();
+  SessionAccept(ProxyMutex *amutex) : Continuation(amutex) { SET_HANDLER(&SessionAccept::mainEvent); }
+
+  ~SessionAccept() {}
 
   virtual void accept(NetVConnection *, MIOBuffer *, IOBufferReader *) = 0;
 
-  // Virtual function allows creation of an SSLNetAccept
-  // or NetAccept transparent to NetProcessor.
-  //
-  // This function should return a pointer
-  // of NetAccept or its subclass.
-  //
-  virtual void *createNetAccept();
-
 private:
-  virtual int mainEvent(int event, void * netvc) = 0;
+  virtual int mainEvent(int event, void *netvc) = 0;
 };
 
 #endif /* I_SessionAccept_H_ */
