@@ -31,53 +31,43 @@
 #define SOCKS_WITH_TS
 
 
-#define SOCKS_DEFAULT_VERSION 0 //defined the configuration variable
-#define SOCKS4_VERSION  4
+#define SOCKS_DEFAULT_VERSION 0 // defined the configuration variable
+#define SOCKS4_VERSION 4
 #define SOCKS5_VERSION 5
-#define SOCKS_CONNECT  1
-#define SOCKS4_REQ_LEN  9
-#define SOCKS4_REP_LEN  8
-#define SOCKS5_REP_LEN 262      //maximum possible
+#define SOCKS_CONNECT 1
+#define SOCKS4_REQ_LEN 9
+#define SOCKS4_REP_LEN 8
+#define SOCKS5_REP_LEN 262 // maximum possible
 #define SOCKS4_REQ_GRANTED 90
 #define SOCKS4_CONN_FAILED 91
 #define SOCKS5_REQ_GRANTED 0
 #define SOCKS5_CONN_FAILED 1
 
-enum
-{
-  //For these two, we need to pick two values which are not used for any of the
+enum {
+  // For these two, we need to pick two values which are not used for any of the
   //"commands" (eg: CONNECT, BIND) in SOCKS protocols.
   NORMAL_SOCKS = 0,
   NO_SOCKS = 48
 };
 
-enum
-{
+enum {
   SOCKS_ATYPE_NONE = 0,
   SOCKS_ATYPE_IPV4 = 1,
   SOCKS_ATYPE_FQHN = 3,
-  SOCKS_ATYPE_IPV6 = 4
+  SOCKS_ATYPE_IPV6 = 4,
 };
 
-struct SocksAddrType
-{
+struct SocksAddrType {
   unsigned char type;
-  union
-  {
-    //mostly it is ipv4. in other cases we will xalloc().
+  union {
+    // mostly it is ipv4. in other cases we will xalloc().
     unsigned char ipv4[4];
     unsigned char *buf;
   } addr;
 
   void reset();
-    SocksAddrType():type(SOCKS_ATYPE_NONE)
-  {
-    addr.buf = 0;
-  }
-   ~SocksAddrType()
-  {
-    reset();
-  }
+  SocksAddrType() : type(SOCKS_ATYPE_NONE) { addr.buf = 0; }
+  ~SocksAddrType() { reset(); }
 };
 
 #endif
