@@ -36,7 +36,7 @@ extern EventType ET_UDP;
 #include "I_UDPNet.h"
 #include "P_UDPPacket.h"
 
-//added by YTS Team, yamsat
+// added by YTS Team, yamsat
 static inline PollCont *get_UDPPollCont(EThread *);
 
 #include "P_UnixUDPConnection.h"
@@ -44,11 +44,10 @@ static inline PollCont *get_UDPPollCont(EThread *);
 
 struct UDPNetHandler;
 
-struct UDPNetProcessorInternal : public UDPNetProcessor
-{
+struct UDPNetProcessorInternal : public UDPNetProcessor {
   virtual int start(int n_udp_threads, size_t stacksize);
-  void udp_read_from_net(UDPNetHandler * nh, UDPConnection * uc);
-  int udp_callback(UDPNetHandler * nh, UDPConnection * uc, EThread * thread);
+  void udp_read_from_net(UDPNetHandler *nh, UDPConnection *uc);
+  int udp_callback(UDPNetHandler *nh, UDPConnection *uc, EThread *thread);
 
   off_t pollCont_offset;
   off_t udpNetHandler_offset;
@@ -57,7 +56,6 @@ struct UDPNetProcessorInternal : public UDPNetProcessor
 extern UDPNetProcessorInternal udpNetInternal;
 
 
-
 // 20 ms slots; 2048 slots  => 40 sec. into the future
 #define SLOT_TIME_MSEC 20
 #define SLOT_TIME HRTIME_MSECONDS(SLOT_TIME_MSEC)
@@ -65,16 +63,14 @@ extern UDPNetProcessorInternal udpNetInternal;
 
 class PacketQueue
 {
- public:
- PacketQueue()
-   : nPackets(0), now_slot(0)
-    {
-      lastPullLongTermQ = 0;
-      init();
-    }
+public:
+  PacketQueue() : nPackets(0), now_slot(0)
+  {
+    lastPullLongTermQ = 0;
+    init();
+  }
 
-  virtual ~ PacketQueue()
-    { }
+  virtual ~PacketQueue() {}
 
   int nPackets;
   ink_hrtime lastPullLongTermQ;
@@ -83,7 +79,8 @@ class PacketQueue
   ink_hrtime delivery_time[N_SLOTS];
   int now_slot;
 
-  void init(void)
+  void
+  init(void)
   {
     now_slot = 0;
     ink_hrtime now = ink_get_hrtime_internal();
@@ -96,7 +93,8 @@ class PacketQueue
     }
   }
 
-  void addPacket(UDPPacketInternal * e, ink_hrtime now = 0)
+  void
+  addPacket(UDPPacketInternal *e, ink_hrtime now = 0)
   {
     int before = 0;
     int slot;
@@ -133,14 +131,14 @@ class PacketQueue
     slot = (s + now_slot) % N_SLOTS;
 
     // so that slot+1 is still "in future".
-    ink_assert((before || delivery_time[slot] <= e->delivery_time) &&
-               (delivery_time[(slot + 1) % N_SLOTS] >= e->delivery_time));
+    ink_assert((before || delivery_time[slot] <= e->delivery_time) && (delivery_time[(slot + 1) % N_SLOTS] >= e->delivery_time));
     e->in_the_priority_queue = 1;
     e->in_heap = slot;
     bucket[slot].enqueue(e);
   }
 
-  UDPPacketInternal *firstPacket(ink_hrtime t)
+  UDPPacketInternal *
+  firstPacket(ink_hrtime t)
   {
     if (t > delivery_time[now_slot]) {
       return bucket[now_slot].head;
@@ -149,25 +147,29 @@ class PacketQueue
     }
   }
 
-  UDPPacketInternal *getFirstPacket()
+  UDPPacketInternal *
+  getFirstPacket()
   {
     nPackets--;
     return dequeue_ready(0);
   }
 
-  int size()
+  int
+  size()
   {
     ink_assert(nPackets >= 0);
     return nPackets;
   }
 
-  bool IsCancelledPacket(UDPPacketInternal * p)
+  bool
+  IsCancelledPacket(UDPPacketInternal *p)
   {
     // discard packets that'll never get sent...
     return ((p->conn->shouldDestroy()) || (p->conn->GetSendGenerationNumber() != p->reqGenerationNum));
   }
 
-  void FreeCancelledPackets(int numSlots)
+  void
+  FreeCancelledPackets(int numSlots)
   {
     UDPPacketInternal *p;
     Queue<UDPPacketInternal> tempQ;
@@ -189,7 +191,8 @@ class PacketQueue
     }
   }
 
-  void advanceNow(ink_hrtime t)
+  void
+  advanceNow(ink_hrtime t)
   {
     int s = now_slot;
     int prev;
@@ -223,13 +226,14 @@ class PacketQueue
     }
 
     if (s != now_slot)
-      Debug("udpnet-service", "Advancing by (%d slots): behind by %" PRId64 " ms",
-            s - now_slot, ink_hrtime_to_msec(t - delivery_time[now_slot]));
+      Debug("udpnet-service", "Advancing by (%d slots): behind by %" PRId64 " ms", s - now_slot,
+            ink_hrtime_to_msec(t - delivery_time[now_slot]));
     now_slot = s;
   }
 
- private:
-  void remove(UDPPacketInternal * e)
+private:
+  void
+  remove(UDPPacketInternal *e)
   {
     nPackets--;
     ink_assert(e->in_the_priority_queue);
@@ -237,10 +241,11 @@ class PacketQueue
     bucket[e->in_heap].remove(e);
   }
 
- public:
-  UDPPacketInternal *dequeue_ready(ink_hrtime t)
+public:
+  UDPPacketInternal *
+  dequeue_ready(ink_hrtime t)
   {
-    (void) t;
+    (void)t;
     UDPPacketInternal *e = bucket[now_slot].dequeue();
     if (e) {
       ink_assert(e->in_the_priority_queue);
@@ -250,12 +255,14 @@ class PacketQueue
     return e;
   }
 
-  void check_ready(ink_hrtime now)
+  void
+  check_ready(ink_hrtime now)
   {
-    (void) now;
+    (void)now;
   }
 
-  ink_hrtime earliest_timeout()
+  ink_hrtime
+  earliest_timeout()
   {
     int s = now_slot;
     for (int i = 0; i < N_SLOTS; i++) {
@@ -267,9 +274,11 @@ class PacketQueue
     return HRTIME_FOREVER;
   }
 
- private:
-  void kill_cancelled_events()
-  { }
+private:
+  void
+  kill_cancelled_events()
+  {
+  }
 };
 
 
@@ -288,20 +297,19 @@ public:
   void service(UDPNetHandler *);
 
   void SendPackets();
-  void SendUDPPacket(UDPPacketInternal * p, int32_t pktLen);
+  void SendUDPPacket(UDPPacketInternal *p, int32_t pktLen);
 
   // Interface exported to the outside world
-  void send(UDPPacket * p);
+  void send(UDPPacket *p);
 
   UDPQueue();
   ~UDPQueue();
 };
 
 
-void initialize_thread_for_udp_net(EThread * thread);
+void initialize_thread_for_udp_net(EThread *thread);
 
-struct UDPNetHandler: public Continuation
-{
+struct UDPNetHandler : public Continuation {
 public:
   // to be polled for read
   Que(UnixUDPConnection, polling_link) udp_polling;
@@ -319,21 +327,21 @@ public:
   ink_hrtime nextCheck;
   ink_hrtime lastCheck;
 
-  int startNetEvent(int event, Event * data);
-  int mainNetEvent(int event, Event * data);
+  int startNetEvent(int event, Event *data);
+  int mainNetEvent(int event, Event *data);
 
   UDPNetHandler();
 };
 
 struct PollCont;
 static inline PollCont *
-get_UDPPollCont(EThread * t)
+get_UDPPollCont(EThread *t)
 {
   return (PollCont *)ETHREAD_GET_PTR(t, udpNetInternal.pollCont_offset);
 }
 
 static inline UDPNetHandler *
-get_UDPNetHandler(EThread * t)
+get_UDPNetHandler(EThread *t)
 {
   return (UDPNetHandler *)ETHREAD_GET_PTR(t, udpNetInternal.udpNetHandler_offset);
 }
