@@ -33,33 +33,19 @@ class UnixNetVConnection;
 //  class UnixNetProcessor
 //
 //////////////////////////////////////////////////////////////////
-struct UnixNetProcessor:public NetProcessor
-{
+struct UnixNetProcessor : public NetProcessor {
 public:
-  virtual Action *accept_internal (
-    Continuation * cont,
-    int fd,
-    AcceptOptions const &opt
-  );
+  virtual Action *accept_internal(Continuation *cont, int fd, AcceptOptions const &opt);
 
-  Action *connect_re_internal(
-    Continuation * cont,
-    sockaddr const* target,
-    NetVCOptions * options = NULL
-  );
-  Action *connect(
-    Continuation * cont,
-    UnixNetVConnection ** vc,
-    sockaddr const* target,
-    NetVCOptions * opt = NULL
-  );
+  Action *connect_re_internal(Continuation *cont, sockaddr const *target, NetVCOptions *options = NULL);
+  Action *connect(Continuation *cont, UnixNetVConnection **vc, sockaddr const *target, NetVCOptions *opt = NULL);
 
   // Virtual function allows etype to be upgraded to ET_SSL for SSLNetProcessor.  Does
   // nothing for NetProcessor
-  virtual void upgradeEtype(EventType & /* etype ATS_UNUSED */) { };
+  virtual void upgradeEtype(EventType & /* etype ATS_UNUSED */){};
 
   virtual NetAccept *createNetAccept();
-  virtual NetVConnection * allocate_vc(EThread *t);
+  virtual NetVConnection *allocate_vc(EThread *t);
 
   virtual int start(int number_of_net_threads, size_t stacksize);
 
@@ -77,11 +63,8 @@ public:
 
 
 TS_INLINE Action *
-NetProcessor::connect_re(
-  Continuation * cont,
-  sockaddr const* addr,
-  NetVCOptions * opts
-) {
+NetProcessor::connect_re(Continuation *cont, sockaddr const *addr, NetVCOptions *opts)
+{
   return static_cast<UnixNetProcessor *>(this)->connect_re_internal(cont, addr, opts);
 }
 
@@ -92,7 +75,7 @@ extern UnixNetProcessor unix_netProcessor;
 // This function should be called for all threads created to
 // accept such events by the EventProcesor.
 //
-extern void initialize_thread_for_net(EThread * thread);
+extern void initialize_thread_for_net(EThread *thread);
 
 //#include "UnixNet.h"
 #endif
