@@ -37,36 +37,41 @@
 #include "P_SSLConfig.h"
 #include "P_SSLUtils.h"
 #include "P_SSLCertLookup.h"
+#include "SSLSessionCache.h"
 #include <records/I_RecHttp.h>
 
 int SSLConfig::configid = 0;
 int SSLCertificateConfig::configid = 0;
 int SSLConfigParams::ssl_maxrecord = 0;
 bool SSLConfigParams::ssl_allow_client_renegotiation = false;
+bool SSLConfigParams::ssl_ocsp_enabled = false;
+int SSLConfigParams::ssl_ocsp_cache_timeout = 3600;
+int SSLConfigParams::ssl_ocsp_request_timeout = 10;
+int SSLConfigParams::ssl_ocsp_update_period = 60;
+size_t SSLConfigParams::session_cache_number_buckets = 1024;
+bool SSLConfigParams::session_cache_skip_on_lock_contention = false;
+size_t SSLConfigParams::session_cache_max_bucket_size = 100;
+
 init_ssl_ctx_func SSLConfigParams::init_ssl_ctx_cb = NULL;
 
-static ConfigUpdateHandler<SSLCertificateConfig> * sslCertUpdate;
+static ConfigUpdateHandler<SSLCertificateConfig> *sslCertUpdate;
 
 SSLConfigParams::SSLConfigParams()
 {
-  serverCertPathOnly =
-    serverCertChainFilename =
-    configFilePath =
-    serverCACertFilename =
-    serverCACertPath =
-    clientCertPath =
-    clientKeyPath =
-    clientCACertFilename =
-    clientCACertPath =
-    cipherSuite =
-    serverKeyPathOnly = NULL;
+  serverCertPathOnly = serverCertChainFilename = configFilePath = serverCACertFilename = serverCACertPath = clientCertPath =
+    clientKeyPath = clientCACertFilename = clientCACertPath = cipherSuite = client_cipherSuite = dhparamsFile = serverKeyPathOnly =
+      NULL;
 
   clientCertLevel = client_verify_depth = verify_depth = clientVerify = 0;
 
   ssl_ctx_options = 0;
-  ssl_session_cache = SSL_SESSION_CACHE_MODE_SERVER;
-  ssl_session_cache_size = 1024*20;
+  ssl_client_ctx_protocols = 0;
+  ssl_session_cache = SSL_SESSION_CACHE_MODE_SERVER_ATS_IMPL;
+  ssl_session_cache_size = 1024 * 100;
+  ssl_session_cache_num_buckets = 1024; // Sessions per bucket is ceil(ssl_session_cache_size / ssl_session_cache_num_buckets)
+  ssl_session_cache_skip_on_contention = 0;
   ssl_session_cache_timeout = 0;
+  ssl_session_cache_auto_clear = 1;
 }
 
 SSLConfigParams::~SSLConfigParams()
@@ -88,6 +93,8 @@ SSLConfigParams::cleanup()
   ats_free_null(serverCertPathOnly);
   ats_free_null(serverKeyPathOnly);
   ats_free_null(cipherSuite);
+  ats_free_null(client_cipherSuite);
+  ats_free_null(dhparamsFile);
 
   clientCertLevel = client_verify_depth = verify_depth = clientVerify = 0;
 }
@@ -105,9 +112,9 @@ set_paths_helper(const char *path, const char *filename, char **final_path, char
 {
   if (final_path) {
     if (path && path[0] != '/') {
-      *final_path = Layout::get()->relative_to(Layout::get()->prefix, path);
-    } else if (!path || path[0] == '\0'){
-      *final_path = ats_strdup(Layout::get()->sysconfdir);
+      *final_path = RecConfigReadPrefixPath(NULL, path);
+    } else if (!path || path[0] == '\0') {
+      *final_path = RecConfigReadConfigDir();
     } else {
       *final_path = ats_strdup(path);
     }
@@ -116,7 +123,6 @@ set_paths_helper(const char *path, const char *filename, char **final_path, char
   if (final_filename) {
     *final_filename = filename ? Layout::get()->relative_to(path, filename) : NULL;
   }
-
 }
 
 void
@@ -130,7 +136,6 @@ SSLConfigParams::initialize()
   char *ssl_client_private_key_filename = NULL;
   char *ssl_client_private_key_path = NULL;
   char *clientCACertRelativePath = NULL;
-  char *multicert_config_file = NULL;
   char *ssl_server_ca_cert_filename = NULL;
   char *ssl_client_ca_cert_filename = NULL;
 
@@ -141,8 +146,11 @@ SSLConfigParams::initialize()
 
   REC_ReadConfigInt32(clientCertLevel, "proxy.config.ssl.client.certification_level");
   REC_ReadConfigStringAlloc(cipherSuite, "proxy.config.ssl.server.cipher_suite");
+  REC_ReadConfigStringAlloc(client_cipherSuite, "proxy.config.ssl.client.cipher_suite");
+  dhparamsFile = RecConfigReadConfigPath("proxy.config.ssl.server.dhparams_file");
 
   int options;
+  int client_ssl_options;
   REC_ReadConfigInteger(options, "proxy.config.ssl.SSLv2");
   if (!options)
     ssl_ctx_options |= SSL_OP_NO_SSLv2;
@@ -153,16 +161,34 @@ SSLConfigParams::initialize()
   if (!options)
     ssl_ctx_options |= SSL_OP_NO_TLSv1;
 
-  // These are not available in all versions of OpenSSL (e.g. CentOS6). Also see http://s.apache.org/TS-2355.
+  REC_ReadConfigInteger(client_ssl_options, "proxy.config.ssl.client.SSLv2");
+  if (!client_ssl_options)
+    ssl_client_ctx_protocols |= SSL_OP_NO_SSLv2;
+  REC_ReadConfigInteger(client_ssl_options, "proxy.config.ssl.client.SSLv3");
+  if (!client_ssl_options)
+    ssl_client_ctx_protocols |= SSL_OP_NO_SSLv3;
+  REC_ReadConfigInteger(client_ssl_options, "proxy.config.ssl.client.TLSv1");
+  if (!client_ssl_options)
+    ssl_client_ctx_protocols |= SSL_OP_NO_TLSv1;
+
+// These are not available in all versions of OpenSSL (e.g. CentOS6). Also see http://s.apache.org/TS-2355.
 #ifdef SSL_OP_NO_TLSv1_1
   REC_ReadConfigInteger(options, "proxy.config.ssl.TLSv1_1");
   if (!options)
     ssl_ctx_options |= SSL_OP_NO_TLSv1_1;
+
+  REC_ReadConfigInteger(client_ssl_options, "proxy.config.ssl.client.TLSv1_1");
+  if (!client_ssl_options)
+    ssl_client_ctx_protocols |= SSL_OP_NO_TLSv1_1;
 #endif
 #ifdef SSL_OP_NO_TLSv1_2
   REC_ReadConfigInteger(options, "proxy.config.ssl.TLSv1_2");
   if (!options)
     ssl_ctx_options |= SSL_OP_NO_TLSv1_2;
+
+  REC_ReadConfigInteger(client_ssl_options, "proxy.config.ssl.client.TLSv1_2");
+  if (!client_ssl_options)
+    ssl_client_ctx_protocols |= SSL_OP_NO_TLSv1_2;
 #endif
 
 #ifdef SSL_OP_CIPHER_SERVER_PREFERENCE
@@ -181,7 +207,7 @@ SSLConfigParams::initialize()
 #endif
   }
 
-  // Enable ephemeral DH parameters for the case where we use a cipher with DH forward security.
+// Enable ephemeral DH parameters for the case where we use a cipher with DH forward security.
 #ifdef SSL_OP_SINGLE_DH_USE
   ssl_ctx_options |= SSL_OP_SINGLE_DH_USE;
 #endif
@@ -193,8 +219,8 @@ SSLConfigParams::initialize()
   // Enable all SSL compatibility workarounds.
   ssl_ctx_options |= SSL_OP_ALL;
 
-  // According to OpenSSL source, applications must enable this if they support the Server Name extension. Since
-  // we do, then we ought to enable this. Httpd also enables this unconditionally.
+// According to OpenSSL source, applications must enable this if they support the Server Name extension. Since
+// we do, then we ought to enable this. Httpd also enables this unconditionally.
 #ifdef SSL_OP_NO_SESSION_RESUMPTION_ON_RENEGOTIATION
   ssl_ctx_options |= SSL_OP_NO_SESSION_RESUMPTION_ON_RENEGOTIATION;
 #endif
@@ -204,9 +230,8 @@ SSLConfigParams::initialize()
   set_paths_helper(serverCertRelativePath, NULL, &serverCertPathOnly, NULL);
   ats_free(serverCertRelativePath);
 
-  REC_ReadConfigStringAlloc(multicert_config_file, "proxy.config.ssl.server.multicert.filename");
-  set_paths_helper(Layout::get()->sysconfdir, multicert_config_file, NULL, &configFilePath);
-  ats_free(multicert_config_file);
+  configFilePath = RecConfigReadConfigPath("proxy.config.ssl.server.multicert.filename");
+  REC_ReadConfigInteger(configExitOnLoadError, "proxy.config.ssl.server.multicert.exit_on_load_fail");
 
   REC_ReadConfigStringAlloc(ssl_server_private_key_path, "proxy.config.ssl.server.private_key.path");
   set_paths_helper(ssl_server_private_key_path, NULL, &serverKeyPathOnly, NULL);
@@ -221,11 +246,26 @@ SSLConfigParams::initialize()
   // SSL session cache configurations
   REC_ReadConfigInteger(ssl_session_cache, "proxy.config.ssl.session_cache");
   REC_ReadConfigInteger(ssl_session_cache_size, "proxy.config.ssl.session_cache.size");
+  REC_ReadConfigInteger(ssl_session_cache_num_buckets, "proxy.config.ssl.session_cache.num_buckets");
+  REC_ReadConfigInteger(ssl_session_cache_skip_on_contention, "proxy.config.ssl.session_cache.skip_cache_on_bucket_contention");
   REC_ReadConfigInteger(ssl_session_cache_timeout, "proxy.config.ssl.session_cache.timeout");
+  REC_ReadConfigInteger(ssl_session_cache_auto_clear, "proxy.config.ssl.session_cache.auto_clear");
+
+  SSLConfigParams::session_cache_max_bucket_size = (size_t)ceil((double)ssl_session_cache_size / ssl_session_cache_num_buckets);
+  SSLConfigParams::session_cache_skip_on_lock_contention = ssl_session_cache_skip_on_contention;
+  SSLConfigParams::session_cache_number_buckets = ssl_session_cache_num_buckets;
+
+  session_cache = new SSLSessionCache();
 
   // SSL record size
   REC_EstablishStaticConfigInt32(ssl_maxrecord, "proxy.config.ssl.max_record_size");
 
+  // SSL OCSP Stapling configurations
+  REC_ReadConfigInt32(ssl_ocsp_enabled, "proxy.config.ssl.ocsp.enabled");
+  REC_EstablishStaticConfigInt32(ssl_ocsp_cache_timeout, "proxy.config.ssl.ocsp.cache_timeout");
+  REC_EstablishStaticConfigInt32(ssl_ocsp_request_timeout, "proxy.config.ssl.ocsp.request_timeout");
+  REC_EstablishStaticConfigInt32(ssl_ocsp_update_period, "proxy.config.ssl.ocsp.update_period");
+
   // ++++++++++++++++++++++++ Client part ++++++++++++++++++++
   client_verify_depth = 7;
   REC_ReadConfigInt32(clientVerify, "proxy.config.ssl.client.verify.server");
@@ -264,39 +304,49 @@ SSLConfig::reconfigure()
 {
   SSLConfigParams *params;
   params = new SSLConfigParams;
-  params->initialize();         // re-read configuration
+  params->initialize(); // re-read configuration
   configid = configProcessor.set(configid, params);
 }
 
 SSLConfigParams *
 SSLConfig::acquire()
 {
-  return ((SSLConfigParams *) configProcessor.get(configid));
+  return ((SSLConfigParams *)configProcessor.get(configid));
 }
 
 void
-SSLConfig::release(SSLConfigParams * params)
+SSLConfig::release(SSLConfigParams *params)
 {
   configProcessor.release(configid, params);
 }
 
-void
+bool
 SSLCertificateConfig::startup()
 {
   sslCertUpdate = new ConfigUpdateHandler<SSLCertificateConfig>();
   sslCertUpdate->attach("proxy.config.ssl.server.multicert.filename");
+  sslCertUpdate->attach("proxy.config.ssl.server.multicert.exit_on_load_fail");
+  sslCertUpdate->attach("proxy.config.ssl.server.ticket_key.filename");
   sslCertUpdate->attach("proxy.config.ssl.server.cert.path");
   sslCertUpdate->attach("proxy.config.ssl.server.private_key.path");
   sslCertUpdate->attach("proxy.config.ssl.server.cert_chain.filename");
 
-  reconfigure();
+  // Exit if there are problems on the certificate loading and the
+  // proxy.config.ssl.server.multicert.exit_on_load_fail is true
+  SSLConfigParams *params = SSLConfig::acquire();
+  if (!reconfigure() && params->configExitOnLoadError) {
+    Error("Problems loading ssl certificate file, %s.  Exiting.", params->configFilePath);
+    _exit(1);
+  }
+  return true;
 }
 
-void
+bool
 SSLCertificateConfig::reconfigure()
 {
+  bool retStatus = true;
   SSLConfig::scoped_config params;
-  SSLCertLookup * lookup = new SSLCertLookup();
+  SSLCertLookup *lookup = new SSLCertLookup();
 
   // Test SSL certificate loading startup. With large numbers of certificates, reloading can take time, so delay
   // twice the healthcheck period to simulate a loading a large certificate set.
@@ -306,11 +356,13 @@ SSLCertificateConfig::reconfigure()
     ink_hrtime_sleep(HRTIME_SECONDS(secs));
   }
 
-  if (SSLParseCertificateConfiguration(params, lookup)) {
-    configid = configProcessor.set(configid, lookup);
-  } else {
-    delete lookup;
+  SSLParseCertificateConfiguration(params, lookup);
+  configid = configProcessor.set(configid, lookup);
+  if (!lookup->is_valid) {
+    retStatus = false;
   }
+
+  return retStatus;
 }
 
 SSLCertLookup *
@@ -320,8 +372,7 @@ SSLCertificateConfig::acquire()
 }
 
 void
-SSLCertificateConfig::release(SSLCertLookup * lookup)
+SSLCertificateConfig::release(SSLCertLookup *lookup)
 {
   configProcessor.release(configid, lookup);
 }
-
