@@ -22,7 +22,7 @@
 #include "ink_config.h"
 #include "P_Net.h"
 
-typedef int (SSLNetAccept::*SSLNetAcceptHandler) (int, void *);
+typedef int (SSLNetAccept::*SSLNetAcceptHandler)(int, void *);
 
 // Virtual function allows the correct
 // etype to be used in NetAccept functions (ET_SSL
@@ -43,14 +43,15 @@ void
 SSLNetAccept::init_accept_per_thread()
 {
   int i, n;
+  NetAccept *a;
+
   if (do_listen(NON_BLOCKING))
     return;
   if (accept_fn == net_accept)
-    SET_HANDLER((SSLNetAcceptHandler) & SSLNetAccept::acceptFastEvent);
+    SET_HANDLER((SSLNetAcceptHandler)&SSLNetAccept::acceptFastEvent);
   else
-    SET_HANDLER((SSLNetAcceptHandler) & SSLNetAccept::acceptEvent);
+    SET_HANDLER((SSLNetAcceptHandler)&SSLNetAccept::acceptEvent);
   period = ACCEPT_PERIOD;
-  NetAccept *a = this;
   n = eventProcessor.n_threads_for_type[SSLNetProcessor::ET_SSL];
   for (i = 0; i < n; i++) {
     if (i < n - 1)
