@@ -24,10 +24,10 @@
 #include "P_SSLNextProtocolAccept.h"
 
 static void
-send_plugin_event(Continuation * plugin, int event, void * edata)
+send_plugin_event(Continuation *plugin, int event, void *edata)
 {
   if (plugin->mutex) {
-    EThread * thread(this_ethread());
+    EThread *thread(this_ethread());
     MUTEX_TAKE_LOCK(plugin->mutex, thread);
     plugin->handleEvent(event, edata);
     MUTEX_UNTAKE_LOCK(plugin->mutex, thread);
@@ -37,11 +37,11 @@ send_plugin_event(Continuation * plugin, int event, void * edata)
 }
 
 static SSLNetVConnection *
-ssl_netvc_cast(int event, void * edata)
+ssl_netvc_cast(int event, void *edata)
 {
   union {
-    VIO * vio;
-    NetVConnection * vc;
+    VIO *vio;
+    NetVConnection *vc;
   } ptr;
 
   switch (event) {
@@ -63,20 +63,18 @@ ssl_netvc_cast(int event, void * edata)
 // NPN extension. The Continuation that receives the read event *must* have a mutex, but we don't want to take a global
 // lock across the handshake, so we make a trampoline to bounce the event from the SSL acceptor to the ultimate session
 // acceptor.
-struct SSLNextProtocolTrampoline : public Continuation
-{
-  explicit
-  SSLNextProtocolTrampoline(const SSLNextProtocolAccept * npn, ProxyMutex* mutex)
-    : Continuation(mutex), npnParent(npn)
+struct SSLNextProtocolTrampoline : public Continuation {
+  explicit SSLNextProtocolTrampoline(const SSLNextProtocolAccept *npn, ProxyMutex *mutex) : Continuation(mutex), npnParent(npn)
   {
     SET_HANDLER(&SSLNextProtocolTrampoline::ioCompletionEvent);
   }
 
-  int ioCompletionEvent(int event, void * edata)
+  int
+  ioCompletionEvent(int event, void *edata)
   {
-    VIO * vio;
-    Continuation * plugin;
-    SSLNetVConnection * netvc;
+    VIO *vio;
+    Continuation *plugin;
+    SSLNetVConnection *netvc;
 
     vio = static_cast<VIO *>(edata);
     netvc = dynamic_cast<SSLNetVConnection *>(vio->vc_server);
@@ -111,13 +109,13 @@ struct SSLNextProtocolTrampoline : public Continuation
     return EVENT_CONT;
   }
 
-  const SSLNextProtocolAccept * npnParent;
+  const SSLNextProtocolAccept *npnParent;
 };
 
 int
-SSLNextProtocolAccept::mainEvent(int event, void * edata)
+SSLNextProtocolAccept::mainEvent(int event, void *edata)
 {
-  SSLNetVConnection * netvc = ssl_netvc_cast(event, edata);
+  SSLNetVConnection *netvc = ssl_netvc_cast(event, edata);
 
   netvc->sslHandshakeBeginTime = ink_get_hrtime();
   Debug("ssl", "[SSLNextProtocolAccept:mainEvent] event %d netvc %p", event, netvc);
@@ -125,6 +123,9 @@ SSLNextProtocolAccept::mainEvent(int event, void * edata)
   switch (event) {
   case NET_EVENT_ACCEPT:
     ink_release_assert(netvc != NULL);
+
+    netvc->setTransparentPassThrough(transparent_passthrough);
+
     // Register our protocol set with the VC and kick off a zero-length read to
     // force the SSLNetVConnection to complete the SSL handshake. Don't tell
     // the endpoint that there is an accept to handle until the read completes
@@ -145,21 +146,19 @@ SSLNextProtocolAccept::accept(NetVConnection *, MIOBuffer *, IOBufferReader *)
 }
 
 bool
-SSLNextProtocolAccept::registerEndpoint(
-    const char * protocol, Continuation * handler)
+SSLNextProtocolAccept::registerEndpoint(const char *protocol, Continuation *handler)
 {
   return this->protoset.registerEndpoint(protocol, handler);
 }
 
 bool
-SSLNextProtocolAccept::unregisterEndpoint(
-    const char * protocol, Continuation * handler)
+SSLNextProtocolAccept::unregisterEndpoint(const char *protocol, Continuation *handler)
 {
   return this->protoset.unregisterEndpoint(protocol, handler);
 }
 
-SSLNextProtocolAccept::SSLNextProtocolAccept(Continuation * ep)
-    : SessionAccept(NULL), buffer(new_empty_MIOBuffer()), endpoint(ep)
+SSLNextProtocolAccept::SSLNextProtocolAccept(Continuation *ep, bool transparent_passthrough)
+  : SessionAccept(NULL), buffer(new_empty_MIOBuffer()), endpoint(ep), transparent_passthrough(transparent_passthrough)
 {
   SET_HANDLER(&SSLNextProtocolAccept::mainEvent);
 }
