@@ -23,17 +23,16 @@
 
 #include "P_Net.h"
 
-#define STATE_VIO_OFFSET ((uintptr_t)&((NetState*)0)->vio)
-#define STATE_FROM_VIO(_x) ((NetState*)(((char*)(_x)) - STATE_VIO_OFFSET))
+#define STATE_VIO_OFFSET ((uintptr_t) & ((NetState *)0)->vio)
+#define STATE_FROM_VIO(_x) ((NetState *)(((char *)(_x)) - STATE_VIO_OFFSET))
 
 #define disable_read(_vc) (_vc)->read.enabled = 0
 #define disable_write(_vc) (_vc)->write.enabled = 0
 #define enable_read(_vc) (_vc)->read.enabled = 1
 #define enable_write(_vc) (_vc)->write.enabled = 1
 
-typedef struct iovec IOVec;
 #ifndef UIO_MAXIOV
-#define NET_MAX_IOV 16          // UIO_MAXIOV shall be at least 16 1003.1g (5.4.1.1)
+#define NET_MAX_IOV 16 // UIO_MAXIOV shall be at least 16 1003.1g (5.4.1.1)
 #else
 #define NET_MAX_IOV UIO_MAXIOV
 #endif
@@ -68,7 +67,8 @@ write_reschedule(NetHandler *nh, UnixNetVConnection *vc)
 void
 net_activity(UnixNetVConnection *vc, EThread *thread)
 {
-  (void) thread;
+  Debug("socket", "net_activity updating inactivity %" PRId64 ", NetVC=%p", vc->inactivity_timeout_in, vc);
+  (void)thread;
 #ifdef INACTIVITY_TIMEOUT
   if (vc->inactivity_timeout && vc->inactivity_timeout_in && vc->inactivity_timeout->ethread == thread)
     vc->inactivity_timeout->schedule_in(vc->inactivity_timeout_in);
@@ -86,7 +86,6 @@ net_activity(UnixNetVConnection *vc, EThread *thread)
   else
     vc->next_inactivity_timeout_at = 0;
 #endif
-
 }
 
 //
@@ -125,6 +124,7 @@ close_UnixNetVConnection(UnixNetVConnection *vc, EThread *t)
     nh->write_enable_list.remove(vc);
     vc->write.in_enabled_list = 0;
   }
+  vc->remove_from_keep_alive_lru();
   vc->free(t);
 }
 
@@ -135,7 +135,23 @@ static inline int
 read_signal_and_update(int event, UnixNetVConnection *vc)
 {
   vc->recursion++;
-  vc->read.vio._cont->handleEvent(event, &vc->read.vio);
+  if (vc->read.vio._cont) {
+    vc->read.vio._cont->handleEvent(event, &vc->read.vio);
+  } else {
+    switch (event) {
+    case VC_EVENT_EOS:
+    case VC_EVENT_ERROR:
+    case VC_EVENT_ACTIVE_TIMEOUT:
+    case VC_EVENT_INACTIVITY_TIMEOUT:
+      Debug("inactivity_cop", "event %d: null read.vio cont, closing vc %p", event, vc);
+      vc->closed = 1;
+      break;
+    default:
+      Error("Unexpected event %d for vc %p", event, vc);
+      ink_release_assert(0);
+      break;
+    }
+  }
   if (!--vc->recursion && vc->closed) {
     /* BZ  31932 */
     ink_assert(vc->thread == this_ethread());
@@ -150,7 +166,23 @@ static inline int
 write_signal_and_update(int event, UnixNetVConnection *vc)
 {
   vc->recursion++;
-  vc->write.vio._cont->handleEvent(event, &vc->write.vio);
+  if (vc->write.vio._cont) {
+    vc->write.vio._cont->handleEvent(event, &vc->write.vio);
+  } else {
+    switch (event) {
+    case VC_EVENT_EOS:
+    case VC_EVENT_ERROR:
+    case VC_EVENT_ACTIVE_TIMEOUT:
+    case VC_EVENT_INACTIVITY_TIMEOUT:
+      Debug("inactivity_cop", "event %d: null write.vio cont, closing vc %p", event, vc);
+      vc->closed = 1;
+      break;
+    default:
+      Error("Unexpected event %d for vc %p", event, vc);
+      ink_release_assert(0);
+      break;
+    }
+  }
   if (!--vc->recursion && vc->closed) {
     /* BZ  31932 */
     ink_assert(vc->thread == this_ethread());
@@ -208,12 +240,11 @@ read_from_net(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
 {
   NetState *s = &vc->read;
   ProxyMutex *mutex = thread->mutex;
-  MIOBufferAccessor & buf = s->vio.buffer;
   int64_t r = 0;
 
   MUTEX_TRY_LOCK_FOR(lock, s->vio.mutex, thread, s->vio._cont);
 
-  if (!lock || lock.m.m_ptr != s->vio.mutex.m_ptr) {
+  if (!lock.is_locked() || lock.get_mutex() != s->vio.mutex.m_ptr) {
     read_reschedule(nh, vc);
     return;
   }
@@ -223,6 +254,7 @@ read_from_net(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
     return;
   }
 
+  MIOBufferAccessor &buf = s->vio.buffer;
   ink_assert(buf.writer());
 
   // if there is nothing to do, disable connection
@@ -265,9 +297,9 @@ read_from_net(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
       } else {
         r = socketManager.readv(vc->con.fd, &tiovec[0], niov);
       }
-      NET_DEBUG_COUNT_DYN_STAT(net_calls_to_read_stat, 1);
+      NET_INCREMENT_DYN_STAT(net_calls_to_read_stat);
       total_read += rattempted;
-    } while (r == rattempted && total_read < toread);
+    } while (rattempted && r == rattempted && total_read < toread);
 
     // if we have already moved some bytes successfully, summarize in r
     if (total_read != rattempted) {
@@ -278,9 +310,8 @@ read_from_net(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
     }
     // check for errors
     if (r <= 0) {
-
       if (r == -EAGAIN || r == -ENOTCONN) {
-        NET_DEBUG_COUNT_DYN_STAT(net_calls_to_read_nodata_stat, 1);
+        NET_INCREMENT_DYN_STAT(net_calls_to_read_nodata_stat);
         vc->read.triggered = 0;
         nh->read_ready_list.remove(vc);
         return;
@@ -321,7 +352,7 @@ read_from_net(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
       if (read_signal_and_update(VC_EVENT_READ_READY, vc) != EVENT_CONT)
         return;
       // change of lock... don't look at shared variables!
-      if (lock.m.m_ptr != s->vio.mutex.m_ptr) {
+      if (lock.get_mutex() != s->vio.mutex.m_ptr) {
         read_reschedule(nh, vc);
         return;
       }
@@ -346,8 +377,9 @@ write_to_net(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
 {
   ProxyMutex *mutex = thread->mutex;
 
-  NET_DEBUG_COUNT_DYN_STAT(net_calls_to_writetonet_stat, 1);
-  NET_DEBUG_COUNT_DYN_STAT(net_calls_to_writetonet_afterpoll_stat, 1);
+  NET_INCREMENT_DYN_STAT(net_calls_to_writetonet_stat);
+  NET_INCREMENT_DYN_STAT(net_calls_to_writetonet_afterpoll_stat);
+
 
   write_to_net_io(nh, vc, thread);
 }
@@ -361,7 +393,7 @@ write_to_net_io(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
 
   MUTEX_TRY_LOCK_FOR(lock, s->vio.mutex, thread, s->vio._cont);
 
-  if (!lock || lock.m.m_ptr != s->vio.mutex.m_ptr) {
+  if (!lock.is_locked() || lock.get_mutex() != s->vio.mutex.m_ptr) {
     write_reschedule(nh, vc);
     return;
   }
@@ -379,13 +411,15 @@ write_to_net_io(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
     if (ret == EVENT_ERROR) {
       vc->write.triggered = 0;
       write_signal_error(nh, vc, err);
-    } else if (ret == SSL_HANDSHAKE_WANT_READ || ret == SSL_HANDSHAKE_WANT_ACCEPT || ret == SSL_HANDSHAKE_WANT_CONNECT
-               || ret == SSL_HANDSHAKE_WANT_WRITE) {
+    } else if (ret == SSL_HANDSHAKE_WANT_READ || ret == SSL_HANDSHAKE_WANT_ACCEPT || ret == SSL_HANDSHAKE_WANT_CONNECT ||
+               ret == SSL_HANDSHAKE_WANT_WRITE) {
       vc->read.triggered = 0;
       nh->read_ready_list.remove(vc);
       vc->write.triggered = 0;
       nh->write_ready_list.remove(vc);
-      if (!(ret == SSL_HANDSHAKE_WANT_READ || ret == SSL_HANDSHAKE_WANT_ACCEPT))
+      if (ret == SSL_HANDSHAKE_WANT_READ || ret == SSL_HANDSHAKE_WANT_ACCEPT)
+        read_reschedule(nh, vc);
+      else
         write_reschedule(nh, vc);
     } else if (ret == EVENT_DONE) {
       vc->write.triggered = 1;
@@ -407,7 +441,7 @@ write_to_net_io(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
     return;
   }
 
-  MIOBufferAccessor & buf = s->vio.buffer;
+  MIOBufferAccessor &buf = s->vio.buffer;
   ink_assert(buf.writer());
 
   // Calculate amount to write
@@ -439,27 +473,27 @@ write_to_net_io(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
     return;
   }
 
-  int64_t total_wrote = 0, wattempted = 0;
+  int64_t total_written = 0, wattempted = 0;
   int needs = 0;
-  int64_t r = vc->load_buffer_and_write(towrite, wattempted, total_wrote, buf, needs);
+  int64_t r = vc->load_buffer_and_write(towrite, wattempted, total_written, buf, needs);
 
   // if we have already moved some bytes successfully, summarize in r
-  if (total_wrote != wattempted) {
+  if (total_written != wattempted) {
     if (r <= 0)
-      r = total_wrote - wattempted;
+      r = total_written - wattempted;
     else
-      r = total_wrote - wattempted + r;
+      r = total_written - wattempted + r;
   }
   // check for errors
-  if (r <= 0) {                 // if the socket was not ready,add to WaitList
+  if (r <= 0) { // if the socket was not ready,add to WaitList
     if (r == -EAGAIN || r == -ENOTCONN) {
-      NET_DEBUG_COUNT_DYN_STAT(net_calls_to_write_nodata_stat, 1);
-      if((needs & EVENTIO_WRITE) == EVENTIO_WRITE) {
+      NET_INCREMENT_DYN_STAT(net_calls_to_write_nodata_stat);
+      if ((needs & EVENTIO_WRITE) == EVENTIO_WRITE) {
         vc->write.triggered = 0;
         nh->write_ready_list.remove(vc);
         write_reschedule(nh, vc);
       }
-      if((needs & EVENTIO_READ) == EVENTIO_READ) {
+      if ((needs & EVENTIO_READ) == EVENTIO_READ) {
         vc->read.triggered = 0;
         nh->read_ready_list.remove(vc);
         read_reschedule(nh, vc);
@@ -475,6 +509,8 @@ write_to_net_io(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
     write_signal_error(nh, vc, (int)-r);
     return;
   } else {
+    int wbe_event = vc->write_buffer_empty_event; // save so we can clear if needed.
+
     NET_SUM_DYN_STAT(net_write_bytes_stat, r);
 
     // Remove data from the buffer and signal continuation.
@@ -483,18 +519,27 @@ write_to_net_io(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
     ink_assert(buf.reader()->read_avail() >= 0);
     s->vio.ndone += r;
 
+    // If the empty write buffer trap is set, clear it.
+    if (!(buf.reader()->is_read_avail_more_than(0)))
+      vc->write_buffer_empty_event = 0;
+
     net_activity(vc, thread);
     // If there are no more bytes to write, signal write complete,
     ink_assert(ntodo >= 0);
     if (s->vio.ntodo() <= 0) {
       write_signal_done(VC_EVENT_WRITE_COMPLETE, nh, vc);
       return;
+    } else if (signalled && (wbe_event != vc->write_buffer_empty_event)) {
+      // @a signalled means we won't send an event, and the event values differing means we
+      // had a write buffer trap and cleared it, so we need to send it now.
+      if (write_signal_and_update(wbe_event, vc) != EVENT_CONT)
+        return;
     } else if (!signalled) {
       if (write_signal_and_update(VC_EVENT_WRITE_READY, vc) != EVENT_CONT) {
         return;
       }
       // change of lock... don't look at shared variables!
-      if (lock.m.m_ptr != s->vio.mutex.m_ptr) {
+      if (lock.get_mutex() != s->vio.mutex.m_ptr) {
         write_reschedule(nh, vc);
         return;
       }
@@ -504,10 +549,10 @@ write_to_net_io(NetHandler *nh, UnixNetVConnection *vc, EThread *thread)
       return;
     }
 
-    if((needs & EVENTIO_WRITE) == EVENTIO_WRITE) {
+    if ((needs & EVENTIO_WRITE) == EVENTIO_WRITE) {
       write_reschedule(nh, vc);
     }
-    if((needs & EVENTIO_READ) == EVENTIO_READ) {
+    if ((needs & EVENTIO_READ) == EVENTIO_READ) {
       read_reschedule(nh, vc);
     }
     return;
@@ -518,18 +563,18 @@ bool
 UnixNetVConnection::get_data(int id, void *data)
 {
   union {
-    TSVIO * vio;
-    void * data;
+    TSVIO *vio;
+    void *data;
   } ptr;
 
   ptr.data = data;
 
   switch (id) {
   case TS_API_DATA_READ_VIO:
-    *ptr.vio = (TSVIO)&this->read.vio;
+    *ptr.vio = (TSVIO) & this->read.vio;
     return true;
   case TS_API_DATA_WRITE_VIO:
-    *ptr.vio = (TSVIO)&this->write.vio;
+    *ptr.vio = (TSVIO) & this->write.vio;
     return true;
   default:
     return false;
@@ -540,12 +585,13 @@ VIO *
 UnixNetVConnection::do_io_read(Continuation *c, int64_t nbytes, MIOBuffer *buf)
 {
   ink_assert(!closed);
+  ink_assert(c || 0 == nbytes);
   read.vio.op = VIO::READ;
-  read.vio.mutex = c->mutex;
+  read.vio.mutex = c ? c->mutex : this->mutex;
   read.vio._cont = c;
   read.vio.nbytes = nbytes;
   read.vio.ndone = 0;
-  read.vio.vc_server = (VConnection *) this;
+  read.vio.vc_server = (VConnection *)this;
   if (buf) {
     read.vio.buffer.writer_for(buf);
     if (!read.enabled)
@@ -562,11 +608,11 @@ UnixNetVConnection::do_io_write(Continuation *c, int64_t nbytes, IOBufferReader
 {
   ink_assert(!closed);
   write.vio.op = VIO::WRITE;
-  write.vio.mutex = c->mutex;
+  write.vio.mutex = c ? c->mutex : this->mutex;
   write.vio._cont = c;
   write.vio.nbytes = nbytes;
   write.vio.ndone = 0;
-  write.vio.vc_server = (VConnection *) this;
+  write.vio.vc_server = (VConnection *)this;
   if (reader) {
     ink_assert(!owner);
     write.vio.buffer.reader_for(reader);
@@ -579,7 +625,7 @@ UnixNetVConnection::do_io_write(Continuation *c, int64_t nbytes, IOBufferReader
 }
 
 void
-UnixNetVConnection::do_io_close(int alerrno /* = -1 */ )
+UnixNetVConnection::do_io_close(int alerrno /* = -1 */)
 {
   disable_read(this);
   disable_write(this);
@@ -610,21 +656,21 @@ UnixNetVConnection::do_io_shutdown(ShutdownHowTo_t howto)
 {
   switch (howto) {
   case IO_SHUTDOWN_READ:
-    socketManager.shutdown(((UnixNetVConnection *) this)->con.fd, 0);
+    socketManager.shutdown(((UnixNetVConnection *)this)->con.fd, 0);
     disable_read(this);
     read.vio.buffer.clear();
     read.vio.nbytes = 0;
     f.shutdown = NET_VC_SHUTDOWN_READ;
     break;
   case IO_SHUTDOWN_WRITE:
-    socketManager.shutdown(((UnixNetVConnection *) this)->con.fd, 1);
+    socketManager.shutdown(((UnixNetVConnection *)this)->con.fd, 1);
     disable_write(this);
     write.vio.buffer.clear();
     write.vio.nbytes = 0;
     f.shutdown = NET_VC_SHUTDOWN_WRITE;
     break;
   case IO_SHUTDOWN_READWRITE:
-    socketManager.shutdown(((UnixNetVConnection *) this)->con.fd, 2);
+    socketManager.shutdown(((UnixNetVConnection *)this)->con.fd, 2);
     disable_read(this);
     disable_write(this);
     read.vio.buffer.clear();
@@ -652,7 +698,7 @@ OOB_callback::retry_OOB_send(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED
 void
 UnixNetVConnection::cancel_OOB()
 {
-  UnixNetVConnection *u = (UnixNetVConnection *) this;
+  UnixNetVConnection *u = (UnixNetVConnection *)this;
   if (u->oob_ptr) {
     if (u->oob_ptr->trigger) {
       u->oob_ptr->trigger->cancel_action();
@@ -666,7 +712,7 @@ UnixNetVConnection::cancel_OOB()
 Action *
 UnixNetVConnection::send_OOB(Continuation *cont, char *buf, int len)
 {
-  UnixNetVConnection *u = (UnixNetVConnection *) this;
+  UnixNetVConnection *u = (UnixNetVConnection *)this;
   ink_assert(len > 0);
   ink_assert(buf);
   ink_assert(!u->oob_ptr);
@@ -728,7 +774,7 @@ UnixNetVConnection::reenable(VIO *vio)
     }
   } else {
     MUTEX_TRY_LOCK(lock, nh->mutex, t);
-    if (!lock) {
+    if (!lock.is_locked()) {
       if (vio == &read.vio) {
         if (!read.in_enabled_list) {
           read.in_enabled_list = 1;
@@ -798,13 +844,11 @@ UnixNetVConnection::UnixNetVConnection()
 #else
     next_inactivity_timeout_at(0),
 #endif
-    active_timeout(NULL), nh(NULL),
-    id(0), flags(0), recursion(0), submit_time(0), oob_ptr(0),
-    from_accept_thread(false)
+    active_timeout(NULL), nh(NULL), id(0), flags(0), recursion(0), submit_time(0), oob_ptr(0), from_accept_thread(false)
 {
   memset(&local_addr, 0, sizeof local_addr);
   memset(&server_addr, 0, sizeof server_addr);
-  SET_HANDLER((NetVConnHandler) & UnixNetVConnection::startEvent);
+  SET_HANDLER((NetVConnHandler)&UnixNetVConnection::startEvent);
 }
 
 // Private methods
@@ -839,7 +883,8 @@ UnixNetVConnection::net_read_io(NetHandler *nh, EThread *lthread)
 // (SSL read does not support overlapped i/o)
 // without duplicating all the code in write_to_net.
 int64_t
-UnixNetVConnection::load_buffer_and_write(int64_t towrite, int64_t &wattempted, int64_t &total_wrote, MIOBufferAccessor & buf, int &needs)
+UnixNetVConnection::load_buffer_and_write(int64_t towrite, int64_t &wattempted, int64_t &total_written, MIOBufferAccessor &buf,
+                                          int &needs)
 {
   int64_t r = 0;
 
@@ -850,7 +895,7 @@ UnixNetVConnection::load_buffer_and_write(int64_t towrite, int64_t &wattempted,
   do {
     IOVec tiovec[NET_MAX_IOV];
     int niov = 0;
-    int64_t total_wrote_last = total_wrote;
+    int64_t total_written_last = total_written;
     while (b && niov < NET_MAX_IOV) {
       // check if we have done this block
       int64_t l = b->read_avail();
@@ -861,12 +906,12 @@ UnixNetVConnection::load_buffer_and_write(int64_t towrite, int64_t &wattempted,
         continue;
       }
       // check if to amount to write exceeds that in this buffer
-      int64_t wavail = towrite - total_wrote;
+      int64_t wavail = towrite - total_written;
       if (l > wavail)
         l = wavail;
       if (!l)
         break;
-      total_wrote += l;
+      total_written += l;
       // build an iov entry
       tiovec[niov].iov_len = l;
       tiovec[niov].iov_base = b->start() + offset;
@@ -875,14 +920,14 @@ UnixNetVConnection::load_buffer_and_write(int64_t towrite, int64_t &wattempted,
       offset = 0;
       b = b->next;
     }
-    wattempted = total_wrote - total_wrote_last;
+    wattempted = total_written - total_written_last;
     if (niov == 1)
       r = socketManager.write(con.fd, tiovec[0].iov_base, tiovec[0].iov_len);
     else
       r = socketManager.writev(con.fd, &tiovec[0], niov);
     ProxyMutex *mutex = thread->mutex;
-    NET_DEBUG_COUNT_DYN_STAT(net_calls_to_write_stat, 1);
-  } while (r == wattempted && total_wrote < towrite);
+    NET_INCREMENT_DYN_STAT(net_calls_to_write_stat);
+  } while (r == wattempted && total_written < towrite);
 
   needs |= EVENTIO_WRITE;
 
@@ -939,7 +984,7 @@ int
 UnixNetVConnection::startEvent(int /* event ATS_UNUSED */, Event *e)
 {
   MUTEX_TRY_LOCK(lock, get_NetHandler(e->ethread)->mutex, e->ethread);
-  if (!lock) {
+  if (!lock.is_locked()) {
     e->schedule_in(NET_RETRY_DELAY);
     return EVENT_CONT;
   }
@@ -956,7 +1001,7 @@ UnixNetVConnection::acceptEvent(int event, Event *e)
   thread = e->ethread;
 
   MUTEX_TRY_LOCK(lock, get_NetHandler(thread)->mutex, e->ethread);
-  if (!lock) {
+  if (!lock.is_locked()) {
     if (event == EVENT_NONE) {
       thread->schedule_in(this, NET_RETRY_DELAY);
       return EVENT_DONE;
@@ -971,11 +1016,11 @@ UnixNetVConnection::acceptEvent(int event, Event *e)
     return EVENT_DONE;
   }
 
-  SET_HANDLER((NetVConnHandler) & UnixNetVConnection::mainEvent);
+  SET_HANDLER((NetVConnHandler)&UnixNetVConnection::mainEvent);
 
   nh = get_NetHandler(thread);
   PollDescriptor *pd = get_PollDescriptor(thread);
-  if (ep.start(pd, this, EVENTIO_READ|EVENTIO_WRITE) < 0) {
+  if (ep.start(pd, this, EVENTIO_READ | EVENTIO_WRITE) < 0) {
     Debug("iocore_net", "acceptEvent : failed EventIO::start\n");
     close_UnixNetVConnection(this, e->ethread);
     return EVENT_DONE;
@@ -1007,12 +1052,11 @@ UnixNetVConnection::mainEvent(int event, Event *e)
   ink_assert(thread == this_ethread());
 
   MUTEX_TRY_LOCK(hlock, get_NetHandler(thread)->mutex, e->ethread);
-  MUTEX_TRY_LOCK(rlock, read.vio.mutex ? (ProxyMutex *) read.vio.mutex : (ProxyMutex *) e->ethread->mutex, e->ethread);
-  MUTEX_TRY_LOCK(wlock, write.vio.mutex ? (ProxyMutex *) write.vio.mutex :
-                 (ProxyMutex *) e->ethread->mutex, e->ethread);
-  if (!hlock || !rlock || !wlock ||
-      (read.vio.mutex.m_ptr && rlock.m.m_ptr != read.vio.mutex.m_ptr) ||
-      (write.vio.mutex.m_ptr && wlock.m.m_ptr != write.vio.mutex.m_ptr)) {
+  MUTEX_TRY_LOCK(rlock, read.vio.mutex ? (ProxyMutex *)read.vio.mutex : (ProxyMutex *)e->ethread->mutex, e->ethread);
+  MUTEX_TRY_LOCK(wlock, write.vio.mutex ? (ProxyMutex *)write.vio.mutex : (ProxyMutex *)e->ethread->mutex, e->ethread);
+  if (!hlock.is_locked() || !rlock.is_locked() || !wlock.is_locked() ||
+      (read.vio.mutex.m_ptr && rlock.get_mutex() != read.vio.mutex.m_ptr) ||
+      (write.vio.mutex.m_ptr && wlock.get_mutex() != write.vio.mutex.m_ptr)) {
 #ifndef INACTIVITY_TIMEOUT
     if (e == active_timeout)
 #endif
@@ -1039,8 +1083,8 @@ UnixNetVConnection::mainEvent(int event, Event *e)
 #else
   if (event == EVENT_IMMEDIATE) {
     /* BZ 49408 */
-    //ink_assert(inactivity_timeout_in);
-    //ink_assert(next_inactivity_timeout_at < ink_get_hrtime());
+    // ink_assert(inactivity_timeout_in);
+    // ink_assert(next_inactivity_timeout_at < ink_get_hrtime());
     if (!inactivity_timeout_in || next_inactivity_timeout_at > ink_get_hrtime())
       return EVENT_CONT;
     signal_event = VC_EVENT_INACTIVITY_TIMEOUT;
@@ -1067,10 +1111,8 @@ UnixNetVConnection::mainEvent(int event, Event *e)
       return EVENT_DONE;
   }
 
-  if (!*signal_timeout &&
-      !*signal_timeout_at &&
-      !closed && write.vio.op == VIO::WRITE &&
-      !(f.shutdown & NET_VC_SHUTDOWN_WRITE) && reader_cont != write.vio._cont && writer_cont == write.vio._cont)
+  if (!*signal_timeout && !*signal_timeout_at && !closed && write.vio.op == VIO::WRITE && !(f.shutdown & NET_VC_SHUTDOWN_WRITE) &&
+      reader_cont != write.vio._cont && writer_cont == write.vio._cont)
     if (write_signal_and_update(signal_event, this) == EVENT_DONE)
       return EVENT_DONE;
   return EVENT_DONE;
@@ -1085,26 +1127,22 @@ UnixNetVConnection::connectUp(EThread *t, int fd)
   thread = t;
   if (check_net_throttle(CONNECT, submit_time)) {
     check_throttle_warning();
-    action_.continuation->handleEvent(NET_EVENT_OPEN_FAILED, (void *) -ENET_THROTTLING);
+    action_.continuation->handleEvent(NET_EVENT_OPEN_FAILED, (void *)-ENET_THROTTLING);
     free(t);
     return CONNECT_FAILURE;
   }
 
   // Force family to agree with remote (server) address.
   options.ip_family = server_addr.sa.sa_family;
-  
+
   //
   // Initialize this UnixNetVConnection
   //
   if (is_debug_tag_set("iocore_net")) {
     char addrbuf[INET6_ADDRSTRLEN];
     Debug("iocore_net", "connectUp:: local_addr=%s:%d [%s]\n",
-      options.local_ip.isValid()
-      ? options.local_ip.toString(addrbuf, sizeof(addrbuf))
-      : "*",
-      options.local_port,
-      NetVCOptions::toString(options.addr_binding)
-    );
+          options.local_ip.isValid() ? options.local_ip.toString(addrbuf, sizeof(addrbuf)) : "*", options.local_port,
+          NetVCOptions::toString(options.addr_binding));
   }
 
   // If this is getting called from the TS API, then we are wiring up a file descriptor
@@ -1117,11 +1155,10 @@ UnixNetVConnection::connectUp(EThread *t, int fd)
   } else {
     int len = sizeof(con.sock_type);
 
-    res = safe_getsockopt(fd, SOL_SOCKET, SO_TYPE, (char *)&con.sock_type, &len);
-    if (res != 0) {
-      goto fail;
-    }
-
+    // This call will fail if fd is not a socket (e.g. it is a
+    // eventfd or a regular file fd.  That is ok, because sock_type
+    // is only used when setting up the socket.
+    safe_getsockopt(fd, SOL_SOCKET, SO_TYPE, (char *)&con.sock_type, &len);
     safe_nonblocking(fd);
     con.fd = fd;
     con.is_connected = true;
@@ -1130,7 +1167,7 @@ UnixNetVConnection::connectUp(EThread *t, int fd)
 
   // Must connect after EventIO::Start() to avoid a race condition
   // when edge triggering is used.
-  if (ep.start(get_PollDescriptor(t), this, EVENTIO_READ|EVENTIO_WRITE) < 0) {
+  if (ep.start(get_PollDescriptor(t), this, EVENTIO_READ | EVENTIO_WRITE) < 0) {
     lerrno = errno;
     Debug("iocore_net", "connectUp : Failed to add to epoll list\n");
     action_.continuation->handleEvent(NET_EVENT_OPEN_FAILED, (void *)0); // 0 == res
@@ -1156,6 +1193,7 @@ UnixNetVConnection::connectUp(EThread *t, int fd)
 
   ink_assert(!inactivity_timeout_in);
   ink_assert(!active_timeout_in);
+  this->set_local_addr();
   action_.continuation->handleEvent(NET_EVENT_OPEN, this);
   return CONNECT_SUCCESS;
 
@@ -1176,10 +1214,11 @@ UnixNetVConnection::free(EThread *t)
   action_.mutex.clear();
   got_remote_addr = 0;
   got_local_addr = 0;
+  attributes = 0;
   read.vio.mutex.clear();
   write.vio.mutex.clear();
   flags = 0;
-  SET_CONTINUATION_HANDLER(this, (NetVConnHandler) & UnixNetVConnection::startEvent);
+  SET_CONTINUATION_HANDLER(this, (NetVConnHandler)&UnixNetVConnection::startEvent);
   nh = NULL;
   read.triggered = 0;
   write.triggered = 0;
@@ -1195,7 +1234,7 @@ UnixNetVConnection::free(EThread *t)
   ink_assert(t == this_ethread());
 
   if (from_accept_thread) {
-    netVCAllocator.free(this);  
+    netVCAllocator.free(this);
   } else {
     THREAD_FREE(this, netVCAllocator, t);
   }
