@@ -32,7 +32,7 @@
 #include "P_Net.h"
 #include "P_UDPNet.h"
 
-typedef int (UDPNetHandler::*UDPNetContHandler) (int, void *);
+typedef int (UDPNetHandler::*UDPNetContHandler)(int, void *);
 
 inkcoreapi ClassAllocator<UDPPacketInternal> udpPacketAllocator("udpPacketAllocator");
 EventType ET_UDP;
@@ -62,10 +62,10 @@ int G_bwGrapherFd;
 sockaddr_in6 G_bwGrapherLoc;
 
 void
-initialize_thread_for_udp_net(EThread * thread)
+initialize_thread_for_udp_net(EThread *thread)
 {
-  new((ink_dummy_for_new *) get_UDPPollCont(thread)) PollCont(thread->mutex);
-  new((ink_dummy_for_new *) get_UDPNetHandler(thread)) UDPNetHandler;
+  new ((ink_dummy_for_new *)get_UDPPollCont(thread)) PollCont(thread->mutex);
+  new ((ink_dummy_for_new *)get_UDPNetHandler(thread)) UDPNetHandler;
 
   // This variable controls how often we cleanup the cancelled packets.
   // If it is set to 0, then cleanup never occurs.
@@ -92,7 +92,7 @@ UDPNetProcessorInternal::start(int n_upd_threads, size_t stacksize)
     return -1;
 
   ET_UDP = eventProcessor.spawn_event_threads(n_upd_threads, "ET_UDP", stacksize);
-  if (ET_UDP < 0)               // Probably can't happen, maybe at some point EventType should be unsigned ?
+  if (ET_UDP < 0) // Probably can't happen, maybe at some point EventType should be unsigned ?
     return -1;
 
   pollCont_offset = eventProcessor.allocate(sizeof(PollCont));
@@ -105,9 +105,9 @@ UDPNetProcessorInternal::start(int n_upd_threads, size_t stacksize)
 }
 
 void
-UDPNetProcessorInternal::udp_read_from_net(UDPNetHandler * nh, UDPConnection * xuc)
+UDPNetProcessorInternal::udp_read_from_net(UDPNetHandler *nh, UDPConnection *xuc)
 {
-  UnixUDPConnection *uc = (UnixUDPConnection *) xuc;
+  UnixUDPConnection *uc = (UnixUDPConnection *)xuc;
 
   // receive packet and queue onto UDPConnection.
   // don't call back connection at this time.
@@ -121,7 +121,7 @@ UDPNetProcessorInternal::udp_read_from_net(UDPNetHandler * nh, UDPConnection * x
     // which gets referenced by IOBufferBlock.
     char buf[65536];
     int buflen = sizeof(buf);
-    r = socketManager.recvfrom(uc->getFd(), buf, buflen, 0, (struct sockaddr *) &fromaddr, &fromlen);
+    r = socketManager.recvfrom(uc->getFd(), buf, buflen, 0, (struct sockaddr *)&fromaddr, &fromlen);
     if (r <= 0) {
       // error
       break;
@@ -148,14 +148,14 @@ UDPNetProcessorInternal::udp_read_from_net(UDPNetHandler * nh, UDPConnection * x
 
 
 int
-UDPNetProcessorInternal::udp_callback(UDPNetHandler * nh, UDPConnection * xuc, EThread * thread)
+UDPNetProcessorInternal::udp_callback(UDPNetHandler *nh, UDPConnection *xuc, EThread *thread)
 {
-  (void) nh;
-  UnixUDPConnection *uc = (UnixUDPConnection *) xuc;
+  (void)nh;
+  UnixUDPConnection *uc = (UnixUDPConnection *)xuc;
 
   if (uc->continuation && uc->mutex) {
     MUTEX_TRY_LOCK_FOR(lock, uc->mutex, thread, uc->continuation);
-    if (!lock) {
+    if (!lock.is_locked()) {
       return 1;
     }
     uc->AddRef();
@@ -172,25 +172,27 @@ UDPNetProcessorInternal::udp_callback(UDPNetHandler * nh, UDPConnection * xuc, E
 }
 
 // cheesy implementation of a asynchronous read and callback for Unix
-class UDPReadContinuation:public Continuation
+class UDPReadContinuation : public Continuation
 {
 public:
-  UDPReadContinuation(Event * completionToken);
+  UDPReadContinuation(Event *completionToken);
   UDPReadContinuation();
   ~UDPReadContinuation();
   inline void free(void);
-  inline void init_token(Event * completionToken);
-  inline void init_read(int fd, IOBufferBlock * buf, int len, struct sockaddr *fromaddr, socklen_t *fromaddrlen);
+  inline void init_token(Event *completionToken);
+  inline void init_read(int fd, IOBufferBlock *buf, int len, struct sockaddr *fromaddr, socklen_t *fromaddrlen);
 
-  void set_timer(int seconds)
+  void
+  set_timer(int seconds)
   {
     timeout_interval = HRTIME_SECONDS(seconds);
   }
 
   void cancel();
-  int readPollEvent(int event, Event * e);
+  int readPollEvent(int event, Event *e);
 
-  Action *getAction()
+  Action *
+  getAction()
   {
     return event;
   }
@@ -198,15 +200,15 @@ public:
   void setupPollDescriptor();
 
 private:
-  Event * event;                // the completion event token created
+  Event *event; // the completion event token created
   // on behalf of the client
   Ptr<IOBufferBlock> readbuf;
   int readlen;
   struct sockaddr_in6 *fromaddr;
   socklen_t *fromaddrlen;
-  int fd;                       // fd we are reading from
-  int ifd;                      // poll fd index
-  ink_hrtime period;            // polling period
+  int fd;            // fd we are reading from
+  int ifd;           // poll fd index
+  ink_hrtime period; // polling period
   ink_hrtime elapsed_time;
   ink_hrtime timeout_interval;
 };
@@ -215,9 +217,9 @@ ClassAllocator<UDPReadContinuation> udpReadContAllocator("udpReadContAllocator")
 
 #define UNINITIALIZED_EVENT_PTR (Event *)0xdeadbeef
 
-UDPReadContinuation::UDPReadContinuation(Event * completionToken)
-  : Continuation(NULL), event(completionToken), readbuf(NULL), readlen(0), fromaddrlen(0), fd(-1),
-    ifd(-1), period(0), elapsed_time(0), timeout_interval(0)
+UDPReadContinuation::UDPReadContinuation(Event *completionToken)
+  : Continuation(NULL), event(completionToken), readbuf(NULL), readlen(0), fromaddrlen(0), fd(-1), ifd(-1), period(0),
+    elapsed_time(0), timeout_interval(0)
 {
   if (completionToken->continuation)
     this->mutex = completionToken->continuation->mutex;
@@ -226,9 +228,10 @@ UDPReadContinuation::UDPReadContinuation(Event * completionToken)
 }
 
 UDPReadContinuation::UDPReadContinuation()
-  : Continuation(NULL), event(UNINITIALIZED_EVENT_PTR), readbuf(NULL), readlen(0), fromaddrlen(0), fd(-1),
-    ifd(-1), period(0), elapsed_time(0), timeout_interval(0)
-{ }
+  : Continuation(NULL), event(UNINITIALIZED_EVENT_PTR), readbuf(NULL), readlen(0), fromaddrlen(0), fd(-1), ifd(-1), period(0),
+    elapsed_time(0), timeout_interval(0)
+{
+}
 
 inline void
 UDPReadContinuation::free(void)
@@ -249,7 +252,7 @@ UDPReadContinuation::free(void)
 }
 
 inline void
-UDPReadContinuation::init_token(Event * completionToken)
+UDPReadContinuation::init_token(Event *completionToken)
 {
   if (completionToken->continuation) {
     this->mutex = completionToken->continuation->mutex;
@@ -260,7 +263,7 @@ UDPReadContinuation::init_token(Event * completionToken)
 }
 
 inline void
-UDPReadContinuation::init_read(int rfd, IOBufferBlock * buf, int len, struct sockaddr *fromaddr_, socklen_t *fromaddrlen_)
+UDPReadContinuation::init_read(int rfd, IOBufferBlock *buf, int len, struct sockaddr *fromaddr_, socklen_t *fromaddrlen_)
 {
   ink_assert(rfd >= 0 && buf != NULL && fromaddr_ != NULL && fromaddrlen_ != NULL);
   fd = rfd;
@@ -276,8 +279,7 @@ UDPReadContinuation::init_read(int rfd, IOBufferBlock * buf, int len, struct soc
 
 UDPReadContinuation::~UDPReadContinuation()
 {
-  if (event != UNINITIALIZED_EVENT_PTR)
-  {
+  if (event != UNINITIALIZED_EVENT_PTR) {
     ink_assert(event != NULL);
     completionUtil::destroy(event);
     event = NULL;
@@ -296,7 +298,7 @@ UDPReadContinuation::setupPollDescriptor()
 {
 #if TS_USE_EPOLL
   Pollfd *pfd;
-  EThread *et = (EThread *) this_thread();
+  EThread *et = (EThread *)this_thread();
   PollCont *pc = get_PollCont(et);
   if (pc->nextPollDescriptor == NULL) {
     pc->nextPollDescriptor = new PollDescriptor;
@@ -312,12 +314,12 @@ UDPReadContinuation::setupPollDescriptor()
 }
 
 int
-UDPReadContinuation::readPollEvent(int event_, Event * e)
+UDPReadContinuation::readPollEvent(int event_, Event *e)
 {
-  (void) event_;
-  (void) e;
+  (void)event_;
+  (void)e;
 
-  //PollCont *pc = get_PollCont(e->ethread);
+  // PollCont *pc = get_PollCont(e->ethread);
   Continuation *c;
 
   if (event->cancelled) {
@@ -339,9 +341,10 @@ UDPReadContinuation::readPollEvent(int event_, Event * e)
       return EVENT_DONE;
     }
   }
-  //ink_assert(ifd < 0 || event_ == EVENT_INTERVAL || (event_ == EVENT_POLL && pc->pollDescriptor->nfds > ifd && pc->pollDescriptor->pfd[ifd].fd == fd));
-  //if (ifd < 0 || event_ == EVENT_INTERVAL || (pc->pollDescriptor->pfd[ifd].revents & POLLIN)) {
-  //ink_assert(!"incomplete");
+  // ink_assert(ifd < 0 || event_ == EVENT_INTERVAL || (event_ == EVENT_POLL && pc->pollDescriptor->nfds > ifd &&
+  // pc->pollDescriptor->pfd[ifd].fd == fd));
+  // if (ifd < 0 || event_ == EVENT_INTERVAL || (pc->pollDescriptor->pfd[ifd].revents & POLLIN)) {
+  // ink_assert(!"incomplete");
   c = completionUtil::getContinuation(event);
   // do read
   socklen_t tmp_fromlen = *fromaddrlen;
@@ -363,13 +366,13 @@ UDPReadContinuation::readPollEvent(int event_, Event * e)
   } else if (rlen < 0 && rlen != -EAGAIN) {
     // signal error.
     *fromaddrlen = tmp_fromlen;
-    completionUtil::setInfo(event, fd, (IOBufferBlock *) readbuf, rlen, errno);
+    completionUtil::setInfo(event, fd, (IOBufferBlock *)readbuf, rlen, errno);
     c = completionUtil::getContinuation(event);
     // TODO: Should we deal with the return code?
     c->handleEvent(NET_EVENT_DATAGRAM_READ_ERROR, event);
     e->cancel();
     free();
-    //delete this;
+    // delete this;
     return EVENT_DONE;
   } else {
     completionUtil::setThread(event, NULL);
@@ -378,7 +381,7 @@ UDPReadContinuation::readPollEvent(int event_, Event * e)
   if (event->cancelled) {
     e->cancel();
     free();
-    //delete this;
+    // delete this;
     return EVENT_DONE;
   }
   // reestablish poll
@@ -403,13 +406,10 @@ UDPReadContinuation::readPollEvent(int event_, Event * e)
  *      return error;
  */
 Action *
-UDPNetProcessor::recvfrom_re(Continuation * cont,
-                             void *token,
-                             int fd,
-                             struct sockaddr * fromaddr, socklen_t *fromaddrlen,
-                             IOBufferBlock * buf, int len, bool useReadCont, int timeout)
+UDPNetProcessor::recvfrom_re(Continuation *cont, void *token, int fd, struct sockaddr *fromaddr, socklen_t *fromaddrlen,
+                             IOBufferBlock *buf, int len, bool useReadCont, int timeout)
 {
-  (void) useReadCont;
+  (void)useReadCont;
   ink_assert(buf->write_avail() >= len);
   int actual;
   Event *event = completionUtil::create();
@@ -451,7 +451,7 @@ UDPNetProcessor::recvfrom_re(Continuation * cont,
  *      return error
  */
 Action *
-UDPNetProcessor::sendmsg_re(Continuation * cont, void *token, int fd, struct msghdr * msg)
+UDPNetProcessor::sendmsg_re(Continuation *cont, void *token, int fd, struct msghdr *msg)
 {
   int actual;
   Event *event = completionUtil::create();
@@ -487,17 +487,17 @@ UDPNetProcessor::sendmsg_re(Continuation * cont, void *token, int fd, struct msg
  *
  */
 Action *
-UDPNetProcessor::sendto_re(Continuation * cont, void *token, int fd, struct sockaddr const* toaddr, int toaddrlen,
-                           IOBufferBlock * buf, int len)
+UDPNetProcessor::sendto_re(Continuation *cont, void *token, int fd, struct sockaddr const *toaddr, int toaddrlen,
+                           IOBufferBlock *buf, int len)
 {
-  (void) token;
+  (void)token;
   ink_assert(buf->read_avail() >= len);
   int nbytes_sent = socketManager.sendto(fd, buf->start(), len, 0, toaddr, toaddrlen);
 
   if (nbytes_sent >= 0) {
     ink_assert(nbytes_sent == len);
     buf->consume(nbytes_sent);
-    cont->handleEvent(NET_EVENT_DATAGRAM_WRITE_COMPLETE, (void *) -1);
+    cont->handleEvent(NET_EVENT_DATAGRAM_WRITE_COMPLETE, (void *)-1);
     return ACTION_RESULT_DONE;
   } else {
     cont->handleEvent(NET_EVENT_DATAGRAM_WRITE_ERROR, (void *)(intptr_t)nbytes_sent);
@@ -507,8 +507,8 @@ UDPNetProcessor::sendto_re(Continuation * cont, void *token, int fd, struct sock
 
 
 bool
-UDPNetProcessor::CreateUDPSocket(int *resfd, sockaddr const* remote_addr, sockaddr* local_addr,
-                                 int *local_addr_len, Action ** status, int send_bufsize, int recv_bufsize)
+UDPNetProcessor::CreateUDPSocket(int *resfd, sockaddr const *remote_addr, sockaddr *local_addr, int *local_addr_len,
+                                 Action **status, int send_bufsize, int recv_bufsize)
 {
   int res = 0, fd = -1;
 
@@ -540,23 +540,18 @@ UDPNetProcessor::CreateUDPSocket(int *resfd, sockaddr const* remote_addr, sockad
   }
   *resfd = fd;
   *status = NULL;
-  Debug("udpnet", "creating a udp socket port = %d, %d---success",
-    ats_ip_port_host_order(remote_addr), ats_ip_port_host_order(local_addr)
-  );
+  Debug("udpnet", "creating a udp socket port = %d, %d---success", ats_ip_port_host_order(remote_addr),
+        ats_ip_port_host_order(local_addr));
   return true;
 SoftError:
-  Debug("udpnet", "creating a udp socket port = %d---soft failure",
-    ats_ip_port_host_order(local_addr)
-  );
+  Debug("udpnet", "creating a udp socket port = %d---soft failure", ats_ip_port_host_order(local_addr));
   if (fd != -1)
     socketManager.close(fd);
   *resfd = -1;
   *status = NULL;
   return false;
 HardError:
-  Debug("udpnet", "creating a udp socket port = %d---hard failure",
-    ats_ip_port_host_order(local_addr)
-  );
+  Debug("udpnet", "creating a udp socket port = %d---hard failure", ats_ip_port_host_order(local_addr));
   if (fd != -1)
     socketManager.close(fd);
   *resfd = -1;
@@ -566,7 +561,7 @@ HardError:
 
 
 Action *
-UDPNetProcessor::UDPBind(Continuation * cont, sockaddr const* addr, int send_bufsize, int recv_bufsize)
+UDPNetProcessor::UDPBind(Continuation *cont, sockaddr const *addr, int send_bufsize, int recv_bufsize)
 {
   int res = 0;
   int fd = -1;
@@ -584,7 +579,7 @@ UDPNetProcessor::UDPBind(Continuation * cont, sockaddr const* addr, int send_buf
   if (ats_is_ip_multicast(addr)) {
     int enable_reuseaddr = 1;
 
-    if ((res = safe_setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, (char *) &enable_reuseaddr, sizeof(enable_reuseaddr)) < 0)) {
+    if ((res = safe_setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, (char *)&enable_reuseaddr, sizeof(enable_reuseaddr)) < 0)) {
       goto Lerror;
     }
   }
@@ -621,9 +616,9 @@ Lerror:
 
 
 // send out all packets that need to be sent out as of time=now
-UDPQueue::UDPQueue()
-  : last_report(0), last_service(0), packets(0), added(0)
-{ }
+UDPQueue::UDPQueue() : last_report(0), last_service(0), packets(0), added(0)
+{
+}
 
 UDPQueue::~UDPQueue()
 {
@@ -633,16 +628,16 @@ UDPQueue::~UDPQueue()
  * Driver function that aggregates packets across cont's and sends them
  */
 void
-UDPQueue::service(UDPNetHandler * nh)
+UDPQueue::service(UDPNetHandler *nh)
 {
-  (void) nh;
+  (void)nh;
   ink_hrtime now = ink_get_hrtime_internal();
   uint64_t timeSpent = 0;
   uint64_t pktSendStartTime;
   UDPPacketInternal *p;
   ink_hrtime pktSendTime;
 
-  p = (UDPPacketInternal *) ink_atomiclist_popall(&atomicQueue);
+  p = (UDPPacketInternal *)ink_atomiclist_popall(&atomicQueue);
   if (p) {
     UDPPacketInternal *pnext = NULL;
     Queue<UDPPacketInternal> stk;
@@ -757,12 +752,12 @@ UDPQueue::SendUDPPacket(UDPPacketInternal *p, int32_t /* pktLen ATS_UNUSED */)
   msg.msg_controllen = 0;
   msg.msg_flags = 0;
 #endif
-  msg.msg_name = (caddr_t) & p->to;
+  msg.msg_name = (caddr_t)&p->to;
   msg.msg_namelen = sizeof(p->to);
   iov_len = 0;
 
   for (b = p->chain; b != NULL; b = b->next) {
-    iov[iov_len].iov_base = (caddr_t) b->start();
+    iov[iov_len].iov_base = (caddr_t)b->start();
     iov[iov_len].iov_len = b->size();
     real_len += iov[iov_len].iov_len;
     iov_len++;
@@ -773,7 +768,7 @@ UDPQueue::SendUDPPacket(UDPPacketInternal *p, int32_t /* pktLen ATS_UNUSED */)
   count = 0;
   while (1) {
     // stupid Linux problem: sendmsg can return EAGAIN
-    n =::sendmsg(p->conn->getFd(), &msg, 0);
+    n = ::sendmsg(p->conn->getFd(), &msg, 0);
     if ((n >= 0) || ((n < 0) && (errno != EAGAIN)))
       // send succeeded or some random error happened.
       break;
@@ -790,7 +785,7 @@ UDPQueue::SendUDPPacket(UDPPacketInternal *p, int32_t /* pktLen ATS_UNUSED */)
 
 
 void
-UDPQueue::send(UDPPacket * p)
+UDPQueue::send(UDPPacket *p)
 {
   // XXX: maybe fastpath for immediate send?
   ink_atomiclist_push(&atomicQueue, p);
@@ -805,25 +800,25 @@ UDPNetHandler::UDPNetHandler()
   ink_atomiclist_init(&udpNewConnections, "UDP Connection queue", offsetof(UnixUDPConnection, newconn_alink.next));
   nextCheck = ink_get_hrtime_internal() + HRTIME_MSECONDS(1000);
   lastCheck = 0;
-  SET_HANDLER((UDPNetContHandler) & UDPNetHandler::startNetEvent);
+  SET_HANDLER((UDPNetContHandler)&UDPNetHandler::startNetEvent);
 }
 
 int
-UDPNetHandler::startNetEvent(int event, Event * e)
+UDPNetHandler::startNetEvent(int event, Event *e)
 {
-  (void) event;
-  SET_HANDLER((UDPNetContHandler) & UDPNetHandler::mainNetEvent);
+  (void)event;
+  SET_HANDLER((UDPNetContHandler)&UDPNetHandler::mainNetEvent);
   trigger_event = e;
   e->schedule_every(-HRTIME_MSECONDS(9));
   return EVENT_CONT;
 }
 
 int
-UDPNetHandler::mainNetEvent(int event, Event * e)
+UDPNetHandler::mainNetEvent(int event, Event *e)
 {
   ink_assert(trigger_event == e && event == EVENT_POLL);
-  (void) event;
-  (void) e;
+  (void)event;
+  (void)e;
 
   PollCont *pc = get_UDPPollCont(e->ethread);
 
@@ -837,9 +832,8 @@ UDPNetHandler::mainNetEvent(int event, Event * e)
 
   EventIO *temp_eptr = NULL;
   for (i = 0; i < pc->pollDescriptor->result; i++) {
-    temp_eptr = (EventIO*) get_ev_data(pc->pollDescriptor,i);
-    if ((get_ev_events(pc->pollDescriptor,i) & EVENTIO_READ)
-        && temp_eptr->type == EVENTIO_UDP_CONNECTION) {
+    temp_eptr = (EventIO *)get_ev_data(pc->pollDescriptor, i);
+    if ((get_ev_events(pc->pollDescriptor, i) & EVENTIO_READ) && temp_eptr->type == EVENTIO_UDP_CONNECTION) {
       uc = temp_eptr->data.uc;
       ink_assert(uc && uc->mutex && uc->continuation);
       ink_assert(uc->refcount >= 1);
@@ -850,8 +844,8 @@ UDPNetHandler::mainNetEvent(int event, Event * e)
         udpNetInternal.udp_read_from_net(this, uc);
         nread++;
       }
-    }                           //if EPOLLIN
-  }                             //end for
+    } // if EPOLLIN
+  }   // end for
 
   // remove dead UDP connections
   ink_hrtime now = ink_get_hrtime_internal();
@@ -861,8 +855,8 @@ UDPNetHandler::mainNetEvent(int event, Event * e)
       ink_assert(uc->refcount >= 1);
       next = uc->polling_link.next;
       if (uc->shouldDestroy()) {
-        //changed by YTS Team, yamsat
-        //udp_polling->remove(uc,uc->polling_link);
+        // changed by YTS Team, yamsat
+        // udp_polling->remove(uc,uc->polling_link);
         uc->Release();
       }
     }
@@ -873,7 +867,7 @@ UDPNetHandler::mainNetEvent(int event, Event * e)
   udp_callbacks.clear();
   while ((uc = q.dequeue())) {
     ink_assert(uc->mutex && uc->continuation);
-    if (udpNetInternal.udp_callback(this, uc, trigger_event->ethread)) {        // not successful
+    if (udpNetInternal.udp_callback(this, uc, trigger_event->ethread)) { // not successful
       // schedule on a thread of its own.
       ink_assert(uc->callback_link.next == NULL);
       ink_assert(uc->callback_link.prev == NULL);
