@@ -49,17 +49,17 @@
 struct Machine {
   typedef Machine self; ///< Self reference type.
 
-  char *hostname;               // name of the internet host
-  int hostname_len;             // size of the string pointed to by hostname
+  char *hostname;   // name of the internet host
+  int hostname_len; // size of the string pointed to by hostname
 
-  IpEndpoint ip;      ///< Prefered IP address of the host (network order)
-  IpEndpoint ip4;     ///< IPv4 address if present.
-  IpEndpoint ip6;     ///< IPv6 address if present.
+  IpEndpoint ip;  ///< Prefered IP address of the host (network order)
+  IpEndpoint ip4; ///< IPv4 address if present.
+  IpEndpoint ip6; ///< IPv6 address if present.
 
-  ip_text_buffer ip_string;              // IP address of the host as a string.
+  ip_text_buffer ip_string; // IP address of the host as a string.
   int ip_string_len;
 
-  char ip_hex_string[TS_IP6_SIZE*2 + 1]; ///< IP address as hex string
+  char ip_hex_string[TS_IP6_SIZE * 2 + 1]; ///< IP address as hex string
   int ip_hex_string_len;
 
   ~Machine();
@@ -70,31 +70,16 @@ struct Machine {
       @note This must be called before called @c instance so that the
       singleton is not @em inadvertently default initialized.
   */
-  static self* init(
-    char const* name = 0, ///< Host name of the machine.
-    sockaddr const* addr = 0 ///< Primary IP adddress of the machine.
-  );
+  static self *init(char const *name = 0,    ///< Host name of the machine.
+                    sockaddr const *addr = 0 ///< Primary IP adddress of the machine.
+                    );
   /// @return The global instance of this class.
-  static self* instance();
+  static self *instance();
 
 protected:
-  Machine(char const* hostname, sockaddr const* addr);
+  Machine(char const *hostname, sockaddr const *addr);
 
-  static self* _instance; ///< Singleton for the class.
+  static self *_instance; ///< Singleton for the class.
 };
 
-/**
-  Creates a Machine Object with the hostname and IP address.  If no
-  hostname or IP address is given, the hostname defaults to the name of
-  the current processor.
-
- */
-void create_this_machine(char *hostname = 0, unsigned int ip = 0);
-
-/**
-  Returns the Machine object created by create_this_machine().
-
- */
-Machine *this_machine();
-
 #endif
