@@ -28,22 +28,22 @@
 #include "ink_autoconf.h"
 
 #if HAVE_STD_SHARED_PTR
-#  include <memory>
+#include <memory>
 #else
-#  include <tr1/memory>
+#include <tr1/memory>
 #endif
 
-namespace atscppapi {
-
+namespace atscppapi
+{
 /**
  * Force the use of std::tr1::shared_ptr
  * \todo Consider adding a simple macro to check if c++0x/11 is enabled
  * and if so change it to std::shared_ptr and #include <memory>s
  */
 #if HAVE_STD_SHARED_PTR
-  using std::shared_ptr;
+using std::shared_ptr;
 #else
-  using std::tr1::shared_ptr;
+using std::tr1::shared_ptr;
 #endif
 
 } /* atscppapi */
