@@ -30,20 +30,21 @@
 // Initialization
 //-------------------------------------------------------------------------
 
-int RecMessageInit();
+// int RecMessageInit();
+void RecMessageRegister();
 
 //-------------------------------------------------------------------------
 // Message Operations
 //-------------------------------------------------------------------------
 
 RecMessage *RecMessageAlloc(RecMessageT msg_type, int initial_size = 256);
-int RecMessageFree(RecMessage * msg);
+int RecMessageFree(RecMessage *msg);
 
-RecMessage *RecMessageMarshal_Realloc(RecMessage * msg, const RecRecord * record);
-int RecMessageUnmarshalFirst(RecMessage * msg, RecMessageItr * itr, RecRecord ** record);
-int RecMessageUnmarshalNext(RecMessage * msg, RecMessageItr * itr, RecRecord ** record);
+RecMessage *RecMessageMarshal_Realloc(RecMessage *msg, const RecRecord *record);
+int RecMessageUnmarshalFirst(RecMessage *msg, RecMessageItr *itr, RecRecord **record);
+int RecMessageUnmarshalNext(RecMessage *msg, RecMessageItr *itr, RecRecord **record);
 
-int RecMessageSend(RecMessage * msg);
+int RecMessageSend(RecMessage *msg);
 int RecMessageRegisterRecvCb(RecMessageRecvCb recv_cb, void *cookie);
 void *RecMessageRecvThis(void *cookie, char *data_raw, int data_len);
 
