@@ -34,14 +34,9 @@
 //-------------------------------------------------------------------------
 
 #define REC_TYPE_IS_STAT(rec_type) \
-  (((rec_type) == RECT_PROCESS) || \
-   ((rec_type) == RECT_PLUGIN) || \
-   ((rec_type) == RECT_NODE) || \
-   ((rec_type) == RECT_CLUSTER))
+  (((rec_type) == RECT_PROCESS) || ((rec_type) == RECT_PLUGIN) || ((rec_type) == RECT_NODE) || ((rec_type) == RECT_CLUSTER))
 
-#define REC_TYPE_IS_CONFIG(rec_type) \
-  (((rec_type) == RECT_CONFIG) || \
-   ((rec_type) == RECT_LOCAL))
+#define REC_TYPE_IS_CONFIG(rec_type) (((rec_type) == RECT_CONFIG) || ((rec_type) == RECT_LOCAL))
 
 
 //-------------------------------------------------------------------------
@@ -56,13 +51,13 @@ RecRecord *RecAlloc(RecT rec_type, const char *name, RecDataT data_type);
 // RecData Utils
 //-------------------------------------------------------------------------
 
-void RecDataClear(RecDataT type, RecData * data);
-void RecDataSetMax(RecDataT type, RecData * data);
-void RecDataSetMin(RecDataT type, RecData * data);
-bool RecDataSet(RecDataT data_type, RecData * data_dst, RecData * data_src);
-bool RecDataSetFromInk64(RecDataT data_type, RecData * data_dst, int64_t data_int64);
-bool RecDataSetFromFloat(RecDataT data_type, RecData * data_dst, float data_float);
-bool RecDataSetFromString(RecDataT data_type, RecData * data_dst, const char *data_string);
+void RecDataClear(RecDataT type, RecData *data);
+void RecDataSetMax(RecDataT type, RecData *data);
+void RecDataSetMin(RecDataT type, RecData *data);
+bool RecDataSet(RecDataT data_type, RecData *data_dst, RecData *data_src);
+bool RecDataSetFromInk64(RecDataT data_type, RecData *data_dst, int64_t data_int64);
+bool RecDataSetFromFloat(RecDataT data_type, RecData *data_dst, float data_float);
+bool RecDataSetFromString(RecDataT data_type, RecData *data_dst, const char *data_string);
 int RecDataCmp(RecDataT type, RecData left, RecData right);
 RecData RecDataAdd(RecDataT type, RecData left, RecData right);
 RecData RecDataSub(RecDataT type, RecData left, RecData right);
