@@ -26,7 +26,6 @@
 #include "P_RecFile.h"
 #include "P_RecCore.h"
 #include "P_RecUtils.h"
-#include "P_RecTree.h"
 #include "I_Layout.h"
 
 static bool g_initialized = false;
@@ -36,8 +35,6 @@ InkHashTable *g_records_ht = NULL;
 ink_rwlock g_records_rwlock;
 int g_num_records = 0;
 
-RecTree *g_records_tree = NULL;
-
 //-------------------------------------------------------------------------
 // register_record
 //-------------------------------------------------------------------------
@@ -46,7 +43,7 @@ register_record(RecT rec_type, const char *name, RecDataT data_type, RecData dat
 {
   RecRecord *r = NULL;
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     ink_release_assert(r->rec_type == rec_type);
     ink_release_assert(r->data_type == data_type);
     // Note: do not set r->data as we want to keep the previous value
@@ -58,7 +55,7 @@ register_record(RecT rec_type, const char *name, RecDataT data_type, RecData dat
     // Set the r->data to its default value as this is a new record
     RecDataSet(r->data_type, &(r->data), &(data_default));
     RecDataSet(r->data_type, &(r->data_default), &(data_default));
-    ink_hash_table_insert(g_records_ht, name, (void *) r);
+    ink_hash_table_insert(g_records_ht, name, (void *)r);
 
     if (REC_TYPE_IS_STAT(r->rec_type)) {
       r->stat_meta.persist_type = persist_type;
@@ -77,38 +74,38 @@ register_record(RecT rec_type, const char *name, RecDataT data_type, RecData dat
 // link_XXX
 //-------------------------------------------------------------------------
 static int
-link_int(const char *name, RecDataT data_type, RecData data, void *cookie)
+link_int(const char * /* name */, RecDataT /* data_type */, RecData data, void *cookie)
 {
-  RecInt *rec_int = (RecInt *) cookie;
+  RecInt *rec_int = (RecInt *)cookie;
   ink_atomic_swap(rec_int, data.rec_int);
   return REC_ERR_OKAY;
 }
 
 static int
-link_int32(const char *name, RecDataT data_type, RecData data, void *cookie)
+link_int32(const char * /* name */, RecDataT /* data_type */, RecData data, void *cookie)
 {
-  *((int32_t *) cookie) = (int32_t) data.rec_int;
+  *((int32_t *)cookie) = (int32_t)data.rec_int;
   return REC_ERR_OKAY;
 }
 
 static int
-link_uint32(const char *name, RecDataT data_type, RecData data, void *cookie)
+link_uint32(const char * /* name */, RecDataT /* data_type */, RecData data, void *cookie)
 {
-  *((uint32_t *) cookie) = (uint32_t) data.rec_int;
+  *((uint32_t *)cookie) = (uint32_t)data.rec_int;
   return REC_ERR_OKAY;
 }
 
 static int
-link_float(const char *name, RecDataT data_type, RecData data, void *cookie)
+link_float(const char * /* name */, RecDataT /* data_type */, RecData data, void *cookie)
 {
-  *((RecFloat *) cookie) = data.rec_float;
+  *((RecFloat *)cookie) = data.rec_float;
   return REC_ERR_OKAY;
 }
 
 static int
-link_counter(const char *name, RecDataT data_type, RecData data, void *cookie)
+link_counter(const char * /* name */, RecDataT /* data_type */, RecData data, void *cookie)
 {
-  RecCounter *rec_counter = (RecCounter *) cookie;
+  RecCounter *rec_counter = (RecCounter *)cookie;
   ink_atomic_swap(rec_counter, data.rec_counter);
   return REC_ERR_OKAY;
 }
@@ -116,9 +113,9 @@ link_counter(const char *name, RecDataT data_type, RecData data, void *cookie)
 // This is a convenience wrapper, to allow us to treat the RecInt's as a
 // 1-byte entity internally.
 static int
-link_byte(const char *name, RecDataT data_type, RecData data, void *cookie)
+link_byte(const char * /* name */, RecDataT /* data_type */, RecData data, void *cookie)
 {
-  RecByte *rec_byte = (RecByte *) cookie;
+  RecByte *rec_byte = (RecByte *)cookie;
   RecByte byte = static_cast<RecByte>(data.rec_int);
 
   ink_atomic_swap(rec_byte, byte);
@@ -129,7 +126,7 @@ link_byte(const char *name, RecDataT data_type, RecData data, void *cookie)
 // cookie e.g. is the DEFAULT_xxx_str value which this functiion keeps up to date with
 // the latest default applied during a config update from records.config
 static int
-link_string_alloc(const char *name, RecDataT data_type, RecData data, void *cookie)
+link_string_alloc(const char * /* name */, RecDataT /* data_type */, RecData data, void *cookie)
 {
   RecString _ss = data.rec_string;
   RecString _new_value = NULL;
@@ -163,7 +160,6 @@ RecCoreInit(RecModeT mode_type, Diags *_diags)
   // Initialize config file parsing data structures.
   RecConfigFileInit();
 
-  g_records_tree = new RecTree(NULL);
   g_num_records = 0;
 
   // initialize record array for our internal stats (this can be reallocated later)
@@ -188,10 +184,10 @@ RecCoreInit(RecModeT mode_type, Diags *_diags)
     // ./etc/trafficserver/records.config
     // ./records.config
     bool file_exists = true;
-    g_rec_config_fpath = Layout::relative_to(Layout::get()->sysconfdir, REC_CONFIG_FILE REC_SHADOW_EXT);
+    g_rec_config_fpath = RecConfigReadConfigPath(NULL, REC_CONFIG_FILE REC_SHADOW_EXT);
     if (RecFileExists(g_rec_config_fpath) == REC_ERR_FAIL) {
       ats_free((char *)g_rec_config_fpath);
-      g_rec_config_fpath = Layout::relative_to(Layout::get()->sysconfdir, REC_CONFIG_FILE);
+      g_rec_config_fpath = RecConfigReadConfigPath(NULL, REC_CONFIG_FILE);
       if (RecFileExists(g_rec_config_fpath) == REC_ERR_FAIL) {
         RecLog(DL_Warning, "Could not find '%s', system will run with defaults\n", REC_CONFIG_FILE);
         file_exists = false;
@@ -211,69 +207,69 @@ RecCoreInit(RecModeT mode_type, Diags *_diags)
 // RecLinkCnfigXXX
 //-------------------------------------------------------------------------
 int
-RecLinkConfigInt(const char *name, RecInt * rec_int)
+RecLinkConfigInt(const char *name, RecInt *rec_int)
 {
   if (RecGetRecordInt(name, rec_int) == REC_ERR_FAIL) {
     return REC_ERR_FAIL;
   }
-  return RecRegisterConfigUpdateCb(name, link_int, (void *) rec_int);
+  return RecRegisterConfigUpdateCb(name, link_int, (void *)rec_int);
 }
 
 int
-RecLinkConfigInt32(const char *name, int32_t * p_int32)
+RecLinkConfigInt32(const char *name, int32_t *p_int32)
 {
-  return RecRegisterConfigUpdateCb(name, link_int32, (void *) p_int32);
+  return RecRegisterConfigUpdateCb(name, link_int32, (void *)p_int32);
 }
 
 int
-RecLinkConfigUInt32(const char *name, uint32_t * p_uint32)
+RecLinkConfigUInt32(const char *name, uint32_t *p_uint32)
 {
-  return RecRegisterConfigUpdateCb(name, link_uint32, (void *) p_uint32);
+  return RecRegisterConfigUpdateCb(name, link_uint32, (void *)p_uint32);
 }
 
 int
-RecLinkConfigFloat(const char *name, RecFloat * rec_float)
+RecLinkConfigFloat(const char *name, RecFloat *rec_float)
 {
   if (RecGetRecordFloat(name, rec_float) == REC_ERR_FAIL) {
     return REC_ERR_FAIL;
   }
-  return RecRegisterConfigUpdateCb(name, link_float, (void *) rec_float);
+  return RecRegisterConfigUpdateCb(name, link_float, (void *)rec_float);
 }
 
 int
-RecLinkConfigCounter(const char *name, RecCounter * rec_counter)
+RecLinkConfigCounter(const char *name, RecCounter *rec_counter)
 {
   if (RecGetRecordCounter(name, rec_counter) == REC_ERR_FAIL) {
     return REC_ERR_FAIL;
   }
-  return RecRegisterConfigUpdateCb(name, link_counter, (void *) rec_counter);
+  return RecRegisterConfigUpdateCb(name, link_counter, (void *)rec_counter);
 }
 
 int
-RecLinkConfigString(const char *name, RecString * rec_string)
+RecLinkConfigString(const char *name, RecString *rec_string)
 {
   if (RecGetRecordString_Xmalloc(name, rec_string) == REC_ERR_FAIL) {
     return REC_ERR_FAIL;
   }
-  return RecRegisterConfigUpdateCb(name, link_string_alloc, (void *) rec_string);
+  return RecRegisterConfigUpdateCb(name, link_string_alloc, (void *)rec_string);
 }
 
 int
-RecLinkConfigByte(const char *name, RecByte * rec_byte)
+RecLinkConfigByte(const char *name, RecByte *rec_byte)
 {
   if (RecGetRecordByte(name, rec_byte) == REC_ERR_FAIL) {
     return REC_ERR_FAIL;
   }
-  return RecRegisterConfigUpdateCb(name, link_byte, (void *) rec_byte);
+  return RecRegisterConfigUpdateCb(name, link_byte, (void *)rec_byte);
 }
 
 int
-RecLinkConfigBool(const char *name, RecBool * rec_bool)
+RecLinkConfigBool(const char *name, RecBool *rec_bool)
 {
   if (RecGetRecordBool(name, rec_bool) == REC_ERR_FAIL) {
     return REC_ERR_FAIL;
   }
-  return RecRegisterConfigUpdateCb(name, link_byte, (void *) rec_bool);
+  return RecRegisterConfigUpdateCb(name, link_byte, (void *)rec_bool);
 }
 
 
@@ -288,7 +284,7 @@ RecRegisterConfigUpdateCb(const char *name, RecConfigUpdateCb update_cb, void *c
 
   ink_rwlock_rdlock(&g_records_rwlock);
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     rec_mutex_acquire(&(r->lock));
     if (REC_TYPE_IS_CONFIG(r->rec_type)) {
       /* -- upgrade to support a list of callback functions
@@ -345,7 +341,7 @@ RecGetRecordInt(const char *name, RecInt *rec_int, bool lock)
 }
 
 int
-RecGetRecordFloat(const char *name, RecFloat * rec_float, bool lock)
+RecGetRecordFloat(const char *name, RecFloat *rec_float, bool lock)
 {
   int err;
   RecData data;
@@ -362,7 +358,7 @@ RecGetRecordString(const char *name, char *buf, int buf_len, bool lock)
   if (lock) {
     ink_rwlock_rdlock(&g_records_rwlock);
   }
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     rec_mutex_acquire(&(r->lock));
     if (!r->registered || (r->data_type != RECD_STRING)) {
       err = REC_ERR_FAIL;
@@ -384,7 +380,7 @@ RecGetRecordString(const char *name, char *buf, int buf_len, bool lock)
 }
 
 int
-RecGetRecordString_Xmalloc(const char *name, RecString * rec_string, bool lock)
+RecGetRecordString_Xmalloc(const char *name, RecString *rec_string, bool lock)
 {
   int err;
   RecData data;
@@ -394,7 +390,7 @@ RecGetRecordString_Xmalloc(const char *name, RecString * rec_string, bool lock)
 }
 
 int
-RecGetRecordCounter(const char *name, RecCounter * rec_counter, bool lock)
+RecGetRecordCounter(const char *name, RecCounter *rec_counter, bool lock)
 {
   int err;
   RecData data;
@@ -426,8 +422,9 @@ RecGetRecordBool(const char *name, RecBool *rec_bool, bool lock)
 //-------------------------------------------------------------------------
 // RecGetRec Attributes
 //-------------------------------------------------------------------------
+
 int
-RecGetRecordType(const char *name, RecT * rec_type, bool lock)
+RecLookupRecord(const char *name, void (*callback)(const RecRecord *, void *), void *data, bool lock)
 {
   int err = REC_ERR_FAIL;
   RecRecord *r;
@@ -436,7 +433,31 @@ RecGetRecordType(const char *name, RecT * rec_type, bool lock)
     ink_rwlock_rdlock(&g_records_rwlock);
   }
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
+    rec_mutex_acquire(&(r->lock));
+    callback(r, data);
+    err = REC_ERR_OKAY;
+    rec_mutex_release(&(r->lock));
+  }
+
+  if (lock) {
+    ink_rwlock_unlock(&g_records_rwlock);
+  }
+
+  return err;
+}
+
+int
+RecGetRecordType(const char *name, RecT *rec_type, bool lock)
+{
+  int err = REC_ERR_FAIL;
+  RecRecord *r;
+
+  if (lock) {
+    ink_rwlock_rdlock(&g_records_rwlock);
+  }
+
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     rec_mutex_acquire(&(r->lock));
     *rec_type = r->rec_type;
     err = REC_ERR_OKAY;
@@ -452,7 +473,7 @@ RecGetRecordType(const char *name, RecT * rec_type, bool lock)
 
 
 int
-RecGetRecordDataType(const char *name, RecDataT * data_type, bool lock)
+RecGetRecordDataType(const char *name, RecDataT *data_type, bool lock)
 {
   int err = REC_ERR_FAIL;
   RecRecord *r = NULL;
@@ -461,7 +482,7 @@ RecGetRecordDataType(const char *name, RecDataT * data_type, bool lock)
     ink_rwlock_rdlock(&g_records_rwlock);
   }
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     rec_mutex_acquire(&(r->lock));
     if (!r->registered) {
       err = REC_ERR_FAIL;
@@ -480,7 +501,7 @@ RecGetRecordDataType(const char *name, RecDataT * data_type, bool lock)
 }
 
 int
-RecGetRecordPersistenceType(const char *name, RecPersistT * persist_type, bool lock)
+RecGetRecordPersistenceType(const char *name, RecPersistT *persist_type, bool lock)
 {
   int err = REC_ERR_FAIL;
   RecRecord *r = NULL;
@@ -491,7 +512,7 @@ RecGetRecordPersistenceType(const char *name, RecPersistT * persist_type, bool l
 
   *persist_type = RECP_NULL;
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     rec_mutex_acquire(&(r->lock));
     if (REC_TYPE_IS_STAT(r->rec_type)) {
       *persist_type = r->stat_meta.persist_type;
@@ -508,7 +529,7 @@ RecGetRecordPersistenceType(const char *name, RecPersistT * persist_type, bool l
 }
 
 int
-RecGetRecordOrderAndId(const char *name, int* order, int* id, bool lock)
+RecGetRecordOrderAndId(const char *name, int *order, int *id, bool lock)
 {
   int err = REC_ERR_FAIL;
   RecRecord *r = NULL;
@@ -517,7 +538,7 @@ RecGetRecordOrderAndId(const char *name, int* order, int* id, bool lock)
     ink_rwlock_rdlock(&g_records_rwlock);
   }
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     if (r->registered) {
       rec_mutex_acquire(&(r->lock));
       if (order)
@@ -546,7 +567,7 @@ RecGetRecordUpdateType(const char *name, RecUpdateT *update_type, bool lock)
     ink_rwlock_rdlock(&g_records_rwlock);
   }
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     rec_mutex_acquire(&(r->lock));
     if (REC_TYPE_IS_CONFIG(r->rec_type)) {
       *update_type = r->config_meta.update_type;
@@ -575,7 +596,7 @@ RecGetRecordCheckType(const char *name, RecCheckT *check_type, bool lock)
     ink_rwlock_rdlock(&g_records_rwlock);
   }
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     rec_mutex_acquire(&(r->lock));
     if (REC_TYPE_IS_CONFIG(r->rec_type)) {
       *check_type = r->config_meta.check_type;
@@ -604,7 +625,7 @@ RecGetRecordCheckExpr(const char *name, char **check_expr, bool lock)
     ink_rwlock_rdlock(&g_records_rwlock);
   }
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     rec_mutex_acquire(&(r->lock));
     if (REC_TYPE_IS_CONFIG(r->rec_type)) {
       *check_expr = r->config_meta.check_expr;
@@ -622,14 +643,17 @@ RecGetRecordCheckExpr(const char *name, char **check_expr, bool lock)
   return err;
 }
 
-
 int
 RecGetRecordDefaultDataString_Xmalloc(char *name, char **buf, bool lock)
 {
   int err;
   RecRecord *r = NULL;
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (lock) {
+    ink_rwlock_rdlock(&g_records_rwlock);
+  }
+
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     *buf = (char *)ats_malloc(sizeof(char) * 1024);
     memset(*buf, 0, 1024);
     err = REC_ERR_OKAY;
@@ -662,6 +686,10 @@ RecGetRecordDefaultDataString_Xmalloc(char *name, char **buf, bool lock)
     err = REC_ERR_FAIL;
   }
 
+  if (lock) {
+    ink_rwlock_unlock(&g_records_rwlock);
+  }
+
   return err;
 }
 
@@ -676,7 +704,7 @@ RecGetRecordAccessType(const char *name, RecAccessT *access, bool lock)
     ink_rwlock_rdlock(&g_records_rwlock);
   }
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     rec_mutex_acquire(&(r->lock));
     *access = r->config_meta.access_type;
     err = REC_ERR_OKAY;
@@ -701,7 +729,7 @@ RecSetRecordAccessType(const char *name, RecAccessT access, bool lock)
     ink_rwlock_rdlock(&g_records_rwlock);
   }
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     rec_mutex_acquire(&(r->lock));
     r->config_meta.access_type = access;
     err = REC_ERR_OKAY;
@@ -730,7 +758,7 @@ RecRegisterStat(RecT rec_type, const char *name, RecDataT data_type, RecData dat
     // type we are registering, then that means that it changed between the previous software
     // version and the current version. If the metric changed to non-persistent, reset to the
     // new default value.
-    if ((r->stat_meta.persist_type == RECP_NULL ||r->stat_meta.persist_type == RECP_PERSISTENT) &&
+    if ((r->stat_meta.persist_type == RECP_NULL || r->stat_meta.persist_type == RECP_PERSISTENT) &&
         persist_type == RECP_NON_PERSISTENT) {
       RecDebug(DL_Debug, "resetting default value for formerly persisted stat '%s'", r->name);
       RecDataSet(r->data_type, &(r->data), &(data_default));
@@ -751,8 +779,7 @@ RecRegisterStat(RecT rec_type, const char *name, RecDataT data_type, RecData dat
 // RecRegisterConfig
 //-------------------------------------------------------------------------
 RecRecord *
-RecRegisterConfig(RecT rec_type, const char *name, RecDataT data_type,
-                  RecData data_default, RecUpdateT update_type,
+RecRegisterConfig(RecT rec_type, const char *name, RecDataT data_type, RecData data_default, RecUpdateT update_type,
                   RecCheckT check_type, const char *check_expr, RecAccessT access_type)
 {
   RecRecord *r;
@@ -787,7 +814,7 @@ RecGetRecord_Xmalloc(const char *name, RecDataT data_type, RecData *data, bool l
     ink_rwlock_rdlock(&g_records_rwlock);
   }
 
-  if (ink_hash_table_lookup(g_records_ht, name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, name, (void **)&r)) {
     rec_mutex_acquire(&(r->lock));
     if (!r->registered || (r->data_type != data_type)) {
       err = REC_ERR_FAIL;
@@ -814,14 +841,14 @@ RecGetRecord_Xmalloc(const char *name, RecDataT data_type, RecData *data, bool l
 // RecForceInsert
 //-------------------------------------------------------------------------
 RecRecord *
-RecForceInsert(RecRecord * record)
+RecForceInsert(RecRecord *record)
 {
   RecRecord *r = NULL;
   bool r_is_a_new_record;
 
   ink_rwlock_wrlock(&g_records_rwlock);
 
-  if (ink_hash_table_lookup(g_records_ht, record->name, (void **) &r)) {
+  if (ink_hash_table_lookup(g_records_ht, record->name, (void **)&r)) {
     r_is_a_new_record = false;
     rec_mutex_acquire(&(r->lock));
     r->rec_type = record->rec_type;
@@ -837,7 +864,10 @@ RecForceInsert(RecRecord * record)
   // set the record value
   RecDataSet(r->data_type, &(r->data), &(record->data));
   RecDataSet(r->data_type, &(r->data_default), &(record->data_default));
+
   r->registered = record->registered;
+  r->rsb_id = record->rsb_id;
+
   if (REC_TYPE_IS_STAT(r->rec_type)) {
     r->stat_meta.persist_type = record->stat_meta.persist_type;
     r->stat_meta.data_raw = record->stat_meta.data_raw;
@@ -851,7 +881,7 @@ RecForceInsert(RecRecord * record)
   }
 
   if (r_is_a_new_record) {
-    ink_hash_table_insert(g_records_ht, r->name, (void *) r);
+    ink_hash_table_insert(g_records_ht, r->name, (void *)r);
   } else {
     rec_mutex_release(&(r->lock));
   }
@@ -867,9 +897,9 @@ RecForceInsert(RecRecord * record)
 //-------------------------------------------------------------------------
 
 static void
-debug_record_callback(RecT rec_type, void *edata, int registered, const char *name, int data_type, RecData *datum)
+debug_record_callback(RecT /* rec_type */, void * /* edata */, int registered, const char *name, int data_type, RecData *datum)
 {
-  switch(data_type) {
+  switch (data_type) {
   case RECD_INT:
     RecDebug(DL_Note, "  ([%d] '%s', '%" PRId64 "')", registered, name, datum->rec_int);
     break;
@@ -877,8 +907,7 @@ debug_record_callback(RecT rec_type, void *edata, int registered, const char *na
     RecDebug(DL_Note, "  ([%d] '%s', '%f')", registered, name, datum->rec_float);
     break;
   case RECD_STRING:
-    RecDebug(DL_Note, "  ([%d] '%s', '%s')",
-             registered, name, datum->rec_string ? datum->rec_string : "NULL");
+    RecDebug(DL_Note, "  ([%d] '%s', '%s')", registered, name, datum->rec_string ? datum->rec_string : "NULL");
     break;
   case RECD_COUNTER:
     RecDebug(DL_Note, "  ([%d] '%s', '%" PRId64 "')", registered, name, datum->rec_counter);
@@ -905,28 +934,12 @@ RecDumpRecords(RecT rec_type, RecDumpEntryCb callback, void *edata)
 }
 
 void
-RecDumpRecordsHt(RecT rec_type) {
+RecDumpRecordsHt(RecT rec_type)
+{
   RecDebug(DL_Note, "Dumping Records:");
   RecDumpRecords(rec_type, debug_record_callback, NULL);
 }
 
-void
-RecGetRecordTree(char *subtree)
-{
-  RecTree *tree = g_records_tree;
-  if (subtree) {
-    tree = tree->rec_tree_get(subtree);
-  }
-  tree->print();
-}
-
-void
-RecGetRecordList(char *var, char ***buffer, int *count)
-{
-  g_records_tree->rec_tree_get_list(&(*var), &(*buffer), &(*count));
-}
-
-
 //-------------------------------------------------------------------------
 // RecGetRecordPrefix_Xmalloc
 //
@@ -937,7 +950,7 @@ int
 RecGetRecordPrefix_Xmalloc(char *prefix, char **buf, int *buf_len)
 {
   int num_records = g_num_records;
-  int result_size = num_records * 256;  /* estimate buffer size */
+  int result_size = num_records * 256; /* estimate buffer size */
   int num_matched = 0;
   char *result = NULL;
 
@@ -964,7 +977,8 @@ RecGetRecordPrefix_Xmalloc(char *prefix, char **buf, int *buf_len)
         break;
       case RECD_STRING:
         num_matched++;
-        bytes_written = snprintf(result + total_bytes_written, bytes_avail, "%s=%s\r\n", r->name, r->data.rec_string ? r->data.rec_string : "NULL");
+        bytes_written = snprintf(result + total_bytes_written, bytes_avail, "%s=%s\r\n", r->name,
+                                 r->data.rec_string ? r->data.rec_string : "NULL");
         break;
       case RECD_COUNTER:
         num_matched++;
@@ -974,7 +988,7 @@ RecGetRecordPrefix_Xmalloc(char *prefix, char **buf, int *buf_len)
         break;
       }
 
-      if(bytes_written <= 0 || bytes_written > bytes_avail) {
+      if (bytes_written <= 0 || bytes_written > bytes_avail) {
         error = 1;
       } else
         total_bytes_written += bytes_written;
@@ -983,7 +997,7 @@ RecGetRecordPrefix_Xmalloc(char *prefix, char **buf, int *buf_len)
     }
   }
 
-  if(error || total_bytes_written == result_size) {
+  if (error || total_bytes_written == result_size) {
     RecLog(DL_Error, "Stat system was unable to fully generate stat list, size exceeded limit of %d", result_size);
   }
 
@@ -1009,7 +1023,7 @@ char *
 REC_ConfigReadString(const char *name)
 {
   char *t = 0;
-  RecGetRecordString_Xmalloc(name, (RecString *) & t);
+  RecGetRecordString_Xmalloc(name, (RecString *)&t);
   return t;
 }
 
@@ -1017,7 +1031,7 @@ RecFloat
 REC_ConfigReadFloat(const char *name)
 {
   RecFloat t = 0;
-  RecGetRecordFloat(name, (RecFloat *) & t);
+  RecGetRecordFloat(name, (RecFloat *)&t);
   return t;
 }
 
@@ -1025,7 +1039,7 @@ RecCounter
 REC_ConfigReadCounter(const char *name)
 {
   RecCounter t = 0;
-  RecGetRecordCounter(name, (RecCounter *) & t);
+  RecGetRecordCounter(name, (RecCounter *)&t);
   return t;
 }
 
@@ -1034,7 +1048,7 @@ REC_ConfigReadCounter(const char *name)
 // Backwards compatibility. TODO: Should remove these.
 //-------------------------------------------------------------------------
 RecInt
-REC_readInteger(const char *name, bool * found, bool lock)
+REC_readInteger(const char *name, bool *found, bool lock)
 {
   ink_assert(name);
   RecInt _tmp = 0;
@@ -1046,7 +1060,7 @@ REC_readInteger(const char *name, bool * found, bool lock)
 }
 
 RecFloat
-REC_readFloat(char *name, bool * found, bool lock)
+REC_readFloat(char *name, bool *found, bool lock)
 {
   ink_assert(name);
   RecFloat _tmp = 0.0;
@@ -1058,7 +1072,7 @@ REC_readFloat(char *name, bool * found, bool lock)
 }
 
 RecCounter
-REC_readCounter(char *name, bool * found, bool lock)
+REC_readCounter(char *name, bool *found, bool lock)
 {
   ink_assert(name);
   RecCounter _tmp = 0;
@@ -1070,7 +1084,7 @@ REC_readCounter(char *name, bool * found, bool lock)
 }
 
 RecString
-REC_readString(const char *name, bool * found, bool lock)
+REC_readString(const char *name, bool *found, bool lock)
 {
   ink_assert(name);
   RecString _tmp = NULL;
@@ -1081,13 +1095,30 @@ REC_readString(const char *name, bool * found, bool lock)
   return _tmp;
 }
 
+//-------------------------------------------------------------------------
+// RecConfigReadConfigDir
+//-------------------------------------------------------------------------
+char *
+RecConfigReadConfigDir()
+{
+  char buf[PATH_NAME_MAX];
+
+  buf[0] = '\0';
+  RecGetRecordString("proxy.config.config_dir", buf, PATH_NAME_MAX);
+  if (strlen(buf) > 0) {
+    return Layout::get()->relative(buf);
+  } else {
+    return ats_strdup(Layout::get()->sysconfdir);
+  }
+}
+
 //-------------------------------------------------------------------------
 // RecConfigReadRuntimeDir
 //-------------------------------------------------------------------------
 char *
 RecConfigReadRuntimeDir()
 {
-  char buf[PATH_NAME_MAX + 1];
+  char buf[PATH_NAME_MAX];
 
   buf[0] = '\0';
   RecGetRecordString("proxy.config.local_state_dir", buf, PATH_NAME_MAX);
@@ -1104,7 +1135,7 @@ RecConfigReadRuntimeDir()
 char *
 RecConfigReadLogDir()
 {
-  char buf[PATH_NAME_MAX + 1];
+  char buf[PATH_NAME_MAX];
 
   buf[0] = '\0';
   RecGetRecordString("proxy.config.log.logfile_dir", buf, PATH_NAME_MAX);
@@ -1121,7 +1152,7 @@ RecConfigReadLogDir()
 char *
 RecConfigReadBinDir()
 {
-  char buf[PATH_NAME_MAX + 1];
+  char buf[PATH_NAME_MAX];
 
   buf[0] = '\0';
   RecGetRecordString("proxy.config.bin_path", buf, PATH_NAME_MAX);
@@ -1138,33 +1169,56 @@ RecConfigReadBinDir()
 char *
 RecConfigReadSnapshotDir()
 {
-  char buf[PATH_NAME_MAX + 1];
-
-  buf[0] = '\0';
-  RecGetRecordString("proxy.config.snapshot_dir", buf, PATH_NAME_MAX);
-  if (strlen(buf) > 0) {
-    return Layout::get()->relative_to(Layout::get()->sysconfdir, buf);
-  } else {
-    return Layout::get()->relative_to(Layout::get()->sysconfdir, "snapshots");
-  }
+  return RecConfigReadConfigPath("proxy.config.snapshot_dir", "snapshots");
 }
 
 //-------------------------------------------------------------------------
 // RecConfigReadConfigPath
 //-------------------------------------------------------------------------
 char *
-RecConfigReadConfigPath(const char * file_variable, const char * default_value)
+RecConfigReadConfigPath(const char *file_variable, const char *default_value)
 {
-  char buf[PATH_NAME_MAX + 1];
+  ats_scoped_str sysconfdir(RecConfigReadConfigDir());
 
-  buf[0] = '\0';
-  RecGetRecordString(file_variable, buf, PATH_NAME_MAX);
-  if (strlen(buf) > 0) {
-    return Layout::get()->relative_to(Layout::get()->sysconfdir, buf);
+  // If the file name is in a configuration variable, look it up first ...
+  if (file_variable) {
+    char buf[PATH_NAME_MAX];
+
+    buf[0] = '\0';
+    RecGetRecordString(file_variable, buf, PATH_NAME_MAX);
+    if (strlen(buf) > 0) {
+      return Layout::get()->relative_to(sysconfdir, buf);
+    }
   }
 
+  // Otherwise take the default ...
   if (default_value) {
-    return Layout::get()->relative_to(Layout::get()->sysconfdir, default_value);
+    return Layout::get()->relative_to(sysconfdir, default_value);
+  }
+
+  return NULL;
+}
+
+//-------------------------------------------------------------------------
+// RecConfigReadPrefixPath
+//-------------------------------------------------------------------------
+char *
+RecConfigReadPrefixPath(const char *file_variable, const char *default_value)
+{
+  char buf[PATH_NAME_MAX];
+
+  // If the file name is in a configuration variable, look it up first ...
+  if (file_variable) {
+    buf[0] = '\0';
+    RecGetRecordString(file_variable, buf, PATH_NAME_MAX);
+    if (strlen(buf) > 0) {
+      return Layout::get()->relative_to(Layout::get()->prefix, buf);
+    }
+  }
+
+  // Otherwise take the default ...
+  if (default_value) {
+    return Layout::get()->relative_to(Layout::get()->prefix, default_value);
   }
 
   return NULL;
@@ -1176,43 +1230,22 @@ RecConfigReadConfigPath(const char * file_variable, const char * default_value)
 char *
 RecConfigReadPersistentStatsPath()
 {
-  xptr<char> rundir(RecConfigReadRuntimeDir());
+  ats_scoped_str rundir(RecConfigReadRuntimeDir());
   return Layout::relative_to(rundir, REC_RAW_STATS_FILE);
 }
 
-//-------------------------------------------------------------------------
-// REC_SignalManager (TS)
-//-------------------------------------------------------------------------
-#if defined(LOCAL_MANAGER)
-
-#include "LocalManager.h"
-
 void
-RecSignalManager(int /* id ATS_UNUSED */, const char */* msg ATS_UNUSED */)
+RecSignalWarning(int sig, const char *fmt, ...)
 {
+  char msg[1024];
+  va_list args;
+
+  va_start(args, fmt);
+  WarningV(fmt, args);
+  va_end(args);
+
+  va_start(args, fmt);
+  vsnprintf(msg, sizeof(msg), fmt, args);
+  RecSignalManager(sig, msg);
+  va_end(args);
 }
-
-int
-RecRegisterManagerCb(int _signal, RecManagerCb _fn, void *_data)
-{
-  return lmgmt->registerMgmtCallback(_signal, _fn, _data);
-}
-
-#elif defined(PROCESS_MANAGER)
-
-#include "ProcessManager.h"
-
-void
-RecSignalManager(int id, const char *msg)
-{
-  ink_assert(pmgmt);
-  pmgmt->signalManager(id, msg);
-}
-
-int
-RecRegisterManagerCb(int _signal, RecManagerCb _fn, void *_data)
-{
-  return pmgmt->registerMgmtCallback(_signal, _fn, _data);
-}
-
-#endif // LOCAL_MANAGER
