@@ -46,32 +46,29 @@
 class Diags;
 
 // extern int diags_on_for_plugins;
-typedef enum
-{
-  DiagsTagType_Debug = 0,       // do not renumber --- used as array index
+typedef enum {
+  DiagsTagType_Debug = 0, // do not renumber --- used as array index
   DiagsTagType_Action = 1
 } DiagsTagType;
 
-struct DiagsModeOutput
-{
+struct DiagsModeOutput {
   bool to_stdout;
   bool to_stderr;
   bool to_syslog;
   bool to_diagslog;
 };
 
-typedef enum
-{                               // do not renumber --- used as array index
-  DL_Diag = 0,                  // process does not die
-  DL_Debug,                     // process does not die
-  DL_Status,                    // process does not die
-  DL_Note,                      // process does not die
-  DL_Warning,                   // process does not die
-  DL_Error,                     // process does not die
-  DL_Fatal,                     // causes process termination
-  DL_Alert,                     // causes process termination
-  DL_Emergency,                 // causes process termination
-  DL_Undefined                  // must be last, used for size!
+typedef enum {  // do not renumber --- used as array index
+  DL_Diag = 0,  // process does not die
+  DL_Debug,     // process does not die
+  DL_Status,    // process does not die
+  DL_Note,      // process does not die
+  DL_Warning,   // process does not die
+  DL_Error,     // process does not die
+  DL_Fatal,     // causes process termination
+  DL_Alert,     // causes process termination
+  DL_Emergency, // causes process termination
+  DL_Undefined  // must be last, used for size!
 } DiagsLevel;
 
 #define DiagsLevel_Count DL_Undefined
@@ -80,13 +77,12 @@ typedef enum
 
 // Cleanup Function Prototype - Called before ink_fatal to
 //   cleanup process state
-typedef void (*DiagsCleanupFunc) ();
+typedef void (*DiagsCleanupFunc)();
 
-struct DiagsConfigState
-{
+struct DiagsConfigState {
   // this is static to eliminate many loads from the critical path
-  static bool enabled[2];                       // one debug, one action
-  DiagsModeOutput outputs[DiagsLevel_Count];    // where each level prints
+  static bool enabled[2];                    // one debug, one action
+  DiagsModeOutput outputs[DiagsLevel_Count]; // where each level prints
 };
 
 
@@ -107,17 +103,27 @@ class SrcLoc
 public:
   const char *file;
   const char *func;
-  const int line;
+  int line;
 
-  bool valid() const {
+  bool
+  valid() const
+  {
     return file && line;
   }
 
-  SrcLoc(const char *_file, const char *_func, int _line)
-    : file(_file), func(_func), line(_line) {
+  SrcLoc(const SrcLoc &rhs) : file(rhs.file), func(rhs.func), line(rhs.line) {}
+
+  SrcLoc(const char *_file, const char *_func, int _line) : file(_file), func(_func), line(_line) {}
+
+  SrcLoc &operator=(const SrcLoc &rhs)
+  {
+    this->file = rhs.file;
+    this->func = rhs.func;
+    this->line = rhs.line;
+    return *this;
   }
 
-  char * str(char *buf, int buflen) const;
+  char *str(char *buf, int buflen) const;
 };
 
 
@@ -139,8 +145,8 @@ public:
 class Diags
 {
 public:
-  Diags(const char *base_debug_tags, const char *base_action_tags, FILE * _diags_log_fp = NULL);
-   ~Diags();
+  Diags(const char *base_debug_tags, const char *base_action_tags, FILE *_diags_log_fp = NULL);
+  ~Diags();
 
   FILE *diags_log_fp;
   const unsigned int magic;
@@ -153,11 +159,15 @@ public:
   // conditional debugging //
   ///////////////////////////
 
-  bool on(DiagsTagType mode = DiagsTagType_Debug) const {
+  bool
+  on(DiagsTagType mode = DiagsTagType_Debug) const
+  {
     return (config.enabled[mode]);
   }
 
-  bool on(const char *tag, DiagsTagType mode = DiagsTagType_Debug) const {
+  bool
+  on(const char *tag, DiagsTagType mode = DiagsTagType_Debug) const
+  {
     return (config.enabled[mode] && tag_activated(tag, mode));
   }
 
@@ -173,16 +183,16 @@ public:
 
   const char *level_name(DiagsLevel dl) const;
 
-  inkcoreapi void print_va(const char *tag, DiagsLevel dl,
-                           const SrcLoc *loc, const char *format_string, va_list ap) const;
+  inkcoreapi void print_va(const char *tag, DiagsLevel dl, const SrcLoc *loc, const char *format_string, va_list ap) const;
 
 
   //////////////////////////////
   // user printing interfaces //
   //////////////////////////////
 
-  void print(const char *tag, DiagsLevel dl, const char *file, const char *func,
-             const int line, const char *format_string, ...) const TS_PRINTFLIKE(7, 8)
+  void
+  print(const char *tag, DiagsLevel dl, const char *file, const char *func, const int line, const char *format_string, ...) const
+    TS_PRINTFLIKE(7, 8)
   {
     va_list ap;
     va_start(ap, format_string);
@@ -200,25 +210,22 @@ public:
   // on the value of the enable flag, and the state of the debug tags. //
   ///////////////////////////////////////////////////////////////////////
 
-  void log_va(const char *tag, DiagsLevel dl, const SrcLoc * loc, const char *format_string, va_list ap)
+  void
+  log_va(const char *tag, DiagsLevel dl, const SrcLoc *loc, const char *format_string, va_list ap)
   {
     if (!on(tag))
       return;
     print_va(tag, dl, loc, format_string, ap);
   }
 
-  void log(const char *tag, DiagsLevel dl,
-           const char *file, const char *func, const int line,
-           const char *format_string, ...) const TS_PRINTFLIKE(7, 8);
+  void log(const char *tag, DiagsLevel dl, const char *file, const char *func, const int line, const char *format_string, ...) const
+    TS_PRINTFLIKE(7, 8);
 
-  void error_va(DiagsLevel dl,
-             const char *file, const char *func, const int line,
-             const char *format_string, va_list ap) const;
+  void error_va(DiagsLevel dl, const char *file, const char *func, const int line, const char *format_string, va_list ap) const;
 
   void
-  error(DiagsLevel level,
-               const char *file, const char *func, const int line,
-               const char *format_string, ...) const TS_PRINTFLIKE(6, 7)
+  error(DiagsLevel level, const char *file, const char *func, const int line, const char *format_string, ...) const
+    TS_PRINTFLIKE(6, 7)
   {
     va_list ap;
     va_start(ap, format_string);
@@ -226,24 +233,26 @@ public:
     va_end(ap);
   }
 
-  void dump(FILE * fp = stdout) const;
+  void dump(FILE *fp = stdout) const;
 
   void activate_taglist(const char *taglist, DiagsTagType mode = DiagsTagType_Debug);
 
   void deactivate_all(DiagsTagType mode = DiagsTagType_Debug);
 
-  const char *base_debug_tags;        // internal copy of default debug tags
-  const char *base_action_tags;       // internal copy of default action tags
+  const char *base_debug_tags;  // internal copy of default debug tags
+  const char *base_action_tags; // internal copy of default action tags
 
 private:
-  mutable ink_mutex tag_table_lock;   // prevents reconfig/read races
-  DFA *activated_tags[2];             // 1 table for debug, 1 for action
+  mutable ink_mutex tag_table_lock; // prevents reconfig/read races
+  DFA *activated_tags[2];           // 1 table for debug, 1 for action
 
-  void lock() const
+  void
+  lock() const
   {
     ink_mutex_acquire(&tag_table_lock);
   }
-  void unlock() const
+  void
+  unlock() const
   {
     ink_mutex_release(&tag_table_lock);
   }
@@ -262,7 +271,7 @@ private:
 //                                                                      //
 //////////////////////////////////////////////////////////////////////////
 
-#if !defined (__GNUC__)
+#if !defined(__GNUC__)
 #ifndef __FUNCTION__
 #define __FUNCTION__ NULL
 #endif
@@ -270,8 +279,8 @@ private:
 
 extern inkcoreapi Diags *diags;
 
-#define DTA(l)    l,__FILE__,__FUNCTION__,__LINE__
-void dummy_debug(const char * tag, const char *fmt, ...) TS_PRINTFLIKE(2, 3);
+#define DTA(l) l, __FILE__, __FUNCTION__, __LINE__
+void dummy_debug(const char *tag, const char *fmt, ...) TS_PRINTFLIKE(2, 3);
 inline void
 dummy_debug(const char *tag, const char *fmt, ...)
 {
@@ -279,49 +288,63 @@ dummy_debug(const char *tag, const char *fmt, ...)
   (void)fmt;
 }
 
-#define Status(...)    diags->error(DTA(DL_Status), __VA_ARGS__)
-#define Note(...)      diags->error(DTA(DL_Note), __VA_ARGS__)
-#define Warning(...)   diags->error(DTA(DL_Warning), __VA_ARGS__)
-#define Error(...)     diags->error(DTA(DL_Error), __VA_ARGS__)
-#define Fatal(...)     diags->error(DTA(DL_Fatal), __VA_ARGS__)
-#define Alert(...)     diags->error(DTA(DL_Alert), __VA_ARGS__)
+#define Status(...) diags->error(DTA(DL_Status), __VA_ARGS__)
+#define Note(...) diags->error(DTA(DL_Note), __VA_ARGS__)
+#define Warning(...) diags->error(DTA(DL_Warning), __VA_ARGS__)
+#define Error(...) diags->error(DTA(DL_Error), __VA_ARGS__)
+#define Fatal(...) diags->error(DTA(DL_Fatal), __VA_ARGS__)
+#define Alert(...) diags->error(DTA(DL_Alert), __VA_ARGS__)
 #define Emergency(...) diags->error(DTA(DL_Emergency), __VA_ARGS__)
 
-#define StatusV(fmt, ap)    diags->error_va(DTA(DL_Status), fmt, ap)
-#define NoteV(fmt, ap)      diags->error_va(DTA(DL_Note), fmt, ap)
-#define WarningV(fmt, ap)   diags->error_va(DTA(DL_Warning), fmt, ap)
-#define ErrorV(fmt, ap)     diags->error_va(DTA(DL_Error), fmt, ap)
-#define FatalV(fmt, ap)     diags->error_va(DTA(DL_Fatal), fmt, ap)
-#define AlertV(fmt, ap)     diags->error_va(DTA(DL_Alert), fmt, ap)
+#define StatusV(fmt, ap) diags->error_va(DTA(DL_Status), fmt, ap)
+#define NoteV(fmt, ap) diags->error_va(DTA(DL_Note), fmt, ap)
+#define WarningV(fmt, ap) diags->error_va(DTA(DL_Warning), fmt, ap)
+#define ErrorV(fmt, ap) diags->error_va(DTA(DL_Error), fmt, ap)
+#define FatalV(fmt, ap) diags->error_va(DTA(DL_Fatal), fmt, ap)
+#define AlertV(fmt, ap) diags->error_va(DTA(DL_Alert), fmt, ap)
 #define EmergencyV(fmt, ap) diags->error_va(DTA(DL_Emergency), fmt, ap)
 
 #ifdef TS_USE_DIAGS
-#define Diag(tag, ...)      if (unlikely(diags->on())) diags->log(tag, DTA(DL_Diag), __VA_ARGS__)
-#define Debug(tag, ...)     if (unlikely(diags->on())) diags->log(tag, DTA(DL_Debug), __VA_ARGS__)
-#define DiagSpecific(flag, tag, ...)  if (unlikely(diags->on())) flag ? diags->print(tag, DTA(DL_Diag), __VA_ARGS__) : \
-                                                                   diags->log(tag, DTA(DL_Diag), __VA_ARGS__)
-#define DebugSpecific(flag, tag, ...)  if (unlikely(diags->on())) flag ? diags->print(tag, DTA(DL_Debug), __VA_ARGS__) : \
-                                                                    diags->log(tag, DTA(DL_Debug), __VA_ARGS__)
+#define Diag(tag, ...)       \
+  if (unlikely(diags->on())) \
+  diags->log(tag, DTA(DL_Diag), __VA_ARGS__)
+#define Debug(tag, ...)      \
+  if (unlikely(diags->on())) \
+  diags->log(tag, DTA(DL_Debug), __VA_ARGS__)
+#define DiagSpecific(flag, tag, ...) \
+  if (unlikely(diags->on()))         \
+  flag ? diags->print(tag, DTA(DL_Diag), __VA_ARGS__) : diags->log(tag, DTA(DL_Diag), __VA_ARGS__)
+#define DebugSpecific(flag, tag, ...) \
+  if (unlikely(diags->on()))          \
+  flag ? diags->print(tag, DTA(DL_Debug), __VA_ARGS__) : diags->log(tag, DTA(DL_Debug), __VA_ARGS__)
 
-#define is_debug_tag_set(_t)     unlikely(diags->on(_t,DiagsTagType_Debug))
-#define is_action_tag_set(_t)    unlikely(diags->on(_t,DiagsTagType_Action))
-#define debug_tag_assert(_t,_a)  (is_debug_tag_set(_t) ? (ink_release_assert(_a), 0) : 0)
-#define action_tag_assert(_t,_a) (is_action_tag_set(_t) ? (ink_release_assert(_a), 0) : 0)
-#define is_diags_on(_t)          unlikely(diags->on(_t))
+#define is_debug_tag_set(_t) unlikely(diags->on(_t, DiagsTagType_Debug))
+#define is_action_tag_set(_t) unlikely(diags->on(_t, DiagsTagType_Action))
+#define debug_tag_assert(_t, _a) (is_debug_tag_set(_t) ? (ink_release_assert(_a), 0) : 0)
+#define action_tag_assert(_t, _a) (is_action_tag_set(_t) ? (ink_release_assert(_a), 0) : 0)
+#define is_diags_on(_t) unlikely(diags->on(_t))
 
 #else // TS_USE_DIAGS
 
-#define Diag(tag, fmt, ...)      if (0) dummy_debug(tag, __VA_ARGS__)
-#define Debug(tag, fmt, ...)     if (0) dummy_debug(tag, __VA_ARGS__)
-#define DiagSpecific(flag, tag, ...)  if (0 && tag) dummy_debug(tag, __VA_ARGS__);
-#define DebugSpecific(flag, tag, ...)  if (0 && tag) dummy_debug(tag, __VA_ARGS__);
+#define Diag(tag, fmt, ...) \
+  if (0)                    \
+  dummy_debug(tag, __VA_ARGS__)
+#define Debug(tag, fmt, ...) \
+  if (0)                     \
+  dummy_debug(tag, __VA_ARGS__)
+#define DiagSpecific(flag, tag, ...) \
+  if (0 && tag)                      \
+    dummy_debug(tag, __VA_ARGS__);
+#define DebugSpecific(flag, tag, ...) \
+  if (0 && tag)                       \
+    dummy_debug(tag, __VA_ARGS__);
 
 
-#define is_debug_tag_set(_t)     0
-#define is_action_tag_set(_t)    0
-#define debug_tag_assert(_t,_a) /**/
-#define action_tag_assert(_t,_a) /**/
-#define is_diags_on(_t)          0
+#define is_debug_tag_set(_t) 0
+#define is_action_tag_set(_t) 0
+#define debug_tag_assert(_t, _a)  /**/
+#define action_tag_assert(_t, _a) /**/
+#define is_diags_on(_t) 0
 
 #endif // TS_USE_DIAGS
-#endif  /*_Diags_h_*/
+#endif /*_Diags_h_*/
