@@ -21,7 +21,7 @@
   limitations under the License.
  */
 
-#if !defined (_ParseRules_h_)
+#if !defined(_ParseRules_h_)
 #define _ParseRules_h_
 
 #include <string.h>
@@ -34,39 +34,39 @@ typedef unsigned int CTypeResult;
 
 // Set this to 0 to disable SI
 // decimal multipliers
-#define USE_SI_MULTILIERS    1
+#define USE_SI_MULTILIERS 1
 
-#define is_char_BIT         (1 << 0)
-#define is_upalpha_BIT      (1 << 1)
-#define is_loalpha_BIT      (1 << 2)
-#define is_alpha_BIT        (1 << 3)
-#define is_digit_BIT        (1 << 4)
-#define is_ctl_BIT          (1 << 5)
-#define is_ws_BIT           (1 << 6)
-#define is_hex_BIT          (1 << 7)
-#define is_pchar_BIT        (1 << 8)
-#define is_extra_BIT        (1 << 9)
-#define is_safe_BIT         (1 << 10)
-#define is_unsafe_BIT       (1 << 11)
-#define is_national_BIT     (1 << 12)
-#define is_reserved_BIT     (1 << 13)
-#define is_unreserved_BIT   (1 << 14)
-#define is_punct_BIT        (1 << 15)
-#define is_end_of_url_BIT   (1 << 16)
-#define is_tspecials_BIT    (1 << 17)
-#define is_spcr_BIT         (1 << 18)
-#define is_splf_BIT         (1 << 19)
-#define is_wslfcr_BIT       (1 << 20)
-#define is_eow_BIT          (1 << 21)
-#define is_token_BIT        (1 << 22)
-#define is_wildmat_BIT      (1 << 23)
-#define is_sep_BIT          (1 << 24)
-#define is_empty_BIT        (1 << 25)
-#define is_alnum_BIT        (1 << 26)
-#define is_space_BIT        (1 << 27)
-#define is_control_BIT      (1 << 28)
-#define is_mime_sep_BIT     (1 << 29)
-#define is_http_field_name_BIT  (1 << 30)
+#define is_char_BIT (1 << 0)
+#define is_upalpha_BIT (1 << 1)
+#define is_loalpha_BIT (1 << 2)
+#define is_alpha_BIT (1 << 3)
+#define is_digit_BIT (1 << 4)
+#define is_ctl_BIT (1 << 5)
+#define is_ws_BIT (1 << 6)
+#define is_hex_BIT (1 << 7)
+#define is_pchar_BIT (1 << 8)
+#define is_extra_BIT (1 << 9)
+#define is_safe_BIT (1 << 10)
+#define is_unsafe_BIT (1 << 11)
+#define is_national_BIT (1 << 12)
+#define is_reserved_BIT (1 << 13)
+#define is_unreserved_BIT (1 << 14)
+#define is_punct_BIT (1 << 15)
+#define is_end_of_url_BIT (1 << 16)
+#define is_tspecials_BIT (1 << 17)
+#define is_spcr_BIT (1 << 18)
+#define is_splf_BIT (1 << 19)
+#define is_wslfcr_BIT (1 << 20)
+#define is_eow_BIT (1 << 21)
+#define is_token_BIT (1 << 22)
+#define is_wildmat_BIT (1 << 23)
+#define is_sep_BIT (1 << 24)
+#define is_empty_BIT (1 << 25)
+#define is_alnum_BIT (1 << 26)
+#define is_space_BIT (1 << 27)
+#define is_control_BIT (1 << 28)
+#define is_mime_sep_BIT (1 << 29)
+#define is_http_field_name_BIT (1 << 30)
 /* shut up the DEC compiler */
 #define is_http_field_value_BIT (((CTypeResult)1) << 31)
 
@@ -83,14 +83,13 @@ public:
   // whitespace definitions //
   ////////////////////////////
 
-  enum
-  {
-    CHAR_SP = 32,               /* space           */
-    CHAR_HT = 9,                /* horizontal tab  */
-    CHAR_LF = 10,               /* line feed       */
-    CHAR_VT = 11,               /* vertical tab    */
-    CHAR_NP = 12,               /* new page        */
-    CHAR_CR = 13                /* carriage return */
+  enum {
+    CHAR_SP = 32, /* space           */
+    CHAR_HT = 9,  /* horizontal tab  */
+    CHAR_LF = 10, /* line feed       */
+    CHAR_VT = 11, /* vertical tab    */
+    CHAR_NP = 12, /* new page        */
+    CHAR_CR = 13  /* carriage return */
   };
 
   /////////////////////
@@ -99,54 +98,54 @@ public:
 
   static CTypeResult is_type(char c, uint32_t bit);
 
-  static CTypeResult is_char(char c);   // ASCII 0-127
-  static CTypeResult is_upalpha(char c);        // A-Z
-  static CTypeResult is_loalpha(char c);        // a-z
-  static CTypeResult is_alpha(char c);  // A-Z,a-z
-  static CTypeResult is_digit(char c);  // 0-9
-  static CTypeResult is_ctl(char c);    // ASCII 0-31,127 (includes ws)
-  static CTypeResult is_hex(char c);    // 0-9,A-F,a-f
-  static CTypeResult is_ws(char c);     // SP,HT
-  static CTypeResult is_cr(char c);     // CR
-  static CTypeResult is_lf(char c);     // LF
-  static CTypeResult is_spcr(char c);   // SP,CR
-  static CTypeResult is_splf(char c);   // SP,LF
-  static CTypeResult is_wslfcr(char c); // SP,HT,LF,CR
-  static CTypeResult is_tspecials(char c);      // HTTP chars that need quoting
-  static CTypeResult is_token(char c);  // token (not CTL or specials)
-  static CTypeResult is_extra(char c);  // !,*,QUOT,(,),COMMA
-  static CTypeResult is_safe(char c);   // [$-_.+]
-  static CTypeResult is_unsafe(char c); // SP,DBLQUOT,#,%,<,>
-  static CTypeResult is_national(char c);       // {,},|,BACKSLASH,^,~,[,],`
-  static CTypeResult is_reserved(char c);       // :,/,?,:,@,&,=
-  static CTypeResult is_unreserved(char c);     // alpha,digit,safe,extra,nat.
-  static CTypeResult is_punct(char c);  // !"#$%&'()*+,-./:;<>=?@_{}|~
-  static CTypeResult is_end_of_url(char c);     // NUL,CR,SP
-  static CTypeResult is_eow(char c);    // NUL,CR,LF
-  static CTypeResult is_wildmat(char c);        // \,*,?,[
-  static CTypeResult is_sep(char c);    // NULL,COMMA,':','!',wslfcr
-  static CTypeResult is_empty(char c);  // wslfcr,#
-  static CTypeResult is_alnum(char c);  // 0-9,A-Z,a-z
-  static CTypeResult is_space(char c);  // ' ' HT,VT,NP,CR,LF
-  static CTypeResult is_control(char c);        // 0-31 127
-  static CTypeResult is_mime_sep(char c);       // ()<>,;\"/[]?{} \t
-  static CTypeResult is_http_field_name(char c);        // not : or mime_sep except for @
-  static CTypeResult is_http_field_value(char c);       // not CR, LF, comma, or "
+  static CTypeResult is_char(char c);             // ASCII 0-127
+  static CTypeResult is_upalpha(char c);          // A-Z
+  static CTypeResult is_loalpha(char c);          // a-z
+  static CTypeResult is_alpha(char c);            // A-Z,a-z
+  static CTypeResult is_digit(char c);            // 0-9
+  static CTypeResult is_ctl(char c);              // ASCII 0-31,127 (includes ws)
+  static CTypeResult is_hex(char c);              // 0-9,A-F,a-f
+  static CTypeResult is_ws(char c);               // SP,HT
+  static CTypeResult is_cr(char c);               // CR
+  static CTypeResult is_lf(char c);               // LF
+  static CTypeResult is_spcr(char c);             // SP,CR
+  static CTypeResult is_splf(char c);             // SP,LF
+  static CTypeResult is_wslfcr(char c);           // SP,HT,LF,CR
+  static CTypeResult is_tspecials(char c);        // HTTP chars that need quoting
+  static CTypeResult is_token(char c);            // token (not CTL or specials)
+  static CTypeResult is_extra(char c);            // !,*,QUOT,(,),COMMA
+  static CTypeResult is_safe(char c);             // [$-_.+]
+  static CTypeResult is_unsafe(char c);           // SP,DBLQUOT,#,%,<,>
+  static CTypeResult is_national(char c);         // {,},|,BACKSLASH,^,~,[,],`
+  static CTypeResult is_reserved(char c);         // :,/,?,:,@,&,=
+  static CTypeResult is_unreserved(char c);       // alpha,digit,safe,extra,nat.
+  static CTypeResult is_punct(char c);            // !"#$%&'()*+,-./:;<>=?@_{}|~
+  static CTypeResult is_end_of_url(char c);       // NUL,CR,SP
+  static CTypeResult is_eow(char c);              // NUL,CR,LF
+  static CTypeResult is_wildmat(char c);          // \,*,?,[
+  static CTypeResult is_sep(char c);              // NULL,COMMA,':','!',wslfcr
+  static CTypeResult is_empty(char c);            // wslfcr,#
+  static CTypeResult is_alnum(char c);            // 0-9,A-Z,a-z
+  static CTypeResult is_space(char c);            // ' ' HT,VT,NP,CR,LF
+  static CTypeResult is_control(char c);          // 0-31 127
+  static CTypeResult is_mime_sep(char c);         // ()<>,;\"/[]?{} \t
+  static CTypeResult is_http_field_name(char c);  // not : or mime_sep except for @
+  static CTypeResult is_http_field_value(char c); // not CR, LF, comma, or "
 
   //////////////////
   // string tests //
   //////////////////
 
-  static CTypeResult is_escape(const char *seq);        // %<hex><hex>
-  static CTypeResult is_uchar(const char *seq); // starts unresrvd or is escape
-  static CTypeResult is_pchar(const char *seq); // uchar,:,@,&,=,+ (see code)
+  static CTypeResult is_escape(const char *seq); // %<hex><hex>
+  static CTypeResult is_uchar(const char *seq);  // starts unresrvd or is escape
+  static CTypeResult is_pchar(const char *seq);  // uchar,:,@,&,=,+ (see code)
 
   ///////////////////
   // unimplemented //
   ///////////////////
 
-  //static CTypeResult   is_comment(const char * str);
-  //static CTypeResult   is_ctext(const char * str);
+  // static CTypeResult   is_comment(const char * str);
+  // static CTypeResult   is_ctext(const char * str);
 
   ////////////////
   // operations //
@@ -166,8 +165,8 @@ public:
   static unsigned char *scan_while(unsigned char *ptr, unsigned int n, uint32_t bitmask);
 
 private:
-    ParseRules(const ParseRules &);
-    ParseRules & operator =(const ParseRules &);
+  ParseRules(const ParseRules &);
+  ParseRules &operator=(const ParseRules &);
 };
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -177,14 +176,14 @@ private:
 inline CTypeResult
 ParseRules::is_type(char c, uint32_t bitmask)
 {
-  return (parseRulesCType[(unsigned char) c] & bitmask);
+  return (parseRulesCType[(unsigned char)c] & bitmask);
 }
 
 inline CTypeResult
 ParseRules::is_char(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_char_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_char_BIT);
 #else
   return ((c & 0x80) == 0);
 #endif
@@ -194,7 +193,7 @@ inline CTypeResult
 ParseRules::is_upalpha(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_upalpha_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_upalpha_BIT);
 #else
   return (c >= 'A' && c <= 'Z');
 #endif
@@ -204,7 +203,7 @@ inline CTypeResult
 ParseRules::is_loalpha(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_loalpha_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_loalpha_BIT);
 #else
   return (c >= 'a' && c <= 'z');
 #endif
@@ -214,7 +213,7 @@ inline CTypeResult
 ParseRules::is_alpha(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_alpha_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_alpha_BIT);
 #else
   return (is_upalpha(c) || is_loalpha(c));
 #endif
@@ -224,7 +223,7 @@ inline CTypeResult
 ParseRules::is_digit(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_digit_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_digit_BIT);
 #else
   return (c >= '0' && c <= '9');
 #endif
@@ -234,7 +233,7 @@ inline CTypeResult
 ParseRules::is_alnum(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_alnum_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_alnum_BIT);
 #else
   return (is_alpha(c) || is_digit(c));
 #endif
@@ -244,7 +243,7 @@ inline CTypeResult
 ParseRules::is_ctl(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_ctl_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_ctl_BIT);
 #else
   return ((!(c & 0x80) && c <= 31) || c == 127);
 #endif
@@ -254,7 +253,7 @@ inline CTypeResult
 ParseRules::is_ws(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_ws_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_ws_BIT);
 #else
   return (c == CHAR_SP || c == CHAR_HT);
 #endif
@@ -264,7 +263,7 @@ inline CTypeResult
 ParseRules::is_hex(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_hex_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_hex_BIT);
 #else
   return ((c >= 'A' && c <= 'F') || (c >= 'a' && c <= 'f') || (c >= '0' && c <= '9'));
 #endif
@@ -286,7 +285,7 @@ inline CTypeResult
 ParseRules::is_splf(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_splf_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_splf_BIT);
 #else
   return (c == CHAR_SP || c == CHAR_LF);
 #endif
@@ -296,7 +295,7 @@ inline CTypeResult
 ParseRules::is_spcr(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_spcr_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_spcr_BIT);
 #else
   return (c == CHAR_SP || c == CHAR_CR);
 #endif
@@ -306,7 +305,7 @@ inline CTypeResult
 ParseRules::is_wslfcr(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_wslfcr_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_wslfcr_BIT);
 #else
   return ParseRules::is_ws(c) || ParseRules::is_splf(c) || ParseRules::is_spcr(c);
 #endif
@@ -316,7 +315,7 @@ inline CTypeResult
 ParseRules::is_extra(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_extra_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_extra_BIT);
 #else
   switch (c) {
   case '!':
@@ -335,7 +334,7 @@ inline CTypeResult
 ParseRules::is_safe(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_safe_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_safe_BIT);
 #else
   return (c == '$' || c == '-' || c == '_' || c == '.' || c == '+');
 #endif
@@ -345,7 +344,7 @@ inline CTypeResult
 ParseRules::is_unsafe(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_unsafe_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_unsafe_BIT);
 #else
   if (is_ctl(c))
     return (true);
@@ -367,7 +366,7 @@ inline CTypeResult
 ParseRules::is_reserved(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_reserved_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_reserved_BIT);
 #else
   switch (c) {
   case ';':
@@ -387,7 +386,7 @@ inline CTypeResult
 ParseRules::is_national(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_national_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_national_BIT);
 #else
   switch (c) {
   case '{':
@@ -409,7 +408,7 @@ inline CTypeResult
 ParseRules::is_unreserved(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_unreserved_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_unreserved_BIT);
 #else
   return (is_alpha(c) || is_digit(c) || is_safe(c) || is_extra(c) || is_national(c));
 #endif
@@ -419,7 +418,7 @@ inline CTypeResult
 ParseRules::is_punct(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_punct_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_punct_BIT);
 #else
   switch (c) {
   case '!':
@@ -463,10 +462,9 @@ inline CTypeResult
 ParseRules::is_end_of_url(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_end_of_url_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_end_of_url_BIT);
 #else
-  return (c == '\0' || c == '\n' || c == ' ' || ParseRules::is_ctl(c)
-    );
+  return (c == '\0' || c == '\n' || c == ' ' || ParseRules::is_ctl(c));
 #endif
 }
 
@@ -513,7 +511,7 @@ inline CTypeResult
 ParseRules::is_tspecials(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_tspecials_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_tspecials_BIT);
 #else
   switch (c) {
   case '(':
@@ -545,7 +543,7 @@ inline CTypeResult
 ParseRules::is_token(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_token_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_token_BIT);
 #else
   return (is_char(c) && !(is_ctl(c) || is_tspecials(c)));
 #endif
@@ -555,7 +553,7 @@ inline char
 ParseRules::ink_toupper(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return parseRulesCTypeToUpper[(unsigned char) c];
+  return parseRulesCTypeToUpper[(unsigned char)c];
 #else
   int up_case = c;
   const int up_case_diff = 'a' - 'A';
@@ -571,7 +569,7 @@ inline char
 ParseRules::ink_tolower(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return parseRulesCTypeToLower[(unsigned char) c];
+  return parseRulesCTypeToLower[(unsigned char)c];
 #else
   int lo_case = c;
   const int lo_case_diff = 'a' - 'A';
@@ -587,7 +585,7 @@ inline CTypeResult
 ParseRules::is_eow(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_eow_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_eow_BIT);
 #else
   return (c == '\0' || c == '\r' || c == '\n');
 #endif
@@ -597,7 +595,7 @@ inline CTypeResult
 ParseRules::is_wildmat(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_wildmat_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_wildmat_BIT);
 #else
   return (c == '*' || c == '?' || c == '[' || c == '\\');
 #endif
@@ -607,7 +605,7 @@ inline CTypeResult
 ParseRules::is_sep(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_sep_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_sep_BIT);
 #else
   return (!c || c == ',' || c == ':' || c == '!' || is_wslfcr(c));
 #endif
@@ -617,7 +615,7 @@ inline CTypeResult
 ParseRules::is_empty(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_empty_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_empty_BIT);
 #else
   return (c == '#' || is_wslfcr(c));
 #endif
@@ -627,7 +625,7 @@ inline CTypeResult
 ParseRules::is_space(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_space_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_space_BIT);
 #else
   switch (c) {
   case CHAR_SP:
@@ -646,9 +644,9 @@ inline CTypeResult
 ParseRules::is_control(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_control_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_control_BIT);
 #else
-  if (((unsigned char) c) < 32 || ((unsigned char) c) == 127)
+  if (((unsigned char)c) < 32 || ((unsigned char)c) == 127)
     return true;
   return false;
 #endif
@@ -658,11 +656,10 @@ inline CTypeResult
 ParseRules::is_mime_sep(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_mime_sep_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_mime_sep_BIT);
 #else
-  if ((c == '(') || (c == ')') || (c == '<') || (c == '>') || (c == '@') ||
-      (c == ',') || (c == ';') || (c == '\\') || (c == '\"') ||
-      (c == '/') || (c == '[') || (c == ']') || (c == '?') || (c == '{') || (c == '}') || (c == ' ') || (c == '\t'))
+  if ((c == '(') || (c == ')') || (c == '<') || (c == '>') || (c == '@') || (c == ',') || (c == ';') || (c == '\\') ||
+      (c == '\"') || (c == '/') || (c == '[') || (c == ']') || (c == '?') || (c == '{') || (c == '}') || (c == ' ') || (c == '\t'))
     return true;
   return false;
 #endif
@@ -672,7 +669,7 @@ inline CTypeResult
 ParseRules::is_http_field_name(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char) c] & is_http_field_name_BIT);
+  return (parseRulesCType[(unsigned char)c] & is_http_field_name_BIT);
 #else
   if ((c == ':') || (is_mime_sep(c) && (c != '@')))
     return false;
@@ -684,7 +681,7 @@ inline CTypeResult
 ParseRules::is_http_field_value(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (CTypeResult) (parseRulesCType[(unsigned char) c] & is_http_field_value_BIT);
+  return (CTypeResult)(parseRulesCType[(unsigned char)c] & is_http_field_value_BIT);
 #else
   switch (c) {
   case CHAR_CR:
@@ -770,7 +767,7 @@ ParseRules::strcasestr(const char *s1, const char *s2)
 
   for (i1 = 0; s1[i1] != '\0'; i1++)
     if (ink_tolower(s1[i1]) == ink_tolower(s2[0]))
-      if (strncasecmp_eow(&s1[i1], &s2[0], (int) s2_len))
+      if (strncasecmp_eow(&s1[i1], &s2[0], (int)s2_len))
         return (&s1[i1]);
 
   return (0);
@@ -798,9 +795,9 @@ static inline int
 ink_get_hex(char c)
 {
   if (ParseRules::is_digit(c))
-    return (int) (c - '0');
+    return (int)(c - '0');
   c = ParseRules::ink_tolower(c);
-  return (int) ((c - 'a') + 10);
+  return (int)((c - 'a') + 10);
 }
 
 int64_t ink_atoi64(const char *);
