@@ -24,44 +24,59 @@
 #ifndef __TS_REGEX_H__
 #define __TS_REGEX_H__
 
+#include "ink_config.h"
+
 #ifdef HAVE_PCRE_PCRE_H
 #include <pcre/pcre.h>
 #else
 #include <pcre.h>
 #endif
 
+enum REFlags {
+  RE_CASE_INSENSITIVE = 0x0001, // default is case sensitive
+  RE_UNANCHORED = 0x0002,       // default (for DFA) is to anchor at the first matching position
+  RE_ANCHORED = 0x0004,         // default (for Regex) is unanchored
+};
 
-enum REFlags
+class Regex
 {
-  RE_CASE_INSENSITIVE = 1
+public:
+  Regex() : regex(NULL), regex_extra(NULL) {}
+  bool compile(const char *pattern, unsigned flags = 0);
+  // It is safe to call exec() concurrently on the same object instance
+  bool exec(const char *str);
+  bool exec(const char *str, int length);
+  ~Regex();
+
+private:
+  pcre *regex;
+  pcre_extra *regex_extra;
 };
 
 typedef struct __pat {
   int _idx;
-  pcre *_re;
-  pcre_extra *_pe;
+  Regex *_re;
   char *_p;
-  __pat * _next;
+  __pat *_next;
 } dfa_pattern;
 
 class DFA
 {
 public:
-  DFA():_my_patterns(0) {
-  }
-  
+  DFA() : _my_patterns(0) {}
+
   ~DFA();
 
-  int compile(const char *pattern, REFlags flags = (REFlags) 0);
-  int compile(const char **patterns, int npatterns, REFlags flags = (REFlags) 0);
-  dfa_pattern * build(const char *pattern, REFlags flags = (REFlags) 0);
-  
+  int compile(const char *pattern, unsigned flags = 0);
+  int compile(const char **patterns, int npatterns, unsigned flags = 0);
+
   int match(const char *str) const;
   int match(const char *str, int length) const;
 
 private:
-  dfa_pattern * _my_patterns;
+  dfa_pattern *build(const char *pattern, unsigned flags = 0);
+
+  dfa_pattern *_my_patterns;
 };
 
-
 #endif /* __TS_REGEX_H__ */
