@@ -45,28 +45,27 @@
 
 
 // status values
-#define REGRESSION_TEST_PASSED         1
-#define REGRESSION_TEST_INPROGRESS     0 // initial value
-#define REGRESSION_TEST_FAILED         -1
-#define REGRESSION_TEST_NOT_RUN        -2
+#define REGRESSION_TEST_PASSED 1
+#define REGRESSION_TEST_INPROGRESS 0 // initial value
+#define REGRESSION_TEST_FAILED -1
+#define REGRESSION_TEST_NOT_RUN -2
 
 // regression types
-#define REGRESSION_TEST_NONE           0
-#define REGRESSION_TEST_QUICK          1
-#define REGRESSION_TEST_NIGHTLY        2
-#define REGRESSION_TEST_EXTENDED       3
- // use only for testing TS error handling!
-#define REGRESSION_TEST_FATAL          4
+#define REGRESSION_TEST_NONE 0
+#define REGRESSION_TEST_QUICK 1
+#define REGRESSION_TEST_NIGHTLY 2
+#define REGRESSION_TEST_EXTENDED 3
+// use only for testing TS error handling!
+#define REGRESSION_TEST_FATAL 4
 
 // regression options
-#define REGRESSION_OPT_EXCLUSIVE       (1 << 0)
+#define REGRESSION_OPT_EXCLUSIVE (1 << 0)
 
 struct RegressionTest;
 
-typedef void TestFunction(RegressionTest * t, int type, int *status);
+typedef void TestFunction(RegressionTest *t, int type, int *status);
 
-struct RegressionTest
-{
+struct RegressionTest {
   const char *name;
   TestFunction *function;
   RegressionTest *next;
@@ -74,7 +73,7 @@ struct RegressionTest
   int printed;
   int opt;
 
-  RegressionTest(const char *name_arg, TestFunction * function_arg, int aopt);
+  RegressionTest(const char *name_arg, TestFunction *function_arg, int aopt);
 
   static int final_status;
   static int ran_tests;
@@ -85,27 +84,20 @@ struct RegressionTest
   static int check_status();
 };
 
-#define REGRESSION_TEST(_f) \
-void RegressionTest_##_f(RegressionTest * t, int atype, int *pstatus); \
-RegressionTest regressionTest_##_f(#_f,&RegressionTest_##_f, 0);\
-void RegressionTest_##_f
+#define REGRESSION_TEST(_f)                                             \
+  void RegressionTest_##_f(RegressionTest *t, int atype, int *pstatus); \
+  RegressionTest regressionTest_##_f(#_f, &RegressionTest_##_f, 0);     \
+  void RegressionTest_##_f
 
-#define EXCLUSIVE_REGRESSION_TEST(_f) \
-void RegressionTest_##_f(RegressionTest * t, int atype, int *pstatus); \
-RegressionTest regressionTest_##_f(#_f,&RegressionTest_##_f, REGRESSION_OPT_EXCLUSIVE);\
-void RegressionTest_##_f
+#define EXCLUSIVE_REGRESSION_TEST(_f)                                                      \
+  void RegressionTest_##_f(RegressionTest *t, int atype, int *pstatus);                    \
+  RegressionTest regressionTest_##_f(#_f, &RegressionTest_##_f, REGRESSION_OPT_EXCLUSIVE); \
+  void RegressionTest_##_f
 
-int rprintf(RegressionTest * t, const char *format, ...);
+int rprintf(RegressionTest *t, const char *format, ...);
 int rperf(RegressionTest *t, const char *tag, double val);
 char *regression_status_string(int status);
 
 extern int regression_level;
 
-#define SignalError(_buf, _already)                                     \
-{                                                                       \
-  if(_already == false) pmgmt->signalManager(MGMT_SIGNAL_CONFIG_ERROR, _buf); \
-  _already = true;                                                      \
-  Warning("%s", _buf);                                                  \
-}                                                                       \
-
 #endif /* _Regression_h */
