@@ -21,14 +21,23 @@
   limitations under the License.
  */
 #ifndef _defalloc_H_
-#define  _defalloc_H_
+#define _defalloc_H_
 
 #include "ink_memory.h"
 
-class DefaultAlloc { public:
-  static void *alloc(int s) { return ats_malloc(s); }
-  static void free(void *p) { ats_free(p); }
+class DefaultAlloc
+{
+public:
+  static void *
+  alloc(int s)
+  {
+    return ats_malloc(s);
+  }
+  static void
+  free(void *p)
+  {
+    ats_free(p);
+  }
 };
 
 #endif
-
