@@ -58,21 +58,20 @@ ink_hash_table_create(InkHashTableKeyType key_type)
   Tcl_HashTable *tcl_ht_ptr;
   int tcl_key_type;
 
-  tcl_ht_ptr = (Tcl_HashTable*)ats_malloc(sizeof(Tcl_HashTable));
+  tcl_ht_ptr = (Tcl_HashTable *)ats_malloc(sizeof(Tcl_HashTable));
 
-  tcl_key_type = -1;
   if (key_type == InkHashTableKeyType_String)
     tcl_key_type = TCL_STRING_KEYS;
   else if (key_type == InkHashTableKeyType_Word)
     tcl_key_type = TCL_ONE_WORD_KEYS;
   else
-    ink_fatal(1, "ink_hash_table_create: bad key_type %d", key_type);
+    ink_fatal("ink_hash_table_create: bad key_type %d", key_type);
 
   Tcl_InitHashTable(tcl_ht_ptr, tcl_key_type);
 
-  ht_ptr = (InkHashTable *) tcl_ht_ptr;
+  ht_ptr = (InkHashTable *)tcl_ht_ptr;
   return (ht_ptr);
-}                               /* End ink_hash_table_create */
+} /* End ink_hash_table_create */
 
 
 /*---------------------------------------------------------------------------*
@@ -84,15 +83,15 @@ ink_hash_table_create(InkHashTableKeyType key_type)
  *---------------------------------------------------------------------------*/
 
 InkHashTable *
-ink_hash_table_destroy(InkHashTable * ht_ptr)
+ink_hash_table_destroy(InkHashTable *ht_ptr)
 {
   Tcl_HashTable *tcl_ht_ptr;
 
-  tcl_ht_ptr = (Tcl_HashTable *) ht_ptr;
+  tcl_ht_ptr = (Tcl_HashTable *)ht_ptr;
   Tcl_DeleteHashTable(tcl_ht_ptr);
   ats_free(tcl_ht_ptr);
-  return (InkHashTable *) 0;
-}                               /* End ink_hash_table_destroy */
+  return (InkHashTable *)0;
+} /* End ink_hash_table_destroy */
 
 
 /*---------------------------------------------------------------------------*
@@ -106,7 +105,7 @@ ink_hash_table_destroy(InkHashTable * ht_ptr)
  *---------------------------------------------------------------------------*/
 
 static int
-_ink_hash_table_free_entry_value(InkHashTable * ht_ptr, InkHashTableEntry * e)
+_ink_hash_table_free_entry_value(InkHashTable *ht_ptr, InkHashTableEntry *e)
 {
   InkHashTableValue value;
 
@@ -116,11 +115,11 @@ _ink_hash_table_free_entry_value(InkHashTable * ht_ptr, InkHashTableEntry * e)
   }
 
   return (0);
-}                               /* End _ink_hash_table_free_entry_value */
+} /* End _ink_hash_table_free_entry_value */
 
 
 static int
-_ink_hash_table_xfree_entry_value(InkHashTable * ht_ptr, InkHashTableEntry * e)
+_ink_hash_table_xfree_entry_value(InkHashTable *ht_ptr, InkHashTableEntry *e)
 {
   InkHashTableValue value;
 
@@ -130,23 +129,23 @@ _ink_hash_table_xfree_entry_value(InkHashTable * ht_ptr, InkHashTableEntry * e)
   }
 
   return (0);
-}                               /* End _ink_hash_table_xfree_entry_value */
+} /* End _ink_hash_table_xfree_entry_value */
 
 InkHashTable *
-ink_hash_table_destroy_and_free_values(InkHashTable * ht_ptr)
+ink_hash_table_destroy_and_free_values(InkHashTable *ht_ptr)
 {
   ink_hash_table_map(ht_ptr, _ink_hash_table_free_entry_value);
   ink_hash_table_destroy(ht_ptr);
-  return (InkHashTable *) 0;
-}                               /* End ink_hash_table_destroy_and_free_values */
+  return (InkHashTable *)0;
+} /* End ink_hash_table_destroy_and_free_values */
 
 InkHashTable *
-ink_hash_table_destroy_and_xfree_values(InkHashTable * ht_ptr)
+ink_hash_table_destroy_and_xfree_values(InkHashTable *ht_ptr)
 {
   ink_hash_table_map(ht_ptr, _ink_hash_table_xfree_entry_value);
   ink_hash_table_destroy(ht_ptr);
-  return (InkHashTable *) 0;
-}                               /* End ink_hash_table_destroy_and_xfree_values */
+  return (InkHashTable *)0;
+} /* End ink_hash_table_destroy_and_xfree_values */
 
 
 /*---------------------------------------------------------------------------*
@@ -159,19 +158,19 @@ ink_hash_table_destroy_and_xfree_values(InkHashTable * ht_ptr)
  *---------------------------------------------------------------------------*/
 
 int
-ink_hash_table_isbound(InkHashTable * ht_ptr, const char *key)
+ink_hash_table_isbound(InkHashTable *ht_ptr, const char *key)
 {
   InkHashTableEntry *he_ptr;
 
   he_ptr = ink_hash_table_lookup_entry(ht_ptr, key);
   return ((he_ptr == NULL) ? 0 : 1);
-}                               /* End ink_hash_table_isbound */
+} /* End ink_hash_table_isbound */
 
 
 /*---------------------------------------------------------------------------*
   int ink_hash_table_lookup(InkHashTable *ht_ptr,
-		            InkHashTableKey key,
-			    InkHashTableValue *value_ptr)
+                            InkHashTableKey key,
+                            InkHashTableValue *value_ptr)
 
   This routine takes a hash table <ht_ptr>, a key <key>, and stores the
   value bound to the key by reference through <value_ptr>.  If no binding is
@@ -180,7 +179,7 @@ ink_hash_table_isbound(InkHashTable * ht_ptr, const char *key)
  *---------------------------------------------------------------------------*/
 
 int
-ink_hash_table_lookup(InkHashTable *ht_ptr, const char* key, InkHashTableValue *value_ptr)
+ink_hash_table_lookup(InkHashTable *ht_ptr, const char *key, InkHashTableValue *value_ptr)
 {
   InkHashTableEntry *he_ptr;
   InkHashTableValue value;
@@ -192,7 +191,7 @@ ink_hash_table_lookup(InkHashTable *ht_ptr, const char* key, InkHashTableValue *
   value = ink_hash_table_entry_value(ht_ptr, he_ptr);
   *value_ptr = value;
   return (1);
-}                               /* End ink_hash_table_lookup */
+} /* End ink_hash_table_lookup */
 
 
 /*---------------------------------------------------------------------------*
@@ -206,14 +205,14 @@ ink_hash_table_lookup(InkHashTable *ht_ptr, const char* key, InkHashTableValue *
  *---------------------------------------------------------------------------*/
 
 int
-ink_hash_table_delete(InkHashTable * ht_ptr, const char *key)
+ink_hash_table_delete(InkHashTable *ht_ptr, const char *key)
 {
   char *tcl_key;
   Tcl_HashTable *tcl_ht_ptr;
   Tcl_HashEntry *tcl_he_ptr;
 
-  tcl_key = (char *) key;
-  tcl_ht_ptr = (Tcl_HashTable *) ht_ptr;
+  tcl_key = (char *)key;
+  tcl_ht_ptr = (Tcl_HashTable *)ht_ptr;
   tcl_he_ptr = Tcl_FindHashEntry(tcl_ht_ptr, tcl_key);
 
   if (!tcl_he_ptr)
@@ -221,13 +220,13 @@ ink_hash_table_delete(InkHashTable * ht_ptr, const char *key)
   Tcl_DeleteHashEntry(tcl_he_ptr);
 
   return (1);
-}                               /* End ink_hash_table_delete */
+} /* End ink_hash_table_delete */
 
 
 /*---------------------------------------------------------------------------*
 
   InkHashTableEntry *ink_hash_table_lookup_entry(InkHashTable *ht_ptr,
-  						 InkHashTableKey key)
+                                                 InkHashTableKey key)
 
   This routine takes a hash table <ht_ptr> and a key <key>, and returns the
   entry matching the key, or NULL otherwise.
@@ -235,25 +234,25 @@ ink_hash_table_delete(InkHashTable * ht_ptr, const char *key)
  *---------------------------------------------------------------------------*/
 
 InkHashTableEntry *
-ink_hash_table_lookup_entry(InkHashTable * ht_ptr, const char* key)
+ink_hash_table_lookup_entry(InkHashTable *ht_ptr, const char *key)
 {
   Tcl_HashTable *tcl_ht_ptr;
   Tcl_HashEntry *tcl_he_ptr;
   InkHashTableEntry *he_ptr;
 
-  tcl_ht_ptr = (Tcl_HashTable *) ht_ptr;
+  tcl_ht_ptr = (Tcl_HashTable *)ht_ptr;
   tcl_he_ptr = Tcl_FindHashEntry(tcl_ht_ptr, key);
-  he_ptr = (InkHashTableEntry *) tcl_he_ptr;
+  he_ptr = (InkHashTableEntry *)tcl_he_ptr;
 
   return (he_ptr);
-}                               /* End ink_hash_table_lookup_entry */
+} /* End ink_hash_table_lookup_entry */
 
 
 /*---------------------------------------------------------------------------*
 
   InkHashTableEntry *ink_hash_table_get_entry(InkHashTable *ht_ptr,
-					      InkHashTableKey key,
-					      int *new_value)
+                                              InkHashTableKey key,
+                                              int *new_value)
 
   This routine takes a hash table <ht_ptr> and a key <key>, and returns the
   entry matching the key, or creates, binds, and returns a new entry.
@@ -267,22 +266,22 @@ ink_hash_table_get_entry(InkHashTable *ht_ptr, const char *key, int *new_value)
   Tcl_HashTable *tcl_ht_ptr;
   Tcl_HashEntry *tcl_he_ptr;
 
-  tcl_ht_ptr = (Tcl_HashTable *) ht_ptr;
+  tcl_ht_ptr = (Tcl_HashTable *)ht_ptr;
   tcl_he_ptr = Tcl_CreateHashEntry(tcl_ht_ptr, key, new_value);
 
   if (tcl_he_ptr == NULL) {
-    ink_fatal(1, "%s: Tcl_CreateHashEntry returned NULL", "ink_hash_table_get_entry");
+    ink_fatal("%s: Tcl_CreateHashEntry returned NULL", "ink_hash_table_get_entry");
   }
 
-  return ((InkHashTableEntry *) tcl_he_ptr);
-}                               /* End ink_hash_table_get_entry */
+  return ((InkHashTableEntry *)tcl_he_ptr);
+} /* End ink_hash_table_get_entry */
 
 
 /*---------------------------------------------------------------------------*
 
   void ink_hash_table_set_entry(InkHashTable *ht_ptr,
-				InkHashTableEntry *he_ptr,
-				InkHashTableValue value)
+                                InkHashTableEntry *he_ptr,
+                                InkHashTableValue value)
 
   This routine takes a hash table <ht_ptr>, a hash table entry <he_ptr>,
   and changes the value field of the entry to <value>.
@@ -290,23 +289,23 @@ ink_hash_table_get_entry(InkHashTable *ht_ptr, const char *key, int *new_value)
  *---------------------------------------------------------------------------*/
 
 void
-ink_hash_table_set_entry(InkHashTable * ht_ptr, InkHashTableEntry * he_ptr, InkHashTableValue value)
+ink_hash_table_set_entry(InkHashTable *ht_ptr, InkHashTableEntry *he_ptr, InkHashTableValue value)
 {
-  (void) ht_ptr;
+  (void)ht_ptr;
   ClientData tcl_value;
   Tcl_HashEntry *tcl_he_ptr;
 
-  tcl_value = (ClientData) value;
-  tcl_he_ptr = (Tcl_HashEntry *) he_ptr;
+  tcl_value = (ClientData)value;
+  tcl_he_ptr = (Tcl_HashEntry *)he_ptr;
   Tcl_SetHashValue(tcl_he_ptr, tcl_value);
-}                               /* End ink_hash_table_set_entry */
+} /* End ink_hash_table_set_entry */
 
 
 /*---------------------------------------------------------------------------*
 
   void ink_hash_table_insert(InkHashTable *ht_ptr,
-			     InkHashTableKey key,
-			     InkHashTableValue value)
+                             InkHashTableKey key,
+                             InkHashTableValue value)
 
   This routine takes a hash table <ht_ptr>, a key <key>, and binds the value
   <value> to the key, replacing any previous binding, if any.
@@ -314,14 +313,14 @@ ink_hash_table_set_entry(InkHashTable * ht_ptr, InkHashTableEntry * he_ptr, InkH
  *---------------------------------------------------------------------------*/
 
 void
-ink_hash_table_insert(InkHashTable * ht_ptr, const char *key, InkHashTableValue value)
+ink_hash_table_insert(InkHashTable *ht_ptr, const char *key, InkHashTableValue value)
 {
   int new_value;
   InkHashTableEntry *he_ptr;
 
   he_ptr = ink_hash_table_get_entry(ht_ptr, key, &new_value);
   ink_hash_table_set_entry(ht_ptr, he_ptr, value);
-}                               /* End ink_hash_table_insert */
+} /* End ink_hash_table_insert */
 
 
 /*---------------------------------------------------------------------------*
@@ -335,24 +334,24 @@ ink_hash_table_insert(InkHashTable * ht_ptr, const char *key, InkHashTableValue
  *---------------------------------------------------------------------------*/
 
 void
-ink_hash_table_map(InkHashTable * ht_ptr, InkHashTableEntryFunction map)
+ink_hash_table_map(InkHashTable *ht_ptr, InkHashTableEntryFunction map)
 {
   int retcode;
   InkHashTableEntry *e;
   InkHashTableIteratorState state;
 
   for (e = ink_hash_table_iterator_first(ht_ptr, &state); e != NULL; e = ink_hash_table_iterator_next(ht_ptr, &state)) {
-    retcode = (*map) (ht_ptr, e);
+    retcode = (*map)(ht_ptr, e);
     if (retcode != 0)
       break;
   }
-}                               /* End ink_hash_table_map */
+} /* End ink_hash_table_map */
 
 
 /*---------------------------------------------------------------------------*
 
   InkHashTableKey ink_hash_table_entry_key(InkHashTable *ht_ptr,
-			                   InkHashTableEntry *entry_ptr)
+                                           InkHashTableEntry *entry_ptr)
 
   This routine takes a hash table <ht_ptr> and a pointer to a hash table
   entry <entry_ptr>, and returns the key portion of the entry.
@@ -360,19 +359,19 @@ ink_hash_table_map(InkHashTable * ht_ptr, InkHashTableEntryFunction map)
  *---------------------------------------------------------------------------*/
 
 InkHashTableKey
-ink_hash_table_entry_key(InkHashTable * ht_ptr, InkHashTableEntry * entry_ptr)
+ink_hash_table_entry_key(InkHashTable *ht_ptr, InkHashTableEntry *entry_ptr)
 {
   char *tcl_key;
 
-  tcl_key = (char*) Tcl_GetHashKey((Tcl_HashTable *) ht_ptr, (Tcl_HashEntry *) entry_ptr);
-  return ((InkHashTableKey) tcl_key);
-}                               /* End ink_hash_table_entry_key */
+  tcl_key = (char *)Tcl_GetHashKey((Tcl_HashTable *)ht_ptr, (Tcl_HashEntry *)entry_ptr);
+  return ((InkHashTableKey)tcl_key);
+} /* End ink_hash_table_entry_key */
 
 
 /*---------------------------------------------------------------------------*
 
   InkHashTableValue ink_hash_table_entry_value(InkHashTable *ht_ptr,
-			                       InkHashTableEntry *entry_ptr)
+                                               InkHashTableEntry *entry_ptr)
 
   This routine takes a hash table <ht_ptr> and a pointer to a hash table
   entry <entry_ptr>, and returns the value portion of the entry.
@@ -380,15 +379,14 @@ ink_hash_table_entry_key(InkHashTable * ht_ptr, InkHashTableEntry * entry_ptr)
  *---------------------------------------------------------------------------*/
 
 InkHashTableValue
-ink_hash_table_entry_value(InkHashTable * ht_ptr, InkHashTableEntry * entry_ptr)
+ink_hash_table_entry_value(InkHashTable *ht_ptr, InkHashTableEntry *entry_ptr)
 {
-  (void) ht_ptr;
+  (void)ht_ptr;
   ClientData tcl_value;
 
-  tcl_value = Tcl_GetHashValue((Tcl_HashEntry *) entry_ptr);
-  return ((InkHashTableValue) tcl_value);
-}                               /* End ink_hash_table_entry_value */
-
+  tcl_value = Tcl_GetHashValue((Tcl_HashEntry *)entry_ptr);
+  return ((InkHashTableValue)tcl_value);
+} /* End ink_hash_table_entry_value */
 
 
 /*---------------------------------------------------------------------------*
@@ -402,7 +400,7 @@ ink_hash_table_entry_value(InkHashTable * ht_ptr, InkHashTableEntry * entry_ptr)
  *---------------------------------------------------------------------------*/
 
 static int
-DumpStringEntry(InkHashTable * ht_ptr, InkHashTableEntry * e)
+DumpStringEntry(InkHashTable *ht_ptr, InkHashTableEntry *e)
 {
   InkHashTableKey key;
   InkHashTableValue value;
@@ -410,23 +408,23 @@ DumpStringEntry(InkHashTable * ht_ptr, InkHashTableEntry * e)
   key = ink_hash_table_entry_key(ht_ptr, e);
   value = ink_hash_table_entry_value(ht_ptr, e);
 
-  fprintf(stderr, "key = '%s', value = '%s'\n", (char *) key, (char *) value);
+  fprintf(stderr, "key = '%s', value = '%s'\n", (char *)key, (char *)value);
 
   return (0);
 }
 
 
 void
-ink_hash_table_dump_strings(InkHashTable * ht_ptr)
+ink_hash_table_dump_strings(InkHashTable *ht_ptr)
 {
   ink_hash_table_map(ht_ptr, DumpStringEntry);
-}                               /* End ink_hash_table_dump_strings */
+} /* End ink_hash_table_dump_strings */
 
 
 /*---------------------------------------------------------------------------*
 
   void ink_hash_table_replace_string(InkHashTable *ht_ptr,
-				     char *string_key, char *string_value)
+                                     char *string_key, char *string_value)
 
   This conveninece routine is intended for hash tables with keys of type
   InkHashTableKeyType_String, and values being dynamically allocated strings.
@@ -436,7 +434,7 @@ ink_hash_table_dump_strings(InkHashTable * ht_ptr)
  *---------------------------------------------------------------------------*/
 
 void
-ink_hash_table_replace_string(InkHashTable * ht_ptr, char *string_key, char *string_value)
+ink_hash_table_replace_string(InkHashTable *ht_ptr, char *string_key, char *string_value)
 {
   int new_value;
   char *old_str;
@@ -448,12 +446,12 @@ ink_hash_table_replace_string(InkHashTable * ht_ptr, char *string_key, char *str
    * still dealing with pointers, and we aren't loosing any bits.
    */
 
-  he_ptr = ink_hash_table_get_entry(ht_ptr, (InkHashTableKey) string_key, &new_value);
+  he_ptr = ink_hash_table_get_entry(ht_ptr, (InkHashTableKey)string_key, &new_value);
   if (new_value == 0) {
-    old_str = (char *) ink_hash_table_entry_value(ht_ptr, he_ptr);
+    old_str = (char *)ink_hash_table_entry_value(ht_ptr, he_ptr);
     if (old_str)
       ats_free(old_str);
   }
 
   ink_hash_table_set_entry(ht_ptr, he_ptr, (InkHashTableValue)(ats_strdup(string_value)));
-}                               /* End ink_hash_table_replace_string */
+} /* End ink_hash_table_replace_string */
