@@ -24,30 +24,32 @@
 #ifndef __INK_RESOURCE_H__
 #define __INK_RESOURCE_H__
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include "ink_mutex.h"
+#include <map>
 
-#include "ink_apidefs.h"
-#include "ink_defs.h"
-#include "ink_memory.h"
+extern volatile int res_track_memory; /* set this to zero to disable resource tracking */
 
-extern volatile int res_track_memory;   /* set this to zero to disable resource tracking */
+#define __RES_PATH(x) #x
+#define _RES_PATH(x) __RES_PATH(x)
+#define RES_PATH(x) x __FILE__ ":" _RES_PATH(__LINE__)
 
-#define __RES_PATH(x)   #x
-#define _RES_PATH(x)    __RES_PATH (x)
-#define RES_PATH(x)     x __FILE__ ":" _RES_PATH (__LINE__)
+class Resource;
 
-struct Resource
+/**
+ * Generic class to keep track of memory usage
+ * Used to keep track of the location in the code that allocated ioBuffer memory
+ */
+class ResourceTracker
 {
-  void *magic;
-  struct Resource *next;
-  const char *path;
-  int64_t value;
-  int64_t snapshot;
-  int64_t baseline;
+public:
+  ResourceTracker(){};
+  static void increment(const char *name, const int64_t size);
+  static void dump(FILE *fd);
+
+private:
+  static Resource &lookup(const char *name);
+  static std::map<const char *, Resource *> _resourceMap;
+  static ink_mutex resourceLock;
 };
 
-typedef struct Resource Resource;
-
 #endif /* __INK_RESOURCE_H__ */
