@@ -32,17 +32,14 @@
   ****************************************************************************/
 
 #ifndef _ink_sprintf_h_
-#define	_ink_sprintf_h_
+#define _ink_sprintf_h_
 
 #include <stdio.h>
 #include <stdarg.h>
 #include "ink_apidefs.h"
 #include "ink_defs.h"
 
-int
-ink_bsprintf(char *buffer, const char *format, ...)
-TS_PRINTFLIKE(2, 3);
-int
-ink_bvsprintf(char *buffer, const char *format, va_list ap);
+int ink_bsprintf(char *buffer, const char *format, ...) TS_PRINTFLIKE(2, 3);
+int ink_bvsprintf(char *buffer, const char *format, va_list ap);
 
 #endif
