@@ -21,9 +21,9 @@
   limitations under the License.
  */
 
-#include "ink_sys_control.h"
-#include "ink_platform.h"
+#include "ink_defs.h"
 #include "ink_assert.h"
+#include "ink_sys_control.h"
 
 rlim_t
 ink_max_out_rlimit(int which, bool max_it, bool unlim_it)
@@ -31,9 +31,9 @@ ink_max_out_rlimit(int which, bool max_it, bool unlim_it)
   struct rlimit rl;
 
 #if defined(linux)
-#  define MAGIC_CAST(x) (enum __rlimit_resource)(x)
+#define MAGIC_CAST(x) (enum __rlimit_resource)(x)
 #else
-#  define MAGIC_CAST(x) x
+#define MAGIC_CAST(x) x
 #endif
 
   if (max_it) {
@@ -51,7 +51,7 @@ ink_max_out_rlimit(int which, bool max_it, bool unlim_it)
     }
   }
 
-#if !defined(darwin)
+#if !(defined(darwin) || defined(freebsd))
   if (unlim_it) {
     ink_release_assert(getrlimit(MAGIC_CAST(which), &rl) >= 0);
     if (rl.rlim_cur != (rlim_t)RLIM_INFINITY) {
@@ -63,3 +63,27 @@ ink_max_out_rlimit(int which, bool max_it, bool unlim_it)
   ink_release_assert(getrlimit(MAGIC_CAST(which), &rl) >= 0);
   return rl.rlim_cur;
 }
+
+rlim_t
+ink_get_max_files()
+{
+  FILE *fd;
+  struct rlimit lim;
+
+  // Linux-only ...
+  if ((fd = fopen("/proc/sys/fs/file-max", "r"))) {
+    uint64_t fmax;
+    if (fscanf(fd, "%" PRIu64 "", &fmax) == 1) {
+      fclose(fd);
+      return static_cast<rlim_t>(fmax);
+    }
+
+    fclose(fd);
+  }
+
+  if (getrlimit(RLIMIT_NOFILE, &lim) == 0) {
+    return lim.rlim_max;
+  }
+
+  return RLIM_INFINITY;
+}
