@@ -26,15 +26,7 @@
 
 #include <sys/resource.h>
 
-#ifdef __cplusplus
-extern "C"
-{
-#endif                          /* __cplusplus */
-
-rlim_t ink_max_out_rlimit(int which, bool max_it=true, bool unlim_it=true);
-
-#ifdef __cplusplus
-}
-#endif                          /* __cplusplus */
+rlim_t ink_max_out_rlimit(int which, bool max_it = true, bool unlim_it = true);
+rlim_t ink_get_max_files();
 
 #endif /*_INK_SYS_CONTROL_H*/
