@@ -30,33 +30,30 @@
  ****************************************************************************/
 #include "libts.h"
 
-struct syslog_fac
-{
+struct syslog_fac {
   char *long_str;
   char *short_str;
   int fac_int;
 };
 
-static const syslog_fac convert_table[] = {
-  {(char *) "LOG_KERN", (char *) "KERN", LOG_KERN},
-  {(char *) "LOG_USER", (char *) "USER", LOG_USER},
-  {(char *) "LOG_MAIL", (char *) "MAIL", LOG_MAIL},
-  {(char *) "LOG_DAEMON", (char *) "DAEMON", LOG_DAEMON},
-  {(char *) "LOG_AUTH", (char *) "AUTH", LOG_AUTH},
-  {(char *) "LOG_LPR", (char *) "LPR", LOG_LPR},
-  {(char *) "LOG_NEWS", (char *) "NEWS", LOG_NEWS},
-  {(char *) "LOG_UUCP", (char *) "UUCP", LOG_UUCP},
-  {(char *) "LOG_CRON", (char *) "CRON", LOG_CRON},
-  {(char *) "LOG_LOCAL0", (char *) "LOCAL0", LOG_LOCAL0},
-  {(char *) "LOG_LOCAL1", (char *) "LOCAL1", LOG_LOCAL1},
-  {(char *) "LOG_LOCAL2", (char *) "LOCAL2", LOG_LOCAL2},
-  {(char *) "LOG_LOCAL3", (char *) "LOCAL3", LOG_LOCAL3},
-  {(char *) "LOG_LOCAL4", (char *) "LOCAL4", LOG_LOCAL4},
-  {(char *) "LOG_LOCAL5", (char *) "LOCAL5", LOG_LOCAL5},
-  {(char *) "LOG_LOCAL6", (char *) "LOCAL6", LOG_LOCAL6},
-  {(char *) "LOG_LOCAL7", (char *) "LOCAL7", LOG_LOCAL7},
-  {(char *) "INVALID_LOG_FAC", (char *) "INVALID", -1}
-};
+static const syslog_fac convert_table[] = {{(char *)"LOG_KERN", (char *) "KERN", LOG_KERN},
+                                           {(char *)"LOG_USER", (char *) "USER", LOG_USER},
+                                           {(char *)"LOG_MAIL", (char *) "MAIL", LOG_MAIL},
+                                           {(char *)"LOG_DAEMON", (char *) "DAEMON", LOG_DAEMON},
+                                           {(char *)"LOG_AUTH", (char *) "AUTH", LOG_AUTH},
+                                           {(char *)"LOG_LPR", (char *) "LPR", LOG_LPR},
+                                           {(char *)"LOG_NEWS", (char *) "NEWS", LOG_NEWS},
+                                           {(char *)"LOG_UUCP", (char *) "UUCP", LOG_UUCP},
+                                           {(char *)"LOG_CRON", (char *) "CRON", LOG_CRON},
+                                           {(char *)"LOG_LOCAL0", (char *) "LOCAL0", LOG_LOCAL0},
+                                           {(char *)"LOG_LOCAL1", (char *) "LOCAL1", LOG_LOCAL1},
+                                           {(char *)"LOG_LOCAL2", (char *) "LOCAL2", LOG_LOCAL2},
+                                           {(char *)"LOG_LOCAL3", (char *) "LOCAL3", LOG_LOCAL3},
+                                           {(char *)"LOG_LOCAL4", (char *) "LOCAL4", LOG_LOCAL4},
+                                           {(char *)"LOG_LOCAL5", (char *) "LOCAL5", LOG_LOCAL5},
+                                           {(char *)"LOG_LOCAL6", (char *) "LOCAL6", LOG_LOCAL6},
+                                           {(char *)"LOG_LOCAL7", (char *) "LOCAL7", LOG_LOCAL7},
+                                           {(char *)"INVALID_LOG_FAC", (char *) "INVALID", -1}};
 static const int convert_table_size = sizeof(convert_table) / sizeof(syslog_fac) - 1;
 
 // int facility_string_to_int(const char* str)
@@ -69,7 +66,6 @@ static const int convert_table_size = sizeof(convert_table) / sizeof(syslog_fac)
 int
 facility_string_to_int(const char *str)
 {
-
   if (str == NULL) {
     return -1;
   }
@@ -78,7 +74,6 @@ facility_string_to_int(const char *str)
     if (strcasecmp(convert_table[i].long_str, str) == 0 || strcasecmp(convert_table[i].short_str, str) == 0) {
       return convert_table[i].fac_int;
     }
-
   }
   return -1;
 }
