@@ -34,8 +34,8 @@
 
  */
 
-#if !defined (_inktomiplus_h_)
-#define	_inktomiplus_h_
+#if !defined(_inktomiplus_h_)
+#define _inktomiplus_h_
 
 /* Removed for now, to fix build on Solaris
 #define std *** _FIXME_REMOVE_DEPENDENCY_ON_THE_STL_ ***
@@ -78,13 +78,18 @@
 #include "Allocator.h"
 #include "Arena.h"
 #include "Bitops.h"
-#include "Compatability.h"
+#include "ConsistentHash.h"
 #include "DynArray.h"
 #include "EventNotify.h"
+#include "Hash.h"
+#include "HashFNV.h"
+#include "HashMD5.h"
+#include "HashSip.h"
 #include "I_Version.h"
 #include "InkPool.h"
 #include "List.h"
 #include "INK_MD5.h"
+#include "MMH.h"
 #include "Map.h"
 #include "MimeTable.h"
 #include "ParseRules.h"
