@@ -24,22 +24,22 @@
 #include "ink_platform.h"
 #include "ink_lockfile.h"
 
-#define LOCKFILE_BUF_LEN 16     // 16 bytes should be enought for a pid
+#define LOCKFILE_BUF_LEN 16 // 16 bytes should be enought for a pid
 
 int
-Lockfile::Open(pid_t * holding_pid)
+Lockfile::Open(pid_t *holding_pid)
 {
   char buf[LOCKFILE_BUF_LEN];
   pid_t val;
   int err;
   *holding_pid = 0;
 
-#define FAIL(x) \
-{ \
-  if (fd > 0) \
-    close (fd); \
-  return (x); \
-}
+#define FAIL(x)  \
+  {              \
+    if (fd > 0)  \
+      close(fd); \
+    return (x);  \
+  }
 
   struct flock lock;
   char *t;
@@ -89,7 +89,7 @@ Lockfile::Open(pid_t * holding_pid)
     *t = '\0';
 
     // coverity[secure_coding]
-    if (sscanf(buf, "%d\n", (int*)&val) != 1) {
+    if (sscanf(buf, "%d\n", (int *)&val) != 1) {
       *holding_pid = 0;
     } else {
       *holding_pid = val;
@@ -118,13 +118,13 @@ Lockfile::Open(pid_t * holding_pid)
   // Return the file descriptor of the opened lockfile. When this file
   // descriptor is closed the lock will be released.
 
-  return (1);                   // success
+  return (1); // success
 
 #undef FAIL
 }
 
 int
-Lockfile::Get(pid_t * holding_pid)
+Lockfile::Get(pid_t *holding_pid)
 {
   char buf[LOCKFILE_BUF_LEN];
   int err;
@@ -152,18 +152,18 @@ Lockfile::Get(pid_t * holding_pid)
     return (-errno);
   }
   // Write our process id to the Lockfile.
-  snprintf(buf, sizeof(buf), "%d\n", (int) getpid());
+  snprintf(buf, sizeof(buf), "%d\n", (int)getpid());
 
   do {
     err = write(fd, buf, strlen(buf));
   } while ((err < 0) && (errno == EINTR));
 
-  if (err != (int) strlen(buf)) {
+  if (err != (int)strlen(buf)) {
     close(fd);
     return (-errno);
   }
 
-  return (1);                   // success
+  return (1); // success
 }
 
 void
@@ -205,14 +205,14 @@ lockfile_kill_internal(pid_t init_pid, int init_sig, pid_t pid, const char * /*
     // Wait for children to exit
     do {
       err = waitpid(-1, &status, WNOHANG);
-      if (err == -1) break;
-    } while(!WIFEXITED(status) && !WIFSIGNALED(status));
+      if (err == -1)
+        break;
+    } while (!WIFEXITED(status) && !WIFSIGNALED(status));
   }
 
   do {
     err = kill(pid, sig);
   } while ((err == 0) || ((err < 0) && (errno == EINTR)));
-
 }
 
 void
@@ -223,10 +223,10 @@ Lockfile::Kill(int sig, int initial_sig, const char *pname)
   pid_t holding_pid;
 
   err = Open(&holding_pid);
-  if (err == 1)                 // success getting the lock file
+  if (err == 1) // success getting the lock file
   {
     Close();
-  } else if (err == 0)          // someone else has the lock
+  } else if (err == 0) // someone else has the lock
   {
     pid = holding_pid;
     if (pid != 0) {
@@ -243,10 +243,10 @@ Lockfile::KillGroup(int sig, int initial_sig, const char *pname)
   pid_t holding_pid;
 
   err = Open(&holding_pid);
-  if (err == 1)                 // success getting the lock file
+  if (err == 1) // success getting the lock file
   {
     Close();
-  } else if (err == 0)          // someone else has the lock
+  } else if (err == 0) // someone else has the lock
   {
     do {
       pid = getpgid(holding_pid);
