@@ -24,36 +24,43 @@
 
 #include "List.h"
 
-class Foo { public:
+class Foo
+{
+public:
   int x;
 
-  void foo() {}
+  void
+  foo()
+  {
+  }
 
   SLINK(Foo, slink);
   LINK(Foo, dlink);
 
-  Foo(int i = 0): x(i) {}
+  Foo(int i = 0) : x(i) {}
 };
 
-int main() {
-   SList(Foo,slink) s;
-   DList(Foo,dlink) d;
-   Que(Foo,dlink) q;
-   Foo *f = new Foo;
-   f->x = 7;
-   s.push(f);
-   d.push(s.pop());
-   q.enqueue(d.pop());
-   for (int i = 0; i < 100; i++)
-     q.enqueue(new Foo(i));
-   int tot = 0;
-   for (int i = 0; i < 101; i++)
-     tot += q.dequeue()->x;
-   if (tot != 4957) {
-     printf("test_List FAILED\n");
-     exit(1);
-   } else {
-     printf("test_List PASSED\n");
-     exit(0);
-   }
+int
+main()
+{
+  SList(Foo, slink) s;
+  DList(Foo, dlink) d;
+  Que(Foo, dlink) q;
+  Foo *f = new Foo;
+  f->x = 7;
+  s.push(f);
+  d.push(s.pop());
+  q.enqueue(d.pop());
+  for (int i = 0; i < 100; i++)
+    q.enqueue(new Foo(i));
+  int tot = 0;
+  for (int i = 0; i < 101; i++)
+    tot += q.dequeue()->x;
+  if (tot != 4957) {
+    printf("test_List FAILED\n");
+    exit(1);
+  } else {
+    printf("test_List PASSED\n");
+    exit(0);
+  }
 }
