@@ -37,18 +37,11 @@
 
 typedef fileEntry snapshot;
 
-const char *SnapshotStrings[] = { "Request Successful\n",
-  "No Snapshot Directory",
-  "Snapshot was not found\n",
-  "Creation of snapshot directory failed\n",
-  "Creation of snapshot file failed\n",
-  "Access to snapshot file Failed\n",
-  "Unable to write to snapshot file\n",
-  "Remove of Snapshot failed\n",
-  "Internal Error: Form Submission was invalid\n",
-  "No Snapshot Name Was Given\n",
-  "Invalid Snapshot name\n"
-};
+const char *SnapshotStrings[] = {"Request Successful\n", "No Snapshot Directory", "Snapshot was not found\n",
+                                 "Creation of snapshot directory failed\n", "Creation of snapshot file failed\n",
+                                 "Access to snapshot file Failed\n", "Unable to write to snapshot file\n",
+                                 "Remove of Snapshot failed\n", "Internal Error: Form Submission was invalid\n",
+                                 "No Snapshot Name Was Given\n", "Invalid Snapshot name\n"};
 
 FileManager::FileManager()
 {
@@ -58,14 +51,17 @@ FileManager::FileManager()
   ink_mutex_init(&accessLock, "File Manager Mutex");
   ink_mutex_init(&cbListLock, "File Changed Callback Mutex");
 
-  xptr<char> snapshotDir(RecConfigReadSnapshotDir());
+  ats_scoped_str snapshotDir(RecConfigReadSnapshotDir());
 
   // Check to see if the directory already exists, if not create it.
-  if (access(snapshotDir, F_OK) == -1) {
-    if (mkdir(snapshotDir, DIR_MODE) < 0) {
-      // Failed to create the snapshot directory
-      mgmt_fatal(stderr, 0, "[FileManager::FileManager] Failed to create the snapshot directory %s: %s\n", (const char *)snapshotDir, strerror(errno));
-    }
+  if (mkdir(snapshotDir, DIR_MODE) < 0 && errno != EEXIST) {
+    // Failed to create the snapshot directory
+    mgmt_fatal(stderr, 0, "[FileManager::FileManager] Failed to create the snapshot directory %s: %s\n", (const char *)snapshotDir,
+               strerror(errno));
+  }
+
+  if (!ink_file_is_directory(snapshotDir)) {
+    mgmt_fatal(stderr, 0, "[FileManager::FileManager] snapshot directory %s is not a directory\n", (const char *)snapshotDir);
   }
 
   this->managedDir = snapshotDir.release();
@@ -80,9 +76,8 @@ FileManager::FileManager()
 //
 FileManager::~FileManager()
 {
-
   callbackListable *cb;
-  fileBinding *bind;
+  Rollback *rb;
   InkHashTableEntry *entry;
   InkHashTableIteratorState iterator_state;
 
@@ -97,23 +92,19 @@ FileManager::~FileManager()
     delete cb;
   }
 
-  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state);
-       entry != NULL; entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
+  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state); entry != NULL;
+       entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
+    rb = (Rollback *)ink_hash_table_entry_value(bindings, entry);
 
-    bind = (fileBinding *) ink_hash_table_entry_value(bindings, entry);
-
-    delete bind->rb;
-    delete bind;
+    delete rb;
   }
 
   ink_hash_table_destroy(bindings);
 
-
   ink_mutex_destroy(&accessLock);
   ink_mutex_destroy(&cbListLock);
 }
 
-
 // void FileManager::registerCallback(FileCallbackFunc func)
 //
 //  Adds a new callback function
@@ -126,7 +117,6 @@ FileManager::~FileManager()
 void
 FileManager::registerCallback(FileCallbackFunc func)
 {
-
   callbackListable *newcb = new callbackListable();
   ink_assert(newcb != NULL);
   newcb->func = func;
@@ -147,14 +137,13 @@ FileManager::registerCallback(FileCallbackFunc func)
 void
 FileManager::addFile(const char *baseFileName, bool root_access_needed)
 {
-
   ink_assert(baseFileName != NULL);
-  fileBinding *newBind = new fileBinding;
 
-  newBind->rb = new Rollback(baseFileName, root_access_needed);
+  Rollback *rb = new Rollback(baseFileName, root_access_needed);
+  rb->configFiles = this;
 
   ink_mutex_acquire(&accessLock);
-  ink_hash_table_insert(bindings, baseFileName, newBind);
+  ink_hash_table_insert(bindings, baseFileName, rb);
   ink_mutex_release(&accessLock);
 }
 
@@ -166,24 +155,17 @@ FileManager::addFile(const char *baseFileName, bool root_access_needed)
 //  If there is no binding, falseis returned
 //
 bool
-FileManager::getRollbackObj(const char *baseFileName, Rollback ** rbPtr)
+FileManager::getRollbackObj(const char *baseFileName, Rollback **rbPtr)
 {
-
-  InkHashTableValue lookup;
-  fileBinding *bind;
+  InkHashTableValue lookup = NULL;
   int found;
 
   ink_mutex_acquire(&accessLock);
   found = ink_hash_table_lookup(bindings, baseFileName, &lookup);
   ink_mutex_release(&accessLock);
 
-  bind = (fileBinding *) lookup;
-  if (found == 0) {
-    return false;
-  } else {
-    *rbPtr = bind->rb;
-    return true;
-  }
+  *rbPtr = (Rollback *)lookup;
+  return (found == 0) ? false : true;
 }
 
 // bool FileManager::fileChanged(const char* baseFileName)
@@ -195,18 +177,16 @@ FileManager::getRollbackObj(const char *baseFileName, Rollback ** rbPtr)
 void
 FileManager::fileChanged(const char *baseFileName, bool incVersion)
 {
-
   callbackListable *cb;
   char *filenameCopy;
 
   ink_mutex_acquire(&cbListLock);
 
-
   for (cb = cblist.head; cb != NULL; cb = cb->link.next) {
     // Dup the string for each callback to be
     //  defensive incase it modified when it is not supposed to be
     filenameCopy = ats_strdup(baseFileName);
-    (*cb->func) (filenameCopy, incVersion);
+    (*cb->func)(filenameCopy, incVersion);
     ats_free(filenameCopy);
   }
   ink_mutex_release(&cbListLock);
@@ -221,11 +201,10 @@ FileManager::fileChanged(const char *baseFileName, bool incVersion)
 textBuffer *
 FileManager::filesManaged()
 {
-
   textBuffer *result = new textBuffer(1024);
   const char *currentName;
   const char separator[] = "\n";
-  fileBinding *bind;
+  Rollback *rb;
   InkHashTableEntry *entry;
   InkHashTableIteratorState iterator_state;
 
@@ -233,11 +212,10 @@ FileManager::filesManaged()
   // To get a stable snap shot, we need to get the rollback
   //   locks on all configuration files so the files
   //   do not change from under us
-  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state);
-       entry != NULL; entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
-
-    bind = (fileBinding *) ink_hash_table_entry_value(bindings, entry);
-    currentName = bind->rb->getBaseName();
+  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state); entry != NULL;
+       entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
+    rb = (Rollback *)ink_hash_table_entry_value(bindings, entry);
+    currentName = rb->getBaseName();
     ink_assert(currentName);
 
     result->copyFrom(currentName, strlen(currentName));
@@ -258,22 +236,20 @@ FileManager::filesManaged()
 void
 FileManager::doRollbackLocks(lockAction_t action)
 {
-
-  fileBinding *bind;
+  Rollback *rb;
   InkHashTableEntry *entry;
   InkHashTableIteratorState iterator_state;
 
-  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state);
-       entry != NULL; entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
-
-    bind = (fileBinding *) ink_hash_table_entry_value(bindings, entry);
+  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state); entry != NULL;
+       entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
+    rb = (Rollback *)ink_hash_table_entry_value(bindings, entry);
 
     switch (action) {
     case ACQUIRE_LOCK:
-      bind->rb->acquireLock();
+      rb->acquireLock();
       break;
     case RELEASE_LOCK:
-      bind->rb->releaseLock();
+      rb->releaseLock();
       break;
     default:
       ink_assert(0);
@@ -282,7 +258,6 @@ FileManager::doRollbackLocks(lockAction_t action)
   }
 }
 
-
 // void FileManager::abortRestore(const char* abortTo)
 //
 //  Iterates through the hash table of managed files
@@ -299,33 +274,30 @@ FileManager::doRollbackLocks(lockAction_t action)
 void
 FileManager::abortRestore(const char *abortTo)
 {
-
-  fileBinding *bind;
+  Rollback *rb;
   InkHashTableEntry *entry;
   InkHashTableIteratorState iterator_state;
   version_t currentVersion;
 
   ink_assert(abortTo != NULL);
 
-  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state);
-       entry != NULL; entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
-
-    bind = (fileBinding *) ink_hash_table_entry_value(bindings, entry);
+  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state); entry != NULL;
+       entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
+    rb = (Rollback *)ink_hash_table_entry_value(bindings, entry);
 
     // We are done
-    if (strcmp(abortTo, bind->rb->getBaseName()) == 0) {
+    if (strcmp(abortTo, rb->getBaseName()) == 0) {
       return;
     }
 
-    currentVersion = bind->rb->getCurrentVersion();
-    if (bind->rb->revertToVersion_ml(currentVersion - 1) != OK_ROLLBACK) {
-      mgmt_fatal(stderr, 0,
-                 "[FileManager::abortRestore] Unable to abort a failed snapshot restore.  Configuration files have been left in a inconsistent state\n");
+    currentVersion = rb->getCurrentVersion();
+    if (rb->revertToVersion_ml(currentVersion - 1) != OK_ROLLBACK) {
+      mgmt_fatal(stderr, 0, "[FileManager::abortRestore] Unable to abort a failed snapshot restore.  Configuration files have been "
+                            "left in a inconsistent state\n");
     }
   }
 }
 
-
 // SnapResult FileManager::restoresSnap(const char* snapName)
 //
 //  Restores the snapshot with snapName.
@@ -336,7 +308,7 @@ FileManager::abortRestore(const char *abortTo)
 SnapResult
 FileManager::restoreSnap(const char *snapName, const char *snapDir)
 {
-  fileBinding *bind;
+  Rollback *rb;
   InkHashTableEntry *entry;
   InkHashTableIteratorState iterator_state;
   SnapResult result = SNAP_OK;
@@ -348,10 +320,8 @@ FileManager::restoreSnap(const char *snapName, const char *snapDir)
 
   ink_mutex_acquire(&accessLock);
 
-
-
   if (access(snapPath, F_OK) == -1) {
-    delete[]snapPath;
+    delete[] snapPath;
     ink_mutex_release(&accessLock);
     return SNAP_NOT_FOUND;
   }
@@ -364,23 +334,22 @@ FileManager::restoreSnap(const char *snapName, const char *snapDir)
   // For each file, load the snap shot file and Roll a new version
   //    of the active file
   //
-  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state);
-       entry != NULL; entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
-
-    bind = (fileBinding *) ink_hash_table_entry_value(bindings, entry);
-    filePath = newPathString(snapPath, bind->rb->getBaseName());
+  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state); entry != NULL;
+       entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
+    rb = (Rollback *)ink_hash_table_entry_value(bindings, entry);
+    filePath = newPathString(snapPath, rb->getBaseName());
     if (readFile(filePath, &storage) != SNAP_OK) {
-      abortRestore(bind->rb->getBaseName());
+      abortRestore(rb->getBaseName());
       result = SNAP_FILE_ACCESS_FAILED;
       break;
     }
 
-    if (bind->rb->forceUpdate_ml(&storage) != OK_ROLLBACK) {
-      abortRestore(bind->rb->getBaseName());
+    if (rb->forceUpdate_ml(&storage) != OK_ROLLBACK) {
+      abortRestore(rb->getBaseName());
       result = SNAP_FILE_ACCESS_FAILED;
       break;
     }
-    delete[]filePath;
+    delete[] filePath;
     filePath = NULL;
     storage.reUse();
   }
@@ -389,16 +358,13 @@ FileManager::restoreSnap(const char *snapName, const char *snapDir)
   ink_mutex_release(&accessLock);
 
   if (filePath != NULL) {
-    delete[]filePath;
+    delete[] filePath;
   }
 
-  delete[]snapPath;
+  delete[] snapPath;
   return result;
 }
 
-
-
-
 // SnapResult FileManager::removeSnap(const char* snapName)
 //
 //
@@ -418,11 +384,11 @@ FileManager::removeSnap(const char *snapName, const char *snapDir)
 
   if (dir == NULL) {
     mgmt_log(stderr, "[FileManager::removeSnap] Unable to open snapshot %s: %s\n", snapName, strerror(errno));
-    delete[]snapPath;
+    delete[] snapPath;
     return SNAP_NOT_FOUND;
   }
 
-  dirEntrySpace = (struct dirent *)ats_malloc(sizeof(struct dirent) + pathconf(".", _PC_NAME_MAX) + 1);
+  dirEntrySpace = (struct dirent *)ats_malloc(sizeof(struct dirent) + ink_file_namemax(".") + 1);
 
   while (readdir_r(dir, dirEntrySpace, &entryPtr) == 0) {
     if (!entryPtr)
@@ -439,7 +405,7 @@ FileManager::removeSnap(const char *snapName, const char *snapDir)
       unlinkFailed = true;
       result = SNAP_REMOVE_FAILED;
     }
-    delete[]snapFilePath;
+    delete[] snapFilePath;
   }
 
   ats_free(dirEntrySpace);
@@ -450,43 +416,31 @@ FileManager::removeSnap(const char *snapName, const char *snapDir)
   if (unlinkFailed == false) {
     if (rmdir(snapPath) < 0) {
       // strerror() isn't reentrant/thread-safe ... Problem? /leif
-      mgmt_log(stderr,
-               "[FileManager::removeSnap] Unable to remove snapshot directory %s: %s\n", snapPath, strerror(errno));
+      mgmt_log(stderr, "[FileManager::removeSnap] Unable to remove snapshot directory %s: %s\n", snapPath, strerror(errno));
       result = SNAP_REMOVE_FAILED;
     } else {
       result = SNAP_OK;
     }
   }
 
-  delete[]snapPath;
+  delete[] snapPath;
   return result;
 }
 
-
-
-
-
-
-
-
-
- //
- //  Creates a new snapshot with snapName
- //     Creates a directory named snapName in the snapshot directory
- //     Places a copy of every config file into the new directory
- //
+//
+//  Creates a new snapshot with snapName
+//     Creates a directory named snapName in the snapshot directory
+//     Places a copy of every config file into the new directory
+//
 
 SnapResult
 FileManager::takeSnap(const char *snapName, const char *snapDir)
 {
-
-  fileBinding *bind;
+  Rollback *rb;
   InkHashTableEntry *entry;
   InkHashTableIteratorState iterator_state;
   char *snapPath;
   SnapResult callResult = SNAP_OK;
-  struct stat snapDirStat;
-
 
   // Make sure the user sent us a name
   if (snapName == NULL || *snapName == '\0') {
@@ -501,42 +455,37 @@ FileManager::takeSnap(const char *snapName, const char *snapDir)
     return SNAP_ILLEGAL_NAME;
   }
 
-
   snapPath = newPathString(snapDir, snapName);
 
-  if (!stat(snapPath, &snapDirStat)) {
-    if (!S_ISDIR(snapDirStat.st_mode)) {
-      delete[]snapPath;
-      return SNAP_DIR_CREATE_FAILED;
-    }
+  if (mkdir(snapPath, DIR_MODE) < 0 && errno != EEXIST) {
+    mgmt_log(stderr, "[FileManager::takeSnap] Failed to create directory for snapshot %s: %s\n", snapName, strerror(errno));
+    delete[] snapPath;
+    return SNAP_DIR_CREATE_FAILED;
   }
-  if (mkdir(snapPath, DIR_MODE) < 0) {
-    mgmt_log(stderr, "[FileManager::takeSnap] Failed to create directory for snapshot %s: %s\n",
-             snapName, strerror(errno));
-    delete[]snapPath;
+
+  if (!ink_file_is_directory(snapPath)) {
+    mgmt_log(stderr, "[FileManager::takeSnap] snapshot directory %s is not a directory\n", snapPath);
+    delete[] snapPath;
     return SNAP_DIR_CREATE_FAILED;
   }
 
   ink_mutex_acquire(&accessLock);
 
-
   // To get a stable snap shot, we need to get the rollback
   //   locks on all configuration files so the files
   //   do not change from under us
   doRollbackLocks(ACQUIRE_LOCK);
 
   // For each file, make a copy in the snap shot directory
-  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state);
-       entry != NULL; entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
-
-    bind = (fileBinding *) ink_hash_table_entry_value(bindings, entry);
-    callResult = this->copyFile(bind->rb, snapPath);
+  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state); entry != NULL;
+       entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
+    rb = (Rollback *)ink_hash_table_entry_value(bindings, entry);
+    callResult = this->copyFile(rb, snapPath);
     if (callResult != SNAP_OK) {
-      // Remove the failed napshot so that we do not have a partial
+      // Remove the failed snapshot so that we do not have a partial
       //   one hanging around
       if (removeSnap(snapName, snapDir) != SNAP_OK) {
-        mgmt_log(stderr,
-                 "[FileManager::takeSnap] Unable to remove failed snapshot %s.  This snapshot should be removed by hand\n",
+        mgmt_log(stderr, "[FileManager::takeSnap] Unable to remove failed snapshot %s.  This snapshot should be removed by hand\n",
                  snapName);
       }
       break;
@@ -548,17 +497,10 @@ FileManager::takeSnap(const char *snapName, const char *snapDir)
   doRollbackLocks(RELEASE_LOCK);
 
   ink_mutex_release(&accessLock);
-  delete[]snapPath;
+  delete[] snapPath;
   return callResult;
 }
 
-
-
-
-
-
-
-
 //
 //  SnapResult FileManager::readFile(const char* filePath, textBuffer* contents)
 //
@@ -566,7 +508,7 @@ FileManager::takeSnap(const char *snapName, const char *snapDir)
 //    the file was successfully read and an error code otherwise
 //
 SnapResult
-FileManager::readFile(const char *filePath, textBuffer * contents)
+FileManager::readFile(const char *filePath, textBuffer *contents)
 {
   int diskFD;
   int readResult;
@@ -581,7 +523,8 @@ FileManager::readFile(const char *filePath, textBuffer * contents)
 
   fcntl(diskFD, F_SETFD, 1);
 
-  while ((readResult = contents->readFromFD(diskFD)) > 0);
+  while ((readResult = contents->readFromFD(diskFD)) > 0)
+    ;
   close(diskFD);
 
   if (readResult < 0) {
@@ -598,7 +541,7 @@ FileManager::readFile(const char *filePath, textBuffer * contents)
 //    directory (snapPath)
 //
 SnapResult
-FileManager::copyFile(Rollback * rb, const char *snapPath)
+FileManager::copyFile(Rollback *rb, const char *snapPath)
 {
   const char *fileName;
   char *filePath;
@@ -621,7 +564,7 @@ FileManager::copyFile(Rollback * rb, const char *snapPath)
 
   if (diskFD < 0) {
     mgmt_log(stderr, "[FileManager::copyFile] Unable to create snapshot file %s: %s\n", fileName, strerror(errno));
-    delete[]filePath;
+    delete[] filePath;
     delete copyBuf;
     return SNAP_FILE_CREATE_FAILED;
   }
@@ -636,18 +579,12 @@ FileManager::copyFile(Rollback * rb, const char *snapPath)
     result = SNAP_OK;
   }
 
-  delete[]filePath;
+  delete[] filePath;
   delete copyBuf;
   close(diskFD);
   return result;
 }
 
-
-
-
-
-
-
 // SnapResult FileManager::WalkSnaps(ExpandingArray* snapList)
 //
 //   Iterates through the snapshot directory and adds every snapshot
@@ -656,7 +593,7 @@ FileManager::copyFile(Rollback * rb, const char *snapPath)
 //   CALLEE should be holding this->accessLock
 //
 SnapResult
-FileManager::WalkSnaps(ExpandingArray * snapList)
+FileManager::WalkSnaps(ExpandingArray *snapList)
 {
   MFresult r;
 
@@ -667,14 +604,12 @@ FileManager::WalkSnaps(ExpandingArray * snapList)
   ink_mutex_acquire(&accessLock);
 
   r = WalkFiles(snapList);
-  //lmgmt->record_data ->setString("proxy.config.snapshot_dir", managedDir);
+  // lmgmt->record_data ->setString("proxy.config.snapshot_dir", managedDir);
 
   ink_mutex_release(&accessLock);
-  return (SnapResult) r;
+  return (SnapResult)r;
 }
 
-
-
 // void FileManger::rereadConfig()
 //
 //   Interates through the list of managed files and
@@ -686,36 +621,56 @@ FileManager::WalkSnaps(ExpandingArray * snapList)
 void
 FileManager::rereadConfig()
 {
-  fileBinding *bind;
+  Rollback *rb;
   InkHashTableEntry *entry;
   InkHashTableIteratorState iterator_state;
 
   ink_mutex_acquire(&accessLock);
-  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state);
-       entry != NULL; entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
-
-    bind = (fileBinding *) ink_hash_table_entry_value(bindings, entry);
-    bind->rb->checkForUserUpdate();
+  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state); entry != NULL;
+       entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
+    rb = (Rollback *)ink_hash_table_entry_value(bindings, entry);
+    rb->checkForUserUpdate(ROLLBACK_CHECK_AND_UPDATE);
   }
   ink_mutex_release(&accessLock);
 
   // INKqa11910
   // need to first check that enable_customizations is enabled
   bool found;
-  int enabled = (int) REC_readInteger("proxy.config.body_factory.enable_customizations",
-                                      &found);
+  int enabled = (int)REC_readInteger("proxy.config.body_factory.enable_customizations", &found);
   if (found && enabled) {
     fileChanged("proxy.config.body_factory.template_sets_dir", true);
   }
 }
 
+bool
+FileManager::isConfigStale()
+{
+  Rollback *rb;
+  InkHashTableEntry *entry;
+  InkHashTableIteratorState iterator_state;
+  bool stale = false;
+
+  ink_mutex_acquire(&accessLock);
+  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state); entry != NULL;
+       entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
+    rb = (Rollback *)ink_hash_table_entry_value(bindings, entry);
+    if (rb->checkForUserUpdate(ROLLBACK_CHECK_ONLY)) {
+      stale = true;
+      break;
+    }
+  }
+
+  ink_mutex_release(&accessLock);
+  return stale;
+}
+
 // void FileManager::displaySnapPage(textBuffer* output, httpResponse& answerHdr)
 //
 //  Generates an HTML page with the add form and the list
 //    of current snapshots
 //
 void
-FileManager::displaySnapOption(textBuffer * output)
+FileManager::displaySnapOption(textBuffer *output)
 {
   ExpandingArray snap_list(25, true);
   SnapResult snap_result;
@@ -730,8 +685,6 @@ FileManager::displaySnapOption(textBuffer * output)
   }
 }
 
-
-
 // void FileManger::createSelect(char* formVar, textBuffer* output, ExpandingArray*)
 //
 //  Creats a form with a select list.  The select options come
@@ -739,7 +692,7 @@ FileManager::displaySnapOption(textBuffer * output)
 //    tag with name action
 //
 void
-FileManager::createSelect(char *action, textBuffer * output, ExpandingArray * options)
+FileManager::createSelect(char *action, textBuffer *output, ExpandingArray *options)
 {
   const char formOpen[] = "<form method=POST action=\"/configure/snap_action.html\">\n<select name=snap>\n";
   const char formEnd[] = "</form>";
@@ -763,7 +716,6 @@ FileManager::createSelect(char *action, textBuffer * output, ExpandingArray * op
   }
 }
 
-
 // bool checkValidName(const char* name)
 //
 // if the string is invalid, ie. all white spaces or contains "irregular" chars,
@@ -776,15 +728,14 @@ FileManager::checkValidName(const char *name)
 
   for (int i = 0; i < length; i++) {
     if (!isprint(name[i]))
-      return false;             // invalid - unprintable char
+      return false; // invalid - unprintable char
     if (!isspace(name[i]))
-      return true;              // has non-white space that is printable
+      return true; // has non-white space that is printable
   }
 
-  return false;                 // all white spaces
+  return false; // all white spaces
 }
 
-
 //  int snapEntryCmpFunc(void* e1, void* e2)
 //
 //  a cmp function for snapshot structs that can
@@ -795,8 +746,8 @@ FileManager::checkValidName(const char *name)
 int
 snapEntryCmpFunc(const void *e1, const void *e2)
 {
-  snapshot *entry1 = (snapshot *) * (void **) e1;
-  snapshot *entry2 = (snapshot *) * (void **) e2;
+  snapshot *entry1 = (snapshot *)*(void **)e1;
+  snapshot *entry2 = (snapshot *)*(void **)e2;
 
   if (entry1->c_time > entry2->c_time) {
     return 1;
