@@ -1,6 +1,6 @@
 /** @file
 
-  This file contains code for class to allow rollback of configuration files 
+  This file contains code for class to allow rollback of configuration files
 
   @section license License
 
@@ -31,30 +31,26 @@
 #include "MgmtSocket.h"
 #include "ink_cap.h"
 #include "I_Layout.h"
+#include "FileManager.h"
 
 #define MAX_VERSION_DIGITS 11
 #define DEFAULT_BACKUPS 2
 
 // Error Strings
-const char *RollbackStrings[] = { "Rollback Ok",
-  "File was not found",
-  "Version was out of date",
-  "System Call Error",
-  "Invalid Version - Version Numbers Must Increase"
-};
+const char *RollbackStrings[] = {"Rollback Ok", "File was not found", "Version was out of date", "System Call Error",
+                                 "Invalid Version - Version Numbers Must Increase"};
 
-Rollback::Rollback(const char *baseFileName, bool root_access_needed_)
-  : root_access_needed(root_access_needed_)
+Rollback::Rollback(const char *baseFileName, bool root_access_needed_) : configFiles(NULL), root_access_needed(root_access_needed_)
 {
-  version_t highestSeen;        // the highest backup version
-  ExpandingArray existVer(25, true);    // Exsisting versions
+  version_t highestSeen;             // the highest backup version
+  ExpandingArray existVer(25, true); // Exsisting versions
   struct stat fileInfo;
   MgmtInt numBak;
   char *alarmMsg;
 
   // To Test, Read/Write access to the file
-  int testFD;                   // For open test
-  int testErrno;                // For open test
+  int testFD;    // For open test
+  int testErrno; // For open test
 
   // In case the file is missing
   char *highestSeenStr;
@@ -65,22 +61,21 @@ Rollback::Rollback(const char *baseFileName, bool root_access_needed_)
 
   // Copy the file name
   fileNameLen = strlen(baseFileName);
-  fileName = new char[fileNameLen + 1];
+  fileName = (char *)ats_malloc(fileNameLen + 1);
   ink_strlcpy(fileName, baseFileName, fileNameLen + 1);
 
   // TODO: Use the runtime directory for storing mutable data
   // XXX: Sysconfdir should be imutable!!!
 
-  if (access(Layout::get()->sysconfdir, F_OK) < 0) {
-    mgmt_elog(0, "[Rollback::Rollback] unable to access() directory '%s': %d, %s\n",
-              Layout::get()->sysconfdir, errno, strerror(errno));
-    mgmt_elog(0, "[Rollback::Rollback] please set the 'TS_ROOT' environment variable\n");
-    _exit(1);
+  ats_scoped_str sysconfdir(RecConfigReadConfigDir());
+  if (access(sysconfdir, F_OK) < 0) {
+    mgmt_fatal(0, "[Rollback::Rollback] unable to access() directory '%s': %d, %s\n", (const char *)sysconfdir, errno,
+               strerror(errno));
   }
 
   if (varIntFromName("proxy.config.admin.number_config_bak", &numBak) == true) {
     if (numBak > 1) {
-      numberBackups = (int) numBak;
+      numberBackups = (int)numBak;
     } else {
       numberBackups = 1;
     }
@@ -90,7 +85,7 @@ Rollback::Rollback(const char *baseFileName, bool root_access_needed_)
 
   ink_mutex_init(&fileAccessLock, "RollBack Mutex");
 
-  currentVersion = 0;           // Prevent UMR with stat file
+  currentVersion = 0; // Prevent UMR with stat file
   highestSeen = findVersions_ml(versionQ);
 
   // Check to make sure that our configuratio file exists
@@ -100,7 +95,6 @@ Rollback::Rollback(const char *baseFileName, bool root_access_needed_)
   //    give up
   //
   if (statFile(ACTIVE_VERSION, &fileInfo) < 0) {
-
     // If we can't find an active version because there is not
     //   one, attempt to rollback to a previous verision if one exists
     //
@@ -114,20 +108,19 @@ Rollback::Rollback(const char *baseFileName, bool root_access_needed_)
         activeVerStr = createPathStr(ACTIVE_VERSION);
 
         if (rename(highestSeenStr, activeVerStr) < 0) {
-          mgmt_log(stderr, "[RollBack::Rollback] Automatic Rollback to prior version failed for %s : %s\n",
-                   fileName, strerror(errno));
+          mgmt_log(stderr, "[RollBack::Rollback] Automatic Rollback to prior version failed for %s : %s\n", fileName,
+                   strerror(errno));
           needZeroLength = true;
         } else {
-          mgmt_log(stderr, "[RollBack::Rollback] Automatic Rollback to version succeded for %s\n",
-                   fileName, strerror(errno));
+          mgmt_log(stderr, "[RollBack::Rollback] Automatic Rollback to version succeded for %s\n", fileName, strerror(errno));
           needZeroLength = false;
           highestSeen--;
           // Since we've made the highestVersion active
           //  remove it from the backup verision q
           versionQ.remove(versionQ.tail);
         }
-        delete[]highestSeenStr;
-        delete[]activeVerStr;
+        ats_free(highestSeenStr);
+        ats_free(activeVerStr);
       } else {
         needZeroLength = true;
       }
@@ -153,11 +146,10 @@ Rollback::Rollback(const char *baseFileName, bool root_access_needed_)
     } else {
       // If is there but we can not stat it, it is unusable to manager
       //   probably due to permissions problems.  Bail!
-      mgmt_fatal(stderr, 0, "[RollBack::Rollback] Unable to find configuration file %s.\n\tStat failed : %s\n",
-                 fileName, strerror(errno));
+      mgmt_fatal(stderr, 0, "[RollBack::Rollback] Unable to find configuration file %s.\n\tStat failed : %s\n", fileName,
+                 strerror(errno));
     }
   } else {
-
     fileLastModified = TS_ARCHIVE_STAT_MTIME(fileInfo);
     currentVersion = highestSeen + 1;
 
@@ -190,7 +182,6 @@ Rollback::Rollback(const char *baseFileName, bool root_access_needed_)
     testFD = openFile(ACTIVE_VERSION, O_RDONLY, &testErrno);
 
     if (testFD < 0) {
-
       // We are unable to either read or write the file
       snprintf(alarmMsg, 2048, "Unable to read or write config file");
       mgmt_log(stderr, "[Rollback::Rollback] %s %s: %s\n", alarmMsg, fileName, strerror(errno));
@@ -211,24 +202,22 @@ Rollback::Rollback(const char *baseFileName, bool root_access_needed_)
 
 Rollback::~Rollback()
 {
-  delete[]fileName;
+  ats_free(fileName);
 }
 
 
- // Rollback::createPathStr(version_t version)
+// Rollback::createPathStr(version_t version)
 //
 //   CALLEE DELETES STORAGE
 //
 char *
 Rollback::createPathStr(version_t version)
 {
+  ats_scoped_str sysconfdir(RecConfigReadConfigDir());
+  int bufSize = strlen(sysconfdir) + fileNameLen + MAX_VERSION_DIGITS + 1;
+  char *buffer = (char *)ats_malloc(bufSize);
 
-  char *buffer;
-  int bufSize = strlen(Layout::get()->sysconfdir) + fileNameLen + MAX_VERSION_DIGITS + 1;
-
-  buffer = new char[bufSize];
-
-  Layout::get()->relative_to(buffer, bufSize, Layout::get()->sysconfdir, fileName);
+  Layout::get()->relative_to(buffer, bufSize, sysconfdir, fileName);
 
   if (version != ACTIVE_VERSION) {
     size_t pos = strlen(buffer);
@@ -247,44 +236,17 @@ Rollback::createPathStr(version_t version)
 int
 Rollback::statFile(version_t version, struct stat *buf)
 {
-  char *filePath;
   int statResult;
-#if !TS_USE_POSIX_CAP
-  uid_t saved_euid = 0;
-#endif
 
   if (version == this->currentVersion) {
     version = ACTIVE_VERSION;
   }
-  filePath = createPathStr(version);
 
-  if (root_access_needed) {
-    if (
-#if TS_USE_POSIX_CAP
-      elevateFileAccess(true)
-#else
-      restoreRootPriv(&saved_euid)
-#endif
-	!= true) {
-      mgmt_log(stderr, "[Rollback] Unable to acquire root privileges.\n");
-    }
-  }
+  ats_scoped_str filePath(createPathStr(version));
+  ElevateAccess access(root_access_needed);
 
   statResult = stat(filePath, buf);
 
-  if (root_access_needed) {
-    if (
-#if TS_USE_POSIX_CAP
-      elevateFileAccess(false)
-#else
-      removeRootPriv(saved_euid)
-#endif
-      != true) {
-      mgmt_log(stderr, "[Rollback] Unable to restore non-root privileges.\n");
-    }
-  }
-
-  delete[]filePath;
   return statResult;
 }
 
@@ -296,54 +258,25 @@ Rollback::statFile(version_t version, struct stat *buf)
 int
 Rollback::openFile(version_t version, int oflags, int *errnoPtr)
 {
-  char *filePath;
   int fd;
-#if !TS_USE_POSIX_CAP
-  uid_t saved_euid = 0;
-#endif
 
-  filePath = createPathStr(version);
-
-  if (root_access_needed) {
-    if (
-#if TS_USE_POSIX_CAP
-      elevateFileAccess(true)
-#else
-      restoreRootPriv(&saved_euid)
-#endif
-      != true) {
-      mgmt_log(stderr, "[Rollback] Unable to acquire root privileges.\n");
-    }
-  }
+  ats_scoped_str filePath(createPathStr(version));
+  ElevateAccess access(root_access_needed);
 
   // TODO: Use the original permissions
   //       Anyhow the _1 files should not be created inside Syconfdir.
   //
   fd = mgmt_open_mode(filePath, oflags, 0644);
-  if (root_access_needed) {
-    if (
-#if TS_USE_POSIX_CAP
-      elevateFileAccess(false)
-#else
-      removeRootPriv(saved_euid)
-#endif
-      != true) {
-      mgmt_log(stderr, "[Rollback] Unable to restore non-root privileges.\n");
-    }
-  }
 
   if (fd < 0) {
     if (errnoPtr != NULL) {
       *errnoPtr = errno;
     }
     mgmt_log(stderr, "[Rollback::openFile] Open of %s failed: %s\n", fileName, strerror(errno));
-  }
-  else {
+  } else {
     fcntl(fd, F_SETFD, 1);
   }
 
-  delete[]filePath;
-
   return fd;
 }
 
@@ -358,8 +291,7 @@ Rollback::closeFile(int fd, bool callSync)
 
   if (result == 0) {
     result = close(fd);
-  }
-  else {
+  } else {
     close(fd);
   }
   return result;
@@ -367,7 +299,7 @@ Rollback::closeFile(int fd, bool callSync)
 
 
 RollBackCodes
-Rollback::updateVersion(textBuffer * buf, version_t basedOn, version_t newVersion, bool notifyChange, bool incVersion)
+Rollback::updateVersion(textBuffer *buf, version_t basedOn, version_t newVersion, bool notifyChange, bool incVersion)
 {
   RollBackCodes returnCode;
 
@@ -379,9 +311,8 @@ Rollback::updateVersion(textBuffer * buf, version_t basedOn, version_t newVersio
 }
 
 RollBackCodes
-Rollback::updateVersion_ml(textBuffer * buf, version_t basedOn, version_t newVersion, bool notifyChange, bool incVersion)
+Rollback::updateVersion_ml(textBuffer *buf, version_t basedOn, version_t newVersion, bool notifyChange, bool incVersion)
 {
-
   RollBackCodes returnCode;
 
   if (basedOn != currentVersion) {
@@ -395,9 +326,8 @@ Rollback::updateVersion_ml(textBuffer * buf, version_t basedOn, version_t newVer
 
 
 RollBackCodes
-Rollback::forceUpdate(textBuffer * buf, version_t newVersion)
+Rollback::forceUpdate(textBuffer *buf, version_t newVersion)
 {
-
   RollBackCodes r;
 
   ink_mutex_acquire(&fileAccessLock);
@@ -408,7 +338,7 @@ Rollback::forceUpdate(textBuffer * buf, version_t newVersion)
 }
 
 RollBackCodes
-Rollback::forceUpdate_ml(textBuffer * buf, version_t newVersion)
+Rollback::forceUpdate_ml(textBuffer *buf, version_t newVersion)
 {
   return this->internalUpdate(buf, newVersion);
 }
@@ -418,13 +348,13 @@ Rollback::forceUpdate_ml(textBuffer * buf, version_t newVersion)
 //  Creates a version from buf.  Callee must be holding the lock
 //
 RollBackCodes
-Rollback::internalUpdate(textBuffer * buf, version_t newVersion, bool notifyChange, bool incVersion)
+Rollback::internalUpdate(textBuffer *buf, version_t newVersion, bool notifyChange, bool incVersion)
 {
   RollBackCodes returnCode;
   char *activeVersion;
   char *currentVersion_local;
   char *nextVersion;
-  int writeBytes;
+  ssize_t writeBytes;
   int diskFD;
   int ret;
   versionInfo *toRemove;
@@ -439,7 +369,7 @@ Rollback::internalUpdate(textBuffer * buf, version_t newVersion, bool notifyChan
   if (newVersion < 0) {
     newVersion = this->currentVersion + 1;
     if (incVersion) {
-      incVersion = false;  //because the version already increment
+      incVersion = false; // because the version already increment
     }
   } else {
     // We need to make sure that the specified version is valid
@@ -450,9 +380,8 @@ Rollback::internalUpdate(textBuffer * buf, version_t newVersion, bool notifyChan
     }
   }
 
-  Debug("rollback",
-        "[Rollback::internalUpdate] Moving %s from version %d to version %d\n",
-        this->fileName, this->currentVersion, newVersion);
+  Debug("rollback", "[Rollback::internalUpdate] Moving %s from version %d to version %d\n", this->fileName, this->currentVersion,
+        newVersion);
 
   currentVersion_local = createPathStr(this->currentVersion);
   activeVersion = createPathStr(ACTIVE_VERSION);
@@ -471,7 +400,7 @@ Rollback::internalUpdate(textBuffer * buf, version_t newVersion, bool notifyChan
   // Write the buffer into the new configuration file
   writeBytes = write(diskFD, buf->bufPtr(), buf->spaceUsed());
   ret = closeFile(diskFD, true);
-  if ((ret < 0) || (writeBytes != buf->spaceUsed())) {
+  if ((ret < 0) || ((size_t)writeBytes != buf->spaceUsed())) {
     mgmt_log(stderr, "[Rollback::internalUpdate] Unable to write new version of %s : %s\n", fileName, strerror(errno));
     returnCode = SYS_CALL_ERROR_ROLLBACK;
     goto UPDATE_CLEANUP;
@@ -485,8 +414,7 @@ Rollback::internalUpdate(textBuffer * buf, version_t newVersion, bool notifyChan
     //    install a new file so that we do not go around in
     //    an endless loop
     if (errno == ENOENT) {
-      mgmt_log(stderr,
-               "[Rollback::internalUpdate] The active version of %s was lost.\n\tThe updated copy was installed.\n",
+      mgmt_log(stderr, "[Rollback::internalUpdate] The active version of %s was lost.\n\tThe updated copy was installed.\n",
                fileName);
       failedLink = true;
     } else {
@@ -535,7 +463,7 @@ Rollback::internalUpdate(textBuffer * buf, version_t newVersion, bool notifyChan
   returnCode = OK_ROLLBACK;
 
   // Post the change to the config file manager
-  if (notifyChange) {
+  if (notifyChange && configFiles) {
     configFiles->fileChanged(fileName, incVersion);
   }
 
@@ -557,18 +485,17 @@ UPDATE_CLEANUP:
     unlink(nextVersion);
   }
 
-  delete[]currentVersion_local;
-  delete[]activeVersion;
-  delete[]nextVersion;
+  ats_free(currentVersion_local);
+  ats_free(activeVersion);
+  ats_free(nextVersion);
+
   return returnCode;
 }
 
 
-
 RollBackCodes
-Rollback::getVersion(version_t version, textBuffer ** buffer)
+Rollback::getVersion(version_t version, textBuffer **buffer)
 {
-
   RollBackCodes r;
 
   this->acquireLock();
@@ -580,14 +507,13 @@ Rollback::getVersion(version_t version, textBuffer ** buffer)
 
 // CALLEE DELETES STORAGE
 RollBackCodes
-Rollback::getVersion_ml(version_t version, textBuffer ** buffer)
+Rollback::getVersion_ml(version_t version, textBuffer **buffer)
 {
-
-  int diskFD;                   // file descriptor for version of the file we are fetching
-  RollBackCodes returnCode;     // our eventual return value
-  struct stat fileInfo;         // Info from fstat
-  int readResult;               // return val of (indirect) read calls
-  textBuffer *newBuffer;        // return buffer
+  int diskFD;               // file descriptor for version of the file we are fetching
+  RollBackCodes returnCode; // our eventual return value
+  struct stat fileInfo;     // Info from fstat
+  int readResult;           // return val of (indirect) read calls
+  textBuffer *newBuffer;    // return buffer
 
   *buffer = NULL;
 
@@ -610,7 +536,6 @@ Rollback::getVersion_ml(version_t version, textBuffer ** buffer)
   newBuffer = new textBuffer(fileInfo.st_size + 1);
 
   do {
-
     readResult = newBuffer->readFromFD(diskFD);
 
     if (readResult < 0) {
@@ -621,9 +546,8 @@ Rollback::getVersion_ml(version_t version, textBuffer ** buffer)
     }
   } while (readResult > 0);
 
-  if (newBuffer->spaceUsed() != fileInfo.st_size) {
-    mgmt_log(stderr,
-             "[Rollback::getVersion] Incorrect amount of data retrieved from %s version %d.  Expected: %d   Got: %d\n",
+  if ((off_t)newBuffer->spaceUsed() != fileInfo.st_size) {
+    mgmt_log(stderr, "[Rollback::getVersion] Incorrect amount of data retrieved from %s version %d.  Expected: %d   Got: %d\n",
              fileName, version, fileInfo.st_size, newBuffer->spaceUsed());
     returnCode = SYS_CALL_ERROR_ROLLBACK;
     delete newBuffer;
@@ -646,7 +570,6 @@ GET_CLEANUP:
 RollBackCodes
 Rollback::revertToVersion(version_t version)
 {
-
   RollBackCodes r;
 
   ink_mutex_acquire(&fileAccessLock);
@@ -667,7 +590,6 @@ Rollback::revertToVersion(version_t version)
 RollBackCodes
 Rollback::revertToVersion_ml(version_t version)
 {
-
   RollBackCodes returnCode;
   textBuffer *revertTo;
 
@@ -687,9 +609,8 @@ Rollback::revertToVersion_ml(version_t version)
 }
 
 version_t
-Rollback::findVersions(ExpandingArray * listNames)
+Rollback::findVersions(ExpandingArray *listNames)
 {
-
   version_t result;
 
   ink_mutex_acquire(&fileAccessLock);
@@ -706,42 +627,39 @@ Rollback::findVersions(ExpandingArray * listNames)
 //   file were found, zero is returned
 //
 version_t
-Rollback::findVersions_ml(ExpandingArray * listNames)
+Rollback::findVersions_ml(ExpandingArray *listNames)
 {
-
   int count = 0;
   version_t highestSeen = 0, version = 0;
+  ats_scoped_str sysconfdir(RecConfigReadConfigDir());
 
   DIR *dir;
   struct dirent *dirEntrySpace;
   struct dirent *entryPtr;
 
-  dir = opendir(Layout::get()->sysconfdir);
+  dir = opendir(sysconfdir);
 
   if (dir == NULL) {
-    mgmt_log(stderr, "[Rollback::findVersions] Unable to open configuration directory: %s: %s\n",
-             Layout::get()->sysconfdir, strerror(errno));
+    mgmt_log(stderr, "[Rollback::findVersions] Unable to open configuration directory: %s: %s\n", (const char *)sysconfdir,
+             strerror(errno));
     return INVALID_VERSION;
   }
   // The fun of Solaris - readdir_r requires a buffer passed into it
   //   The man page says this obscene expression gives us the proper
   //     size
-  dirEntrySpace = (struct dirent *)ats_malloc(sizeof(struct dirent) + pathconf(".", _PC_NAME_MAX) + 1);
+  dirEntrySpace = (struct dirent *)ats_malloc(sizeof(struct dirent) + ink_file_namemax(".") + 1);
 
   while (readdir_r(dir, dirEntrySpace, &entryPtr) == 0) {
     if (!entryPtr)
       break;
 
-    if ((version = extractVersionInfo(listNames, entryPtr->d_name))
-        != INVALID_VERSION) {
+    if ((version = extractVersionInfo(listNames, entryPtr->d_name)) != INVALID_VERSION) {
       count++;
 
       if (version > highestSeen) {
         highestSeen = version;
       }
-
     }
-
   }
 
   ats_free(dirEntrySpace);
@@ -760,7 +678,7 @@ Rollback::findVersions_ml(ExpandingArray * listNames)
 //     if there is no match.
 //
 version_t
-Rollback::extractVersionInfo(ExpandingArray * listNames, const char *testFileName)
+Rollback::extractVersionInfo(ExpandingArray *listNames, const char *testFileName)
 {
   const char *currentVersionStr, *str;
   version_t version = INVALID_VERSION;
@@ -772,18 +690,17 @@ Rollback::extractVersionInfo(ExpandingArray * listNames, const char *testFileNam
   //  is the same as our fileName
   if (strlen(testFileName) > fileNameLen) {
     if (strncmp(testFileName, fileName, fileNameLen) == 0) {
-
       // Check for the underscore
       if (*(testFileName + fileNameLen) == '_') {
         // Check for the integer version number
         currentVersionStr = str = testFileName + fileNameLen + 1;
 
-        for (; isdigit(*str) && *str != '\0'; str++);
+        for (; isdigit(*str) && *str != '\0'; str++)
+          ;
 
         // Do not tolerate anything but numbers on the end
         //   of the file
         if (*str == '\0') {
-
           version = atoi(currentVersionStr);
 
           // Add info about version number and modTime
@@ -795,7 +712,7 @@ Rollback::extractVersionInfo(ExpandingArray * listNames, const char *testFileNam
               verInfo = (versionInfo *)ats_malloc(sizeof(versionInfo));
               verInfo->version = version;
               verInfo->modTime = fileInfo.st_mtime;
-              listNames->addEntry((void *) verInfo);
+              listNames->addEntry((void *)verInfo);
             }
           }
         }
@@ -829,7 +746,7 @@ Rollback::findVersions_ml(Queue<versionInfo> &q)
 
   // Add the entries on to our passed in q
   for (int i = 0; i < num; i++) {
-    foundVer = (versionInfo *) versions[i];
+    foundVer = (versionInfo *)versions[i];
     //  We need to create our own copy so that
     //   constructor gets run
     addInfo = new versionInfo;
@@ -857,7 +774,6 @@ Rollback::removeVersion(version_t version)
 RollBackCodes
 Rollback::removeVersion_ml(version_t version)
 {
-
   struct stat statInfo;
   char *versionPath;
   versionInfo *removeInfo = NULL;
@@ -870,9 +786,8 @@ Rollback::removeVersion_ml(version_t version)
 
   versionPath = createPathStr(version);
   if (unlink(versionPath) < 0) {
-    delete[]versionPath;
-    mgmt_log(stderr, "[Rollback::removeVersion] Unlink failed on %s version %d: %s\n",
-             fileName, version, strerror(errno));
+    ats_free(versionPath);
+    mgmt_log(stderr, "[Rollback::removeVersion] Unlink failed on %s version %d: %s\n", fileName, version, strerror(errno));
     return SYS_CALL_ERROR_ROLLBACK;
   }
   // Take the version we just removed off of the backup queue
@@ -894,7 +809,7 @@ Rollback::removeVersion_ml(version_t version)
 
   numVersions--;
 
-  delete[]versionPath;
+  ats_free(versionPath);
   return OK_ROLLBACK;
 }
 
@@ -913,7 +828,6 @@ Rollback::versionTimeStamp(version_t version)
 time_t
 Rollback::versionTimeStamp_ml(version_t version)
 {
-
   struct stat buf;
 
   if (this->statFile(version, &buf) < 0) {
@@ -968,9 +882,8 @@ Rollback::setLastModifiedTime()
 //    of creating a new timestamp
 //
 bool
-Rollback::checkForUserUpdate()
+Rollback::checkForUserUpdate(RollBackCheckType how)
 {
-
   struct stat fileInfo;
   bool result;
 
@@ -987,20 +900,20 @@ Rollback::checkForUserUpdate()
   }
 
   if (fileLastModified < TS_ARCHIVE_STAT_MTIME(fileInfo)) {
+    if (how == ROLLBACK_CHECK_AND_UPDATE) {
+      // We've been modified, Roll a new version
+      currentVersion_local = this->getCurrentVersion();
+      r = this->getVersion_ml(currentVersion_local, &buf);
+      if (r == OK_ROLLBACK) {
+        r = this->updateVersion_ml(buf, currentVersion_local);
+        delete buf;
+      }
+      if (r != OK_ROLLBACK) {
+        mgmt_log(stderr, "[Rollback::checkForUserUpdate] Failed to roll changed user file %s: %s", fileName, RollbackStrings[r]);
+      }
 
-    // We've been modified, Roll a new version
-    currentVersion_local = this->getCurrentVersion();
-    r = this->getVersion_ml(currentVersion_local, &buf);
-    if (r == OK_ROLLBACK) {
-      r = this->updateVersion_ml(buf, currentVersion_local);
-      delete buf;
+      mgmt_log(stderr, "User has changed config file %s\n", fileName);
     }
-    if (r != OK_ROLLBACK) {
-      mgmt_log(stderr, "[Rollback::checkForUserUpdate] Failed to roll changed user file %s: %s",
-               fileName, RollbackStrings[r]);
-    }
-
-    mgmt_log(stderr, "User has changed config file %s\n", fileName);
 
     result = true;
   } else {
@@ -1018,8 +931,8 @@ Rollback::checkForUserUpdate()
 int
 versionCmp(const void *i1, const void *i2)
 {
-  versionInfo *v1 = (versionInfo *) * (void **) i1;
-  versionInfo *v2 = (versionInfo *) * (void **) i2;
+  versionInfo *v1 = (versionInfo *)*(void **)i1;
+  versionInfo *v2 = (versionInfo *)*(void **)i2;
 
   if ((v1->version) < v2->version) {
     return -1;
