@@ -29,10 +29,10 @@
  *
  ***************************************************************************/
 
-#include "ink_platform.h"
-#include "Main.h"
+#include "libts.h"
 #include "MgmtUtils.h"
 #include "LocalManager.h"
+#include "ClusterCom.h"
 #include "FileManager.h"
 #include "Rollback.h"
 #include "WebMgmtUtils.h"
@@ -46,12 +46,13 @@
 #include "CfgContextUtils.h"
 #include "EventCallback.h"
 #include "I_Layout.h"
-
-extern int diags_init;          // from Main.cc
+#include "ink_cap.h"
 
 // global variable
 CallbackTable *local_event_callbacks;
 
+extern FileManager *configFiles; // global in traffic_manager
+
 /*-------------------------------------------------------------------------
  * Init
  *-------------------------------------------------------------------------
@@ -87,14 +88,13 @@ Terminate()
   return TS_ERR_OKAY;
 }
 
-
 /*-------------------------------------------------------------------------
  * Diags
  *-------------------------------------------------------------------------
  * Uses the Traffic Manager diags object to display the diags output.
  */
 void
-Diags(TSDiagsT mode, const char *fmt, va_list ap)
+DiagnosticMessage(TSDiagsT mode, const char *fmt, va_list ap)
 {
   // Mapping TSDiagsT to Diags.h:DiagsLevel
   // Simple casting would work, but not inflexible
@@ -131,13 +131,12 @@ Diags(TSDiagsT mode, const char *fmt, va_list ap)
     level = DL_Diag;
   }
 
-  if (diags_init) {             // check that diags is initialized
+  if (diags) { // check that diags is initialized
     diags->print_va("TSMgmtAPI", level, NULL, fmt, ap);
     va_end(ap);
   }
 }
 
-
 /***************************************************************************
  * Control Operations
  ***************************************************************************/
@@ -176,20 +175,20 @@ ProxyStateSet(TSProxyStateT state, TSCacheClearT clear)
 
   switch (state) {
   case TS_PROXY_OFF:
-    if (!ProxyShutdown())       // from WebMgmtUtils
-      goto Lerror;              // unsuccessful shutdown
+    if (!ProxyShutdown()) // from WebMgmtUtils
+      goto Lerror;        // unsuccessful shutdown
     break;
   case TS_PROXY_ON:
-    if (lmgmt->processRunning())        // already on
+    if (lmgmt->processRunning()) // already on
       break;
 
     // taken from mgmt/Main.cc when check the -tsArgs option
     // Update cmd line overrides/environmental overrides/etc
     switch (clear) {
-    case TS_CACHE_CLEAR_ON:   // traffic_server -K
+    case TS_CACHE_CLEAR_ON: // traffic_server -K
       snprintf(tsArgs, sizeof(tsArgs), "-K -M");
       break;
-    case TS_CACHE_CLEAR_HOSTDB:       // traffic_server -k
+    case TS_CACHE_CLEAR_HOSTDB: // traffic_server -k
       snprintf(tsArgs, sizeof(tsArgs), "-k -M");
       break;
     case TS_CACHE_CLEAR_OFF:
@@ -204,7 +203,7 @@ ProxyStateSet(TSProxyStateT state, TSCacheClearT clear)
       break;
     }
 
-    if (strlen(tsArgs) > 0) {   /* Passed command line args for proxy */
+    if (strlen(tsArgs) > 0) { /* Passed command line args for proxy */
       ats_free(lmgmt->proxy_options);
       lmgmt->proxy_options = ats_strdup(tsArgs);
       mgmt_log("[ProxyStateSet] Traffic Server Args: '%s'\n", lmgmt->proxy_options);
@@ -225,9 +224,185 @@ ProxyStateSet(TSProxyStateT state, TSCacheClearT clear)
   return TS_ERR_OKAY;
 
 Lerror:
-  return TS_ERR_FAIL;          /* failed to set proxy  state */
+  return TS_ERR_FAIL; /* failed to set proxy  state */
 }
 
+#if TS_USE_REMOTE_UNWINDING
+
+#include <libunwind.h>
+#include <libunwind-ptrace.h>
+#include <sys/ptrace.h>
+#include <cxxabi.h>
+
+typedef Vec<pid_t> threadlist;
+
+static threadlist
+threads_for_process(pid_t proc)
+{
+  DIR *dir = NULL;
+  struct dirent *entry = NULL;
+
+  char path[64];
+  threadlist threads;
+
+  if (snprintf(path, sizeof(path), "/proc/%ld/task", (long)proc) >= (int)sizeof(path)) {
+    goto done;
+  }
+
+  dir = opendir(path);
+  if (dir == NULL) {
+    goto done;
+  }
+
+  while ((entry = readdir(dir))) {
+    pid_t threadid;
+
+    if (isdot(entry->d_name) || isdotdot(entry->d_name)) {
+      continue;
+    }
+
+    threadid = strtol(entry->d_name, NULL, 10);
+    if (threadid > 0) {
+      threads.push_back(threadid);
+      Debug("backtrace", "found thread %ld", (long)threadid);
+    }
+  }
+
+
+done:
+  if (dir) {
+    closedir(dir);
+  }
+
+  return threads;
+}
+
+static void
+backtrace_for_thread(pid_t threadid, textBuffer &text)
+{
+  int status;
+  unw_addr_space_t addr_space = NULL;
+  unw_cursor_t cursor;
+  void *ap = NULL;
+  pid_t target = -1;
+  unsigned level = 0;
+
+  // First, attach to the child, causing it to stop.
+  status = ptrace(PTRACE_ATTACH, threadid, 0, 0);
+  if (status < 0) {
+    Debug("backtrace", "ptrace(ATTACH, %ld) -> %s (%d)", (long)threadid, strerror(errno), errno);
+    return;
+  }
+
+  // Wait for it to stop (XXX should be a timed wait ...)
+  target = waitpid(threadid, &status, __WALL | WUNTRACED);
+  Debug("backtrace", "waited for target %ld, found PID %ld, %s", (long)threadid, (long)target,
+        WIFSTOPPED(status) ? "STOPPED" : "???");
+  if (target < 0) {
+    goto done;
+  }
+
+  ap = _UPT_create(threadid);
+  Debug("backtrace", "created UPT %p", ap);
+  if (ap == NULL) {
+    goto done;
+  }
+
+  addr_space = unw_create_addr_space(&_UPT_accessors, 0 /* byteorder */);
+  Debug("backtrace", "created address space %p", addr_space);
+  if (addr_space == NULL) {
+    goto done;
+  }
+
+  status = unw_init_remote(&cursor, addr_space, ap);
+  Debug("backtrace", "unw_init_remote(...) -> %d", status);
+  if (status != 0) {
+    goto done;
+  }
+
+  while (unw_step(&cursor) > 0) {
+    unw_word_t ip;
+    unw_word_t offset;
+    char buf[256];
+
+    unw_get_reg(&cursor, UNW_REG_IP, &ip);
+
+    if (unw_get_proc_name(&cursor, buf, sizeof(buf), &offset) == 0) {
+      int status;
+      char *name = abi::__cxa_demangle(buf, NULL, NULL, &status);
+      text.format("%-4u 0x%016llx %s + %p\n", level, (unsigned long long)ip, name ? name : buf, (void *)offset);
+      free(name);
+    } else {
+      text.format("%-4u 0x%016llx 0x0 + %p\n", level, (unsigned long long)ip, (void *)offset);
+    }
+
+    ++level;
+  }
+
+done:
+  if (addr_space) {
+    unw_destroy_addr_space(addr_space);
+  }
+
+  if (ap) {
+    _UPT_destroy(ap);
+  }
+
+  status = ptrace(PTRACE_DETACH, target, NULL, NULL);
+  Debug("backtrace", "ptrace(DETACH, %ld) -> %d (errno %d)", (long)target, status, errno);
+}
+
+TSMgmtError
+ServerBacktrace(unsigned /* options */, char **trace)
+{
+  *trace = NULL;
+
+  // Unfortunately, we need to be privileged here. We either need to be root or to be holding
+  // the CAP_SYS_PTRACE capability. Even though we are the parent traffic_manager, it is not
+  // traceable without privilege because the process credentials do not match.
+  ElevateAccess access(true, ElevateAccess::TRACE_PRIVILEGE);
+  threadlist threads(threads_for_process(lmgmt->watched_process_pid));
+  textBuffer text(0);
+
+  Debug("backtrace", "tracing %zd threads for traffic_server PID %ld", threads.count(), (long)lmgmt->watched_process_pid);
+  for_Vec(pid_t, threadid, threads)
+  {
+    Debug("backtrace", "tracing thread %ld", (long)threadid);
+    // Get the thread name using /proc/PID/comm
+    ats_scoped_fd fd;
+    char threadname[128];
+
+    snprintf(threadname, sizeof(threadname), "/proc/%ld/comm", (long)threadid);
+    fd = open(threadname, O_RDONLY);
+    if (fd >= 0) {
+      text.format("Thread %ld, ", (long)threadid);
+      text.readFromFD(fd);
+      text.chomp();
+    } else {
+      text.format("Thread %ld", (long)threadid);
+    }
+
+    text.format(":\n");
+
+    backtrace_for_thread(threadid, text);
+    text.format("\n");
+  }
+
+  *trace = text.release();
+  return TS_ERR_OKAY;
+}
+
+#else /* TS_USE_REMOTE_UNWINDING */
+
+TSMgmtError
+ServerBacktrace(unsigned /* options */, char **trace)
+{
+  *trace = NULL;
+  return TS_ERR_NOT_SUPPORTED;
+}
+
+#endif
+
 /*-------------------------------------------------------------------------
  * Reconfigure
  *-------------------------------------------------------------------------
@@ -236,8 +411,10 @@ Lerror:
 TSMgmtError
 Reconfigure()
 {
-  configFiles->rereadConfig();  // TM rereads
-  lmgmt->signalEvent(MGMT_EVENT_PLUGIN_CONFIG_UPDATE, "*");     // TS rereads
+  configFiles->rereadConfig();                              // TM rereads
+  lmgmt->signalEvent(MGMT_EVENT_PLUGIN_CONFIG_UPDATE, "*"); // TS rereads
+  RecSetRecordInt("proxy.node.config.reconfigure_time", time(NULL));
+  RecSetRecordInt("proxy.node.config.reconfigure_required", 0);
 
   return TS_ERR_OKAY;
 }
@@ -249,13 +426,14 @@ Reconfigure()
  * restart Traffic Manager!!
  */
 TSMgmtError
-Restart(bool cluster)
+Restart(unsigned options)
 {
-  if (cluster) {                // Enqueue an event to restart the proxies across the cluster
+  if (options & TS_RESTART_OPT_CLUSTER) {
+    // Enqueue an event to restart the proxies across the cluster
     // this will kill TM completely;traffic_cop will restart TM/TS
     lmgmt->ccom->sendClusterMessage(CLUSTER_MSG_SHUTDOWN_MANAGER);
-  } else {                      // just bounce local proxy
-    lmgmt->mgmtShutdown();
+  } else {
+    lmgmt->mgmt_shutdown_outstanding = (options & TS_RESTART_OPT_DRAIN) ? MGMT_PENDING_IDLE_RESTART : MGMT_PENDING_RESTART;
   }
 
   return TS_ERR_OKAY;
@@ -267,12 +445,12 @@ Restart(bool cluster)
  * Bounces traffic_server process(es).
  */
 TSMgmtError
-Bounce(bool cluster)
+Bounce(unsigned options)
 {
-  if (cluster) {
+  if (options & TS_RESTART_OPT_CLUSTER) {
     lmgmt->ccom->sendClusterMessage(CLUSTER_MSG_BOUNCE_PROCESS);
   } else {
-    lmgmt->processBounce();
+    lmgmt->mgmt_shutdown_outstanding = (options & TS_RESTART_OPT_DRAIN) ? MGMT_PENDING_IDLE_BOUNCE : MGMT_PENDING_BOUNCE;
   }
 
   return TS_ERR_OKAY;
@@ -287,7 +465,7 @@ Bounce(bool cluster)
  * this source or CoreAPIRemote.cc yields the same set of symbols).
  */
 TSMgmtError
-StorageDeviceCmdOffline(char const* dev)
+StorageDeviceCmdOffline(const char *dev)
 {
   lmgmt->signalEvent(MGMT_EVENT_STORAGE_DEVICE_CMD_OFFLINE, dev);
   return TS_ERR_OKAY;
@@ -302,7 +480,7 @@ StorageDeviceCmdOffline(char const* dev)
  * The record info associated with rec_name will be returned in rec_ele.
  */
 TSMgmtError
-MgmtRecordGet(const char *rec_name, TSRecordEle * rec_ele)
+MgmtRecordGet(const char *rec_name, TSRecordEle *rec_ele)
 {
   RecDataT rec_type;
   char rec_val[MAX_BUF_SIZE];
@@ -323,19 +501,18 @@ MgmtRecordGet(const char *rec_name, TSRecordEle * rec_ele)
     rec_ele->rec_type = TS_REC_COUNTER;
     if (!varCounterFromName(rec_name, &(counter_val)))
       return TS_ERR_FAIL;
-    rec_ele->valueT.counter_val = (TSCounter) counter_val;
+    rec_ele->valueT.counter_val = (TSCounter)counter_val;
 
-    Debug("RecOp", "[MgmtRecordGet] Get Counter Var %s = %" PRId64"\n", rec_ele->rec_name,
-          rec_ele->valueT.counter_val);
+    Debug("RecOp", "[MgmtRecordGet] Get Counter Var %s = %" PRId64 "\n", rec_ele->rec_name, rec_ele->valueT.counter_val);
     break;
 
   case RECD_INT:
     rec_ele->rec_type = TS_REC_INT;
     if (!varIntFromName(rec_name, &(int_val)))
       return TS_ERR_FAIL;
-    rec_ele->valueT.int_val = (TSInt) int_val;
+    rec_ele->valueT.int_val = (TSInt)int_val;
 
-    Debug("RecOp", "[MgmtRecordGet] Get Int Var %s = %" PRId64"\n", rec_ele->rec_name, rec_ele->valueT.int_val);
+    Debug("RecOp", "[MgmtRecordGet] Get Int Var %s = %" PRId64 "\n", rec_ele->rec_name, rec_ele->valueT.int_val);
     break;
 
   case RECD_FLOAT:
@@ -350,8 +527,7 @@ MgmtRecordGet(const char *rec_name, TSRecordEle * rec_ele)
     if (!varStrFromName(rec_name, rec_val, MAX_BUF_SIZE))
       return TS_ERR_FAIL;
 
-
-    if (rec_val[0] != '\0') {   // non-NULL string value
+    if (rec_val[0] != '\0') { // non-NULL string value
       // allocate memory & duplicate string value
       str_val = ats_strdup(rec_val);
     } else {
@@ -363,7 +539,7 @@ MgmtRecordGet(const char *rec_name, TSRecordEle * rec_ele)
     Debug("RecOp", "[MgmtRecordGet] Get String Var %s = %s\n", rec_ele->rec_name, rec_ele->valueT.string_val);
     break;
 
-  default:                     // UNKOWN TYPE
+  default: // UNKOWN TYPE
     Debug("RecOp", "[MgmtRecordGet] Get Failed : %d is Unknown Var type %s\n", rec_type, rec_name);
     return TS_ERR_FAIL;
   }
@@ -381,6 +557,12 @@ MgmtRecordGetMatching(const char * /* regex */, TSList /* rec_vals */)
   return TS_ERR_FAIL;
 }
 
+TSMgmtError
+MgmtConfigRecordDescribe(const char * /* rec_name */, unsigned /* flags */, TSConfigRecordDescription * /* val */)
+{
+  return TS_ERR_NOT_SUPPORTED;
+}
+
 /*-------------------------------------------------------------------------
  * reads the RecordsConfig info to determine which type of action is needed
  * when the record rec_name is changed; if the rec_name is invalid,
@@ -395,26 +577,25 @@ determine_action_need(const char *rec_name)
     return TS_ACTION_UNDEFINED;
 
   switch (update_t) {
-  case RECU_NULL:                // default:don't know behaviour
+  case RECU_NULL: // default:don't know behaviour
     return TS_ACTION_UNDEFINED;
 
-  case RECU_DYNAMIC:             // update dynamically by rereading config files
+  case RECU_DYNAMIC: // update dynamically by rereading config files
     return TS_ACTION_RECONFIGURE;
 
-  case RECU_RESTART_TS:          // requires TS restart
+  case RECU_RESTART_TS: // requires TS restart
     return TS_ACTION_RESTART;
 
-  case RECU_RESTART_TM:          // requires TM/TS restart
+  case RECU_RESTART_TM: // requires TM/TS restart
     return TS_ACTION_RESTART;
 
-  default:                     // shouldn't get here actually
+  default: // shouldn't get here actually
     return TS_ACTION_UNDEFINED;
   }
 
-  return TS_ACTION_UNDEFINED;  // ERROR
+  return TS_ACTION_UNDEFINED; // ERROR
 }
 
-
 /*-------------------------------------------------------------------------
  * MgmtRecordSet
  *-------------------------------------------------------------------------
@@ -428,7 +609,7 @@ determine_action_need(const char *rec_name)
  *   and false otherwise
  */
 TSMgmtError
-MgmtRecordSet(const char *rec_name, const char *val, TSActionNeedT * action_need)
+MgmtRecordSet(const char *rec_name, const char *val, TSActionNeedT *action_need)
 {
   Debug("RecOp", "[MgmtRecordSet] Start\n");
 
@@ -445,7 +626,6 @@ MgmtRecordSet(const char *rec_name, const char *val, TSActionNeedT * action_need
   return TS_ERR_FAIL;
 }
 
-
 /*-------------------------------------------------------------------------
  * MgmtRecordSetInt
  *-------------------------------------------------------------------------
@@ -454,7 +634,7 @@ MgmtRecordSet(const char *rec_name, const char *val, TSActionNeedT * action_need
  * Converts the integer value to a string and call MgmtRecordSet
  */
 TSMgmtError
-MgmtRecordSetInt(const char *rec_name, MgmtInt int_val, TSActionNeedT * action_need)
+MgmtRecordSetInt(const char *rec_name, MgmtInt int_val, TSActionNeedT *action_need)
 {
   if (!rec_name || !action_need)
     return TS_ERR_PARAMS;
@@ -468,14 +648,13 @@ MgmtRecordSetInt(const char *rec_name, MgmtInt int_val, TSActionNeedT * action_n
   return MgmtRecordSet(rec_name, str_val, action_need);
 }
 
-
 /*-------------------------------------------------------------------------
  * MgmtRecordSetCounter
  *-------------------------------------------------------------------------
  * converts the counter_val to a string and uses MgmtRecordSet
  */
 TSMgmtError
-MgmtRecordSetCounter(const char *rec_name, MgmtIntCounter counter_val, TSActionNeedT * action_need)
+MgmtRecordSetCounter(const char *rec_name, MgmtIntCounter counter_val, TSActionNeedT *action_need)
 {
   if (!rec_name || !action_need)
     return TS_ERR_PARAMS;
@@ -489,7 +668,6 @@ MgmtRecordSetCounter(const char *rec_name, MgmtIntCounter counter_val, TSActionN
   return MgmtRecordSet(rec_name, str_val, action_need);
 }
 
-
 /*-------------------------------------------------------------------------
  * MgmtRecordSetFloat
  *-------------------------------------------------------------------------
@@ -497,7 +675,7 @@ MgmtRecordSetCounter(const char *rec_name, MgmtIntCounter counter_val, TSActionN
  * and calls MgmtRecordSet
  */
 TSMgmtError
-MgmtRecordSetFloat(const char *rec_name, MgmtFloat float_val, TSActionNeedT * action_need)
+MgmtRecordSetFloat(const char *rec_name, MgmtFloat float_val, TSActionNeedT *action_need)
 {
   if (!rec_name || !action_need)
     return TS_ERR_PARAMS;
@@ -511,19 +689,17 @@ MgmtRecordSetFloat(const char *rec_name, MgmtFloat float_val, TSActionNeedT * ac
   return MgmtRecordSet(rec_name, str_val, action_need);
 }
 
-
 /*-------------------------------------------------------------------------
  * MgmtRecordSetString
  *-------------------------------------------------------------------------
  * The string value is copied so it's okay to free the string later
  */
 TSMgmtError
-MgmtRecordSetString(const char *rec_name, const char *string_val, TSActionNeedT * action_need)
+MgmtRecordSetString(const char *rec_name, const char *string_val, TSActionNeedT *action_need)
 {
   return MgmtRecordSet(rec_name, string_val, action_need);
 }
 
-
 /**************************************************************************
  * FILE OPERATIONS
  *************************************************************************/
@@ -550,7 +726,6 @@ ReadFile(TSFileNameT file, char **text, int *size, int *version)
 
   Debug("FileOp", "[get_lines_from_file] START\n");
 
-
   fname = filename_to_string(file);
   if (!fname)
     return TS_ERR_READ_FILE;
@@ -568,10 +743,10 @@ ReadFile(TSFileNameT file, char **text, int *size, int *version)
   old_file_lines = old_file_content->bufPtr();
   old_file_len = strlen(old_file_lines);
 
-  *text = ats_strdup(old_file_lines);      //make copy before deleting textBuffer
+  *text = ats_strdup(old_file_lines); // make copy before deleting textBuffer
   *size = old_file_len;
 
-  delete old_file_content;      // delete textBuffer
+  delete old_file_content; // delete textBuffer
 
   return TS_ERR_OKAY;
 }
@@ -589,7 +764,7 @@ ReadFile(TSFileNameT file, char **text, int *size, int *version)
  *                  version number above this one
  */
 TSMgmtError
-WriteFile(TSFileNameT file, char *text, int size, int version)
+WriteFile(TSFileNameT file, const char *text, int size, int version)
 {
   const char *fname;
   Rollback *file_rb;
@@ -597,7 +772,6 @@ WriteFile(TSFileNameT file, char *text, int size, int version)
   int ret;
   version_t ver;
 
-
   fname = filename_to_string(file);
   if (!fname)
     return TS_ERR_WRITE_FILE;
@@ -606,7 +780,7 @@ WriteFile(TSFileNameT file, char *text, int size, int version)
   mgmt_log(stderr, "[CfgFileIO::WriteFile] %s\n", fname);
   if (!(configFiles->getRollbackObj(fname, &file_rb))) {
     mgmt_log(stderr, "[CfgFileIO::WriteFile] ERROR getting rollback object\n");
-    //goto generate_error_msg;
+    // goto generate_error_msg;
   }
 
   // if version < 0 then, just use next version in sequence;
@@ -615,7 +789,7 @@ WriteFile(TSFileNameT file, char *text, int size, int version)
     // check that the current version is equal to or less than the version
     // that wants to be written
     ver = file_rb->getCurrentVersion();
-    if (ver != version)         // trying to commit an old version
+    if (ver != version) // trying to commit an old version
       return TS_ERR_WRITE_FILE;
   }
   // use rollback object to update file with new content
@@ -648,14 +822,14 @@ WriteFile(TSFileNameT file, char *text, int size, int version)
  * of alarms in the current alarm processor
  */
 TSMgmtError
-EventSignal(char * /* event_name ATS_UNUSED */, va_list /* ap ATS_UNUSED */)
+EventSignal(const char * /* event_name ATS_UNUSED */, va_list /* ap ATS_UNUSED */)
 {
-  //char *text;
-  //int id;
+  // char *text;
+  // int id;
 
-  //id = get_event_id(event_name);
-  //text = get_event_text(event_name);
-  //lmgmt->alarm_keeper->signalAlarm(id, text, NULL);
+  // id = get_event_id(event_name);
+  // text = get_event_text(event_name);
+  // lmgmt->alarm_keeper->signalAlarm(id, text, NULL);
 
   return TS_ERR_OKAY;
 }
@@ -668,7 +842,7 @@ EventSignal(char * /* event_name ATS_UNUSED */, va_list /* ap ATS_UNUSED */)
 
  */
 TSMgmtError
-EventResolve(char *event_name)
+EventResolve(const char *event_name)
 {
   alarm_t a;
 
@@ -689,7 +863,7 @@ EventResolve(char *event_name)
  * note: returns list of local alarms at that instant of fn call (snapshot)
  */
 TSMgmtError
-ActiveEventGetMlt(LLQ * active_events)
+ActiveEventGetMlt(LLQ *active_events)
 {
   InkHashTable *event_ht;
   InkHashTableEntry *entry;
@@ -706,16 +880,15 @@ ActiveEventGetMlt(LLQ * active_events)
   event_ht = lmgmt->alarm_keeper->getLocalAlarms();
 
   // iterate through hash-table and insert event_name's into active_events list
-  for (entry = ink_hash_table_iterator_first(event_ht, &iterator_state);
-       entry != NULL; entry = ink_hash_table_iterator_next(event_ht, &iterator_state)) {
-
-    char *key = (char *) ink_hash_table_entry_key(event_ht, entry);
+  for (entry = ink_hash_table_iterator_first(event_ht, &iterator_state); entry != NULL;
+       entry = ink_hash_table_iterator_next(event_ht, &iterator_state)) {
+    char *key = (char *)ink_hash_table_entry_key(event_ht, entry);
 
     // convert key to int; insert into llQ
     event_id = ink_atoi(key);
     event_name = get_event_name(event_id);
     if (event_name) {
-      if (!enqueue(active_events, event_name))  // returns true if successful
+      if (!enqueue(active_events, event_name)) // returns true if successful
         return TS_ERR_FAIL;
     }
   }
@@ -730,7 +903,7 @@ ActiveEventGetMlt(LLQ * active_events)
  * unresolved; otherwise sets *is_current to false.
  */
 TSMgmtError
-EventIsActive(char *event_name, bool * is_current)
+EventIsActive(const char *event_name, bool *is_current)
 {
   alarm_t a;
 
@@ -742,7 +915,7 @@ EventIsActive(char *event_name, bool * is_current)
   if (a < 0)
     return TS_ERR_PARAMS;
   if (lmgmt->alarm_keeper->isCurrentAlarm(a))
-    *is_current = true;         // currently an event
+    *is_current = true; // currently an event
   else
     *is_current = false;
 
@@ -761,10 +934,9 @@ EventIsActive(char *event_name, bool * is_current)
  * stored in the the hashtable, not in the TM alarm processor model
  */
 TSMgmtError
-EventSignalCbRegister(char *event_name, TSEventSignalFunc func, void *data)
+EventSignalCbRegister(const char *event_name, TSEventSignalFunc func, void *data)
 {
   return cb_table_register(local_event_callbacks, event_name, func, data, NULL);
-
 }
 
 /*-------------------------------------------------------------------------
@@ -773,7 +945,7 @@ EventSignalCbRegister(char *event_name, TSEventSignalFunc func, void *data)
  * Removes the callback function from the local side CallbackTable
  */
 TSMgmtError
-EventSignalCbUnregister(char *event_name, TSEventSignalFunc func)
+EventSignalCbUnregister(const char *event_name, TSEventSignalFunc func)
 {
   return cb_table_unregister(local_event_callbacks, event_name, func);
 }
@@ -782,25 +954,16 @@ EventSignalCbUnregister(char *event_name, TSEventSignalFunc func)
  * Snapshots
  ***************************************************************************/
 TSMgmtError
-SnapshotTake(char *snapshot_name)
+SnapshotTake(const char *snapshot_name)
 {
-  char *snapDirFromRecordsConf;
-  bool found;
-  char snapDir[PATH_NAME_MAX + 1];
+  ats_scoped_str snapdir;
 
   if (!snapshot_name)
     return TS_ERR_PARAMS;
 
-  int rec_err = RecGetRecordString_Xmalloc("proxy.config.snapshot_dir", &snapDirFromRecordsConf);
-  found = (rec_err == REC_ERR_OKAY);
-  ink_release_assert(found);
-  // XXX: Why was that offset to config dir?
-  //      Any path should be prefix relative thought
-  //
-  Layout::relative_to(snapDir, sizeof(snapDir), Layout::get()->sysconfdir, snapDirFromRecordsConf);
-  ats_free(snapDirFromRecordsConf);
+  snapdir = RecConfigReadSnapshotDir();
 
-  SnapResult result = configFiles->takeSnap(snapshot_name, snapDir);
+  SnapResult result = configFiles->takeSnap(snapshot_name, snapdir);
   if (result != SNAP_OK)
     return TS_ERR_FAIL;
   else
@@ -808,26 +971,16 @@ SnapshotTake(char *snapshot_name)
 }
 
 TSMgmtError
-SnapshotRestore(char *snapshot_name)
+SnapshotRestore(const char *snapshot_name)
 {
-  char *snapDirFromRecordsConf;
-  bool found;
-  char snapDir[PATH_NAME_MAX + 1];
+  ats_scoped_str snapdir;
 
   if (!snapshot_name)
     return TS_ERR_PARAMS;
 
-  int rec_err = RecGetRecordString_Xmalloc("proxy.config.snapshot_dir", &snapDirFromRecordsConf);
-  found = (rec_err == REC_ERR_OKAY);
-  ink_release_assert(found);
-  // XXX: Why was that offset to config dir?
-  //      Any path should be prefix relative thought
-  //
-  Layout::relative_to(snapDir, sizeof(snapDir), Layout::get()->sysconfdir, snapDirFromRecordsConf);
-  ats_free(snapDirFromRecordsConf);
+  snapdir = RecConfigReadSnapshotDir();
 
-  SnapResult result = configFiles->restoreSnap(snapshot_name, snapDir);
-  ats_free(snapDirFromRecordsConf);
+  SnapResult result = configFiles->restoreSnap(snapshot_name, snapdir);
   if (result != SNAP_OK)
     return TS_ERR_FAIL;
   else
@@ -835,26 +988,16 @@ SnapshotRestore(char *snapshot_name)
 }
 
 TSMgmtError
-SnapshotRemove(char *snapshot_name)
+SnapshotRemove(const char *snapshot_name)
 {
-  char *snapDirFromRecordsConf;
-  bool found;
-  char snapDir[PATH_NAME_MAX + 1];
+  ats_scoped_str snapdir;
 
   if (!snapshot_name)
     return TS_ERR_PARAMS;
 
-  int rec_err = RecGetRecordString_Xmalloc("proxy.config.snapshot_dir", &snapDirFromRecordsConf);
-  found = (rec_err == REC_ERR_OKAY);
-  ink_release_assert(found);
-  // XXX: Why was that offset to config dir?
-  //      Any path should be prefix relative thought
-  //
-  Layout::relative_to(snapDir, sizeof(snapDir), Layout::get()->sysconfdir, snapDirFromRecordsConf);
-  ats_free(snapDirFromRecordsConf);
+  snapdir = RecConfigReadSnapshotDir();
 
-  SnapResult result = configFiles->removeSnap(snapshot_name, snapDir);
-  ats_free(snapDirFromRecordsConf);
+  SnapResult result = configFiles->removeSnap(snapshot_name, snapdir);
   if (result != SNAP_OK)
     return TS_ERR_FAIL;
   else
@@ -863,7 +1006,7 @@ SnapshotRemove(char *snapshot_name)
 
 /* based on FileManager.cc::displaySnapOption() */
 TSMgmtError
-SnapshotGetMlt(LLQ * snapshots)
+SnapshotGetMlt(LLQ *snapshots)
 {
   ExpandingArray snap_list(25, true);
   SnapResult snap_result;
@@ -876,7 +1019,7 @@ SnapshotGetMlt(LLQ * snapshots)
 
   num_snaps = snap_list.getNumEntries();
   for (int i = 0; i < num_snaps; i++) {
-    snap_name = (char *) (snap_list[i]);
+    snap_name = (char *)(snap_list[i]);
     if (snap_name)
       enqueue(snapshots, ats_strdup(snap_name));
   }
