@@ -46,20 +46,12 @@
 #include "CoreAPIShared.h"
 #include "CfgContextUtils.h"
 #include "NetworkUtilsRemote.h"
-#include "NetworkUtilsDefs.h"
-#include "EventRegistration.h"
 #include "EventCallback.h"
-
-// extern variables
-extern CallbackTable *remote_event_callbacks;   // from EventRegistration
-extern int main_socket_fd;      // from NetworkUtils
-extern int event_socket_fd;
+#include "MgmtMarshall.h"
 
 // forward declarations
-TSMgmtError send_and_parse_basic(OpType op);
-TSMgmtError send_and_parse_list(OpType op, LLQ * list);
-TSMgmtError send_and_parse_name(OpType op, char *name);
-TSMgmtError mgmt_record_set(const char *rec_name, const char *rec_val, TSActionNeedT * action_need);
+static TSMgmtError send_and_parse_list(OpType op, LLQ *list);
+static TSMgmtError mgmt_record_set(const char *rec_name, const char *rec_val, TSActionNeedT *action_need);
 
 // global variables
 // need to store the thread id associated with socket_test_thread
@@ -71,25 +63,6 @@ TSInitOptionT ts_init_options;
 /***************************************************************************
  * Helper Functions
  ***************************************************************************/
-/*-------------------------------------------------------------------------
- * send_and_parse_basic (helper function)
- *-------------------------------------------------------------------------
- * helper function used by operations which only require sending a simple
- * operation type and parsing a simple error return value
- */
-TSMgmtError
-send_and_parse_basic(OpType op)
-{
-  TSMgmtError err;
-
-  err = send_request(main_socket_fd, op);
-  if (err != TS_ERR_OKAY)
-    return err;                 // networking error
-
-  err = parse_reply(main_socket_fd);
-
-  return err;
-}
 
 /*-------------------------------------------------------------------------
  * send_and_parse_list (helper function)
@@ -99,68 +72,60 @@ send_and_parse_basic(OpType op)
  * (delimited with REMOTE_DELIM_STR) and storing the tokens in the list
  * parameter
  */
-TSMgmtError
-send_and_parse_list(OpType op, LLQ * list)
+static TSMgmtError
+send_and_parse_list(OpType op, LLQ *list)
 {
   TSMgmtError ret;
-  char *list_str;
   const char *tok;
   Tokenizer tokens(REMOTE_DELIM_STR);
   tok_iter_state i_state;
 
-  if (!list)
+  MgmtMarshallInt optype = op;
+  MgmtMarshallInt err;
+  MgmtMarshallData reply = {NULL, 0};
+  MgmtMarshallString strval = NULL;
+
+  if (!list) {
     return TS_ERR_PARAMS;
+  }
 
   // create and send request
-  ret = send_request(main_socket_fd, op);
-  if (ret != TS_ERR_OKAY)
-    return ret;
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, op, &optype);
+  if (ret != TS_ERR_OKAY) {
+    goto done;
+  }
 
-  // parse the reply = delimited list of ids of active event names
-  ret = parse_reply_list(main_socket_fd, &list_str);
-  if (ret != TS_ERR_OKAY)
-    return ret;
+  ret = recv_mgmt_message(main_socket_fd, reply);
+  if (ret != TS_ERR_OKAY) {
+    goto done;
+  }
 
-  // tokenize the list_str and put into LLQ; use Tokenizer
-  if (!list_str)
-    return TS_ERR_FAIL;
+  ret = recv_mgmt_response(reply.ptr, reply.len, op, &err, &strval);
+  if (ret != TS_ERR_OKAY) {
+    goto done;
+  }
 
-  tokens.Initialize(list_str, COPY_TOKS);
+  if (err != TS_ERR_OKAY) {
+    ret = (TSMgmtError)err;
+    goto done;
+  }
+
+  // tokenize the strval and put into LLQ; use Tokenizer
+  tokens.Initialize(strval, COPY_TOKS);
   tok = tokens.iterFirst(&i_state);
   while (tok != NULL) {
-    enqueue(list, ats_strdup(tok));        // add token to LLQ
+    enqueue(list, ats_strdup(tok)); // add token to LLQ
     tok = tokens.iterNext(&i_state);
   }
 
-  ats_free(list_str);
-  return TS_ERR_OKAY;
-}
-
-/*-------------------------------------------------------------------------
- * send_and_parse_name (helper function)
- *-------------------------------------------------------------------------
- * helper function used by operations which only require sending a simple
- * operation type with one string name argument and then parsing a simple
- * TSMgmtError reply
- * NOTE: name can be a NULL parameter!
- */
-TSMgmtError
-send_and_parse_name(OpType op, char *name)
-{
-  TSMgmtError ret;
-
-  // create and send request
-  ret = send_request_name(main_socket_fd, op, name);
-  if (ret != TS_ERR_OKAY)
-    return ret;
-
-  // parse the reply
-  ret = parse_reply(main_socket_fd);
+  ret = TS_ERR_OKAY;
 
+done:
+  ats_free(reply.ptr);
+  ats_free(strval);
   return ret;
 }
 
-
 /*-------------------------------------------------------------------------
  * mgmt_record_set (helper function)
  *-------------------------------------------------------------------------
@@ -168,31 +133,55 @@ send_and_parse_name(OpType op, char *name)
  * NOTE: regardless of the type of the record being set,
  * it is converted to a string. Then on the local side, the
  * CoreAPI::MgmtRecordSet function will do the appropriate type
- * converstion from the string to the record's type (eg. MgmtInt, MgmtString..)
+ * conversion from the string to the record's type (eg. MgmtInt, MgmtString..)
  * Hence, on the local side, don't have to worry about typecasting a
  * void*. Just read out the string from socket and pass it MgmtRecordSet.
  */
-TSMgmtError
-mgmt_record_set(const char *rec_name, const char *rec_val, TSActionNeedT * action_need)
+static TSMgmtError
+mgmt_record_set(const char *rec_name, const char *rec_val, TSActionNeedT *action_need)
 {
-  TSMgmtError err;
+  TSMgmtError ret;
 
-  if (!rec_name || !rec_val || !action_need)
+  MgmtMarshallInt optype = RECORD_SET;
+  MgmtMarshallString name = const_cast<MgmtMarshallString>(rec_name);
+  MgmtMarshallString value = const_cast<MgmtMarshallString>(rec_val);
+
+  MgmtMarshallData reply = {NULL, 0};
+  MgmtMarshallInt err;
+  MgmtMarshallInt action = TS_ACTION_UNDEFINED;
+
+  if (!rec_name || !rec_val || !action_need) {
     return TS_ERR_PARAMS;
+  }
+
+  *action_need = TS_ACTION_UNDEFINED;
 
   // create and send request
-  err = send_request_name_value(main_socket_fd, RECORD_SET, rec_name, rec_val);
-  if (err != TS_ERR_OKAY)
-    return err;
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, RECORD_SET, &optype, &name, &value);
+  if (ret != TS_ERR_OKAY) {
+    return ret;
+  }
 
-  // parse the reply to get TSMgmtError response and TSActionNeedT
-  err = parse_record_set_reply(main_socket_fd, action_need);
+  ret = recv_mgmt_message(main_socket_fd, reply);
+  if (ret != TS_ERR_OKAY) {
+    return ret;
+  }
 
-  return err;
+  ret = recv_mgmt_response(reply.ptr, reply.len, RECORD_SET, &err, &action);
+  ats_free(reply.ptr);
+
+  if (ret != TS_ERR_OKAY) {
+    return ret;
+  }
+
+  if (err != TS_ERR_OKAY) {
+    return (TSMgmtError)err;
+  }
+
+  *action_need = (TSActionNeedT)action;
+  return TS_ERR_OKAY;
 }
 
-
-
 /***************************************************************************
  * SetUp Operations
  ***************************************************************************/
@@ -235,7 +224,7 @@ Init(const char *socket_path, TSInitOptionT options)
 
   // if connected, create event thread that listens for events from TM
   if (0 == (ts_init_options & TS_MGMT_OPT_NO_EVENTS)) {
-    ts_event_thread = ink_thread_create(event_poll_thread_main, &event_socket_fd, 0, DEFAULT_STACK_SIZE);
+    ts_event_thread = ink_thread_create(event_poll_thread_main, &event_socket_fd);
   } else {
     ts_event_thread = static_cast<ink_thread>(NULL);
   }
@@ -245,13 +234,12 @@ END:
   // create thread that periodically checks the socket connection
   // with TM alive - reconnects if not alive
   if (0 == (ts_init_options & TS_MGMT_OPT_NO_SOCK_TESTS)) {
-    ts_test_thread = ink_thread_create(socket_test_thread, NULL, 0, DEFAULT_STACK_SIZE);
+    ts_test_thread = ink_thread_create(socket_test_thread, NULL);
   } else {
     ts_test_thread = static_cast<ink_thread>(NULL);
   }
 
   return err;
-
 }
 
 // does clean up for remote API client; destroy structures and disconnects
@@ -290,7 +278,7 @@ Terminate()
   // Clear operation
   ts_test_thread = static_cast<ink_thread>(NULL);
   ts_event_thread = static_cast<ink_thread>(NULL);
-  set_socket_paths(NULL);       // clear the socket_path
+  set_socket_paths(NULL); // clear the socket_path
 
   return TS_ERR_OKAY;
 }
@@ -300,17 +288,18 @@ Terminate()
 // diagnostics, the diagnostics will be outputted to the machine
 // the remote client is logged into (the one TM is running on)
 void
-Diags(TSDiagsT mode, const char *fmt, va_list ap)
+DiagnosticMessage(TSDiagsT mode, const char *fmt, va_list ap)
 {
   char diag_msg[MAX_BUF_SIZE];
 
+  MgmtMarshallInt optype = DIAGS;
+  MgmtMarshallInt level = mode;
+  MgmtMarshallString msg = diag_msg;
+
   // format the diag message now so it can be sent
   // vsnprintf does not compile on DEC
   vsnprintf(diag_msg, MAX_BUF_SIZE - 1, fmt, ap);
-  TSMgmtError ret = send_diags_msg(main_socket_fd, mode, diag_msg);
-  if (ret != TS_ERR_OKAY) {
-    //fprintf(stderr, "[Diags] error sending diags message\n");
-  }
+  (void)MGMTAPI_SEND_MESSAGE(main_socket_fd, DIAGS, &optype, &level, &msg);
 }
 
 /***************************************************************************
@@ -320,37 +309,92 @@ TSProxyStateT
 ProxyStateGet()
 {
   TSMgmtError ret;
-  TSProxyStateT state;
+  MgmtMarshallInt optype = PROXY_STATE_GET;
+  MgmtMarshallData reply = {NULL, 0};
+  MgmtMarshallInt err;
+  MgmtMarshallInt state;
 
-  ret = send_request(main_socket_fd, PROXY_STATE_GET);
-  if (ret != TS_ERR_OKAY)      // Networking error
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, PROXY_STATE_GET, &optype);
+  if (ret != TS_ERR_OKAY) {
     return TS_PROXY_UNDEFINED;
+  }
 
-  ret = parse_proxy_state_get_reply(main_socket_fd, &state);
-  if (ret != TS_ERR_OKAY)      // Newtorking error
+  ret = recv_mgmt_message(main_socket_fd, reply);
+  if (ret != TS_ERR_OKAY) {
     return TS_PROXY_UNDEFINED;
+  }
 
-  return state;
+  ret = recv_mgmt_response(reply.ptr, reply.len, PROXY_STATE_GET, &err, &state);
+  ats_free(reply.ptr);
+
+  if (ret != TS_ERR_OKAY || err != TS_ERR_OKAY) {
+    return TS_PROXY_UNDEFINED;
+  }
+
+  return (TSProxyStateT)state;
 }
 
 TSMgmtError
 ProxyStateSet(TSProxyStateT state, TSCacheClearT clear)
 {
   TSMgmtError ret;
+  MgmtMarshallInt optype = PROXY_STATE_SET;
+  MgmtMarshallInt pstate = state;
+  MgmtMarshallInt pclear = clear;
 
-  ret = send_proxy_state_set_request(main_socket_fd, state, clear);
-  if (ret != TS_ERR_OKAY)
-    return ret;                 // networking error
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, PROXY_STATE_SET, &optype, &pstate, &pclear);
+  return (ret == TS_ERR_OKAY) ? parse_generic_response(PROXY_STATE_GET, main_socket_fd) : ret;
+}
 
-  ret = parse_reply(main_socket_fd);
+TSMgmtError
+ServerBacktrace(unsigned options, char **trace)
+{
+  ink_release_assert(trace != NULL);
+  TSMgmtError ret;
+  MgmtMarshallInt optype = SERVER_BACKTRACE;
+  MgmtMarshallInt err;
+  MgmtMarshallInt flags = options;
+  MgmtMarshallData reply = {NULL, 0};
+  MgmtMarshallString strval = NULL;
 
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, SERVER_BACKTRACE, &optype, &flags);
+  if (ret != TS_ERR_OKAY) {
+    goto fail;
+  }
+
+  ret = recv_mgmt_message(main_socket_fd, reply);
+  if (ret != TS_ERR_OKAY) {
+    goto fail;
+  }
+
+  ret = recv_mgmt_response(reply.ptr, reply.len, SERVER_BACKTRACE, &err, &strval);
+  if (ret != TS_ERR_OKAY) {
+    goto fail;
+  }
+
+  if (err != TS_ERR_OKAY) {
+    ret = (TSMgmtError)err;
+    goto fail;
+  }
+
+  ats_free(reply.ptr);
+  *trace = strval;
+  return TS_ERR_OKAY;
+
+fail:
+  ats_free(reply.ptr);
+  ats_free(strval);
   return ret;
 }
 
 TSMgmtError
 Reconfigure()
 {
-  return send_and_parse_basic(RECONFIGURE);
+  TSMgmtError ret;
+  MgmtMarshallInt optype = RECONFIGURE;
+
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, RECONFIGURE, &optype);
+  return (ret == TS_ERR_OKAY) ? parse_generic_response(RECONFIGURE, main_socket_fd) : ret;
 }
 
 /*-------------------------------------------------------------------------
@@ -363,16 +407,18 @@ Reconfigure()
  * so keep trying to reconnect until successful or for MAX_CONN_TRIES
  */
 TSMgmtError
-Restart(bool cluster)
+Restart(unsigned options)
 {
   TSMgmtError ret;
+  MgmtMarshallInt optype = RESTART;
+  MgmtMarshallInt oval = options;
 
-  ret = send_request_bool(main_socket_fd, RESTART, cluster);
-  if (ret != TS_ERR_OKAY)
-    return ret;                 // networking error
-
-  ret = parse_reply(main_socket_fd);
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, RESTART, &optype, &oval);
+  if (ret != TS_ERR_OKAY) {
+    return ret;
+  }
 
+  ret = parse_generic_response(RESTART, main_socket_fd);
   if (ret == TS_ERR_OKAY) {
     ret = reconnect_loop(MAX_CONN_TRIES);
   }
@@ -380,112 +426,220 @@ Restart(bool cluster)
   return ret;
 }
 
-
 /*-------------------------------------------------------------------------
  * Bounce
  *-------------------------------------------------------------------------
  * Restart the traffic_server process(es) only.
  */
 TSMgmtError
-Bounce(bool cluster)
+Bounce(unsigned options)
 {
   TSMgmtError ret;
+  MgmtMarshallInt optype = BOUNCE;
+  MgmtMarshallInt oval = options;
 
-  ret = send_request_bool(main_socket_fd, BOUNCE, cluster);
-  if (ret != TS_ERR_OKAY)
-    return ret;                 // networking error
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, BOUNCE, &optype, &oval);
 
-  return parse_reply(main_socket_fd);
+  return (ret == TS_ERR_OKAY) ? parse_generic_response(BOUNCE, main_socket_fd) : ret;
 }
 
-
 /*-------------------------------------------------------------------------
  * StorageDeviceCmdOffline
  *-------------------------------------------------------------------------
  * Disable a storage device.
  */
 TSMgmtError
-StorageDeviceCmdOffline(char const* dev)
+StorageDeviceCmdOffline(char const *dev)
 {
   TSMgmtError ret;
-  ret = send_request_name(main_socket_fd, STORAGE_DEVICE_CMD_OFFLINE, dev);
-  return TS_ERR_OKAY != ret ? ret : parse_reply(main_socket_fd);
+  MgmtMarshallInt optype = STORAGE_DEVICE_CMD_OFFLINE;
+  MgmtMarshallString name = const_cast<MgmtMarshallString>(dev);
+
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, STORAGE_DEVICE_CMD_OFFLINE, &optype, &name);
+  return (ret == TS_ERR_OKAY) ? parse_generic_response(STORAGE_DEVICE_CMD_OFFLINE, main_socket_fd) : ret;
 }
 
 /***************************************************************************
  * Record Operations
  ***************************************************************************/
-static TSMgmtError
-mgmt_record_get_reply(TSRecordEle * rec_ele)
+
+static void
+mgmt_record_convert_value(TSRecordT rec_type, const MgmtMarshallData &data, TSRecordValueT &value)
 {
-  TSMgmtError ret;
-  void *val;
-  char *name;
-
-  ink_zero(*rec_ele);
-  rec_ele->rec_type = TS_REC_UNDEFINED;
-
-  // parse the reply to get record value and type
-  ret = parse_record_get_reply(main_socket_fd, &(rec_ele->rec_type), &val, &name);
-  if (ret != TS_ERR_OKAY) {
-    return ret;
-  }
-
   // convert the record value to appropriate type
-  if (val) {
-    switch (rec_ele->rec_type) {
+  if (data.ptr) {
+    switch (rec_type) {
     case TS_REC_INT:
-      rec_ele->valueT.int_val = *(TSInt *) val;
+      ink_assert(data.len == sizeof(TSInt));
+      value.int_val = *(TSInt *)data.ptr;
       break;
     case TS_REC_COUNTER:
-      rec_ele->valueT.counter_val = *(TSCounter *) val;
+      ink_assert(data.len == sizeof(TSCounter));
+      value.counter_val = *(TSCounter *)data.ptr;
       break;
     case TS_REC_FLOAT:
-      rec_ele->valueT.float_val = *(TSFloat *) val;
+      ink_assert(data.len == sizeof(TSFloat));
+      value.float_val = *(TSFloat *)data.ptr;
       break;
     case TS_REC_STRING:
-      rec_ele->valueT.string_val = ats_strdup((char *) val);
+      ink_assert(data.len == strlen((char *)data.ptr) + 1);
+      value.string_val = ats_strdup((char *)data.ptr);
       break;
     default:
       ; // nothing ... shut up compiler!
     }
   }
+}
 
-  if (name) {
-    rec_ele->rec_name = name;
+static TSMgmtError
+mgmt_record_get_reply(OpType op, TSRecordEle *rec_ele)
+{
+  TSMgmtError ret;
+
+  MgmtMarshallData reply = {NULL, 0};
+  MgmtMarshallInt err;
+  MgmtMarshallInt type;
+  MgmtMarshallString name = NULL;
+  MgmtMarshallData value = {NULL, 0};
+
+  ink_zero(*rec_ele);
+  rec_ele->rec_type = TS_REC_UNDEFINED;
+
+  // Receive the next record reply.
+  ret = recv_mgmt_message(main_socket_fd, reply);
+  if (ret != TS_ERR_OKAY) {
+    return ret;
   }
 
-  ats_free(val);
-  return TS_ERR_OKAY;
+  ret = recv_mgmt_response(reply.ptr, reply.len, op, &err, &type, &name, &value);
+  ats_free(reply.ptr);
+  if (ret != TS_ERR_OKAY) {
+    goto done;
+  }
+
+  if (err != TS_ERR_OKAY) {
+    ret = (TSMgmtError)err;
+    goto done;
+  }
+
+  rec_ele->rec_type = (TSRecordT)type;
+  rec_ele->rec_name = ats_strdup(name);
+  mgmt_record_convert_value(rec_ele->rec_type, value, rec_ele->valueT);
+
+done:
+  ats_free(name);
+  ats_free(value.ptr);
+  return ret;
 }
 
 // note that the record value is being sent as chunk of memory, regardless of
 // record type; it's not being converted to a string!!
 TSMgmtError
-MgmtRecordGet(const char *rec_name, TSRecordEle * rec_ele)
+MgmtRecordGet(const char *rec_name, TSRecordEle *rec_ele)
 {
   TSMgmtError ret;
+  MgmtMarshallInt optype = RECORD_GET;
+  MgmtMarshallString record = const_cast<MgmtMarshallString>(rec_name);
 
   if (!rec_name || !rec_ele) {
     return TS_ERR_PARAMS;
   }
 
   // create and send request
-  ret = send_record_get_request(main_socket_fd, rec_name);
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, RECORD_GET, &optype, &record);
+  return (ret == TS_ERR_OKAY) ? mgmt_record_get_reply(RECORD_GET, rec_ele) : ret;
+}
+
+TSMgmtError
+MgmtConfigRecordDescribe(const char *rec_name, unsigned options, TSConfigRecordDescription *val)
+{
+  TSMgmtError ret;
+  MgmtMarshallInt optype = RECORD_DESCRIBE_CONFIG;
+  MgmtMarshallInt flags = options;
+  MgmtMarshallString record = const_cast<MgmtMarshallString>(rec_name);
+
+  MgmtMarshallData reply = {NULL, 0};
+
+  // create and send request
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, RECORD_DESCRIBE_CONFIG, &optype, &record, &flags);
   if (ret != TS_ERR_OKAY) {
     return ret;
   }
 
-  return mgmt_record_get_reply(rec_ele);
+  ret = recv_mgmt_message(main_socket_fd, reply);
+  if (ret != TS_ERR_OKAY) {
+    return ret;
+  } else {
+    MgmtMarshallInt err;
+    MgmtMarshallString name = NULL;
+    MgmtMarshallString expr = NULL;
+    MgmtMarshallData value = {NULL, 0};
+    MgmtMarshallData deflt = {NULL, 0};
+
+    MgmtMarshallInt rtype;
+    MgmtMarshallInt rclass;
+    MgmtMarshallInt version;
+    MgmtMarshallInt rsb;
+    MgmtMarshallInt order;
+    MgmtMarshallInt access;
+    MgmtMarshallInt update;
+    MgmtMarshallInt updatetype;
+    MgmtMarshallInt checktype;
+
+    ret = recv_mgmt_response(reply.ptr, reply.len, RECORD_DESCRIBE_CONFIG, &err, &name, &value, &deflt, &rtype, &rclass, &version,
+                             &rsb, &order, &access, &update, &updatetype, &checktype, &expr);
+
+    ats_free(reply.ptr);
+
+    if (ret != TS_ERR_OKAY) {
+      goto done;
+    }
+
+    if (err != TS_ERR_OKAY) {
+      ret = (TSMgmtError)err;
+      goto done;
+    }
+
+    // Everything is cool, populate the description ...
+    val->rec_name = ats_strdup(name);
+    val->rec_checkexpr = ats_strdup(expr);
+    val->rec_type = (TSRecordT)rtype;
+    val->rec_class = rclass;
+    val->rec_version = version;
+    val->rec_rsb = rsb;
+    val->rec_order = order;
+    val->rec_access = access;
+    val->rec_updatetype = updatetype;
+    val->rec_checktype = checktype;
+
+    mgmt_record_convert_value(val->rec_type, value, val->rec_value);
+    mgmt_record_convert_value(val->rec_type, deflt, val->rec_default);
+
+  done:
+    ats_free(name);
+    ats_free(expr);
+    ats_free(value.ptr);
+    ats_free(deflt.ptr);
+    return ret;
+  }
+
+  return ret;
 }
 
 TSMgmtError
-MgmtRecordGetMatching(const char * regex, TSList rec_vals)
+MgmtRecordGetMatching(const char *regex, TSList rec_vals)
 {
-  TSMgmtError       ret;
-  TSRecordEle * rec_ele;
+  TSMgmtError ret;
+  TSRecordEle *rec_ele;
 
-  ret = send_record_match_request(main_socket_fd, regex);
+  MgmtMarshallInt optype = RECORD_MATCH_GET;
+  MgmtMarshallString record = const_cast<MgmtMarshallString>(regex);
+
+  if (!regex || !rec_vals) {
+    return TS_ERR_PARAMS;
+  }
+
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, RECORD_MATCH_GET, &optype, &record);
   if (ret != TS_ERR_OKAY) {
     return ret;
   }
@@ -494,33 +648,34 @@ MgmtRecordGetMatching(const char * regex, TSList rec_vals)
     rec_ele = TSRecordEleCreate();
 
     // parse the reply to get record value and type
-    ret = mgmt_record_get_reply(rec_ele);
+    ret = mgmt_record_get_reply(RECORD_MATCH_GET, rec_ele);
     if (ret != TS_ERR_OKAY) {
+      TSRecordEleDestroy(rec_ele);
       goto fail;
     }
 
     // A NULL record ends the list.
     if (rec_ele->rec_type == TS_REC_UNDEFINED) {
+      TSRecordEleDestroy(rec_ele);
       break;
     }
 
-    enqueue((LLQ *) rec_vals, rec_ele);
+    enqueue((LLQ *)rec_vals, rec_ele);
   }
 
   return TS_ERR_OKAY;
 
 fail:
 
-  TSRecordEleDestroy(rec_ele);
-  for (rec_ele = (TSRecordEle *) dequeue((LLQ *) rec_vals); rec_ele; rec_ele = (TSRecordEle *) dequeue((LLQ *) rec_vals)) {
-      TSRecordEleDestroy(rec_ele);
+  for (rec_ele = (TSRecordEle *)dequeue((LLQ *)rec_vals); rec_ele; rec_ele = (TSRecordEle *)dequeue((LLQ *)rec_vals)) {
+    TSRecordEleDestroy(rec_ele);
   }
 
   return ret;
 }
 
 TSMgmtError
-MgmtRecordSet(const char *rec_name, const char *val, TSActionNeedT * action_need)
+MgmtRecordSet(const char *rec_name, const char *val, TSActionNeedT *action_need)
 {
   TSMgmtError ret;
 
@@ -534,7 +689,7 @@ MgmtRecordSet(const char *rec_name, const char *val, TSActionNeedT * action_need
 // first convert the MgmtInt into a string
 // NOTE: use long long, not just long, MgmtInt = int64_t
 TSMgmtError
-MgmtRecordSetInt(const char *rec_name, MgmtInt int_val, TSActionNeedT * action_need)
+MgmtRecordSetInt(const char *rec_name, MgmtInt int_val, TSActionNeedT *action_need)
 {
   char str_val[MAX_RECORD_SIZE];
   TSMgmtError ret;
@@ -551,7 +706,7 @@ MgmtRecordSetInt(const char *rec_name, MgmtInt int_val, TSActionNeedT * action_n
 
 // first convert the MgmtIntCounter into a string
 TSMgmtError
-MgmtRecordSetCounter(const char *rec_name, MgmtIntCounter counter_val, TSActionNeedT * action_need)
+MgmtRecordSetCounter(const char *rec_name, MgmtIntCounter counter_val, TSActionNeedT *action_need)
 {
   char str_val[MAX_RECORD_SIZE];
   TSMgmtError ret;
@@ -568,7 +723,7 @@ MgmtRecordSetCounter(const char *rec_name, MgmtIntCounter counter_val, TSActionN
 
 // first convert the MgmtFloat into string
 TSMgmtError
-MgmtRecordSetFloat(const char *rec_name, MgmtFloat float_val, TSActionNeedT * action_need)
+MgmtRecordSetFloat(const char *rec_name, MgmtFloat float_val, TSActionNeedT *action_need)
 {
   char str_val[MAX_RECORD_SIZE];
   TSMgmtError ret;
@@ -581,9 +736,8 @@ MgmtRecordSetFloat(const char *rec_name, MgmtFloat float_val, TSActionNeedT * ac
   return ret;
 }
 
-
 TSMgmtError
-MgmtRecordSetString(const char *rec_name, const char *string_val, TSActionNeedT * action_need)
+MgmtRecordSetString(const char *rec_name, const char *string_val, TSActionNeedT *action_need)
 {
   TSMgmtError ret;
 
@@ -594,7 +748,6 @@ MgmtRecordSetString(const char *rec_name, const char *string_val, TSActionNeedT
   return ret;
 }
 
-
 /***************************************************************************
  * File Operations
  ***************************************************************************/
@@ -615,17 +768,42 @@ TSMgmtError
 ReadFile(TSFileNameT file, char **text, int *size, int *version)
 {
   TSMgmtError ret;
+  MgmtMarshallInt optype = FILE_READ;
+  MgmtMarshallInt fid = file;
 
-  // marshal data into message request to be sent over socket
-  // create connection and send request
-  ret = send_file_read_request(main_socket_fd, file);
-  if (ret != TS_ERR_OKAY)
+  MgmtMarshallData reply = {NULL, 0};
+  MgmtMarshallInt err;
+  MgmtMarshallInt vers;
+  MgmtMarshallData data = {NULL, 0};
+
+  *text = NULL;
+  *size = *version = 0;
+
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, FILE_READ, &optype, &fid);
+  if (ret != TS_ERR_OKAY) {
     return ret;
+  }
 
-  // read response from socket and unmarshal the response
-  ret = parse_file_read_reply(main_socket_fd, version, size, text);
+  ret = recv_mgmt_message(main_socket_fd, reply);
+  if (ret != TS_ERR_OKAY) {
+    return ret;
+  }
 
-  return ret;
+  ret = recv_mgmt_response(reply.ptr, reply.len, FILE_READ, &err, &vers, &data);
+  ats_free(reply.ptr);
+
+  if (ret != TS_ERR_OKAY) {
+    return ret;
+  }
+
+  if (err != TS_ERR_OKAY) {
+    return (TSMgmtError)err;
+  }
+
+  *version = vers;
+  *text = (char *)data.ptr;
+  *size = (int)data.len;
+  return TS_ERR_OKAY;
 }
 
 /*-------------------------------------------------------------------------
@@ -643,20 +821,19 @@ ReadFile(TSFileNameT file, char **text, int *size, int *version)
  * Traffic Manager.
  */
 TSMgmtError
-WriteFile(TSFileNameT file, char *text, int size, int version)
+WriteFile(TSFileNameT file, const char *text, int size, int version)
 {
   TSMgmtError ret;
 
-  ret = send_file_write_request(main_socket_fd, file, version, size, text);
-  if (ret != TS_ERR_OKAY)
-    return ret;
+  MgmtMarshallInt optype = FILE_WRITE;
+  MgmtMarshallInt fid = file;
+  MgmtMarshallInt vers = version;
+  MgmtMarshallData data = {(void *)text, (size_t)size};
 
-  ret = parse_reply(main_socket_fd);
-
-  return ret;
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, FILE_WRITE, &optype, &fid, &vers, &data);
+  return (ret == TS_ERR_OKAY) ? parse_generic_response(FILE_WRITE, main_socket_fd) : ret;
 }
 
-
 /***************************************************************************
  * Events
  ***************************************************************************/
@@ -666,7 +843,7 @@ WriteFile(TSFileNameT file, char *text, int size, int version)
  * LAN - need to implement
  */
 TSMgmtError
-EventSignal(char */* event_name ATS_UNUSED */, va_list /* ap ATS_UNUSED */)
+EventSignal(const char * /* event_name ATS_UNUSED */, va_list /* ap ATS_UNUSED */)
 {
   return TS_ERR_FAIL;
 }
@@ -679,12 +856,17 @@ EventSignal(char */* event_name ATS_UNUSED */, va_list /* ap ATS_UNUSED */)
  *          not the event id
  */
 TSMgmtError
-EventResolve(char *event_name)
+EventResolve(const char *event_name)
 {
+  TSMgmtError ret;
+  MgmtMarshallInt optype = EVENT_RESOLVE;
+  MgmtMarshallString name = const_cast<MgmtMarshallString>(event_name);
+
   if (!event_name)
     return TS_ERR_PARAMS;
 
-  return (send_and_parse_name(EVENT_RESOLVE, event_name));
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, EVENT_RESOLVE, &optype, &name);
+  return (ret == TS_ERR_OKAY) ? parse_generic_response(EVENT_RESOLVE, main_socket_fd) : ret;
 }
 
 /*-------------------------------------------------------------------------
@@ -694,7 +876,7 @@ EventResolve(char *event_name)
  * note:    list of event names returned in network msg which must be tokenized
  */
 TSMgmtError
-ActiveEventGetMlt(LLQ * active_events)
+ActiveEventGetMlt(LLQ *active_events)
 {
   if (!active_events)
     return TS_ERR_PARAMS;
@@ -708,24 +890,39 @@ ActiveEventGetMlt(LLQ * active_events)
  * determines if the event_name is active; sets result in is_current
  */
 TSMgmtError
-EventIsActive(char *event_name, bool * is_current)
+EventIsActive(const char *event_name, bool *is_current)
 {
   TSMgmtError ret;
+  MgmtMarshallInt optype = EVENT_ACTIVE;
+  MgmtMarshallString name = const_cast<MgmtMarshallString>(event_name);
+
+  MgmtMarshallData reply = {NULL, 0};
+  MgmtMarshallInt err;
+  MgmtMarshallInt bval;
 
   if (!event_name || !is_current)
     return TS_ERR_PARAMS;
 
   // create and send request
-  ret = send_request_name(main_socket_fd, EVENT_ACTIVE, event_name);
-  if (ret != TS_ERR_OKAY)
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, EVENT_ACTIVE, &optype, &name);
+  if (ret != TS_ERR_OKAY) {
     return ret;
+  }
 
-  // parse the reply
-  ret = parse_event_active_reply(main_socket_fd, is_current);
-  if (ret != TS_ERR_OKAY)
+  ret = recv_mgmt_message(main_socket_fd, reply);
+  if (ret != TS_ERR_OKAY) {
     return ret;
+  }
 
-  return ret;
+  ret = recv_mgmt_response(reply.ptr, reply.len, EVENT_ACTIVE, &err, &bval);
+  ats_free(reply.ptr);
+
+  if (ret != TS_ERR_OKAY) {
+    return ret;
+  }
+
+  *is_current = (bval != 0);
+  return (TSMgmtError)err;
 }
 
 /*-------------------------------------------------------------------------
@@ -738,25 +935,28 @@ EventIsActive(char *event_name, bool * is_current)
  * which events have remote callbacks registered on it.
  */
 TSMgmtError
-EventSignalCbRegister(char *event_name, TSEventSignalFunc func, void *data)
+EventSignalCbRegister(const char *event_name, TSEventSignalFunc func, void *data)
 {
-  bool first_time = 0;
-  TSMgmtError err;
+  bool first_time = false;
+  TSMgmtError ret;
 
   if (func == NULL)
     return TS_ERR_PARAMS;
   if (!remote_event_callbacks)
     return TS_ERR_FAIL;
 
-  err = cb_table_register(remote_event_callbacks, event_name, func, data, &first_time);
-  if (err != TS_ERR_OKAY)
-    return err;
+  ret = cb_table_register(remote_event_callbacks, event_name, func, data, &first_time);
+  if (ret != TS_ERR_OKAY)
+    return ret;
 
   // if we need to notify traffic manager of the event then send msg
   if (first_time) {
-    err = send_request_name(event_socket_fd, EVENT_REG_CALLBACK, event_name);
-    if (err != TS_ERR_OKAY)
-      return err;
+    MgmtMarshallInt optype = EVENT_REG_CALLBACK;
+    MgmtMarshallString name = const_cast<MgmtMarshallString>(event_name);
+
+    ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, EVENT_REG_CALLBACK, &optype, &name);
+    if (ret != TS_ERR_OKAY)
+      return ret;
   }
 
   return TS_ERR_OKAY;
@@ -777,7 +977,7 @@ EventSignalCbRegister(char *event_name, TSEventSignalFunc func, void *data)
  *                     specified
  */
 TSMgmtError
-EventSignalCbUnregister(char *event_name, TSEventSignalFunc func)
+EventSignalCbUnregister(const char *event_name, TSEventSignalFunc func)
 {
   TSMgmtError err;
 
@@ -801,51 +1001,55 @@ EventSignalCbUnregister(char *event_name, TSEventSignalFunc func)
 /***************************************************************************
  * Snapshots
  ***************************************************************************/
-TSMgmtError
-SnapshotTake(char *snapshot_name)
+static TSMgmtError
+snapshot_message(OpType op, const char *snapshot_name)
 {
+  TSMgmtError ret;
+  MgmtMarshallInt optype = op;
+  MgmtMarshallString name = const_cast<MgmtMarshallString>(snapshot_name);
+
   if (!snapshot_name)
     return TS_ERR_PARAMS;
 
-  return send_and_parse_name(SNAPSHOT_TAKE, snapshot_name);
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, op, &optype, &name);
+  return (ret == TS_ERR_OKAY) ? parse_generic_response(op, main_socket_fd) : ret;
 }
 
 TSMgmtError
-SnapshotRestore(char *snapshot_name)
+SnapshotTake(const char *snapshot_name)
 {
-  if (!snapshot_name)
+  return snapshot_message(SNAPSHOT_TAKE, snapshot_name);
+}
+
+TSMgmtError
+SnapshotRestore(const char *snapshot_name)
+{
+  return snapshot_message(SNAPSHOT_RESTORE, snapshot_name);
+}
+
+TSMgmtError
+SnapshotRemove(const char *snapshot_name)
+{
+  return snapshot_message(SNAPSHOT_REMOVE, snapshot_name);
+}
+
+TSMgmtError
+SnapshotGetMlt(LLQ *snapshots)
+{
+  if (!snapshots)
     return TS_ERR_PARAMS;
 
-  return send_and_parse_name(SNAPSHOT_RESTORE, snapshot_name);
-}
-
-TSMgmtError
-SnapshotRemove(char *snapshot_name)
-{
-  if (!snapshot_name)
-    return TS_ERR_PARAMS;
-
-  return send_and_parse_name(SNAPSHOT_REMOVE, snapshot_name);
-}
-
-TSMgmtError
-SnapshotGetMlt(LLQ * snapshots)
-{
   return send_and_parse_list(SNAPSHOT_GET_MLT, snapshots);
 }
 
 TSMgmtError
-StatsReset(bool cluster, const char* name)
+StatsReset(bool cluster, const char *stat_name)
 {
   TSMgmtError ret;
+  OpType op = cluster ? STATS_RESET_CLUSTER : STATS_RESET_NODE;
+  MgmtMarshallInt optype = op;
+  MgmtMarshallString name = const_cast<MgmtMarshallString>(stat_name);
 
-  if (cluster) {
-    ret = send_request_name(main_socket_fd, STATS_RESET_CLUSTER, name);
-  } else {
-    ret = send_request_name(main_socket_fd, STATS_RESET_NODE, name);
-  }
-  if (ret != TS_ERR_OKAY)
-    return ret;                 // networking error
-
-  return parse_reply(main_socket_fd);
+  ret = MGMTAPI_SEND_MESSAGE(main_socket_fd, op, &optype, &name);
+  return (ret == TS_ERR_OKAY) ? parse_generic_response(op, main_socket_fd) : ret;
 }
