@@ -32,17 +32,20 @@
 #include "libts.h"
 #include "LocalManager.h"
 #include "MgmtSocket.h"
+#include "MgmtMarshall.h"
+#include "MgmtUtils.h"
 #include "EventControlMain.h"
 #include "CoreAPI.h"
 #include "NetworkUtilsLocal.h"
-#include "NetworkUtilsDefs.h"
-
+#include "NetworkMessage.h"
 
 // variables that are very important
 ink_mutex mgmt_events_lock;
 LLQ *mgmt_events;
 InkHashTable *accepted_clients; // list of all accepted client connections
 
+static TSMgmtError handle_event_message(EventClientT *client, void *req, size_t reqlen);
+
 /*********************************************************************
  * new_event_client
  *
@@ -73,7 +76,7 @@ new_event_client()
  * note: None
  *********************************************************************/
 void
-delete_event_client(EventClientT * client)
+delete_event_client(EventClientT *client)
 {
   if (client) {
     ats_free(client->adr);
@@ -91,13 +94,13 @@ delete_event_client(EventClientT * client)
  * output:
  *********************************************************************/
 void
-remove_event_client(EventClientT * client, InkHashTable * table)
+remove_event_client(EventClientT *client, InkHashTable *table)
 {
   // close client socket
-  close_socket(client->sock_info.fd);       // close client socket
+  close_socket(client->fd); // close client socket
 
   // remove client binding from hash table
-  ink_hash_table_delete(table, (char *) &client->sock_info.fd);
+  ink_hash_table_delete(table, (char *)&client->fd);
 
   // free ClientT
   delete_event_client(client);
@@ -134,7 +137,6 @@ init_mgmt_events()
   return TS_ERR_OKAY;
 }
 
-
 /*********************************************************************
  * delete_mgmt_events
  *
@@ -172,7 +174,7 @@ delete_mgmt_events()
  * note: None
  *********************************************************************/
 void
-delete_event_queue(LLQ * q)
+delete_event_queue(LLQ *q)
 {
   if (!q)
     return;
@@ -181,7 +183,7 @@ delete_event_queue(LLQ * q)
   TSMgmtEvent *ele;
 
   while (!queue_is_empty(q)) {
-    ele = (TSMgmtEvent *) dequeue(q);
+    ele = (TSMgmtEvent *)dequeue(q);
     ats_free(ele);
   }
 
@@ -209,13 +211,13 @@ apiEventCallback(alarm_t newAlarm, const char * /* ip ATS_UNUSED */, const char
   newEvent = TSEventCreate();
   newEvent->id = newAlarm;
   newEvent->name = get_event_name(newEvent->id);
-  //newEvent->ip   = ats_strdup(ip);
+  // newEvent->ip   = ats_strdup(ip);
   if (desc)
     newEvent->description = ats_strdup(desc);
   else
     newEvent->description = ats_strdup("None");
 
-  //add it to the mgmt_events list
+  // add it to the mgmt_events list
   ink_mutex_acquire(&mgmt_events_lock);
   enqueue(mgmt_events, newEvent);
   ink_mutex_release(&mgmt_events_lock);
@@ -236,13 +238,11 @@ void *
 event_callback_main(void *arg)
 {
   int ret;
-  OpType op_t;                  // what kind of operation?
   int *socket_fd;
-  int con_socket_fd;            // main socket for listening to new connections
-  char *req;                    // the request msg sent over from client
+  int con_socket_fd; // main socket for listening to new connections
 
-  socket_fd = (int *) arg;
-  con_socket_fd = *socket_fd;   // the socket for event callbacks
+  socket_fd = (int *)arg;
+  con_socket_fd = *socket_fd; // the socket for event callbacks
 
   Debug("event", "[event_callback_main] listen on socket = %d\n", con_socket_fd);
 
@@ -260,13 +260,13 @@ event_callback_main(void *arg)
   lmgmt->alarm_keeper->registerCallback(apiEventCallback);
 
   // now we can start listening, accepting connections and servicing requests
-  int new_con_fd;               // new connection fd when socket accepts connection
+  int new_con_fd; // new connection fd when socket accepts connection
 
-  fd_set selectFDs;             // for select call
-  InkHashTableEntry *con_entry; // used to obtain fd to alarms mapping
-  EventClientT *client_entry;   // an entry of fd to alarms mapping
-  InkHashTableIteratorState con_state;  // used to iterate through hash table
-  int fds_ready;                // return value for select go here
+  fd_set selectFDs;                    // for select call
+  InkHashTableEntry *con_entry;        // used to obtain fd to alarms mapping
+  EventClientT *client_entry;          // an entry of fd to alarms mapping
+  InkHashTableIteratorState con_state; // used to iterate through hash table
+  int fds_ready;                       // return value for select go here
   struct timeval timeout;
   int addr_len = (sizeof(struct sockaddr));
 
@@ -286,15 +286,15 @@ event_callback_main(void *arg)
 
     // iterate through all entries in hash table
     while (con_entry) {
-      client_entry = (EventClientT *) ink_hash_table_entry_value(accepted_clients, con_entry);
-      if (client_entry->sock_info.fd >= 0) {    // add fd to select set
-        FD_SET(client_entry->sock_info.fd, &selectFDs);
+      client_entry = (EventClientT *)ink_hash_table_entry_value(accepted_clients, con_entry);
+      if (client_entry->fd >= 0) { // add fd to select set
+        FD_SET(client_entry->fd, &selectFDs);
       }
       con_entry = ink_hash_table_iterator_next(accepted_clients, &con_state);
     }
 
     // select call - timeout is set so we can check events at regular intervals
-    fds_ready = mgmt_select(FD_SETSIZE, &selectFDs, (fd_set *) NULL, (fd_set *) NULL, &timeout);
+    fds_ready = mgmt_select(FD_SETSIZE, &selectFDs, (fd_set *)NULL, (fd_set *)NULL, &timeout);
 
     // check return
     if (fds_ready > 0) {
@@ -308,73 +308,54 @@ event_callback_main(void *arg)
         EventClientT *new_client_con = new_event_client();
 
         if (!new_client_con) {
-          //Debug ("TS_Control_Main", "can't create new EventClientT for new connection\n");
+          // Debug ("TS_Control_Main", "can't create new EventClientT for new connection\n");
         } else {
           // accept connection
           new_con_fd = mgmt_accept(con_socket_fd, new_client_con->adr, &addr_len);
-          new_client_con->sock_info.fd = new_con_fd;
-          new_client_con->sock_info.SSLcon = NULL;
-          ink_hash_table_insert(accepted_clients, (char *) &new_client_con->sock_info.fd, new_client_con);
+          new_client_con->fd = new_con_fd;
+          ink_hash_table_insert(accepted_clients, (char *)&new_client_con->fd, new_client_con);
           Debug("event", "[event_callback_main] Accept new connection: fd=%d\n", new_con_fd);
         }
-      }                         // end if (new_con_fd >= 0 && FD_ISSET(new_con_fd, &selectFDs))
+      } // end if (new_con_fd >= 0 && FD_ISSET(new_con_fd, &selectFDs))
 
       // some other file descriptor; for each one, service request
-      if (fds_ready > 0) {      // RECEIVED A REQUEST from remote API client
+      if (fds_ready > 0) { // RECEIVED A REQUEST from remote API client
         // see if there are more fd to set - iterate through all entries in hash table
         con_entry = ink_hash_table_iterator_first(accepted_clients, &con_state);
         while (con_entry) {
-          client_entry = (EventClientT *) ink_hash_table_entry_value(accepted_clients, con_entry);
+          client_entry = (EventClientT *)ink_hash_table_entry_value(accepted_clients, con_entry);
           // got information check
-          if (client_entry->sock_info.fd && FD_ISSET(client_entry->sock_info.fd, &selectFDs)) {
+          if (client_entry->fd && FD_ISSET(client_entry->fd, &selectFDs)) {
             // SERVICE REQUEST - read the op and message into a buffer
             // clear the fields first
-            op_t = UNDEFINED_OP;
-            ret = preprocess_msg(client_entry->sock_info, (OpType *) & op_t, &req);
-            if (ret == TS_ERR_NET_READ || ret == TS_ERR_NET_EOF) {    // preprocess_msg FAILED!
+            void *req;
+            size_t reqlen;
+
+            ret = preprocess_msg(client_entry->fd, &req, &reqlen);
+            if (ret == TS_ERR_NET_READ || ret == TS_ERR_NET_EOF) { // preprocess_msg FAILED!
               Debug("event", "[event_callback_main] preprocess_msg FAILED; skip! \n");
               remove_event_client(client_entry, accepted_clients);
               con_entry = ink_hash_table_iterator_next(accepted_clients, &con_state);
               continue;
             }
-            // determine which handler function to call based on operation
-            switch (op_t) {
 
-            case EVENT_REG_CALLBACK:
-              handle_event_reg_callback(client_entry, req);
-              ats_free(req);     // free the request allocated by preprocess_msg
-              if (ret == TS_ERR_NET_WRITE || ret == TS_ERR_NET_EOF) {
-                Debug("event", "[event_callback_main] ERROR: handle_event_reg_callback\n");
-                remove_event_client(client_entry, accepted_clients);
-                con_entry = ink_hash_table_iterator_next(accepted_clients, &con_state);
-                continue;
-              }
-              break;
+            ret = handle_event_message(client_entry, req, reqlen);
+            ats_free(req);
 
-            case EVENT_UNREG_CALLBACK:
+            if (ret == TS_ERR_NET_WRITE || ret == TS_ERR_NET_EOF) {
+              Debug("event", "[event_callback_main] ERROR: handle_control_message\n");
+              remove_event_client(client_entry, accepted_clients);
+              con_entry = ink_hash_table_iterator_next(accepted_clients, &con_state);
+              continue;
+            }
 
-              handle_event_unreg_callback(client_entry, req);
-              ats_free(req);     // free the request allocated by preprocess_msg
-              if (ret == TS_ERR_NET_WRITE || ret == TS_ERR_NET_EOF) {
-                Debug("event", "[event_callback_main] ERROR: handle_event_unreg_callback\n");
-                remove_event_client(client_entry, accepted_clients);
-                con_entry = ink_hash_table_iterator_next(accepted_clients, &con_state);
-                continue;
-              }
-              break;
-
-            default:
-              break;
-
-            }                   // end switch (op_t)
-
-          }                     // end if(client_entry->sock_info.fd && FD_ISSET(client_entry->sock_info.fd, &selectFDs))
+          } // end if(client_entry->fd && FD_ISSET(client_entry->fd, &selectFDs))
 
           con_entry = ink_hash_table_iterator_next(accepted_clients, &con_state);
-        }                       // end while (con_entry)
-      }                         // end if (fds_ready > 0)
+        } // end while (con_entry)
+      }   // end if (fds_ready > 0)
 
-    }                           // end if (fds_ready > 0)
+    } // end if (fds_ready > 0)
 
     // ------------ service loop is done, check for events now -------------
     // for each event in the mgmt_events list, uses the event id to check the
@@ -383,42 +364,46 @@ event_callback_main(void *arg)
 
     TSMgmtEvent *event;
 
-    if (!mgmt_events || queue_is_empty(mgmt_events)) {  //no events to process
-      //fprintf(stderr, "[event_callback_main] NO EVENTS TO PROCESS\n");
+    if (!mgmt_events || queue_is_empty(mgmt_events)) { // no events to process
+      // fprintf(stderr, "[event_callback_main] NO EVENTS TO PROCESS\n");
       Debug("event", "[event_callback_main] NO EVENTS TO PROCESS\n");
       continue;
     }
     // iterate through each event in mgmt_events
     while (!queue_is_empty(mgmt_events)) {
-      ink_mutex_acquire(&mgmt_events_lock);     //acquire lock
-      event = (TSMgmtEvent *) dequeue(mgmt_events);        // get what we want
-      ink_mutex_release(&mgmt_events_lock);     // release lock
+      ink_mutex_acquire(&mgmt_events_lock);        // acquire lock
+      event = (TSMgmtEvent *)dequeue(mgmt_events); // get what we want
+      ink_mutex_release(&mgmt_events_lock);        // release lock
 
       if (!event)
         continue;
 
-      //fprintf(stderr, "[event_callback_main] have an EVENT TO PROCESS\n");
+      // fprintf(stderr, "[event_callback_main] have an EVENT TO PROCESS\n");
 
       // iterate through all entries in hash table, if any
       con_entry = ink_hash_table_iterator_first(accepted_clients, &con_state);
       while (con_entry) {
-        client_entry = (EventClientT *) ink_hash_table_entry_value(accepted_clients, con_entry);
+        client_entry = (EventClientT *)ink_hash_table_entry_value(accepted_clients, con_entry);
         if (client_entry->events_registered[event->id]) {
-          ret = send_event_notification(client_entry->sock_info, event);
-          if (ret != TS_ERR_OKAY) {    // send_event_notification failed!
-            Debug("event", "sending even notification to fd [%d] failed.\n", client_entry->sock_info.fd);
+          MgmtMarshallInt optype = EVENT_NOTIFY;
+          MgmtMarshallString name = event->name;
+          MgmtMarshallString desc = event->description;
+
+          ret = send_mgmt_request(client_entry->fd, EVENT_NOTIFY, &optype, &name, &desc);
+          if (ret != TS_ERR_OKAY) {
+            Debug("event", "sending even notification to fd [%d] failed.\n", client_entry->fd);
           }
         }
         // get next client connection, if any
         con_entry = ink_hash_table_iterator_next(accepted_clients, &con_state);
-      }                         // end while(con_entry)
+      } // end while(con_entry)
 
       // now we can delete the event
-      //fprintf(stderr, "[event_callback_main] DELETE EVENT\n");
+      // fprintf(stderr, "[event_callback_main] DELETE EVENT\n");
       TSEventDestroy(event);
-    }                           // end while (!queue_is_empty)
+    } // end while (!queue_is_empty)
 
-  }                             // end while (1)
+  } // end while (1)
 
   // delete tables
   delete_mgmt_events();
@@ -426,12 +411,12 @@ event_callback_main(void *arg)
   // iterate through hash table; close client socket connections and remove entry
   con_entry = ink_hash_table_iterator_first(accepted_clients, &con_state);
   while (con_entry) {
-    client_entry = (EventClientT *) ink_hash_table_entry_value(accepted_clients, con_entry);
-    if (client_entry->sock_info.fd >= 0) {
-      close_socket(client_entry->sock_info.fd);     // close socket
+    client_entry = (EventClientT *)ink_hash_table_entry_value(accepted_clients, con_entry);
+    if (client_entry->fd >= 0) {
+      close_socket(client_entry->fd);
     }
-    ink_hash_table_delete(accepted_clients, (char *) &client_entry->sock_info.fd);      // remove binding
-    delete_event_client(client_entry);  // free ClientT
+    ink_hash_table_delete(accepted_clients, (char *)&client_entry->fd); // remove binding
+    delete_event_client(client_entry);                                  // free ClientT
     con_entry = ink_hash_table_iterator_next(accepted_clients, &con_state);
   }
   // all entries should be removed and freed already
@@ -454,23 +439,38 @@ event_callback_main(void *arg)
  * output: TS_ERR_xx
  * note: the req should be the event name; does not send a reply to client
  *************************************************************************/
-TSMgmtError
-handle_event_reg_callback(EventClientT * client, char *req)
+static TSMgmtError
+handle_event_reg_callback(EventClientT *client, void *req, size_t reqlen)
 {
+  MgmtMarshallInt optype;
+  MgmtMarshallString name = NULL;
+  TSMgmtError ret;
+
+  ret = recv_mgmt_request(req, reqlen, EVENT_REG_CALLBACK, &optype, &name);
+  if (ret != TS_ERR_OKAY) {
+    goto done;
+  }
+
   // mark the specified alarm as "wanting to be notified" in the client's alarm_registered list
-  if (req == NULL) {            // mark all alarms
+  if (strlen(name) == 0) { // mark all alarms
     for (int i = 0; i < NUM_EVENTS; i++) {
       client->events_registered[i] = true;
     }
   } else {
-    int id = get_event_id(req); // req == event_name
+    int id = get_event_id(name);
     if (id < 0) {
-      return TS_ERR_FAIL;
+      ret = TS_ERR_FAIL;
+      goto done;
     }
+
     client->events_registered[id] = true;
   }
 
-  return TS_ERR_OKAY;
+  ret = TS_ERR_OKAY;
+
+done:
+  ats_free(name);
+  return ret;
 }
 
 /**************************************************************************
@@ -482,21 +482,96 @@ handle_event_reg_callback(EventClientT * client, char *req)
  * output: TS_ERR_xx
  * note: the req should be the event name; does not send reply to client
  *************************************************************************/
-TSMgmtError
-handle_event_unreg_callback(EventClientT * client, char *req)
+static TSMgmtError
+handle_event_unreg_callback(EventClientT *client, void *req, size_t reqlen)
 {
+  MgmtMarshallInt optype;
+  MgmtMarshallString name = NULL;
+  TSMgmtError ret;
+
+  ret = recv_mgmt_request(req, reqlen, EVENT_UNREG_CALLBACK, &optype, &name);
+  if (ret != TS_ERR_OKAY) {
+    goto done;
+  }
+
   // mark the specified alarm as "wanting to be notified" in the client's alarm_registered list
-  if (req == NULL) {            // mark all alarms
+  if (strlen(name) == 0) { // mark all alarms
     for (int i = 0; i < NUM_EVENTS; i++) {
       client->events_registered[i] = false;
     }
   } else {
-    int id = get_event_id(req); // req == event_name
+    int id = get_event_id(name);
     if (id < 0) {
-      return TS_ERR_FAIL;
+      ret = TS_ERR_FAIL;
+      goto done;
     }
+
     client->events_registered[id] = false;
   }
 
-  return TS_ERR_OKAY;
+  ret = TS_ERR_OKAY;
+
+done:
+  ats_free(name);
+  return ret;
+}
+
+typedef TSMgmtError (*event_message_handler)(EventClientT *, void *, size_t);
+
+static const event_message_handler handlers[] = {
+  NULL,                        // FILE_READ
+  NULL,                        // FILE_WRITE
+  NULL,                        // RECORD_SET
+  NULL,                        // RECORD_GET
+  NULL,                        // PROXY_STATE_GET
+  NULL,                        // PROXY_STATE_SET
+  NULL,                        // RECONFIGURE
+  NULL,                        // RESTART
+  NULL,                        // BOUNCE
+  NULL,                        // EVENT_RESOLVE
+  NULL,                        // EVENT_GET_MLT
+  NULL,                        // EVENT_ACTIVE
+  handle_event_reg_callback,   // EVENT_REG_CALLBACK
+  handle_event_unreg_callback, // EVENT_UNREG_CALLBACK
+  NULL,                        // EVENT_NOTIFY
+  NULL,                        // SNAPSHOT_TAKE
+  NULL,                        // SNAPSHOT_RESTORE
+  NULL,                        // SNAPSHOT_REMOVE
+  NULL,                        // SNAPSHOT_GET_MLT
+  NULL,                        // DIAGS
+  NULL,                        // STATS_RESET_NODE
+  NULL,                        // STATS_RESET_CLUSTER
+  NULL,                        // STORAGE_DEVICE_CMD_OFFLINE
+  NULL,                        // RECORD_MATCH_GET
+};
+
+static TSMgmtError
+handle_event_message(EventClientT *client, void *req, size_t reqlen)
+{
+  OpType optype = extract_mgmt_request_optype(req, reqlen);
+
+  if (optype < 0 || static_cast<unsigned>(optype) >= countof(handlers)) {
+    goto fail;
+  }
+
+  if (handlers[optype] == NULL) {
+    goto fail;
+  }
+
+  if (mgmt_has_peereid()) {
+    uid_t euid = -1;
+    gid_t egid = -1;
+
+    // For now, all event messages require privilege. This is compatible with earlier
+    // versions of Traffic Server that always required privilege.
+    if (mgmt_get_peereid(client->fd, &euid, &egid) == -1 || (euid != 0 && euid != geteuid())) {
+      return TS_ERR_PERMISSION_DENIED;
+    }
+  }
+
+  return handlers[optype](client, req, reqlen);
+
+fail:
+  mgmt_elog(0, "%s: missing handler for type %d event message\n", __func__, (int)optype);
+  return TS_ERR_PARAMS;
 }
