@@ -31,7 +31,7 @@
  *   free callers from allocating the memory.
  ***************************************************************************/
 
-Token::Token():name(NULL), value(NULL)
+Token::Token() : name(NULL), value(NULL)
 {
 }
 
@@ -44,8 +44,8 @@ Token::~Token()
 void
 Token::setName(const char *str)
 {
-  name = (char *) strtrim(str);
-  //name = ats_strdup(str_copy); DOESN't WORK
+  name = (char *)strtrim(str);
+  // name = ats_strdup(str_copy); DOESN't WORK
 }
 
 //
@@ -55,7 +55,7 @@ Token::setName(const char *str)
 void
 Token::setValue(const char *str)
 {
-  char *str_copy = (char *) strtrim(str);
+  char *str_copy = (char *)strtrim(str);
   // Can't use ats_strdup after strtrim?
   //  value = ats_strdup(str);
   ink_assert(value == NULL);
@@ -72,7 +72,7 @@ Token::setValue(const char *str)
 void
 Token::appendValue(const char *str)
 {
-  char *str_copy = (char *) strtrim(str);
+  char *str_copy = (char *)strtrim(str);
   static bool firstTime = true;
 
   if (value == NULL) {
@@ -105,7 +105,7 @@ Token::Print()
  *   function calls in addition to the common length() and the debugging
  *   print() member functions.
  ***************************************************************************/
-TokenList::TokenList():length(0)
+TokenList::TokenList() : length(0)
 {
 }
 
@@ -114,7 +114,7 @@ TokenList::~TokenList()
   Token *token = NULL;
 
   while ((token = dequeue())) {
-    delete(token);
+    delete (token);
   }
 }
 
@@ -122,7 +122,7 @@ void
 TokenList::Print()
 {
   printf("\tRULE -->");
-  for (Token * token = first(); token; token = next(token)) {
+  for (Token *token = first(); token; token = next(token)) {
     token->Print();
   }
   printf("\n");
@@ -138,8 +138,7 @@ TokenList::Print()
  ***************************************************************************/
 
 Rule::Rule()
-  : tokenList(NULL),
-    m_filetype(TS_FNAME_UNDEFINED), m_filename(NULL), m_ruleStr(NULL), m_comment(NULL), m_errorHint(NULL)
+  : tokenList(NULL), m_filetype(TS_FNAME_UNDEFINED), m_filename(NULL), m_ruleStr(NULL), m_comment(NULL), m_errorHint(NULL)
 {
 }
 
@@ -187,39 +186,39 @@ Rule::Print()
 TokenList *
 Rule::parse(const char *const_rule, TSFileNameT filetype)
 {
-  char *rule = (char *) const_rule;
+  char *rule = (char *)const_rule;
   m_filetype = filetype;
 
   switch (m_filetype) {
-  case TS_FNAME_CACHE_OBJ:    /* cache.config */
+  case TS_FNAME_CACHE_OBJ: /* cache.config */
     return cacheParse(rule);
-  case TS_FNAME_CONGESTION:   /* congestion.config */
+  case TS_FNAME_CONGESTION: /* congestion.config */
     return congestionParse(rule, 1, 15);
-  case TS_FNAME_HOSTING:      /* hosting.config */
+  case TS_FNAME_HOSTING: /* hosting.config */
     return hostingParse(rule);
-  case TS_FNAME_ICP_PEER:     /* icp.config */
+  case TS_FNAME_ICP_PEER: /* icp.config */
     return icpParse(rule, 8, 8);
-  case TS_FNAME_IP_ALLOW:     /* ip_allow.config */
+  case TS_FNAME_IP_ALLOW: /* ip_allow.config */
     return ip_allowParse(rule);
-  case TS_FNAME_LOGS_XML:     /* logs_xml.config */
+  case TS_FNAME_LOGS_XML: /* logs_xml.config */
     return logs_xmlParse(rule);
   case TS_FNAME_PARENT_PROXY: /* parent.config */
     return parentParse(rule);
-  case TS_FNAME_VOLUME:    /* volume.config */
+  case TS_FNAME_VOLUME: /* volume.config */
     return volumeParse(rule);
-  case TS_FNAME_PLUGIN:       /* plugin.config */
+  case TS_FNAME_PLUGIN: /* plugin.config */
     return pluginParse(rule);
-  case TS_FNAME_REMAP:        /* remap.config */
+  case TS_FNAME_REMAP: /* remap.config */
     return remapParse(rule);
-  case TS_FNAME_SOCKS:        /* socks.config */
+  case TS_FNAME_SOCKS: /* socks.config */
     return socksParse(rule);
-  case TS_FNAME_SPLIT_DNS:    /* splitdns.config */
+  case TS_FNAME_SPLIT_DNS: /* splitdns.config */
     return splitdnsParse(rule);
-  case TS_FNAME_STORAGE:      /* storage.config */
+  case TS_FNAME_STORAGE: /* storage.config */
     return storageParse(rule);
-  case TS_FNAME_UPDATE_URL:   /* update.config */
+  case TS_FNAME_UPDATE_URL: /* update.config */
     return updateParse(rule);
-  case TS_FNAME_VADDRS:       /* vaddrs.config */
+  case TS_FNAME_VADDRS: /* vaddrs.config */
     return vaddrsParse(rule);
   default:
     return NULL;
@@ -237,7 +236,7 @@ Rule::arm_securityParse(char *rule)
   ruleTok.Initialize(rule);
   tok_iter_state ruleTok_state;
   const char *tokenStr = ruleTok.iterFirst(&ruleTok_state);
-  Token *token = (Token *) NULL;
+  Token *token = (Token *)NULL;
   TokenList *m_tokenList = new TokenList();
 
   // ASSUMPTIONS:
@@ -245,25 +244,23 @@ Rule::arm_securityParse(char *rule)
   //   every token starts with a digit is a "value" or part of a "value"
   //   NO SPACE for port/ip range
   for (; tokenStr; tokenStr = ruleTok.iterNext(&ruleTok_state)) {
-
     // If 1st element is non-digit, it is a value
     if (!ParseRules::is_digit(tokenStr[0])) {
-
       // it is a name
-      if (token != (Token *) NULL) {
+      if (token != (Token *)NULL) {
         // We have a token that hasn't been enqueue, enqueue it
         m_tokenList->enqueue(token);
       }
 
-      token = new Token(); // Create a new token
+      token = new Token();      // Create a new token
       token->setName(tokenStr); // Set token Name
-    } else if (token != (Token *) NULL) {
+    } else if (token != (Token *)NULL) {
       // it is a value or part of a value
-      token->appendValue(tokenStr);     // ISA port# or IP; append to value
+      token->appendValue(tokenStr); // ISA port# or IP; append to value
     }
   }
 
-  if (token != (Token *) NULL) {        // Enqueue the last token -- we haven't done it yet.
+  if (token != (Token *)NULL) { // Enqueue the last token -- we haven't done it yet.
     m_tokenList->enqueue(token);
   }
 
@@ -310,7 +307,6 @@ Rule::cacheParse(char *rule, unsigned short minNumToken, unsigned short maxNumTo
   TokenList *m_tokenList = new TokenList();
 
   for (; tokenStr; tokenStr = ruleTok.iterNext(&ruleTok_state)) {
-
     if (!insideQuote) {
       Tokenizer subruleTok("=");
       int numSubRuleTok = subruleTok.Initialize(tokenStr);
@@ -320,6 +316,7 @@ Rule::cacheParse(char *rule, unsigned short minNumToken, unsigned short maxNumTo
       // Every token must have a '=' sign
       if (numSubRuleTok < 2) {
         setErrorHint("'=' is expected in space-delimited token");
+        delete m_tokenList;
         return NULL;
       }
 
@@ -349,13 +346,13 @@ Rule::cacheParse(char *rule, unsigned short minNumToken, unsigned short maxNumTo
         //          printf("%s 1\n", subtoken);
         token->appendValue(newStr);
       }
-      ats_free((void*)newStr);
+      ats_free((void *)newStr);
 
     } else {
       //      printf("%s 2\n", tokenStr);
       newStr = strtrim(tokenStr, '\"');
       token->appendValue(newStr);
-      ats_free((void*)newStr);
+      ats_free((void *)newStr);
       insideQuote = inQuote(tokenStr);
       if (insideQuote) {
         //              printf("enqueue\n");
@@ -370,7 +367,6 @@ Rule::cacheParse(char *rule, unsigned short minNumToken, unsigned short maxNumTo
 }
 
 
-
 /**
  * congestionParse
  **/
@@ -405,7 +401,7 @@ Rule::icpParse(char *rule, unsigned short minNumToken, unsigned short maxNumToke
   tok_iter_state ruleTok_state;
   const char *tokenStr = ruleTok.iterFirst(&ruleTok_state);
   Token *token;
-  TokenList *m_tokenList = new TokenList();
+  TokenList *m_tokenList;
 
   // Sanity Check -- number of token
   if (numRuleTok < minNumToken) {
@@ -419,6 +415,7 @@ Rule::icpParse(char *rule, unsigned short minNumToken, unsigned short maxNumToke
   }
 
 
+  m_tokenList = new TokenList();
   for (; tokenStr; tokenStr = ruleTok.iterNext(&ruleTok_state)) {
     token = new Token();
     token->setName(tokenStr);
@@ -589,7 +586,7 @@ Rule::socksParse(char *rule)
   TokenList *m_tokenList = new TokenList();
 
   /* check which rule type it is */
-  if (strcmp(tokenStr, "no_socks") == 0) {      /* TS_SOCKS_BYPASS rule type */
+  if (strcmp(tokenStr, "no_socks") == 0) { /* TS_SOCKS_BYPASS rule type */
     /* the token name = "no socks", the value = "list of ip addresses" */
     token = new Token();
     token->setName(tokenStr);
@@ -598,14 +595,14 @@ Rule::socksParse(char *rule)
       token->appendValue(tokenStr);
     }
     m_tokenList->enqueue(token);
-  } else if (strcmp(tokenStr, "auth") == 0) {   /* TS_SOCKS_AUTH rule type */
-    /* first token:  name = "auth", value = "u"
-       second token: name = <username>
-       third token:  name = <password> */
+  } else if (strcmp(tokenStr, "auth") == 0) { /* TS_SOCKS_AUTH rule type */
+                                              /* first token:  name = "auth", value = "u"
+                                                 second token: name = <username>
+                                                 third token:  name = <password> */
     token = new Token();
     token->setName(tokenStr);
     tokenStr = ruleTok.iterNext(&ruleTok_state);
-    token->setValue(tokenStr);  /* should be "u" authoriziation type */
+    token->setValue(tokenStr); /* should be "u" authoriziation type */
     m_tokenList->enqueue(token);
 
     /* create tokens for username and password */
@@ -615,7 +612,7 @@ Rule::socksParse(char *rule)
       m_tokenList->enqueue(token);
     }
 
-  } else {                      /* TS_SOCKS_MULTIPLE rule type */
+  } else { /* TS_SOCKS_MULTIPLE rule type */
     for (; tokenStr; tokenStr = ruleTok.iterNext(&ruleTok_state)) {
       /* token is a name-value pair separated with = sign */
       if (!insideQuote) {
@@ -656,13 +653,13 @@ Rule::socksParse(char *rule)
           //          printf("%s 1\n", subtoken);
           token->appendValue(newStr);
         }
-        ats_free((void*)newStr);
+        ats_free((void *)newStr);
 
       } else {
         //      printf("%s 2\n", tokenStr);
         newStr = strtrim(tokenStr, '\"');
         token->appendValue(newStr);
-        ats_free((void*)newStr);
+        ats_free((void *)newStr);
         insideQuote = inQuote(tokenStr);
         if (insideQuote) {
           //              printf("enqueue\n");
@@ -672,8 +669,7 @@ Rule::socksParse(char *rule)
           insideQuote = true;
         }
       }
-    }                           /* end for loop */
-
+    } /* end for loop */
   }
 
   return m_tokenList;
@@ -716,7 +712,6 @@ Rule::splitdnsParse(char *rule)
   TokenList *m_tokenList = new TokenList();
 
   for (; tokenStr; tokenStr = ruleTok.iterNext(&ruleTok_state)) {
-
     if (!insideQuote) {
       Tokenizer subruleTok("=");
       int numSubRuleTok = subruleTok.Initialize(tokenStr);
@@ -726,6 +721,7 @@ Rule::splitdnsParse(char *rule)
       // Every token must have a '=' sign
       if (numSubRuleTok < 2) {
         setErrorHint("'=' is expected in space-delimited token");
+        delete m_tokenList;
         return NULL;
       }
 
@@ -743,13 +739,13 @@ Rule::splitdnsParse(char *rule)
         //          printf("%s 1\n", subtoken);
         token->appendValue(newStr);
       }
-      ats_free((void*)newStr);
+      ats_free((void *)newStr);
 
     } else {
       //            printf("%s 2\n", tokenStr);
       newStr = strtrim(tokenStr, '\"');
       token->appendValue(newStr);
-      ats_free((void*)newStr);
+      ats_free((void *)newStr);
       insideQuote = inQuote(tokenStr);
       if (insideQuote) {
         //              printf("enqueue\n");
@@ -780,7 +776,7 @@ Rule::updateParse(char *rule)
   // NOTE: ignore white spaces before/after the '\'
   // There should only be 5 tokens; if there are 6 tokens, the
   // sixth token must be all white spaces
-  if (numRuleTok<5 || numRuleTok> 6 || (numRuleTok == 6 && strspn(ruleTok[5], " ") != strlen(ruleTok[5]))) {
+  if (numRuleTok < 5 || numRuleTok > 6 || (numRuleTok == 6 && strspn(ruleTok[5], " ") != strlen(ruleTok[5]))) {
     setErrorHint("Expecting exactly 5 '\' delimited tokens");
     return NULL;
   }
@@ -849,7 +845,7 @@ Rule::storageParse(char *rule)
   // at least one token, anyways
   token = new Token();
   token->setName(tokenStr);
-  if (numRuleTok > 1) {         // numRulTok == 2
+  if (numRuleTok > 1) { // numRulTok == 2
     tokenStr = ruleTok.iterNext(&ruleTok_state);
     token->setValue(tokenStr);
   }
@@ -865,10 +861,10 @@ Rule::storageParse(char *rule)
  *   RETURN true  if "str" contains odd  number of quotes (")
  *          false if "str" contains even number of quotes (including zero)
  */
-bool Rule::inQuote(const char *str)
+bool
+Rule::inQuote(const char *str)
 {
-  unsigned
-    numQuote = 0;
+  unsigned numQuote = 0;
   for (const char *ptr = str; *ptr != '\0'; ptr++) {
     if (*ptr == '\"') {
       numQuote++;
@@ -887,8 +883,7 @@ bool Rule::inQuote(const char *str)
  *   continue parsing each rule.
  *   NOTE: a rule that spans more than one line would be a problem in here.
  ***************************************************************************/
-RuleList::RuleList()
- : length(0), m_filename(NULL)
+RuleList::RuleList() : length(0), m_filename(NULL)
 {
   m_filetype = TS_FNAME_UNDEFINED;
 }
@@ -907,7 +902,7 @@ void
 RuleList::Print()
 {
   printf("RULELIST-->\n");
-  for (Rule * rule = first(); rule; rule = next(rule)) {
+  for (Rule *rule = first(); rule; rule = next(rule)) {
     rule->Print();
   }
   printf("length: %u\n", length);
@@ -925,39 +920,38 @@ RuleList::parse(char *fileBuf, const char *filename)
   m_filename = ats_strdup(filename);
 
   if (strstr(filename, "cache.config")) {
-    m_filetype = TS_FNAME_CACHE_OBJ;   /* cache.config */
+    m_filetype = TS_FNAME_CACHE_OBJ; /* cache.config */
   } else if (strstr(filename, "congestion.config")) {
-    m_filetype = TS_FNAME_CONGESTION;  /* congestion.config */
+    m_filetype = TS_FNAME_CONGESTION; /* congestion.config */
   } else if (strstr(filename, "hosting.config")) {
-    m_filetype = TS_FNAME_HOSTING;     /* hosting.config */
+    m_filetype = TS_FNAME_HOSTING; /* hosting.config */
   } else if (strstr(filename, "icp.config")) {
-    m_filetype = TS_FNAME_ICP_PEER;    /* icp.config */
+    m_filetype = TS_FNAME_ICP_PEER; /* icp.config */
   } else if (strstr(filename, "ip_allow.config")) {
-    m_filetype = TS_FNAME_IP_ALLOW;    /* ip_allow.config */
+    m_filetype = TS_FNAME_IP_ALLOW; /* ip_allow.config */
   } else if (strstr(filename, "logs_xml.config")) {
-    m_filetype = TS_FNAME_LOGS_XML;    /* logs_xml.config */
+    m_filetype = TS_FNAME_LOGS_XML; /* logs_xml.config */
   } else if (strstr(filename, "parent.config")) {
-    m_filetype = TS_FNAME_PARENT_PROXY;        /* parent.config */
+    m_filetype = TS_FNAME_PARENT_PROXY; /* parent.config */
   } else if (strstr(filename, "volume.config")) {
-    m_filetype = TS_FNAME_VOLUME;   /* volume.config */
+    m_filetype = TS_FNAME_VOLUME; /* volume.config */
   } else if (strstr(filename, "plugin.config")) {
-    m_filetype = TS_FNAME_PLUGIN;      /* plugin.config */
+    m_filetype = TS_FNAME_PLUGIN; /* plugin.config */
   } else if (strstr(filename, "remap.config")) {
-    m_filetype = TS_FNAME_REMAP;       /* remap.config */
+    m_filetype = TS_FNAME_REMAP; /* remap.config */
   } else if (strstr(filename, "socks.config")) {
-    m_filetype = TS_FNAME_SOCKS;       /* socks.config */
+    m_filetype = TS_FNAME_SOCKS; /* socks.config */
   } else if (strstr(filename, "splitdns.config")) {
-    m_filetype = TS_FNAME_SPLIT_DNS;   /* splitdns.config */
+    m_filetype = TS_FNAME_SPLIT_DNS; /* splitdns.config */
   } else if (strstr(filename, "update.config")) {
-    m_filetype = TS_FNAME_UPDATE_URL;  /* update.config */
+    m_filetype = TS_FNAME_UPDATE_URL; /* update.config */
   } else if (strstr(filename, "vaddrs.config")) {
-    m_filetype = TS_FNAME_VADDRS;      /* vaddrs.config */
+    m_filetype = TS_FNAME_VADDRS; /* vaddrs.config */
   } else if (strstr(filename, "plugin.config")) {
-    m_filetype = TS_FNAME_UNDEFINED;   /* plugin.config */
+    m_filetype = TS_FNAME_UNDEFINED; /* plugin.config */
   } else if (strstr(filename, "storage.config")) {
-    m_filetype = TS_FNAME_STORAGE;     /* storage.config */
-  }
-  else {
+    m_filetype = TS_FNAME_STORAGE; /* storage.config */
+  } else {
     m_filetype = TS_FNAME_UNDEFINED;
   }
 
@@ -992,7 +986,7 @@ RuleList::parse(char *fileBuf, TSFileNameT filetype)
   while (line) {
     Rule *rule = new Rule();
 
-    if (line[0] == '#') {       // is this comment
+    if (line[0] == '#') { // is this comment
       rule->setComment(line);
     } else {
       TokenList *m_tokenList = rule->parse(line, filetype);
@@ -1000,7 +994,7 @@ RuleList::parse(char *fileBuf, TSFileNameT filetype)
         rule->setRuleStr(line);
         rule->tokenList = m_tokenList;
       } else {
-        //rule->setComment("## WARNING: The following configuration rule is invalid!");
+        // rule->setComment("## WARNING: The following configuration rule is invalid!");
         size_t error_rule_size = sizeof(char) * (strlen(line) + strlen("#ERROR: ") + 1);
         char *error_rule = (char *)ats_malloc(error_rule_size);
 
@@ -1010,13 +1004,13 @@ RuleList::parse(char *fileBuf, TSFileNameT filetype)
       }
     }
 
-    //rule->Print();
+    // rule->Print();
     this->enqueue(rule);
 
     // Get next line
     line = lineTok.iterNext(&lineTok_state);
   }
-  //this->Print();
+  // this->Print();
 }
 
 
@@ -1029,10 +1023,10 @@ RuleList::parse(char *fileBuf, TSFileNameT filetype)
 char *
 strtrim(char *str) {
   while(isspace(*str)) {
-	str++;
+        str++;
   }
   while(isspace(str[strlen(str)-1])) {
-	str[strlen(str)-1] = '\0';
+        str[strlen(str)-1] = '\0';
   }
   return str;
 }
@@ -1046,7 +1040,7 @@ strtrim(const char *str_in, char chr)
 {
   char *str = ats_strdup(str_in);
 
-  char *str_ptr = str;          // so we can free str later if it changes
+  char *str_ptr = str; // so we can free str later if it changes
   while (*str == chr) {
     str++;
   }
