@@ -71,7 +71,7 @@ str_to_datatype(const char *str)
  * @return CcTxnState hashEntry added, should be ignore and pass, or fail
  */
 static TSReturnCode
-CcHttpTxnConfigFind(const char *name, int length, CcConfigKey * conf, TSRecordDataType * type)
+CcHttpTxnConfigFind(const char *name, int length, CcConfigKey *conf, TSRecordDataType *type)
 {
   *type = TS_RECORDDATATYPE_NULL;
 
@@ -125,7 +125,7 @@ static CcPluginConfig *
 initConfig(const char *fn)
 {
   CcPluginData *plugin_data = getCcPlugin();
-  CcPluginConfig *config = static_cast < CcPluginConfig * >(TSmalloc(sizeof(CcPluginConfig)));
+  CcPluginConfig *config = static_cast<CcPluginConfig *>(TSmalloc(sizeof(CcPluginConfig)));
 
   // Default config
   if (NULL == plugin_data || NULL == plugin_data->global_config) {
@@ -168,7 +168,7 @@ initConfig(const char *fn)
           char *ln, *tok;
           char *s = buf;
 
-          ++line_num;           // First line is #1 ...
+          ++line_num; // First line is #1 ...
           while (isspace(*s))
             ++s;
           tok = strtok_r(s, " \t", &ln);
@@ -260,11 +260,11 @@ initConfig(const char *fn)
     config->required_header_len = 0;
   }
 
-  TSDebug(PLUGIN_NAME, "enabled = %d", static_cast < int >(config->enabled));
+  TSDebug(PLUGIN_NAME, "enabled = %d", static_cast<int>(config->enabled));
   TSDebug(PLUGIN_NAME, "required_header = %s", config->required_header);
-  TSDebug(PLUGIN_NAME, "insert_lock_retry_time = %d", static_cast < int >(config->insert_lock_retry_time));
-  TSDebug(PLUGIN_NAME, "max_lock_retry_timeout = %d", static_cast < int >(config->max_lock_retry_timeout));
-  TSDebug(PLUGIN_NAME, "keep_pass_record_time = %d", static_cast < int >(config->keep_pass_record_time));
+  TSDebug(PLUGIN_NAME, "insert_lock_retry_time = %d", static_cast<int>(config->insert_lock_retry_time));
+  TSDebug(PLUGIN_NAME, "max_lock_retry_timeout = %d", static_cast<int>(config->max_lock_retry_timeout));
+  TSDebug(PLUGIN_NAME, "keep_pass_record_time = %d", static_cast<int>(config->keep_pass_record_time));
 
   return config;
 }
@@ -278,7 +278,7 @@ initConfig(const char *fn)
  * @return int64_t current Hash Map size
  */
 static int64_t
-getCurrentHashEntries(UintMap * map)
+getCurrentHashEntries(UintMap *map)
 {
   static int64_t cur = 0;
   static int64_t max = 0;
@@ -308,7 +308,7 @@ getCurrentHashEntries(UintMap * map)
  * @return int64_t current List size
  */
 static int64_t
-getCurrentKeepPassEntries(UsecList * list)
+getCurrentKeepPassEntries(UsecList *list)
 {
   CcPluginData *plugin_data = getCcPlugin();
   static int64_t cur = 0;
@@ -342,10 +342,10 @@ addOrCheckKeepPassRecords(uint32_t hash_key, int64_t timeout)
   CcPluginData *plugin_data = getCcPlugin();
   UintMap *active_hash_map = plugin_data->active_hash_map;
   UsecList *keep_pass_list = plugin_data->keep_pass_list;
-  std::list < PassRecord >::iterator it;
+  std::list<PassRecord>::iterator it;
   PassRecord passRecord;
   bool added = true;
-  TSHRTime cur_ms = TShrtime() / TS_HRTIME_MSECOND;     // TS-2200, ats_dev-4.1+
+  TSHRTime cur_ms = TShrtime() / TS_HRTIME_MSECOND; // TS-2200, ats_dev-4.1+
 
   // Only gc per 0.1ms
   if (0 == hash_key && timeout == 0) {
@@ -363,7 +363,7 @@ addOrCheckKeepPassRecords(uint32_t hash_key, int64_t timeout)
     if (keep_pass_list->empty()) {
       push_back = true;
     } else {
-      PassRecord & lastRecord = *(keep_pass_list->end());
+      PassRecord &lastRecord = *(keep_pass_list->end());
 
       if (lastRecord.timeout <= passRecord.timeout) {
         push_back = true;
@@ -373,15 +373,15 @@ addOrCheckKeepPassRecords(uint32_t hash_key, int64_t timeout)
     if (push_back) {
       keep_pass_list->push_back(passRecord);
       getCurrentKeepPassEntries(keep_pass_list);
-      TSDebug(PLUGIN_NAME,
-              "push_back pass entry with timeout = %zd, hash_key = %u", passRecord.timeout, passRecord.hash_key);
+      TSDebug(PLUGIN_NAME, "push_back pass entry with timeout = %" PRId64 ", hash_key = %" PRIu32, passRecord.timeout,
+              passRecord.hash_key);
     } else {
       added = false;
     }
   }
 
   for (it = keep_pass_list->begin(); it != keep_pass_list->end(); ++it) {
-    PassRecord & thisRecord = *it;
+    PassRecord &thisRecord = *it;
 
     if (thisRecord.timeout <= cur_ms) {
       UintMap::iterator pos = active_hash_map->find(thisRecord.hash_key);
@@ -391,15 +391,14 @@ addOrCheckKeepPassRecords(uint32_t hash_key, int64_t timeout)
       }
       keep_pass_list->erase(it++);
       getCurrentKeepPassEntries(keep_pass_list);
-      TSDebug(PLUGIN_NAME,
-              "remove pass entry with timeout = %zd, hash_key = %u", thisRecord.timeout, thisRecord.hash_key);
+      TSDebug(PLUGIN_NAME, "remove pass entry with timeout = %" PRId64 ", hash_key = %" PRIu32, thisRecord.timeout,
+              thisRecord.hash_key);
     } else if (false == added) {
       if (thisRecord.timeout >= passRecord.timeout) {
         keep_pass_list->insert(it, passRecord);
         getCurrentKeepPassEntries(keep_pass_list);
-        TSDebug(PLUGIN_NAME,
-                "insert pass entry with timeout = %zd, hash_key = %u", passRecord.timeout, passRecord.hash_key);
-        added = true;
+        TSDebug(PLUGIN_NAME, "insert pass entry with timeout = %" PRId64 ", hash_key = %" PRIu32, passRecord.timeout,
+                passRecord.hash_key);
         break;
       }
     } else {
@@ -419,7 +418,7 @@ addOrCheckKeepPassRecords(uint32_t hash_key, int64_t timeout)
  * @return CcTxnState hashEntry added, should be ignore and pass, or fail
  */
 static CcTxnState
-insertNewHashEntry(CcTxnData * txn_data)
+insertNewHashEntry(CcTxnData *txn_data)
 {
   CcPluginData *plugin_data = getCcPlugin();
   CcTxnState ret = CC_NONE;
@@ -430,14 +429,14 @@ insertNewHashEntry(CcTxnData * txn_data)
   }
 
   if (TS_SUCCESS == TSMutexLockTry(plugin_data->mutex)) {
-    std::pair < std::map < uint32_t, int8_t >::iterator, bool > map_ret;
+    std::pair<std::map<uint32_t, int8_t>::iterator, bool> map_ret;
     int64_t size = 0;
     addOrCheckKeepPassRecords(0, 0);
     map_ret = active_hash_map->insert(std::make_pair(txn_data->hash_key, CC_INSERT));
     size = getCurrentHashEntries(active_hash_map);
     TSMutexUnlock(plugin_data->mutex);
     if (false != map_ret.second) {
-      TSDebug(PLUGIN_NAME, "[%" PRIu64 "] hash_key inserted, active_hash_map.size = %zd", txn_data->seq_id, size);
+      TSDebug(PLUGIN_NAME, "[%" PRIu64 "] hash_key inserted, active_hash_map.size = %" PRId64, txn_data->seq_id, size);
       ret = CC_INSERT;
     } else if (CC_PASS == map_ret.first->second) {
       TSDebug(PLUGIN_NAME, "hash value = %d, previous request mark it non-cacheable", map_ret.first->second);
@@ -451,7 +450,7 @@ insertNewHashEntry(CcTxnData * txn_data)
   }
 
   if (CC_INSERT != ret && CC_PASS != ret) {
-    TSHRTime cur_ms = TShrtime() / TS_HRTIME_MSECOND;   // TS-2200, ats_dev-4.1+
+    TSHRTime cur_ms = TShrtime() / TS_HRTIME_MSECOND; // TS-2200, ats_dev-4.1+
 
     if (0 == txn_data->wait_time) {
       txn_data->wait_time = cur_ms;
@@ -459,12 +458,12 @@ insertNewHashEntry(CcTxnData * txn_data)
       txn_data->wait_time = cur_ms - txn_data->wait_time;
       // Pass cache lock
       ret = CC_PASS;
-      TSDebug(PLUGIN_NAME, "timeout (%zd > %d), pass plugin",
-              txn_data->wait_time, static_cast < int32_t > (txn_data->config->max_lock_retry_timeout));
+      TSDebug(PLUGIN_NAME, "timeout (%" PRId64 " > %d), pass plugin", txn_data->wait_time,
+              static_cast<int32_t>(txn_data->config->max_lock_retry_timeout));
     }
   } else if (0 != txn_data->wait_time) {
     txn_data->wait_time = TShrtime() / 1000000 - txn_data->wait_time;
-    TSDebug(PLUGIN_NAME, "waited for %zd ms", txn_data->wait_time);
+    TSDebug(PLUGIN_NAME, "waited for %" PRId64 " ms", txn_data->wait_time);
   }
 
   return ret;
@@ -478,7 +477,7 @@ insertNewHashEntry(CcTxnData * txn_data)
  * @return TSReturnCode Success or failure
  */
 static TSReturnCode
-updateOrRemoveHashEntry(CcTxnData * txn_data)
+updateOrRemoveHashEntry(CcTxnData *txn_data)
 {
   TSReturnCode ret = TS_ERROR;
   CcPluginData *plugin_data = getCcPlugin();
@@ -504,14 +503,14 @@ updateOrRemoveHashEntry(CcTxnData * txn_data)
       size = getCurrentHashEntries(active_hash_map);
       TSMutexUnlock(plugin_data->mutex);
 
-      TSDebug(PLUGIN_NAME, "[%" PRIu64 "] hashEntry updated, active_hash_map.size = %zd", txn_data->seq_id, size);
+      TSDebug(PLUGIN_NAME, "[%" PRIu64 "] hashEntry updated, active_hash_map.size = %" PRId64, txn_data->seq_id, size);
       txn_data->cc_state = CC_PASSED;
     } else {
       addOrCheckKeepPassRecords(0, 0);
       size = getCurrentHashEntries(active_hash_map);
       TSMutexUnlock(plugin_data->mutex);
 
-      TSDebug(PLUGIN_NAME, "[%" PRIu64 "] hashEntry removed, active_hash_map.size = %zd", txn_data->seq_id, size);
+      TSDebug(PLUGIN_NAME, "[%" PRIu64 "] hashEntry removed, active_hash_map.size = %" PRId64, txn_data->seq_id, size);
       txn_data->cc_state = CC_DONE;
     }
     ret = TS_SUCCESS;
@@ -623,7 +622,7 @@ isResponseCacheable(TSMBuffer bufp, TSMLoc hdr_loc)
 static int
 retryCacheUrlLock(TSCont contp, TSEvent /* event ATS_UNUSED */, void * /* edata ATS_UNUSED */)
 {
-  TryLockData *data = reinterpret_cast < TryLockData * >(TSContDataGet(contp));
+  TryLockData *data = reinterpret_cast<TryLockData *>(TSContDataGet(contp));
   TSDebug(PLUGIN_NAME, "[%" PRIu64 "] event = %d retry", data->txn_data->seq_id, data->event);
   collapsedConnectionMainHandler(NULL, data->event, data->txn_data->txnp);
   TSfree(data);
@@ -643,10 +642,10 @@ retryCacheUrlLock(TSCont contp, TSEvent /* event ATS_UNUSED */, void * /* edata
  * @return void
  */
 static void
-addMutexRetry(CcTxnData * txn_data, TSEvent event, TSHRTime timeout)
+addMutexRetry(CcTxnData *txn_data, TSEvent event, TSHRTime timeout)
 {
   TSCont contp = TSContCreate(retryCacheUrlLock, NULL);
-  TryLockData *data = static_cast < TryLockData * >(TSmalloc(sizeof(TryLockData)));
+  TryLockData *data = static_cast<TryLockData *>(TSmalloc(sizeof(TryLockData)));
 
   data->event = event;
   data->txn_data = txn_data;
@@ -671,9 +670,9 @@ getCcTxnData(TSHttpTxn txnp, bool create, bool remap)
   CcPluginData *plugin_data = getCcPlugin();
   CcTxnData *txn_data = NULL;
 
-  txn_data = reinterpret_cast < CcTxnData * >(TSHttpTxnArgGet(txnp, plugin_data->txn_slot));
+  txn_data = reinterpret_cast<CcTxnData *>(TSHttpTxnArgGet(txnp, plugin_data->txn_slot));
   if (NULL == txn_data && true == create) {
-    txn_data = static_cast < CcTxnData * >(TSmalloc(sizeof(CcTxnData)));
+    txn_data = static_cast<CcTxnData *>(TSmalloc(sizeof(CcTxnData)));
     txn_data->config = plugin_data->global_config;
     txn_data->seq_id = plugin_data->seq_id++;
     txn_data->txnp = txnp;
@@ -701,7 +700,7 @@ getCcTxnData(TSHttpTxn txnp, bool create, bool remap)
  * @return void
  */
 static void
-freeCcTxnData(CcTxnData * txn_data)
+freeCcTxnData(CcTxnData *txn_data)
 {
   CcPluginData *plugin_data = getCcPlugin();
 
@@ -726,14 +725,14 @@ freeCcTxnData(CcTxnData * txn_data)
  * @return TSReturnCode
  */
 static TSReturnCode
-lookupAndTryLockCacheUrl(CcTxnData * txn_data, TSEvent event)
+lookupAndTryLockCacheUrl(CcTxnData *txn_data, TSEvent event)
 {
   CcTxnState ret;
   CcPluginData *plugin_data = getCcPlugin();
 
   if (0 == txn_data->hash_key) {
     // New request, check is GET method and gen hash_key
-    TSMBuffer bufp = (TSMBuffer) NULL;
+    TSMBuffer bufp = (TSMBuffer)NULL;
     TSMLoc hdr_loc = TS_NULL_MLOC;
     int method_len;
     const char *method = NULL;
@@ -745,10 +744,8 @@ lookupAndTryLockCacheUrl(CcTxnData * txn_data, TSEvent event)
     }
 
     if (txn_data->config->required_header_len > 0) {
-      TSMLoc field_loc = TSMimeHdrFieldFind(bufp,
-                                            hdr_loc,
-                                            txn_data->config->required_header,
-                                            txn_data->config->required_header_len);
+      TSMLoc field_loc =
+        TSMimeHdrFieldFind(bufp, hdr_loc, txn_data->config->required_header, txn_data->config->required_header_len);
       if (!field_loc) {
         TSDebug(PLUGIN_NAME, "%s header not found, ignore it", txn_data->config->required_header);
         TSHandleMLocRelease(bufp, TS_NULL_MLOC, hdr_loc);
@@ -815,9 +812,9 @@ lookupAndTryLockCacheUrl(CcTxnData * txn_data, TSEvent event)
  * @return TSReturnCode
  */
 static TSReturnCode
-testResponseCacheable(CcTxnData * txn_data)
+testResponseCacheable(CcTxnData *txn_data)
 {
-  TSMBuffer bufp = (TSMBuffer) NULL;
+  TSMBuffer bufp = (TSMBuffer)NULL;
   TSMLoc hdr_loc = TS_NULL_MLOC;
   TSHttpStatus resp_status;
 
@@ -866,7 +863,7 @@ testResponseCacheable(CcTxnData * txn_data)
  * @return TSReturnCode
  */
 static TSReturnCode
-testCacheLookupResult(CcTxnData * txn_data)
+testCacheLookupResult(CcTxnData *txn_data)
 {
   int status = 0;
 
@@ -902,13 +899,12 @@ testCacheLookupResult(CcTxnData * txn_data)
 static int
 collapsedConnectionMainHandler(TSCont /* contp ATS_UNUSED */, TSEvent event, void *edata)
 {
-  TSHttpTxn txnp = reinterpret_cast < TSHttpTxn > (edata);
+  TSHttpTxn txnp = reinterpret_cast<TSHttpTxn>(edata);
   CcTxnData *txn_data = getCcTxnData(txnp, TS_EVENT_HTTP_POST_REMAP == event, false);
 
   if (NULL != txn_data) {
-    TSDebug(PLUGIN_NAME,
-            "[%" PRIu64 "], event = %d, txn_data-> hash_key = %u, cc_state = %d",
-            txn_data->seq_id, event, txn_data->hash_key, txn_data->cc_state);
+    TSDebug(PLUGIN_NAME, "[%" PRIu64 "], event = %d, txn_data-> hash_key = %u, cc_state = %d", txn_data->seq_id, event,
+            txn_data->hash_key, txn_data->cc_state);
 
     switch (event) {
     case TS_EVENT_HTTP_POST_REMAP:
@@ -935,6 +931,7 @@ collapsedConnectionMainHandler(TSCont /* contp ATS_UNUSED */, TSEvent event, voi
     case TS_EVENT_HTTP_TXN_CLOSE:
       if (CC_DONE == txn_data->cc_state) {
         freeCcTxnData(txn_data);
+        txn_data = NULL;
         TSHttpTxnReenable(txnp, TS_EVENT_HTTP_CONTINUE);
       } else if (CC_PASS == txn_data->cc_state || CC_PASSED == txn_data->cc_state) {
         // keep pass sentinel for config->keep_pass_record_time
@@ -943,12 +940,13 @@ collapsedConnectionMainHandler(TSCont /* contp ATS_UNUSED */, TSEvent event, voi
             addMutexRetry(txn_data, event, 0);
           } else {
             freeCcTxnData(txn_data);
+            txn_data = NULL;
           }
         } else {
           txn_data->cc_state = CC_REMOVE;
         }
       }
-      if (CC_INSERT == txn_data->cc_state || CC_REMOVE == txn_data->cc_state) {
+      if (txn_data && (CC_INSERT == txn_data->cc_state || CC_REMOVE == txn_data->cc_state)) {
         txn_data->cc_state = CC_REMOVE;
         if (TS_SUCCESS == updateOrRemoveHashEntry(txn_data)) {
           freeCcTxnData(txn_data);
@@ -982,7 +980,7 @@ getCcPlugin()
 
   if (NULL == data) {
     TSMgmtInt read_while_writer = 0;
-    data = static_cast < CcPluginData * >(TSmalloc(sizeof(CcPluginData)));
+    data = static_cast<CcPluginData *>(TSmalloc(sizeof(CcPluginData)));
     data->mutex = TSMutexCreate();
     data->active_hash_map = new UintMap();
     data->keep_pass_list = new UsecList();
@@ -990,38 +988,28 @@ getCcPlugin()
     data->global_config = NULL;
     TSHttpArgIndexReserve(PLUGIN_NAME, "reserve txn_data slot", &(data->txn_slot));
 
-    if (TS_SUCCESS == TSMgmtIntGet("proxy.config.cache.enable_read_while_writer",
-                                   &read_while_writer) && read_while_writer > 0) {
+    if (TS_SUCCESS == TSMgmtIntGet("proxy.config.cache.enable_read_while_writer", &read_while_writer) && read_while_writer > 0) {
       data->read_while_writer = true;
     }
 
     data->tol_global_hook_reqs =
-      TSStatCreate("collapsed_connection.total.global.reqs",
-                   TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
+      TSStatCreate("collapsed_connection.total.global.reqs", TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
     data->tol_remap_hook_reqs =
-      TSStatCreate("collapsed_connection.total.remap.reqs",
-                   TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
+      TSStatCreate("collapsed_connection.total.remap.reqs", TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
     data->tol_collapsed_reqs =
-      TSStatCreate("collapsed_connection.total.collapsed.reqs",
-                   TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
+      TSStatCreate("collapsed_connection.total.collapsed.reqs", TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
     data->tol_non_cacheable_reqs =
-      TSStatCreate("collapsed_connection.total.noncacheable.reqs",
-                   TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
+      TSStatCreate("collapsed_connection.total.noncacheable.reqs", TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
     data->tol_got_passed_reqs =
-      TSStatCreate("collapsed_connection.total.got_passed.reqs",
-                   TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
+      TSStatCreate("collapsed_connection.total.got_passed.reqs", TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
     data->cur_hash_entries =
-      TSStatCreate("collapsed_connection.current.hash.entries",
-                   TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
-    data->cur_keep_pass_entries =
-      TSStatCreate("collapsed_connection.current.keep_pass.entries",
-                   TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
+      TSStatCreate("collapsed_connection.current.hash.entries", TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
+    data->cur_keep_pass_entries = TSStatCreate("collapsed_connection.current.keep_pass.entries", TS_RECORDDATATYPE_INT,
+                                               TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
     data->max_hash_entries =
-      TSStatCreate("collapsed_connection.max.hash.entries",
-                   TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
+      TSStatCreate("collapsed_connection.max.hash.entries", TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
     data->max_keep_pass_entries =
-      TSStatCreate("collapsed_connection.max.keep_pass.entries",
-                   TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
+      TSStatCreate("collapsed_connection.max.keep_pass.entries", TS_RECORDDATATYPE_INT, TS_STAT_NON_PERSISTENT, TS_STAT_SYNC_SUM);
   }
 
   return data;
@@ -1031,7 +1019,7 @@ getCcPlugin()
 // Initialize the TSRemapAPI plugin.
 //
 TSReturnCode
-TSRemapInit(TSRemapInterface * api_info, char *errbuf, int errbuf_size)
+TSRemapInit(TSRemapInterface *api_info, char *errbuf, int errbuf_size)
 {
   if (!api_info) {
     strncpy(errbuf, "[TSRemapInit] - Invalid TSRemapInterface argument", errbuf_size - 1);
@@ -1044,8 +1032,8 @@ TSRemapInit(TSRemapInterface * api_info, char *errbuf, int errbuf_size)
   }
 
   if (api_info->tsremap_version < TSREMAP_VERSION) {
-    snprintf(errbuf, errbuf_size - 1, "[TSRemapInit] - Incorrect API version %ld.%ld",
-             api_info->tsremap_version >> 16, (api_info->tsremap_version & 0xffff));
+    snprintf(errbuf, errbuf_size - 1, "[TSRemapInit] - Incorrect API version %ld.%ld", api_info->tsremap_version >> 16,
+             (api_info->tsremap_version & 0xffff));
     return TS_ERROR;
   }
 
@@ -1059,9 +1047,9 @@ TSReturnCode
 TSRemapNewInstance(int argc, char *argv[], void **ih, char *, int)
 {
   if (argc > 2) {
-    *ih = static_cast < CcPluginConfig * >(initConfig(argv[2]));
+    *ih = static_cast<CcPluginConfig *>(initConfig(argv[2]));
   } else {
-    *ih = static_cast < CcPluginConfig * >(initConfig(NULL));
+    *ih = static_cast<CcPluginConfig *>(initConfig(NULL));
   }
 
   return TS_SUCCESS;
@@ -1070,7 +1058,7 @@ TSRemapNewInstance(int argc, char *argv[], void **ih, char *, int)
 void
 TSRemapDeleteInstance(void *ih)
 {
-  CcPluginConfig *config = static_cast < CcPluginConfig * >(ih);
+  CcPluginConfig *config = static_cast<CcPluginConfig *>(ih);
 
   if (NULL != config->required_header) {
     TSfree(config->required_header);
@@ -1085,11 +1073,11 @@ TSRemapDeleteInstance(void *ih)
 TSRemapStatus
 TSRemapDoRemap(void *ih, TSHttpTxn rh, TSRemapRequestInfo * /* rri ATS_UNUSED */)
 {
-  TSHttpTxn txnp = static_cast < TSHttpTxn > (rh);
+  TSHttpTxn txnp = static_cast<TSHttpTxn>(rh);
   CcPluginData *plugin_data = getCcPlugin();
   CcTxnData *txn_data = getCcTxnData(txnp, true, true);
 
-  txn_data->config = reinterpret_cast < CcPluginConfig * >(ih);
+  txn_data->config = reinterpret_cast<CcPluginConfig *>(ih);
 
   if (!plugin_data->global_config || !plugin_data->global_config->enabled) {
     if (txn_data->config->enabled) {
@@ -1121,9 +1109,9 @@ TSPluginInit(int argc, const char *argv[])
   TSMgmtInt http_cache = 0;
   TSCont contp = NULL;
 
-  info.plugin_name = const_cast < char *>(PLUGIN_NAME);
-  info.vendor_name = const_cast < char *>(PLUGIN_VENDOR);
-  info.support_email = const_cast < char *>(PLUGIN_SUPPORT);
+  info.plugin_name = const_cast<char *>(PLUGIN_NAME);
+  info.vendor_name = const_cast<char *>(PLUGIN_VENDOR);
+  info.support_email = const_cast<char *>(PLUGIN_SUPPORT);
 
   if (TS_SUCCESS != TSPluginRegister(TS_SDK_VERSION_3_0, &info)) {
     TSError("Plugin registration failed");
