@@ -90,6 +90,7 @@ typedef struct {
   /* Digest header field value index */
   int idx;
 
+  TSVConn connp;
   TSIOBuffer cache_bufp;
 
   const char *value;
@@ -113,8 +114,8 @@ cache_open_write(TSCont contp, void *edata)
   char *value;
   int length;
 
-  WriteData *data = (WriteData *) TSContDataGet(contp);
-  data->connp = (TSVConn) edata;
+  WriteData *data = (WriteData *)TSContDataGet(contp);
+  data->connp = (TSVConn)edata;
 
   TSCacheKeyDestroy(data->key);
 
@@ -163,7 +164,7 @@ cache_open_write(TSCont contp, void *edata)
 
   TSfree(value);
 
-  /* Reuse the TSCacheWrite() continuation */
+  /* Reentrant!  Reuse the TSCacheWrite() continuation. */
   TSVConnWrite(data->connp, contp, readerp, nbytes);
 
   return 0;
@@ -172,9 +173,9 @@ cache_open_write(TSCont contp, void *edata)
 /* Do nothing */
 
 static int
-cache_open_write_failed(TSCont contp, void */* edata ATS_UNUSED */)
+cache_open_write_failed(TSCont contp, void * /* edata ATS_UNUSED */)
 {
-  WriteData *data = (WriteData *) TSContDataGet(contp);
+  WriteData *data = (WriteData *)TSContDataGet(contp);
   TSContDestroy(contp);
 
   TSCacheKeyDestroy(data->key);
@@ -184,9 +185,9 @@ cache_open_write_failed(TSCont contp, void */* edata ATS_UNUSED */)
 }
 
 static int
-write_vconn_write_complete(TSCont contp, void */* edata ATS_UNUSED */)
+write_vconn_write_complete(TSCont contp, void * /* edata ATS_UNUSED */)
 {
-  WriteData *data = (WriteData *) TSContDataGet(contp);
+  WriteData *data = (WriteData *)TSContDataGet(contp);
   TSContDestroy(contp);
 
   /* The object is not committed to the cache until the VConnection is
@@ -229,7 +230,9 @@ write_handler(TSCont contp, TSEvent event, void *edata)
  *
  *    1.  Check if we are "closed" before doing anything else to avoid
  *        errors.
+ *
  *    2.  Then deal with any input that's available now.
+ *
  *    3.  Check if the input is complete after dealing with any
  *        available input in case it was the last of it.  If it is
  *        complete, tell downstream, thank upstream, and finish
@@ -293,23 +296,24 @@ write_handler(TSCont contp, TSEvent event, void *edata)
  * and the transaction won't get logged.  (If there are upstream
  * transformations they won't get a chance to clean up otherwise!)
  *
- * Summary of the cases into which each event can fall:
+ * Summary of the cases each event can fall into:
  *
  *    Closed        *We* are "closed".  Clean up allocated data.
- *
- *       Start      First (and last) time the handler was called.
- *                  (This happens when the response is 304 Not Modified.)
- *
- *       Not start  (This happens when the client or origin disconnect
+ *     │
+ *     ├ Start      First (and last) time the handler was called.
+ *     │            (This happens when the response is 304 Not
+ *     │            Modified.)
+ *     │
+ *     └ Not start  (This happens when the client or origin disconnect
  *                  before the message is complete.)
  *
  *    Start         First time the handler was called.  Initialize
- *                  data here because we can't call TSVConnWrite()
- *                  before TS_HTTP_RESPONSE_TRANSFORM_HOOK.
- *
- *       Content length
- *
- *       Chunked response
+ *     │            data here because we can't call TSVConnWrite()
+ *     │            before TS_HTTP_RESPONSE_TRANSFORM_HOOK.
+ *     │
+ *     ├ Content length
+ *     │
+ *     └ Chunked response
  *
  *    Upstream closed
  *                  (This happens when the content length is zero or
@@ -319,27 +323,27 @@ write_handler(TSCont contp, TSEvent event, void *edata)
  *    Available input
  *
  *    Input complete
- *
- *       Deja vu    There might be multiple TS_EVENT_IMMEDIATE events
- *                  between the end of the input and the
- *                  TS_EVENT_VCONN_WRITE_COMPLETE event from
- *                  downstream.
- *
- *       Not deja vu
+ *     │
+ *     ├ Deja vu    There might be multiple TS_EVENT_IMMEDIATE events
+ *     │            between the end of the input and the
+ *     │            TS_EVENT_VCONN_WRITE_COMPLETE event from
+ *     │            downstream.
+ *     │
+ *     └ Not deja vu
  *                  Tell downstream and thank upstream.
  *
  *    Downstream complete
  *                  Clean up the output buffer. */
 
 static int
-vconn_write_ready(TSCont contp, void */* edata ATS_UNUSED */)
+vconn_write_ready(TSCont contp, void * /* edata ATS_UNUSED */)
 {
   const char *value;
   int64_t length;
 
   char digest[32]; /* SHA-256 */
 
-  TransformData *transform_data = (TransformData *) TSContDataGet(contp);
+  TransformData *transform_data = (TransformData *)TSContDataGet(contp);
 
   /* Check if we are "closed" before doing anything else to avoid
    * errors.  We *must* check for this case, if only to clean up
@@ -374,7 +378,8 @@ vconn_write_ready(TSCont contp, void */* edata ATS_UNUSED */)
 
     /* Determines the Content-Length header (or a chunked response) */
 
-    /* Avoid failed assert "nbytes >= 0" if the response is chunked */
+    /* Reentrant!  Avoid failed assert "nbytes >= 0" if the response
+     * is chunked. */
     int nbytes = TSVIONBytesGet(input_viop);
     transform_data->output_viop = TSVConnWrite(output_connp, contp, readerp, nbytes < 0 ? INT64_MAX : nbytes);
 
@@ -387,7 +392,6 @@ vconn_write_ready(TSCont contp, void */* edata ATS_UNUSED */)
    * we get the final chunk of a chunked response. */
   TSIOBufferReader readerp = TSVIOReaderGet(input_viop);
   if (readerp) {
-
     int avail = TSIOBufferReaderAvail(readerp);
     if (avail) {
       TSIOBufferCopy(transform_data->output_bufp, readerp, avail, 0);
@@ -395,7 +399,6 @@ vconn_write_ready(TSCont contp, void */* edata ATS_UNUSED */)
       /* Feed content to the message digest */
       TSIOBufferBlock blockp = TSIOBufferReaderStart(readerp);
       while (blockp) {
-
         /* No allocation? */
         value = TSIOBufferBlockReadStart(blockp, readerp, &length);
         SHA256_Update(&transform_data->c, value, length);
@@ -419,17 +422,16 @@ vconn_write_ready(TSCont contp, void */* edata ATS_UNUSED */)
 
     TSContCall(TSVIOContGet(input_viop), TS_EVENT_VCONN_WRITE_READY, input_viop);
 
-  /* Don't finish computing the digest (and tell downstream and thank
-   * upstream) more than once!  There might be multiple
-   * TS_EVENT_IMMEDIATE events between the end of the input and the
-   * TS_EVENT_VCONN_WRITE_COMPLETE event from downstream, e.g.
-   * INKVConnInternal::reenable() is called by
-   * HttpTunnel::producer_handler() when more input is available and
-   * TransformVConnection::do_io_shutdown() is called by
-   * HttpSM::tunnel_handler_transform_write() when we send our own
-   * TS_EVENT_VCONN_WRITE_COMPLETE event upstream. */
+    /* Don't finish computing the digest (and tell downstream and thank
+     * upstream) more than once!  There might be multiple
+     * TS_EVENT_IMMEDIATE events between the end of the input and the
+     * TS_EVENT_VCONN_WRITE_COMPLETE event from downstream, e.g.
+     * INKVConnInternal::reenable() is called by
+     * HttpTunnel::producer_handler() when more input is available and
+     * TransformVConnection::do_io_shutdown() is called by
+     * HttpSM::tunnel_handler_transform_write() when we send our own
+     * TS_EVENT_VCONN_WRITE_COMPLETE event upstream. */
   } else if (transform_data->txnp) {
-
     int ndone = TSVIONDoneGet(input_viop);
     TSVIONBytesSet(transform_data->output_viop, ndone);
 
@@ -444,9 +446,9 @@ vconn_write_ready(TSCont contp, void */* edata ATS_UNUSED */)
 
     /* Write the digest to the cache */
 
-    SHA256_Final((unsigned char *) digest, &transform_data->c);
+    SHA256_Final((unsigned char *)digest, &transform_data->c);
 
-    WriteData *write_data = (WriteData *) TSmalloc(sizeof(WriteData));
+    WriteData *write_data = (WriteData *)TSmalloc(sizeof(WriteData));
     write_data->txnp = transform_data->txnp;
 
     /* Don't finish computing the digest more than once! */
@@ -454,7 +456,6 @@ vconn_write_ready(TSCont contp, void */* edata ATS_UNUSED */)
 
     write_data->key = TSCacheKeyCreate();
     if (TSCacheKeyDigestSet(write_data->key, digest, sizeof(digest)) != TS_SUCCESS) {
-
       TSCacheKeyDestroy(write_data->key);
       TSfree(write_data);
 
@@ -468,6 +469,7 @@ vconn_write_ready(TSCont contp, void */* edata ATS_UNUSED */)
     contp = TSContCreate(write_handler, NULL);
     TSContDataSet(contp, write_data);
 
+    /* Reentrant! */
     TSCacheWrite(contp, write_data->key);
   }
 
@@ -475,9 +477,9 @@ vconn_write_ready(TSCont contp, void */* edata ATS_UNUSED */)
 }
 
 static int
-transform_vconn_write_complete(TSCont contp, void */* edata ATS_UNUSED */)
+transform_vconn_write_complete(TSCont contp, void * /* edata ATS_UNUSED */)
 {
-  TransformData *data = (TransformData *) TSContDataGet(contp);
+  TransformData *data = (TransformData *)TSContDataGet(contp);
   TSContDestroy(contp);
 
   TSIOBufferDestroy(data->output_bufp);
@@ -513,8 +515,8 @@ transform_handler(TSCont contp, TSEvent event, void *edata)
 static int
 http_read_response_hdr(TSCont /* contp ATS_UNUSED */, void *edata)
 {
-  TransformData *data = (TransformData *) TSmalloc(sizeof(TransformData));
-  data->txnp = (TSHttpTxn) edata;
+  TransformData *data = (TransformData *)TSmalloc(sizeof(TransformData));
+  data->txnp = (TSHttpTxn)edata;
 
   /* Can't initialize data here because we can't call TSVConnWrite()
    * before TS_HTTP_RESPONSE_TRANSFORM_HOOK */
@@ -538,14 +540,13 @@ http_read_response_hdr(TSCont /* contp ATS_UNUSED */, void *edata)
 static int
 cache_open_read(TSCont contp, void *edata)
 {
-  SendData *data = (SendData *) TSContDataGet(contp);
-
-  TSVConn connp = (TSVConn) edata;
+  SendData *data = (SendData *)TSContDataGet(contp);
+  data->connp = (TSVConn)edata;
 
   data->cache_bufp = TSIOBufferCreate();
 
-  /* Reuse the TSCacheRead() continuation */
-  TSVConnRead(connp, contp, data->cache_bufp, INT64_MAX);
+  /* Reentrant!  Reuse the TSCacheRead() continuation. */
+  TSVConnRead(data->connp, contp, data->cache_bufp, INT64_MAX);
 
   return 0;
 }
@@ -553,9 +554,9 @@ cache_open_read(TSCont contp, void *edata)
 /* Do nothing, just reenable the response */
 
 static int
-cache_open_read_failed(TSCont contp, void */* edata ATS_UNUSED */)
+cache_open_read_failed(TSCont contp, void * /* edata ATS_UNUSED */)
 {
-  SendData *data = (SendData *) TSContDataGet(contp);
+  SendData *data = (SendData *)TSContDataGet(contp);
   TSContDestroy(contp);
 
   TSCacheKeyDestroy(data->key);
@@ -574,13 +575,14 @@ cache_open_read_failed(TSCont contp, void */* edata ATS_UNUSED */)
  * cached */
 
 static int
-rewrite_handler(TSCont contp, TSEvent event, void */* edata ATS_UNUSED */)
+rewrite_handler(TSCont contp, TSEvent event, void * /* edata ATS_UNUSED */)
 {
-  SendData *data = (SendData *) TSContDataGet(contp);
+  SendData *data = (SendData *)TSContDataGet(contp);
   TSContDestroy(contp);
 
-  switch (event) {
+  TSCacheKeyDestroy(data->key);
 
+  switch (event) {
   /* Yes: Rewrite the Location header and reenable the response */
   case TS_EVENT_CACHE_OPEN_READ:
 
@@ -599,8 +601,6 @@ rewrite_handler(TSCont contp, TSEvent event, void */* edata ATS_UNUSED */)
 
   TSIOBufferDestroy(data->cache_bufp);
 
-  TSCacheKeyDestroy(data->key);
-
   TSHandleMLocRelease(data->resp_bufp, data->hdr_loc, data->location_loc);
   TSHandleMLocRelease(data->resp_bufp, TS_NULL_MLOC, data->hdr_loc);
 
@@ -613,11 +613,13 @@ rewrite_handler(TSCont contp, TSEvent event, void */* edata ATS_UNUSED */)
 /* Read the URL stored at the digest */
 
 static int
-vconn_read_ready(TSCont contp, void */* edata ATS_UNUSED */)
+vconn_read_ready(TSCont contp, void * /* edata ATS_UNUSED */)
 {
-  SendData *data = (SendData *) TSContDataGet(contp);
+  SendData *data = (SendData *)TSContDataGet(contp);
   TSContDestroy(contp);
 
+  TSVConnClose(data->connp);
+
   TSIOBufferReader readerp = TSIOBufferReaderAlloc(data->cache_bufp);
 
   TSIOBufferBlock blockp = TSIOBufferReaderStart(readerp);
@@ -665,6 +667,10 @@ vconn_read_ready(TSCont contp, void */* edata ATS_UNUSED */)
   contp = TSContCreate(rewrite_handler, NULL);
   TSContDataSet(contp, data);
 
+  /* Reentrant!  (Particularly in case of a cache miss.)
+   * rewrite_handler() will clean up the TSVConnRead() buffer so be
+   * sure to close this virtual connection or CacheVC::openReadMain()
+   * will continue operating on it! */
   TSCacheRead(contp, data->key);
 
   return 0;
@@ -677,7 +683,6 @@ static int
 digest_handler(TSCont contp, TSEvent event, void *edata)
 {
   switch (event) {
-
   /* Yes: Read the URL stored at that key */
   case TS_EVENT_CACHE_OPEN_READ:
     return cache_open_read(contp, edata);
@@ -699,18 +704,17 @@ digest_handler(TSCont contp, TSEvent event, void *edata)
 /* TSCacheRead() handler: Check if the Location URL is already cached */
 
 static int
-location_handler(TSCont contp, TSEvent event, void */* edata ATS_UNUSED */)
+location_handler(TSCont contp, TSEvent event, void * /* edata ATS_UNUSED */)
 {
   const char *value;
   int length;
 
   char digest[33]; /* ATS_BASE64_DECODE_DSTLEN() */
 
-  SendData *data = (SendData *) TSContDataGet(contp);
+  SendData *data = (SendData *)TSContDataGet(contp);
   TSContDestroy(contp);
 
   switch (event) {
-
   /* Yes: Do nothing, just reenable the response */
   case TS_EVENT_CACHE_OPEN_READ:
     break;
@@ -720,8 +724,8 @@ location_handler(TSCont contp, TSEvent event, void */* edata ATS_UNUSED */)
 
     /* No allocation, freed with data->resp_bufp? */
     value = TSMimeHdrFieldValueStringGet(data->resp_bufp, data->hdr_loc, data->digest_loc, data->idx, &length);
-    if (TSBase64Decode(value + 8, length - 8, (unsigned char *) digest, sizeof(digest), NULL) != TS_SUCCESS
-        || TSCacheKeyDigestSet(data->key, digest, 32 /* SHA-256 */ ) != TS_SUCCESS) {
+    if (TSBase64Decode(value + 8, length - 8, (unsigned char *)digest, sizeof(digest), NULL) != TS_SUCCESS ||
+        TSCacheKeyDigestSet(data->key, digest, 32 /* SHA-256 */) != TS_SUCCESS) {
       break;
     }
 
@@ -732,6 +736,7 @@ location_handler(TSCont contp, TSEvent event, void */* edata ATS_UNUSED */)
     contp = TSContCreate(digest_handler, NULL);
     TSContDataSet(contp, data);
 
+    /* Reentrant! */
     TSCacheRead(contp, data->key);
 
     return 0;
@@ -764,8 +769,8 @@ http_send_response_hdr(TSCont contp, void *edata)
   const char *value;
   int length;
 
-  SendData *data = (SendData *) TSmalloc(sizeof(SendData));
-  data->txnp = (TSHttpTxn) edata;
+  SendData *data = (SendData *)TSmalloc(sizeof(SendData));
+  data->txnp = (TSHttpTxn)edata;
 
   if (TSHttpTxnClientRespGet(data->txnp, &data->resp_bufp, &data->hdr_loc) != TS_SUCCESS) {
     TSError("Couldn't retrieve client response header");
@@ -786,6 +791,7 @@ http_send_response_hdr(TSCont contp, void *edata)
   /* Assumption: We want to minimize cache reads, so check first that
    *
    *    1.  the response has a Location header and
+   *
    *    2.  the response has a Digest header.
    *
    * Then scan if the URL or digest already exist in the cache. */
@@ -810,7 +816,6 @@ http_send_response_hdr(TSCont contp, void *edata)
   /* No allocation, freed with data->resp_bufp? */
   value = TSMimeHdrFieldValueStringGet(data->resp_bufp, data->hdr_loc, data->location_loc, -1, &length);
   if (TSUrlParse(data->resp_bufp, data->url_loc, &value, value + length) != TS_PARSE_DONE) {
-
     TSHandleMLocRelease(data->resp_bufp, TS_NULL_MLOC, data->url_loc);
     TSHandleMLocRelease(data->resp_bufp, data->hdr_loc, data->location_loc);
     TSHandleMLocRelease(data->resp_bufp, TS_NULL_MLOC, data->hdr_loc);
@@ -838,10 +843,8 @@ http_send_response_hdr(TSCont contp, void *edata)
   /* ... and a Digest header */
   data->digest_loc = TSMimeHdrFieldFind(data->resp_bufp, data->hdr_loc, "Digest", 6);
   while (data->digest_loc) {
-
     int count = TSMimeHdrFieldValuesCount(data->resp_bufp, data->hdr_loc, data->digest_loc);
     for (data->idx = 0; data->idx < count; data->idx += 1) {
-
       /* No allocation, freed with data->resp_bufp? */
       value = TSMimeHdrFieldValueStringGet(data->resp_bufp, data->hdr_loc, data->digest_loc, data->idx, &length);
       if (length < 8 + 44 /* 32 bytes, Base64 */ || strncasecmp(value, "SHA-256=", 8)) {
@@ -853,6 +856,7 @@ http_send_response_hdr(TSCont contp, void *edata)
       contp = TSContCreate(location_handler, NULL);
       TSContDataSet(contp, data);
 
+      /* Reentrant! */
       TSCacheRead(contp, data->key);
 
       return 0;
@@ -897,13 +901,13 @@ handler(TSCont contp, TSEvent event, void *edata)
 }
 
 void
-TSPluginInit(int /* argc ATS_UNUSED */, const char */* argv ATS_UNUSED */[])
+TSPluginInit(int /* argc ATS_UNUSED */, const char * /* argv ATS_UNUSED */ [])
 {
   TSPluginRegistrationInfo info;
 
-  info.plugin_name = (char *) "metalink";
-  info.vendor_name = (char *) "Apache Software Foundation";
-  info.support_email = (char *) "dev@trafficserver.apache.org";
+  info.plugin_name = (char *)"metalink";
+  info.vendor_name = (char *)"Apache Software Foundation";
+  info.support_email = (char *)"dev@trafficserver.apache.org";
 
   if (TSPluginRegister(TS_SDK_VERSION_3_0, &info) != TS_SUCCESS) {
     TSError("Plugin registration failed");
