@@ -41,8 +41,8 @@
 #include "iniparser.h"
 
 /*---------------------------- Defines -------------------------------------*/
-#define ASCIILINESZ         (1024)
-#define INI_INVALID_KEY     ((char*)-1)
+#define ASCIILINESZ (1024)
+#define INI_INVALID_KEY ((char *)-1)
 
 /*---------------------------------------------------------------------------
                         Private to this module
@@ -51,13 +51,13 @@
  * This enum stores the status for each parsed line (internal use only).
  */
 typedef enum _line_status_ {
-    LINE_UNPROCESSED,
-    LINE_ERROR,
-    LINE_EMPTY,
-    LINE_COMMENT,
-    LINE_SECTION,
-    LINE_VALUE
-} line_status ;
+  LINE_UNPROCESSED,
+  LINE_ERROR,
+  LINE_EMPTY,
+  LINE_COMMENT,
+  LINE_SECTION,
+  LINE_VALUE,
+} line_status;
 
 /*-------------------------------------------------------------------------*/
 /**
@@ -71,20 +71,22 @@ typedef enum _line_status_ {
   allocated, it will be modified at each function call (not re-entrant).
  */
 /*--------------------------------------------------------------------------*/
-static char * strlwc(const char * s)
+static char *
+strlwc(const char *s)
 {
-    static char l[ASCIILINESZ+1];
-    int i ;
+  static char l[ASCIILINESZ + 1];
+  int i;
 
-    if (s==NULL) return NULL ;
-    memset(l, 0, ASCIILINESZ+1);
-    i=0 ;
-    while (s[i] && i<ASCIILINESZ) {
-        l[i] = (char)tolower((int)s[i]);
-        i++ ;
-    }
-    l[ASCIILINESZ]=(char)0;
-    return l ;
+  if (s == NULL)
+    return NULL;
+  memset(l, 0, ASCIILINESZ + 1);
+  i = 0;
+  while (s[i] && i < ASCIILINESZ) {
+    l[i] = (char)tolower((int)s[i]);
+    i++;
+  }
+  l[ASCIILINESZ] = (char)0;
+  return l;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -101,24 +103,27 @@ static char * strlwc(const char * s)
   (not re-entrant).
  */
 /*--------------------------------------------------------------------------*/
-static char * strstrip(char * s)
+static char *
+strstrip(char *s)
 {
-    static char l[ASCIILINESZ+1];
-	char * last ;
-	
-    if (s==NULL) return NULL ;
-    
-	while (isspace((int)*s) && *s) s++;
-	memset(l, 0, ASCIILINESZ+1);
-	strcpy(l, s);
-	last = l + strlen(l);
-	while (last > l) {
-		if (!isspace((int)*(last-1)))
-			break ;
-		last -- ;
-	}
-	*last = (char)0;
-	return (char*)l ;
+  static char l[ASCIILINESZ + 1];
+  char *last;
+
+  if (s == NULL)
+    return NULL;
+
+  while (isspace((int)*s) && *s)
+    s++;
+  memset(l, 0, ASCIILINESZ + 1);
+  strcpy(l, s);
+  last = l + strlen(l);
+  while (last > l) {
+    if (!isspace((int)*(last - 1)))
+      break;
+    last--;
+  }
+  *last = (char)0;
+  return (char *)l;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -139,21 +144,23 @@ static char * strstrip(char * s)
   This function returns -1 in case of error.
  */
 /*--------------------------------------------------------------------------*/
-int iniparser_getnsec(dictionary * d)
+int
+iniparser_getnsec(dictionary *d)
 {
-    int i ;
-    int nsec ;
+  int i;
+  int nsec;
 
-    if (d==NULL) return -1 ;
-    nsec=0 ;
-    for (i=0 ; i<d->size ; i++) {
-        if (d->key[i]==NULL)
-            continue ;
-        if (strchr(d->key[i], ':')==NULL) {
-            nsec ++ ;
-        }
+  if (d == NULL)
+    return -1;
+  nsec = 0;
+  for (i = 0; i < d->size; i++) {
+    if (d->key[i] == NULL)
+      continue;
+    if (strchr(d->key[i], ':') == NULL) {
+      nsec++;
     }
-    return nsec ;
+  }
+  return nsec;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -170,26 +177,28 @@ int iniparser_getnsec(dictionary * d)
   This function returns NULL in case of error.
  */
 /*--------------------------------------------------------------------------*/
-char * iniparser_getsecname(dictionary * d, int n)
+char *
+iniparser_getsecname(dictionary *d, int n)
 {
-    int i ;
-    int foundsec ;
+  int i;
+  int foundsec;
 
-    if (d==NULL || n<0) return NULL ;
-    foundsec=0 ;
-    for (i=0 ; i<d->size ; i++) {
-        if (d->key[i]==NULL)
-            continue ;
-        if (strchr(d->key[i], ':')==NULL) {
-            foundsec++ ;
-            if (foundsec>n)
-                break ;
-        }
+  if (d == NULL || n < 0)
+    return NULL;
+  foundsec = 0;
+  for (i = 0; i < d->size; i++) {
+    if (d->key[i] == NULL)
+      continue;
+    if (strchr(d->key[i], ':') == NULL) {
+      foundsec++;
+      if (foundsec > n)
+        break;
     }
-    if (foundsec<=n) {
-        return NULL ;
-    }
-    return d->key[i] ;
+  }
+  if (foundsec <= n) {
+    return NULL;
+  }
+  return d->key[i];
 }
 
 /*-------------------------------------------------------------------------*/
@@ -205,21 +214,23 @@ char * iniparser_getsecname(dictionary * d, int n)
   purposes mostly.
  */
 /*--------------------------------------------------------------------------*/
-void iniparser_dump(dictionary * d, FILE * f)
+void
+iniparser_dump(dictionary *d, FILE *f)
 {
-    int     i ;
+  int i;
 
-    if (d==NULL || f==NULL) return ;
-    for (i=0 ; i<d->size ; i++) {
-        if (d->key[i]==NULL)
-            continue ;
-        if (d->val[i]!=NULL) {
-            fprintf(f, "[%s]=[%s]\n", d->key[i], d->val[i]);
-        } else {
-            fprintf(f, "[%s]=UNDEF\n", d->key[i]);
-        }
+  if (d == NULL || f == NULL)
+    return;
+  for (i = 0; i < d->size; i++) {
+    if (d->key[i] == NULL)
+      continue;
+    if (d->val[i] != NULL) {
+      fprintf(f, "[%s]=[%s]\n", d->key[i], d->val[i]);
+    } else {
+      fprintf(f, "[%s]=UNDEF\n", d->key[i]);
     }
-    return ;
+  }
+  return;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -233,44 +244,43 @@ void iniparser_dump(dictionary * d, FILE * f)
   It is Ok to specify @c stderr or @c stdout as output files.
  */
 /*--------------------------------------------------------------------------*/
-void iniparser_dump_ini(dictionary * d, FILE * f)
+void
+iniparser_dump_ini(dictionary *d, FILE *f)
 {
-    int     i, j ;
-    char    keym[ASCIILINESZ+1];
-    int     nsec ;
-    char *  secname ;
-    int     seclen ;
+  int i, j;
+  char keym[ASCIILINESZ + 1];
+  int nsec;
+  char *secname;
+  int seclen;
 
-    if (d==NULL || f==NULL) return ;
+  if (d == NULL || f == NULL)
+    return;
 
-    nsec = iniparser_getnsec(d);
-    if (nsec<1) {
-        /* No section in file: dump all keys as they are */
-        for (i=0 ; i<d->size ; i++) {
-            if (d->key[i]==NULL)
-                continue ;
-            fprintf(f, "%s = %s\n", d->key[i], d->val[i]);
-        }
-        return ;
+  nsec = iniparser_getnsec(d);
+  if (nsec < 1) {
+    /* No section in file: dump all keys as they are */
+    for (i = 0; i < d->size; i++) {
+      if (d->key[i] == NULL)
+        continue;
+      fprintf(f, "%s = %s\n", d->key[i], d->val[i]);
     }
-    for (i=0 ; i<nsec ; i++) {
-        secname = iniparser_getsecname(d, i) ;
-        seclen  = (int)strlen(secname);
-        fprintf(f, "\n[%s]\n", secname);
-        sprintf(keym, "%s:", secname);
-        for (j=0 ; j<d->size ; j++) {
-            if (d->key[j]==NULL)
-                continue ;
-            if (!strncmp(d->key[j], keym, seclen+1)) {
-                fprintf(f,
-                        "%-30s = %s\n",
-                        d->key[j]+seclen+1,
-                        d->val[j] ? d->val[j] : "");
-            }
-        }
+    return;
+  }
+  for (i = 0; i < nsec; i++) {
+    secname = iniparser_getsecname(d, i);
+    seclen = (int)strlen(secname);
+    fprintf(f, "\n[%s]\n", secname);
+    sprintf(keym, "%s:", secname);
+    for (j = 0; j < d->size; j++) {
+      if (d->key[j] == NULL)
+        continue;
+      if (!strncmp(d->key[j], keym, seclen + 1)) {
+        fprintf(f, "%-30s = %s\n", d->key[j] + seclen + 1, d->val[j] ? d->val[j] : "");
+      }
     }
-    fprintf(f, "\n");
-    return ;
+  }
+  fprintf(f, "\n");
+  return;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -288,17 +298,18 @@ void iniparser_dump_ini(dictionary * d, FILE * f)
   the dictionary, do not free or modify it.
  */
 /*--------------------------------------------------------------------------*/
-char * iniparser_getstring(dictionary * d, const char * key, char * def)
+char *
+iniparser_getstring(dictionary *d, const char *key, char *def)
 {
-    char * lc_key ;
-    char * sval ;
+  char *lc_key;
+  char *sval;
 
-    if (d==NULL || key==NULL)
-        return def ;
+  if (d == NULL || key == NULL)
+    return def;
 
-    lc_key = strlwc(key);
-    sval = dictionary_get(d, lc_key, def);
-    return sval ;
+  lc_key = strlwc(key);
+  sval = dictionary_get(d, lc_key, def);
+  return sval;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -328,13 +339,15 @@ char * iniparser_getstring(dictionary * d, const char * key, char * def)
   Credits: Thanks to A. Becker for suggesting strtol()
  */
 /*--------------------------------------------------------------------------*/
-int iniparser_getint(dictionary * d, const char * key, int notfound)
+int
+iniparser_getint(dictionary *d, const char *key, int notfound)
 {
-    char    *   str ;
+  char *str;
 
-    str = iniparser_getstring(d, key, INI_INVALID_KEY);
-    if (str==INI_INVALID_KEY) return notfound ;
-    return (int)strtol(str, NULL, 0);
+  str = iniparser_getstring(d, key, INI_INVALID_KEY);
+  if (str == INI_INVALID_KEY)
+    return notfound;
+  return (int)strtol(str, NULL, 0);
 }
 
 /*-------------------------------------------------------------------------*/
@@ -350,13 +363,15 @@ int iniparser_getint(dictionary * d, const char * key, int notfound)
   the notfound value is returned.
  */
 /*--------------------------------------------------------------------------*/
-double iniparser_getdouble(dictionary * d, char * key, double notfound)
+double
+iniparser_getdouble(dictionary *d, char *key, double notfound)
 {
-    char    *   str ;
+  char *str;
 
-    str = iniparser_getstring(d, key, INI_INVALID_KEY);
-    if (str==INI_INVALID_KEY) return notfound ;
-    return atof(str);
+  str = iniparser_getstring(d, key, INI_INVALID_KEY);
+  if (str == INI_INVALID_KEY)
+    return notfound;
+  return atof(str);
 }
 
 /*-------------------------------------------------------------------------*/
@@ -391,21 +406,23 @@ double iniparser_getdouble(dictionary * d, char * key, double notfound)
   necessarily have to be 0 or 1.
  */
 /*--------------------------------------------------------------------------*/
-int iniparser_getboolean(dictionary * d, const char * key, int notfound)
+int
+iniparser_getboolean(dictionary *d, const char *key, int notfound)
 {
-    char    *   c ;
-    int         ret ;
+  char *c;
+  int ret;
 
-    c = iniparser_getstring(d, key, INI_INVALID_KEY);
-    if (c==INI_INVALID_KEY) return notfound ;
-    if (c[0]=='y' || c[0]=='Y' || c[0]=='1' || c[0]=='t' || c[0]=='T') {
-        ret = 1 ;
-    } else if (c[0]=='n' || c[0]=='N' || c[0]=='0' || c[0]=='f' || c[0]=='F') {
-        ret = 0 ;
-    } else {
-        ret = notfound ;
-    }
-    return ret;
+  c = iniparser_getstring(d, key, INI_INVALID_KEY);
+  if (c == INI_INVALID_KEY)
+    return notfound;
+  if (c[0] == 'y' || c[0] == 'Y' || c[0] == '1' || c[0] == 't' || c[0] == 'T') {
+    ret = 1;
+  } else if (c[0] == 'n' || c[0] == 'N' || c[0] == '0' || c[0] == 'f' || c[0] == 'F') {
+    ret = 0;
+  } else {
+    ret = notfound;
+  }
+  return ret;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -420,16 +437,14 @@ int iniparser_getboolean(dictionary * d, const char * key, int notfound)
   of querying for the presence of sections in a dictionary.
  */
 /*--------------------------------------------------------------------------*/
-int iniparser_find_entry(
-    dictionary  *   ini,
-    char        *   entry
-)
+int
+iniparser_find_entry(dictionary *ini, char *entry)
 {
-    int found=0 ;
-    if (iniparser_getstring(ini, entry, INI_INVALID_KEY)!=INI_INVALID_KEY) {
-        found = 1 ;
-    }
-    return found ;
+  int found = 0;
+  if (iniparser_getstring(ini, entry, INI_INVALID_KEY) != INI_INVALID_KEY) {
+    found = 1;
+  }
+  return found;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -445,9 +460,10 @@ int iniparser_find_entry(
   It is Ok to set val to NULL.
  */
 /*--------------------------------------------------------------------------*/
-int iniparser_set(dictionary * ini, char * entry, char * val)
+int
+iniparser_set(dictionary *ini, char *entry, char *val)
 {
-    return dictionary_set(ini, strlwc(entry), val) ;
+  return dictionary_set(ini, strlwc(entry), val);
 }
 
 /*-------------------------------------------------------------------------*/
@@ -460,9 +476,10 @@ int iniparser_set(dictionary * ini, char * entry, char * val)
   If the given entry can be found, it is deleted from the dictionary.
  */
 /*--------------------------------------------------------------------------*/
-void iniparser_unset(dictionary * ini, char * entry)
+void
+iniparser_unset(dictionary *ini, char *entry)
 {
-    dictionary_unset(ini, strlwc(entry));
+  dictionary_unset(ini, strlwc(entry));
 }
 
 /*-------------------------------------------------------------------------*/
@@ -475,64 +492,59 @@ void iniparser_unset(dictionary * ini, char * entry)
   @return   line_status value
  */
 /*--------------------------------------------------------------------------*/
-static line_status iniparser_line(
-    char * input_line,
-    char * section,
-    char * key,
-    char * value)
-{   
-    line_status sta ;
-    char        line[ASCIILINESZ+1];
-    int         len ;
+static line_status
+iniparser_line(char *input_line, char *section, char *key, char *value)
+{
+  line_status sta;
+  char line[ASCIILINESZ + 1];
+  int len;
 
-    strcpy(line, strstrip(input_line));
-    len = (int)strlen(line);
+  strcpy(line, strstrip(input_line));
+  len = (int)strlen(line);
 
-    sta = LINE_UNPROCESSED ;
-    if (len<1) {
-        /* Empty line */
-        sta = LINE_EMPTY ;
-    } else if (line[0]=='#') {
-        /* Comment line */
-        sta = LINE_COMMENT ; 
-    } else if (line[0]=='[' && line[len-1]==']') {
-        /* Section name */
-        sscanf(line, "[%[^]]", section);
-        strcpy(section, strstrip(section));
-        strcpy(section, strlwc(section));
-        sta = LINE_SECTION ;
-    } else if (sscanf (line, "%[^=] = \"%[^\"]\"", key, value) == 2
-           ||  sscanf (line, "%[^=] = '%[^\']'",   key, value) == 2
-           ||  sscanf (line, "%[^=] = %[^;#]",     key, value) == 2) {
-        /* Usual key=value, with or without comments */
-        strcpy(key, strstrip(key));
-        strcpy(key, strlwc(key));
-        strcpy(value, strstrip(value));
-        /*
-         * sscanf cannot handle '' or "" as empty values
-         * this is done here
-         */
-        if (!strcmp(value, "\"\"") || (!strcmp(value, "''"))) {
-            value[0]=0 ;
-        }
-        sta = LINE_VALUE ;
-    } else if (sscanf(line, "%[^=] = %[;#]", key, value)==2
-           ||  sscanf(line, "%[^=] %[=]", key, value) == 2) {
-        /*
-         * Special cases:
-         * key=
-         * key=;
-         * key=#
-         */
-        strcpy(key, strstrip(key));
-        strcpy(key, strlwc(key));
-        value[0]=0 ;
-        sta = LINE_VALUE ;
-    } else {
-        /* Generate syntax error */
-        sta = LINE_ERROR ;
+  sta = LINE_UNPROCESSED;
+  if (len < 1) {
+    /* Empty line */
+    sta = LINE_EMPTY;
+  } else if (line[0] == '#') {
+    /* Comment line */
+    sta = LINE_COMMENT;
+  } else if (line[0] == '[' && line[len - 1] == ']') {
+    /* Section name */
+    sscanf(line, "[%[^]]", section);
+    strcpy(section, strstrip(section));
+    strcpy(section, strlwc(section));
+    sta = LINE_SECTION;
+  } else if (sscanf(line, "%[^=] = \"%[^\"]\"", key, value) == 2 || sscanf(line, "%[^=] = '%[^\']'", key, value) == 2 ||
+             sscanf(line, "%[^=] = %[^;#]", key, value) == 2) {
+    /* Usual key=value, with or without comments */
+    strcpy(key, strstrip(key));
+    strcpy(key, strlwc(key));
+    strcpy(value, strstrip(value));
+    /*
+     * sscanf cannot handle '' or "" as empty values
+     * this is done here
+     */
+    if (!strcmp(value, "\"\"") || (!strcmp(value, "''"))) {
+      value[0] = 0;
     }
-    return sta ;
+    sta = LINE_VALUE;
+  } else if (sscanf(line, "%[^=] = %[;#]", key, value) == 2 || sscanf(line, "%[^=] %[=]", key, value) == 2) {
+    /*
+     * Special cases:
+     * key=
+     * key=;
+     * key=#
+     */
+    strcpy(key, strstrip(key));
+    strcpy(key, strlwc(key));
+    value[0] = 0;
+    sta = LINE_VALUE;
+  } else {
+    /* Generate syntax error */
+    sta = LINE_ERROR;
+  }
+  return sta;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -549,105 +561,100 @@ static line_status iniparser_line(
   The returned dictionary must be freed using iniparser_freedict().
  */
 /*--------------------------------------------------------------------------*/
-dictionary * iniparser_load(const char * ininame)
+dictionary *
+iniparser_load(const char *ininame)
 {
-    FILE * in ;
+  FILE *in;
 
-    char line    [ASCIILINESZ+1] ;
-    char section [ASCIILINESZ+1] ;
-    char key     [ASCIILINESZ+1] ;
-    char tmp     [ASCIILINESZ+1] ;
-    char val     [ASCIILINESZ+1] ;
+  char line[ASCIILINESZ + 1];
+  char section[ASCIILINESZ + 1];
+  char key[ASCIILINESZ + 1];
+  char tmp[ASCIILINESZ + 1];
+  char val[ASCIILINESZ + 1];
 
-    int  last=0 ;
-    int  len ;
-    int  lineno=0 ;
-    int  errs=0;
+  int last = 0;
+  int len;
+  int lineno = 0;
+  int errs = 0;
 
-    dictionary * dict ;
+  dictionary *dict;
 
-    if ((in=fopen(ininame, "r"))==NULL) {
-        fprintf(stderr, "iniparser: cannot open %s\n", ininame);
-        return NULL ;
-    }
+  if ((in = fopen(ininame, "r")) == NULL) {
+    fprintf(stderr, "iniparser: cannot open %s\n", ininame);
+    return NULL;
+  }
 
-    dict = dictionary_new(0) ;
-    if (!dict) {
-        fclose(in);
-        return NULL ;
-    }
-
-    memset(line,    0, ASCIILINESZ);
-    memset(section, 0, ASCIILINESZ);
-    memset(key,     0, ASCIILINESZ);
-    memset(val,     0, ASCIILINESZ);
-    last=0 ;
-
-    while (fgets(line+last, ASCIILINESZ-last, in)!=NULL) {
-        lineno++ ;
-        len = (int)strlen(line)-1;
-        /* Safety check against buffer overflows */
-        if (line[len]!='\n') {
-            fprintf(stderr,
-                    "iniparser: input line too long in %s (%d)\n",
-                    ininame,
-                    lineno);
-            dictionary_del(dict);
-            fclose(in);
-            return NULL ;
-        }
-        /* Get rid of \n and spaces at end of line */
-        while ((len>=0) &&
-                ((line[len]=='\n') || (isspace(line[len])))) {
-            line[len]=0 ;
-            len-- ;
-        }
-        /* Detect multi-line */
-        if (line[len]=='\\') {
-            /* Multi-line value */
-            last=len ;
-            continue ;
-        } else {
-            last=0 ;
-        }
-        switch (iniparser_line(line, section, key, val)) {
-            case LINE_EMPTY:
-            case LINE_COMMENT:
-            break ;
-
-            case LINE_SECTION:
-            errs = dictionary_set(dict, section, NULL);
-            break ;
-
-            case LINE_VALUE:
-            sprintf(tmp, "%s:%s", section, key);
-            errs = dictionary_set(dict, tmp, val) ;
-            break ;
-
-            case LINE_ERROR:
-            fprintf(stderr, "iniparser: syntax error in %s (%d):\n",
-                    ininame,
-                    lineno);
-            fprintf(stderr, "-> %s\n", line);
-            errs++ ;
-            break;
-
-            default:
-            break ;
-        }
-        memset(line, 0, ASCIILINESZ);
-        last=0;
-        if (errs<0) {
-            fprintf(stderr, "iniparser: memory allocation failure\n");
-            break ;
-        }
-    }
-    if (errs) {
-        dictionary_del(dict);
-        dict = NULL ;
-    }
+  dict = dictionary_new(0);
+  if (!dict) {
     fclose(in);
-    return dict ;
+    return NULL;
+  }
+
+  memset(line, 0, ASCIILINESZ);
+  memset(section, 0, ASCIILINESZ);
+  memset(key, 0, ASCIILINESZ);
+  memset(val, 0, ASCIILINESZ);
+  last = 0;
+
+  while (fgets(line + last, ASCIILINESZ - last, in) != NULL) {
+    lineno++;
+    len = (int)strlen(line) - 1;
+    /* Safety check against buffer overflows */
+    if (line[len] != '\n') {
+      fprintf(stderr, "iniparser: input line too long in %s (%d)\n", ininame, lineno);
+      dictionary_del(dict);
+      fclose(in);
+      return NULL;
+    }
+    /* Get rid of \n and spaces at end of line */
+    while ((len >= 0) && ((line[len] == '\n') || (isspace(line[len])))) {
+      line[len] = 0;
+      len--;
+    }
+    /* Detect multi-line */
+    if (line[len] == '\\') {
+      /* Multi-line value */
+      last = len;
+      continue;
+    } else {
+      last = 0;
+    }
+    switch (iniparser_line(line, section, key, val)) {
+    case LINE_EMPTY:
+    case LINE_COMMENT:
+      break;
+
+    case LINE_SECTION:
+      errs = dictionary_set(dict, section, NULL);
+      break;
+
+    case LINE_VALUE:
+      sprintf(tmp, "%s:%s", section, key);
+      errs = dictionary_set(dict, tmp, val);
+      break;
+
+    case LINE_ERROR:
+      fprintf(stderr, "iniparser: syntax error in %s (%d):\n", ininame, lineno);
+      fprintf(stderr, "-> %s\n", line);
+      errs++;
+      break;
+
+    default:
+      break;
+    }
+    memset(line, 0, ASCIILINESZ);
+    last = 0;
+    if (errs < 0) {
+      fprintf(stderr, "iniparser: memory allocation failure\n");
+      break;
+    }
+  }
+  if (errs) {
+    dictionary_del(dict);
+    dict = NULL;
+  }
+  fclose(in);
+  return dict;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -661,9 +668,10 @@ dictionary * iniparser_load(const char * ininame)
   gets out of the current context.
  */
 /*--------------------------------------------------------------------------*/
-void iniparser_freedict(dictionary * d)
+void
+iniparser_freedict(dictionary *d)
 {
-    dictionary_del(d);
+  dictionary_del(d);
 }
 
 /* vim: set ts=4 et sw=4 tw=75 */
