@@ -8,7 +8,7 @@
   with the License.  You may obtain a copy of the License at
 
   http://www.apache.org/licenses/LICENSE-2.0
- 
+
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -21,52 +21,52 @@
 #include <netinet/in.h>
 #include "ts_lua_util.h"
 
-static void ts_lua_inject_client_request_client_addr_api(lua_State * L);
-static void ts_lua_inject_client_request_server_addr_api(lua_State * L);
+static void ts_lua_inject_client_request_client_addr_api(lua_State *L);
+static void ts_lua_inject_client_request_server_addr_api(lua_State *L);
 
-static int ts_lua_client_request_header_get(lua_State * L);
-static int ts_lua_client_request_header_set(lua_State * L);
-static int ts_lua_client_request_get_headers(lua_State * L);
-static int ts_lua_client_request_get_url(lua_State * L);
-static int ts_lua_client_request_get_pristine_url(lua_State * L);
-static int ts_lua_client_request_get_url_host(lua_State * L);
-static int ts_lua_client_request_set_url_host(lua_State * L);
-static int ts_lua_client_request_get_url_port(lua_State * L);
-static int ts_lua_client_request_set_url_port(lua_State * L);
-static int ts_lua_client_request_get_url_scheme(lua_State * L);
-static int ts_lua_client_request_set_url_scheme(lua_State * L);
+static int ts_lua_client_request_header_get(lua_State *L);
+static int ts_lua_client_request_header_set(lua_State *L);
+static int ts_lua_client_request_get_headers(lua_State *L);
+static int ts_lua_client_request_get_url(lua_State *L);
+static int ts_lua_client_request_get_pristine_url(lua_State *L);
+static int ts_lua_client_request_get_url_host(lua_State *L);
+static int ts_lua_client_request_set_url_host(lua_State *L);
+static int ts_lua_client_request_get_url_port(lua_State *L);
+static int ts_lua_client_request_set_url_port(lua_State *L);
+static int ts_lua_client_request_get_url_scheme(lua_State *L);
+static int ts_lua_client_request_set_url_scheme(lua_State *L);
 
-static int ts_lua_client_request_get_uri(lua_State * L);
-static int ts_lua_client_request_set_uri(lua_State * L);
-static int ts_lua_client_request_set_uri_args(lua_State * L);
-static int ts_lua_client_request_get_uri_args(lua_State * L);
-static int ts_lua_client_request_get_method(lua_State * L);
-static int ts_lua_client_request_set_method(lua_State * L);
-static int ts_lua_client_request_get_version(lua_State * L);
-static int ts_lua_client_request_set_version(lua_State * L);
+static int ts_lua_client_request_get_uri(lua_State *L);
+static int ts_lua_client_request_set_uri(lua_State *L);
+static int ts_lua_client_request_set_uri_args(lua_State *L);
+static int ts_lua_client_request_get_uri_args(lua_State *L);
+static int ts_lua_client_request_get_method(lua_State *L);
+static int ts_lua_client_request_set_method(lua_State *L);
+static int ts_lua_client_request_get_version(lua_State *L);
+static int ts_lua_client_request_set_version(lua_State *L);
 
-static int ts_lua_client_request_get_body_size(lua_State * L);
-static int ts_lua_client_request_get_header_size(lua_State * L);
+static int ts_lua_client_request_get_body_size(lua_State *L);
+static int ts_lua_client_request_get_header_size(lua_State *L);
 
-static void ts_lua_inject_client_request_socket_api(lua_State * L);
-static void ts_lua_inject_client_request_header_api(lua_State * L);
-static void ts_lua_inject_client_request_headers_api(lua_State * L);
-static void ts_lua_inject_client_request_url_api(lua_State * L);
-static void ts_lua_inject_client_request_uri_api(lua_State * L);
-static void ts_lua_inject_client_request_args_api(lua_State * L);
-static void ts_lua_inject_client_request_method_api(lua_State * L);
-static void ts_lua_inject_client_request_version_api(lua_State * L);
-static void ts_lua_inject_client_request_body_size_api(lua_State * L);
-static void ts_lua_inject_client_request_header_size_api(lua_State * L);
+static void ts_lua_inject_client_request_socket_api(lua_State *L);
+static void ts_lua_inject_client_request_header_api(lua_State *L);
+static void ts_lua_inject_client_request_headers_api(lua_State *L);
+static void ts_lua_inject_client_request_url_api(lua_State *L);
+static void ts_lua_inject_client_request_uri_api(lua_State *L);
+static void ts_lua_inject_client_request_args_api(lua_State *L);
+static void ts_lua_inject_client_request_method_api(lua_State *L);
+static void ts_lua_inject_client_request_version_api(lua_State *L);
+static void ts_lua_inject_client_request_body_size_api(lua_State *L);
+static void ts_lua_inject_client_request_header_size_api(lua_State *L);
 
 
-static int ts_lua_client_request_client_addr_get_ip(lua_State * L);
-static int ts_lua_client_request_client_addr_get_port(lua_State * L);
-static int ts_lua_client_request_client_addr_get_addr(lua_State * L);
+static int ts_lua_client_request_client_addr_get_ip(lua_State *L);
+static int ts_lua_client_request_client_addr_get_port(lua_State *L);
+static int ts_lua_client_request_client_addr_get_addr(lua_State *L);
 
 
 void
-ts_lua_inject_client_request_api(lua_State * L)
+ts_lua_inject_client_request_api(lua_State *L)
 {
   lua_newtable(L);
 
@@ -85,14 +85,14 @@ ts_lua_inject_client_request_api(lua_State * L)
 }
 
 static void
-ts_lua_inject_client_request_socket_api(lua_State * L)
+ts_lua_inject_client_request_socket_api(lua_State *L)
 {
   ts_lua_inject_client_request_client_addr_api(L);
   ts_lua_inject_client_request_server_addr_api(L);
 }
 
 static void
-ts_lua_inject_client_request_client_addr_api(lua_State * L)
+ts_lua_inject_client_request_client_addr_api(lua_State *L)
 {
   lua_newtable(L);
 
@@ -109,17 +109,17 @@ ts_lua_inject_client_request_client_addr_api(lua_State * L)
 }
 
 static void
-ts_lua_inject_client_request_server_addr_api(lua_State * L ATS_UNUSED)
+ts_lua_inject_client_request_server_addr_api(lua_State *L ATS_UNUSED)
 {
   return;
 }
 
 static void
-ts_lua_inject_client_request_header_api(lua_State * L)
+ts_lua_inject_client_request_header_api(lua_State *L)
 {
-  lua_newtable(L);              /* .header */
+  lua_newtable(L); /* .header */
 
-  lua_createtable(L, 0, 2);     /* metatable for .header */
+  lua_createtable(L, 0, 2); /* metatable for .header */
 
   lua_pushcfunction(L, ts_lua_client_request_header_get);
   lua_setfield(L, -2, "__index");
@@ -132,7 +132,7 @@ ts_lua_inject_client_request_header_api(lua_State * L)
 }
 
 static int
-ts_lua_client_request_header_get(lua_State * L)
+ts_lua_client_request_header_get(lua_State *L)
 {
   const char *key;
   const char *val;
@@ -148,12 +148,9 @@ ts_lua_client_request_header_get(lua_State * L)
   key = luaL_checklstring(L, 2, &key_len);
 
   if (key && key_len) {
-
     field_loc = TSMimeHdrFieldFind(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, key, key_len);
     if (field_loc) {
-      val =
-        TSMimeHdrFieldValueStringGet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc, -1,
-                                     &val_len);
+      val = TSMimeHdrFieldValueStringGet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc, -1, &val_len);
       lua_pushlstring(L, val, val_len);
       TSHandleMLocRelease(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc);
 
@@ -169,7 +166,7 @@ ts_lua_client_request_header_get(lua_State * L)
 }
 
 static int
-ts_lua_client_request_header_set(lua_State * L)
+ts_lua_client_request_header_set(lua_State *L)
 {
   const char *key;
   const char *val;
@@ -202,17 +199,15 @@ ts_lua_client_request_header_set(lua_State * L)
     }
 
   } else if (field_loc) {
-    TSMimeHdrFieldValueStringSet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc, 0, val,
-                                 val_len);
+    TSMimeHdrFieldValueStringSet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc, -1, val, val_len);
 
-  } else if (TSMimeHdrFieldCreateNamed(http_ctx->client_request_bufp, http_ctx->client_request_hdrp,
-                                       key, key_len, &field_loc) != TS_SUCCESS) {
+  } else if (TSMimeHdrFieldCreateNamed(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, key, key_len, &field_loc) !=
+             TS_SUCCESS) {
     TSError("[%s] TSMimeHdrFieldCreateNamed error", __FUNCTION__);
     return 0;
 
   } else {
-    TSMimeHdrFieldValueStringSet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc, -1, val,
-                                 val_len);
+    TSMimeHdrFieldValueStringSet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc, -1, val, val_len);
     TSMimeHdrFieldAppend(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc);
   }
 
@@ -223,14 +218,14 @@ ts_lua_client_request_header_set(lua_State * L)
 }
 
 static void
-ts_lua_inject_client_request_headers_api(lua_State * L)
+ts_lua_inject_client_request_headers_api(lua_State *L)
 {
   lua_pushcfunction(L, ts_lua_client_request_get_headers);
   lua_setfield(L, -2, "get_headers");
 }
 
 static int
-ts_lua_client_request_get_headers(lua_State * L)
+ts_lua_client_request_get_headers(lua_State *L)
 {
   const char *name;
   const char *value;
@@ -248,13 +243,9 @@ ts_lua_client_request_get_headers(lua_State * L)
   field_loc = TSMimeHdrFieldGet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, 0);
 
   while (field_loc) {
-
     name = TSMimeHdrFieldNameGet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc, &name_len);
     if (name && name_len) {
-
-      value =
-        TSMimeHdrFieldValueStringGet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc, -1,
-                                     &value_len);
+      value = TSMimeHdrFieldValueStringGet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc, -1, &value_len);
       lua_pushlstring(L, name, name_len);
       lua_pushlstring(L, value, value_len);
       lua_rawset(L, -3);
@@ -269,7 +260,7 @@ ts_lua_client_request_get_headers(lua_State * L)
 }
 
 static void
-ts_lua_inject_client_request_url_api(lua_State * L)
+ts_lua_inject_client_request_url_api(lua_State *L)
 {
   lua_pushcfunction(L, ts_lua_client_request_get_url);
   lua_setfield(L, -2, "get_url");
@@ -294,7 +285,7 @@ ts_lua_inject_client_request_url_api(lua_State * L)
 }
 
 static void
-ts_lua_inject_client_request_uri_api(lua_State * L)
+ts_lua_inject_client_request_uri_api(lua_State *L)
 {
   lua_pushcfunction(L, ts_lua_client_request_set_uri);
   lua_setfield(L, -2, "set_uri");
@@ -304,7 +295,7 @@ ts_lua_inject_client_request_uri_api(lua_State * L)
 }
 
 static int
-ts_lua_client_request_get_url(lua_State * L)
+ts_lua_client_request_get_url(lua_State *L)
 {
   char *url;
   int url_len;
@@ -313,7 +304,7 @@ ts_lua_client_request_get_url(lua_State * L)
 
   http_ctx = ts_lua_get_http_ctx(L);
 
-  url = TSUrlStringGet(http_ctx->client_request_bufp, http_ctx->client_request_url, &url_len);
+  url = TSHttpTxnEffectiveUrlStringGet(http_ctx->txnp, &url_len);
 
   if (url) {
     lua_pushlstring(L, url, url_len);
@@ -327,7 +318,7 @@ ts_lua_client_request_get_url(lua_State * L)
 }
 
 static int
-ts_lua_client_request_get_pristine_url(lua_State * L)
+ts_lua_client_request_get_pristine_url(lua_State *L)
 {
   char *url;
   int url_len;
@@ -358,10 +349,10 @@ ts_lua_client_request_get_pristine_url(lua_State * L)
 }
 
 static int
-ts_lua_client_request_get_url_host(lua_State * L)
+ts_lua_client_request_get_url_host(lua_State *L)
 {
   const char *host;
-  int len;
+  int len = 0;
 
   ts_lua_http_ctx *http_ctx;
 
@@ -369,13 +360,35 @@ ts_lua_client_request_get_url_host(lua_State * L)
 
   host = TSUrlHostGet(http_ctx->client_request_bufp, http_ctx->client_request_url, &len);
 
+  if (len == 0) {
+    char *key = "Host";
+    char *l_key = "host";
+    int key_len = 4;
+
+
+    TSMLoc field_loc;
+
+    field_loc = TSMimeHdrFieldFind(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, key, key_len);
+    if (field_loc) {
+      host = TSMimeHdrFieldValueStringGet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc, -1, &len);
+      TSHandleMLocRelease(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc);
+
+    } else {
+      field_loc = TSMimeHdrFieldFind(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, l_key, key_len);
+      if (field_loc) {
+        host = TSMimeHdrFieldValueStringGet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc, -1, &len);
+        TSHandleMLocRelease(http_ctx->client_request_bufp, http_ctx->client_request_hdrp, field_loc);
+      }
+    }
+  }
+
   lua_pushlstring(L, host, len);
 
   return 1;
 }
 
 static int
-ts_lua_client_request_set_url_host(lua_State * L)
+ts_lua_client_request_set_url_host(lua_State *L)
 {
   const char *host;
   size_t len;
@@ -392,7 +405,7 @@ ts_lua_client_request_set_url_host(lua_State * L)
 }
 
 static int
-ts_lua_client_request_get_url_port(lua_State * L)
+ts_lua_client_request_get_url_port(lua_State *L)
 {
   int port;
 
@@ -408,7 +421,7 @@ ts_lua_client_request_get_url_port(lua_State * L)
 }
 
 static int
-ts_lua_client_request_set_url_port(lua_State * L)
+ts_lua_client_request_set_url_port(lua_State *L)
 {
   int port;
 
@@ -424,7 +437,7 @@ ts_lua_client_request_set_url_port(lua_State * L)
 }
 
 static int
-ts_lua_client_request_get_url_scheme(lua_State * L)
+ts_lua_client_request_get_url_scheme(lua_State *L)
 {
   const char *scheme;
   int len;
@@ -441,7 +454,7 @@ ts_lua_client_request_get_url_scheme(lua_State * L)
 }
 
 static int
-ts_lua_client_request_set_url_scheme(lua_State * L)
+ts_lua_client_request_set_url_scheme(lua_State *L)
 {
   const char *scheme;
   size_t len;
@@ -458,7 +471,7 @@ ts_lua_client_request_set_url_scheme(lua_State * L)
 }
 
 static int
-ts_lua_client_request_get_uri(lua_State * L)
+ts_lua_client_request_get_uri(lua_State *L)
 {
   char uri[TS_LUA_MAX_URL_LENGTH];
   const char *path;
@@ -473,13 +486,17 @@ ts_lua_client_request_get_uri(lua_State * L)
 
   uri_len = snprintf(uri, TS_LUA_MAX_URL_LENGTH, "/%.*s", path_len, path);
 
-  lua_pushlstring(L, uri, uri_len);
+  if (uri_len >= TS_LUA_MAX_URL_LENGTH) {
+    lua_pushlstring(L, uri, TS_LUA_MAX_URL_LENGTH - 1);
+  } else {
+    lua_pushlstring(L, uri, uri_len);
+  }
 
   return 1;
 }
 
 static int
-ts_lua_client_request_set_uri(lua_State * L)
+ts_lua_client_request_set_uri(lua_State *L)
 {
   const char *path;
   size_t path_len;
@@ -502,7 +519,7 @@ ts_lua_client_request_set_uri(lua_State * L)
 
 
 static void
-ts_lua_inject_client_request_args_api(lua_State * L)
+ts_lua_inject_client_request_args_api(lua_State *L)
 {
   lua_pushcfunction(L, ts_lua_client_request_set_uri_args);
   lua_setfield(L, -2, "set_uri_args");
@@ -512,7 +529,7 @@ ts_lua_inject_client_request_args_api(lua_State * L)
 }
 
 static int
-ts_lua_client_request_get_uri_args(lua_State * L)
+ts_lua_client_request_get_uri_args(lua_State *L)
 {
   const char *param;
   int param_len;
@@ -533,7 +550,7 @@ ts_lua_client_request_get_uri_args(lua_State * L)
 }
 
 static int
-ts_lua_client_request_set_uri_args(lua_State * L)
+ts_lua_client_request_set_uri_args(lua_State *L)
 {
   const char *param;
   size_t param_len;
@@ -549,7 +566,7 @@ ts_lua_client_request_set_uri_args(lua_State * L)
 }
 
 static int
-ts_lua_client_request_client_addr_get_ip(lua_State * L)
+ts_lua_client_request_client_addr_get_ip(lua_State *L)
 {
   struct sockaddr const *client_ip;
   char cip[128];
@@ -563,11 +580,10 @@ ts_lua_client_request_client_addr_get_ip(lua_State * L)
     lua_pushnil(L);
 
   } else {
-
     if (client_ip->sa_family == AF_INET) {
-      inet_ntop(AF_INET, (const void *) &((struct sockaddr_in *) client_ip)->sin_addr, cip, sizeof(cip));
+      inet_ntop(AF_INET, (const void *)&((struct sockaddr_in *)client_ip)->sin_addr, cip, sizeof(cip));
     } else {
-      inet_ntop(AF_INET6, (const void *) &((struct sockaddr_in6 *) client_ip)->sin6_addr, cip, sizeof(cip));
+      inet_ntop(AF_INET6, (const void *)&((struct sockaddr_in6 *)client_ip)->sin6_addr, cip, sizeof(cip));
     }
 
     lua_pushstring(L, cip);
@@ -577,7 +593,7 @@ ts_lua_client_request_client_addr_get_ip(lua_State * L)
 }
 
 static int
-ts_lua_client_request_client_addr_get_port(lua_State * L)
+ts_lua_client_request_client_addr_get_port(lua_State *L)
 {
   struct sockaddr const *client_ip;
   ts_lua_http_ctx *http_ctx;
@@ -591,11 +607,10 @@ ts_lua_client_request_client_addr_get_port(lua_State * L)
     lua_pushnil(L);
 
   } else {
-
     if (client_ip->sa_family == AF_INET) {
-      port = ((struct sockaddr_in *) client_ip)->sin_port;
+      port = ((struct sockaddr_in *)client_ip)->sin_port;
     } else {
-      port = ((struct sockaddr_in6 *) client_ip)->sin6_port;
+      port = ((struct sockaddr_in6 *)client_ip)->sin6_port;
     }
 
     lua_pushnumber(L, port);
@@ -605,7 +620,7 @@ ts_lua_client_request_client_addr_get_port(lua_State * L)
 }
 
 static int
-ts_lua_client_request_client_addr_get_addr(lua_State * L)
+ts_lua_client_request_client_addr_get_addr(lua_State *L)
 {
   struct sockaddr const *client_ip;
   ts_lua_http_ctx *http_ctx;
@@ -623,14 +638,13 @@ ts_lua_client_request_client_addr_get_addr(lua_State * L)
     lua_pushnil(L);
 
   } else {
-
     if (client_ip->sa_family == AF_INET) {
-      port = ((struct sockaddr_in *) client_ip)->sin_port;
-      inet_ntop(AF_INET, (const void *) &((struct sockaddr_in *) client_ip)->sin_addr, cip, sizeof(cip));
+      port = ntohs(((struct sockaddr_in *)client_ip)->sin_port);
+      inet_ntop(AF_INET, (const void *)&((struct sockaddr_in *)client_ip)->sin_addr, cip, sizeof(cip));
       family = AF_INET;
     } else {
-      port = ((struct sockaddr_in6 *) client_ip)->sin6_port;
-      inet_ntop(AF_INET6, (const void *) &((struct sockaddr_in6 *) client_ip)->sin6_addr, cip, sizeof(cip));
+      port = ntohs(((struct sockaddr_in6 *)client_ip)->sin6_port);
+      inet_ntop(AF_INET6, (const void *)&((struct sockaddr_in6 *)client_ip)->sin6_addr, cip, sizeof(cip));
       family = AF_INET6;
     }
 
@@ -643,7 +657,7 @@ ts_lua_client_request_client_addr_get_addr(lua_State * L)
 }
 
 static void
-ts_lua_inject_client_request_method_api(lua_State * L)
+ts_lua_inject_client_request_method_api(lua_State *L)
 {
   lua_pushcfunction(L, ts_lua_client_request_get_method);
   lua_setfield(L, -2, "get_method");
@@ -653,7 +667,7 @@ ts_lua_inject_client_request_method_api(lua_State * L)
 }
 
 static int
-ts_lua_client_request_get_method(lua_State * L)
+ts_lua_client_request_get_method(lua_State *L)
 {
   const char *method;
   int method_len;
@@ -674,7 +688,7 @@ ts_lua_client_request_get_method(lua_State * L)
 }
 
 static int
-ts_lua_client_request_set_method(lua_State * L)
+ts_lua_client_request_set_method(lua_State *L)
 {
   const char *method;
   size_t method_len;
@@ -693,14 +707,14 @@ ts_lua_client_request_set_method(lua_State * L)
 }
 
 static void
-ts_lua_inject_client_request_body_size_api(lua_State * L)
+ts_lua_inject_client_request_body_size_api(lua_State *L)
 {
   lua_pushcfunction(L, ts_lua_client_request_get_body_size);
   lua_setfield(L, -2, "get_body_size");
 }
 
 static int
-ts_lua_client_request_get_body_size(lua_State * L)
+ts_lua_client_request_get_body_size(lua_State *L)
 {
   int64_t body_size;
   ts_lua_http_ctx *http_ctx;
@@ -714,7 +728,7 @@ ts_lua_client_request_get_body_size(lua_State * L)
 }
 
 static void
-ts_lua_inject_client_request_version_api(lua_State * L)
+ts_lua_inject_client_request_version_api(lua_State *L)
 {
   lua_pushcfunction(L, ts_lua_client_request_get_version);
   lua_setfield(L, -2, "get_version");
@@ -724,7 +738,7 @@ ts_lua_inject_client_request_version_api(lua_State * L)
 }
 
 static int
-ts_lua_client_request_get_version(lua_State * L)
+ts_lua_client_request_get_version(lua_State *L)
 {
   int version;
   char buf[32];
@@ -736,14 +750,18 @@ ts_lua_client_request_get_version(lua_State * L)
 
   version = TSHttpHdrVersionGet(http_ctx->client_request_bufp, http_ctx->client_request_hdrp);
 
-  n = snprintf(buf, sizeof(buf) - 1, "%d.%d", TS_HTTP_MAJOR(version), TS_HTTP_MINOR(version));
-  lua_pushlstring(L, buf, n);
+  n = snprintf(buf, sizeof(buf), "%d.%d", TS_HTTP_MAJOR(version), TS_HTTP_MINOR(version));
+  if (n >= (int)sizeof(buf)) {
+    lua_pushlstring(L, buf, sizeof(buf) - 1);
+  } else if (n > 0) {
+    lua_pushlstring(L, buf, n);
+  }
 
   return 1;
 }
 
 static int
-ts_lua_client_request_set_version(lua_State * L)
+ts_lua_client_request_set_version(lua_State *L)
 {
   const char *version;
   size_t len;
@@ -763,14 +781,14 @@ ts_lua_client_request_set_version(lua_State * L)
 }
 
 static void
-ts_lua_inject_client_request_header_size_api(lua_State * L)
+ts_lua_inject_client_request_header_size_api(lua_State *L)
 {
   lua_pushcfunction(L, ts_lua_client_request_get_header_size);
   lua_setfield(L, -2, "get_header_size");
 }
 
 static int
-ts_lua_client_request_get_header_size(lua_State * L)
+ts_lua_client_request_get_header_size(lua_State *L)
 {
   int header_size;
   ts_lua_http_ctx *http_ctx;
