@@ -34,18 +34,18 @@
 using namespace std;
 using namespace Gzip;
 
-//FIXME: custom dictionaries would be nice. configurable/content-type?
-//FIXME: look into autoscaling the compression level based on connection speed
+// FIXME: custom dictionaries would be nice. configurable/content-type?
+// FIXME: look into autoscaling the compression level based on connection speed
 // a gprs device might benefit from a higher compression ratio, whereas a desktop w. high bandwith
 // might be served better with little or no compression at all
-//FIXME: look into compressing from the task thread pool
-//FIXME: make normalizing accept encoding configurable
+// FIXME: look into compressing from the task thread pool
+// FIXME: make normalizing accept encoding configurable
 
 // from mod_deflate:
 // ZLIB's compression algorithm uses a
-// 0-9 based scale that GZIP does where '1' is 'Best speed' 
-// and '9' is 'Best compression'. Testing has proved level '6' 
-// to be about the best level to use in an HTTP Server. 
+// 0-9 based scale that GZIP does where '1' is 'Best speed'
+// and '9' is 'Best compression'. Testing has proved level '6'
+// to be about the best level to use in an HTTP Server.
 
 const int ZLIB_COMPRESSION_LEVEL = 6;
 
@@ -54,8 +54,8 @@ int arg_idx_host_configuration;
 int arg_idx_url_disallowed;
 
 
-const char * global_hidden_header_name;
-Configuration* config = NULL;
+const char *global_hidden_header_name;
+Configuration *config = NULL;
 const char *dictionary = NULL;
 
 static GzipData *
@@ -64,7 +64,7 @@ gzip_data_alloc(int compression_type)
   GzipData *data;
   int err;
 
-  data = (GzipData *) TSmalloc(sizeof(GzipData));
+  data = (GzipData *)TSmalloc(sizeof(GzipData));
   data->downstream_vio = NULL;
   data->downstream_buffer = NULL;
   data->downstream_reader = NULL;
@@ -79,7 +79,7 @@ gzip_data_alloc(int compression_type)
   data->zstrm.total_out = 0;
   data->zstrm.zalloc = gzip_alloc;
   data->zstrm.zfree = gzip_free;
-  data->zstrm.opaque = (voidpf) 0;
+  data->zstrm.opaque = (voidpf)0;
   data->zstrm.data_type = Z_ASCII;
 
   int window_bits = (compression_type == COMPRESSION_TYPE_GZIP) ? WINDOW_BITS_GZIP : WINDOW_BITS_DEFLATE;
@@ -91,7 +91,7 @@ gzip_data_alloc(int compression_type)
   }
 
   if (dictionary) {
-    err = deflateSetDictionary(&data->zstrm, (const Bytef *) dictionary, strlen(dictionary));
+    err = deflateSetDictionary(&data->zstrm, (const Bytef *)dictionary, strlen(dictionary));
     if (err != Z_OK) {
       fatal("gzip-transform: ERROR: deflateSetDictionary (%d)!", err);
     }
@@ -102,12 +102,12 @@ gzip_data_alloc(int compression_type)
 
 
 static void
-gzip_data_destroy(GzipData * data)
+gzip_data_destroy(GzipData *data)
 {
   TSReleaseAssert(data);
 
-  //deflateEnd returnvalue ignore is intentional
-  //it would spew log on every client abort
+  // deflateEnd returnvalue ignore is intentional
+  // it would spew log on every client abort
   deflateEnd(&data->zstrm);
 
   if (data->downstream_buffer) {
@@ -152,14 +152,13 @@ gzip_vary_header(TSMBuffer bufp, TSMLoc hdr_loc)
 
   ce_loc = TSMimeHdrFieldFind(bufp, hdr_loc, "Vary", sizeof("Vary") - 1);
   if (ce_loc) {
-    int idx, count, len; 
+    int idx, count, len;
     const char *value;
 
     count = TSMimeHdrFieldValuesCount(bufp, hdr_loc, ce_loc);
-    for(idx=0; idx<count; idx++) {
+    for (idx = 0; idx < count; idx++) {
       value = TSMimeHdrFieldValueStringGet(bufp, hdr_loc, ce_loc, idx, &len);
-      if (len &&
-          strncasecmp("Accept-Encoding", value, len) == 0) {
+      if (len && strncasecmp("Accept-Encoding", value, len) == 0) {
         // Bail, Vary: Accept-Encoding already sent from origin
         TSHandleMLocRelease(bufp, hdr_loc, ce_loc);
         return TS_SUCCESS;
@@ -170,7 +169,8 @@ gzip_vary_header(TSMBuffer bufp, TSMLoc hdr_loc)
     TSHandleMLocRelease(bufp, hdr_loc, ce_loc);
   } else {
     if ((ret = TSMimeHdrFieldCreateNamed(bufp, hdr_loc, "Vary", sizeof("Vary") - 1, &ce_loc)) == TS_SUCCESS) {
-      if ((ret = TSMimeHdrFieldValueStringInsert(bufp, hdr_loc, ce_loc, -1, "Accept-Encoding", sizeof("Accept-Encoding") - 1)) == TS_SUCCESS) {
+      if ((ret = TSMimeHdrFieldValueStringInsert(bufp, hdr_loc, ce_loc, -1, "Accept-Encoding", sizeof("Accept-Encoding") - 1)) ==
+          TS_SUCCESS) {
         ret = TSMimeHdrFieldAppend(bufp, hdr_loc, ce_loc);
       }
 
@@ -185,7 +185,7 @@ gzip_vary_header(TSMBuffer bufp, TSMLoc hdr_loc)
   return ret;
 }
 
-//FIXME: the etag alteration isn't proper. it should modify the value inside quotes
+// FIXME: the etag alteration isn't proper. it should modify the value inside quotes
 //       specify a very header..
 static TSReturnCode
 gzip_etag_header(TSMBuffer bufp, TSMLoc hdr_loc)
@@ -199,8 +199,8 @@ gzip_etag_header(TSMBuffer bufp, TSMLoc hdr_loc)
     int changetag = 1;
     int strl;
     const char *strv = TSMimeHdrFieldValueStringGet(bufp, hdr_loc, ce_loc, -1, &strl);
-    //do not alter weak etags.
-    //FIXME: consider just making the etag weak for compressed content
+    // do not alter weak etags.
+    // FIXME: consider just making the etag weak for compressed content
     if (strl >= 2) {
       if ((strv[0] == 'w' || strv[0] == 'W') && strv[1] == '/') {
         changetag = 0;
@@ -219,12 +219,12 @@ gzip_etag_header(TSMBuffer bufp, TSMLoc hdr_loc)
   return ret;
 }
 
-//FIXME: some things are potentially compressible. those responses
+// FIXME: some things are potentially compressible. those responses
 static void
-gzip_transform_init(TSCont contp, GzipData * data)
+gzip_transform_init(TSCont contp, GzipData *data)
 {
-  //update the vary, content-encoding, and etag response headers
-  //prepare the downstream for transforming
+  // update the vary, content-encoding, and etag response headers
+  // prepare the downstream for transforming
 
   TSVConn downstream_conn;
   TSMBuffer bufp;
@@ -238,8 +238,7 @@ gzip_transform_init(TSCont contp, GzipData * data)
   }
 
   if (gzip_content_encoding_header(bufp, hdr_loc, data->compression_type) == TS_SUCCESS &&
-      gzip_vary_header(bufp, hdr_loc) == TS_SUCCESS &&
-      gzip_etag_header(bufp, hdr_loc) == TS_SUCCESS) {
+      gzip_vary_header(bufp, hdr_loc) == TS_SUCCESS && gzip_etag_header(bufp, hdr_loc) == TS_SUCCESS) {
     downstream_conn = TSTransformOutputVConnGet(contp);
     data->downstream_buffer = TSIOBufferCreate();
     data->downstream_reader = TSIOBufferReaderAlloc(data->downstream_buffer);
@@ -250,9 +249,8 @@ gzip_transform_init(TSCont contp, GzipData * data)
 }
 
 
-
 static void
-gzip_transform_one(GzipData * data, TSIOBufferReader upstream_reader, int amount)
+gzip_transform_one(GzipData *data, TSIOBufferReader upstream_reader, int amount)
 {
   TSIOBufferBlock downstream_blkp;
   const char *upstream_buffer;
@@ -260,6 +258,9 @@ gzip_transform_one(GzipData * data, TSIOBufferReader upstream_reader, int amount
   int64_t upstream_length, downstream_length;
   int err;
 
+  TSHttpTxn txnp = (TSHttpTxn)data->txn;
+  HostConfiguration *hc = (HostConfiguration *)TSHttpTxnArgGet(txnp, arg_idx_host_configuration);
+
   while (amount > 0) {
     downstream_blkp = TSIOBufferReaderStart(upstream_reader);
     if (!downstream_blkp) {
@@ -277,17 +278,23 @@ gzip_transform_one(GzipData * data, TSIOBufferReader upstream_reader, int amount
       upstream_length = amount;
     }
 
-    data->zstrm.next_in = (unsigned char *) upstream_buffer;
+    data->zstrm.next_in = (unsigned char *)upstream_buffer;
     data->zstrm.avail_in = upstream_length;
 
     while (data->zstrm.avail_in > 0) {
       downstream_blkp = TSIOBufferStart(data->downstream_buffer);
       downstream_buffer = TSIOBufferBlockWriteStart(downstream_blkp, &downstream_length);
 
-      data->zstrm.next_out = (unsigned char *) downstream_buffer;
+      data->zstrm.next_out = (unsigned char *)downstream_buffer;
       data->zstrm.avail_out = downstream_length;
 
-      err = deflate(&data->zstrm, Z_NO_FLUSH);
+      if (!hc->flush()) {
+        debug("gzip_transform: deflate with Z_NO_FLUSH");
+        err = deflate(&data->zstrm, Z_NO_FLUSH);
+      } else {
+        debug("gzip_transform: deflate with Z_SYNC_FLUSH");
+        err = deflate(&data->zstrm, Z_SYNC_FLUSH);
+      }
 
       if (err != Z_OK)
         warning("deflate() call failed: %d", err);
@@ -310,7 +317,7 @@ gzip_transform_one(GzipData * data, TSIOBufferReader upstream_reader, int amount
 }
 
 static void
-gzip_transform_finish(GzipData * data)
+gzip_transform_finish(GzipData *data)
 {
   if (data->state == transform_state_output) {
     TSIOBufferBlock downstream_blkp;
@@ -324,17 +331,17 @@ gzip_transform_finish(GzipData * data)
       downstream_blkp = TSIOBufferStart(data->downstream_buffer);
 
       downstream_buffer = TSIOBufferBlockWriteStart(downstream_blkp, &downstream_length);
-      data->zstrm.next_out = (unsigned char *) downstream_buffer;
+      data->zstrm.next_out = (unsigned char *)downstream_buffer;
       data->zstrm.avail_out = downstream_length;
 
       err = deflate(&data->zstrm, Z_FINISH);
 
-      if (downstream_length > (int64_t) data->zstrm.avail_out) {
+      if (downstream_length > (int64_t)data->zstrm.avail_out) {
         TSIOBufferProduce(data->downstream_buffer, downstream_length - data->zstrm.avail_out);
         data->downstream_length += (downstream_length - data->zstrm.avail_out);
       }
 
-      if (err == Z_OK) {        /* some more data to encode */
+      if (err == Z_OK) { /* some more data to encode */
         continue;
       }
 
@@ -344,9 +351,8 @@ gzip_transform_finish(GzipData * data)
       break;
     }
 
-    if (data->downstream_length != (int64_t) (data->zstrm.total_out)) {
-      error("gzip-transform: ERROR: output lengths don't match (%d, %ld)", data->downstream_length,
-            data->zstrm.total_out);
+    if (data->downstream_length != (int64_t)(data->zstrm.total_out)) {
+      error("gzip-transform: ERROR: output lengths don't match (%d, %ld)", data->downstream_length, data->zstrm.total_out);
     }
 
     gzip_log_ratio(data->zstrm.total_in, data->downstream_length);
@@ -363,7 +369,7 @@ gzip_transform_do(TSCont contp)
   int64_t upstream_avail;
   int64_t downstream_bytes_written;
 
-  data = (GzipData*)TSContDataGet(contp);
+  data = (GzipData *)TSContDataGet(contp);
   if (data->state == transform_state_initialized) {
     gzip_transform_init(contp, data);
   }
@@ -421,17 +427,16 @@ static int
 gzip_transform(TSCont contp, TSEvent event, void * /* edata ATS_UNUSED */)
 {
   if (TSVConnClosedGet(contp)) {
-    gzip_data_destroy((GzipData*)TSContDataGet(contp));
+    gzip_data_destroy((GzipData *)TSContDataGet(contp));
     TSContDestroy(contp);
     return 0;
   } else {
     switch (event) {
-    case TS_EVENT_ERROR:{
-        debug("gzip_transform: TS_EVENT_ERROR starts");
-        TSVIO upstream_vio = TSVConnWriteVIOGet(contp);
-        TSContCall(TSVIOContGet(upstream_vio), TS_EVENT_ERROR, upstream_vio);
-      }
-      break;
+    case TS_EVENT_ERROR: {
+      debug("gzip_transform: TS_EVENT_ERROR starts");
+      TSVIO upstream_vio = TSVConnWriteVIOGet(contp);
+      TSContCall(TSVIOContGet(upstream_vio), TS_EVENT_ERROR, upstream_vio);
+    } break;
     case TS_EVENT_VCONN_WRITE_COMPLETE:
       TSVConnShutdown(TSTransformOutputVConnGet(contp), 0, 1);
       break;
@@ -453,7 +458,7 @@ gzip_transform(TSCont contp, TSEvent event, void * /* edata ATS_UNUSED */)
 
 
 static int
-gzip_transformable(TSHttpTxn txnp, int server, HostConfiguration * host_configuration, int *compress_type)
+gzip_transformable(TSHttpTxn txnp, int server, HostConfiguration *host_configuration, int *compress_type)
 {
   /* Server response header */
   TSMBuffer bufp;
@@ -478,7 +483,7 @@ gzip_transformable(TSHttpTxn txnp, int server, HostConfiguration * host_configur
   resp_status = TSHttpHdrStatusGet(bufp, hdr_loc);
   TSHandleMLocRelease(bufp, TS_NULL_MLOC, hdr_loc);
 
-  //conservatively pick some statusses to compress
+  // conservatively pick some statusses to compress
   if (!(resp_status == 200 || resp_status == 404 || resp_status == 500)) {
     info("http response status [%d] is not compressible", resp_status);
     return 0;
@@ -486,7 +491,7 @@ gzip_transformable(TSHttpTxn txnp, int server, HostConfiguration * host_configur
 
   TSHttpTxnClientReqGet(txnp, &cbuf, &chdr);
 
-  //the only compressible method is currently GET.
+  // the only compressible method is currently GET.
   int method_length;
   const char *method = TSHttpHdrMethodGet(cbuf, chdr, &method_length);
   if (!(method_length == TS_HTTP_LEN_GET && memcmp(method, TS_HTTP_METHOD_GET, TS_HTTP_LEN_GET) == 0)) {
@@ -499,7 +504,7 @@ gzip_transformable(TSHttpTxn txnp, int server, HostConfiguration * host_configur
   if (cfield != TS_NULL_MLOC) {
     compression_acceptable = 0;
     nvalues = TSMimeHdrFieldValuesCount(cbuf, chdr, cfield);
-    for (i=0; i<nvalues; i++) {
+    for (i = 0; i < nvalues; i++) {
       value = TSMimeHdrFieldValueStringGet(cbuf, chdr, cfield, i, &len);
       if (!value) {
         continue;
@@ -558,7 +563,7 @@ gzip_transformable(TSHttpTxn txnp, int server, HostConfiguration * host_configur
   value = TSMimeHdrFieldValueStringGet(bufp, hdr_loc, field_loc, -1, &len);
 
   int rv = host_configuration->ContentTypeIsCompressible(value, len);
-  if (!rv) { 
+  if (!rv) {
     info("content-type [%.*s] not compressible", len, value);
   }
   TSHandleMLocRelease(bufp, hdr_loc, field_loc);
@@ -568,15 +573,15 @@ gzip_transformable(TSHttpTxn txnp, int server, HostConfiguration * host_configur
 
 
 static void
-gzip_transform_add(TSHttpTxn txnp, int /* server ATS_UNUSED */, HostConfiguration * hc, int compress_type)
+gzip_transform_add(TSHttpTxn txnp, int /* server ATS_UNUSED */, HostConfiguration *hc, int compress_type)
 {
-  int *tmp = (int *) TSHttpTxnArgGet(txnp, arg_idx_hooked);
+  int *tmp = (int *)TSHttpTxnArgGet(txnp, arg_idx_hooked);
   if (tmp) {
-    //happens on cache_stale_hit
+    // happens on cache_stale_hit
     debug("transform hook already set, bail");
     return;
   } else {
-    TSHttpTxnArgSet(txnp, arg_idx_hooked, (void *) &GZIP_ONE);
+    TSHttpTxnArgSet(txnp, arg_idx_hooked, (void *)&GZIP_ONE);
     info("adding compression transform");
   }
 
@@ -584,7 +589,7 @@ gzip_transform_add(TSHttpTxn txnp, int /* server ATS_UNUSED */, HostConfiguratio
 
   if (!hc->cache()) {
     TSHttpTxnTransformedRespCache(txnp, 0);
-  } else { 
+  } else {
     TSHttpTxnTransformedRespCache(txnp, 1);
   }
 
@@ -620,7 +625,7 @@ cache_transformable(TSHttpTxn txnp)
   return 0;
 }
 
-HostConfiguration * 
+HostConfiguration *
 find_host_configuration(TSHttpTxn /* txnp ATS_UNUSED */, TSMBuffer bufp, TSMLoc locp)
 {
   TSMLoc fieldp = TSMimeHdrFieldFind(bufp, locp, TS_MIME_FIELD_HOST, TS_MIME_LEN_HOST);
@@ -630,7 +635,7 @@ find_host_configuration(TSHttpTxn /* txnp ATS_UNUSED */, TSMBuffer bufp, TSMLoc
     const char *strv = TSMimeHdrFieldValueStringGet(bufp, locp, fieldp, -1, &strl);
     TSHandleMLocRelease(bufp, locp, fieldp);
 
-    HostConfiguration * host_configuration = config->Find(strv, strl);   
+    HostConfiguration *host_configuration = config->Find(strv, strl);
     return host_configuration;
   }
 
@@ -641,91 +646,83 @@ find_host_configuration(TSHttpTxn /* txnp ATS_UNUSED */, TSMBuffer bufp, TSMLoc
 static int
 transform_plugin(TSCont /* contp ATS_UNUSED */, TSEvent event, void *edata)
 {
-  TSHttpTxn txnp = (TSHttpTxn) edata;
+  TSHttpTxn txnp = (TSHttpTxn)edata;
   int compress_type = COMPRESSION_TYPE_DEFLATE;
 
   switch (event) {
-    case TS_EVENT_HTTP_READ_REQUEST_HDR:
-      {
+  case TS_EVENT_HTTP_READ_REQUEST_HDR: {
+    TSMBuffer req_buf;
+    TSMLoc req_loc;
+    if (TSHttpTxnClientReqGet(txnp, &req_buf, &req_loc) == TS_SUCCESS) {
+      int url_len;
+      char *url = TSHttpTxnEffectiveUrlStringGet(txnp, &url_len);
+      HostConfiguration *hc = find_host_configuration(txnp, req_buf, req_loc);
+      // we could clone the hosting configuration here, to make it deletable on reload?
+      TSHttpTxnArgSet(txnp, arg_idx_host_configuration, (void *)hc);
+
+      if (!hc->enabled() || !hc->IsUrlAllowed(url, url_len)) {
+        // FIXME: no double negatives
+        TSHttpTxnArgSet(txnp, arg_idx_url_disallowed, (void *)&GZIP_ONE);
+        info("url [%.*s] not allowed", url_len, url);
+      } else {
+        normalize_accept_encoding(txnp, req_buf, req_loc);
+      }
+      TSfree(url);
+      TSHandleMLocRelease(req_buf, TS_NULL_MLOC, req_loc);
+    }
+    TSHttpTxnReenable(txnp, TS_EVENT_HTTP_CONTINUE);
+  } break;
+
+  case TS_EVENT_HTTP_READ_RESPONSE_HDR: {
+    // os: the accept encoding header needs to be restored..
+    // otherwise the next request won't get a cache hit on this
+    HostConfiguration *hc = (HostConfiguration *)TSHttpTxnArgGet(txnp, arg_idx_host_configuration);
+    if (hc != NULL) {
+      if (hc->remove_accept_encoding()) {
         TSMBuffer req_buf;
         TSMLoc req_loc;
-        if (TSHttpTxnClientReqGet(txnp, &req_buf, &req_loc) == TS_SUCCESS) {
-          int url_len;
-          char * url = TSHttpTxnEffectiveUrlStringGet(txnp, &url_len);
-          HostConfiguration * hc = find_host_configuration(txnp, req_buf, req_loc);
-          //we could clone the hosting configuration here, to make it deletable on reload?
-          TSHttpTxnArgSet(txnp, arg_idx_host_configuration, (void *) hc);
-
-          if (!hc->enabled() || !hc->IsUrlAllowed(url, url_len)) {
-            //FIXME: no double negatives
-            TSHttpTxnArgSet(txnp, arg_idx_url_disallowed, (void *) &GZIP_ONE);
-            info("url [%.*s] not allowed", url_len, url);
-          } else {
-            normalize_accept_encoding(txnp, req_buf, req_loc);	
-          }
-          TSfree(url);
+        if (TSHttpTxnServerReqGet(txnp, &req_buf, &req_loc) == TS_SUCCESS) {
+          restore_accept_encoding(txnp, req_buf, req_loc, global_hidden_header_name);
           TSHandleMLocRelease(req_buf, TS_NULL_MLOC, req_loc);
         }
-        TSHttpTxnReenable(txnp, TS_EVENT_HTTP_CONTINUE);
       }
-      break;
 
-    case TS_EVENT_HTTP_READ_RESPONSE_HDR:
-      {
-        //os: the accept encoding header needs to be restored..
-        //otherwise the next request won't get a cache hit on this
-        HostConfiguration * hc = (HostConfiguration*)TSHttpTxnArgGet(txnp, arg_idx_host_configuration);
-        if (hc != NULL) { 
-          if (hc->remove_accept_encoding()) {
-            TSMBuffer req_buf;
-            TSMLoc req_loc;
-            if (TSHttpTxnServerReqGet(txnp, &req_buf, &req_loc) == TS_SUCCESS) {
-              restore_accept_encoding(txnp, req_buf, req_loc, global_hidden_header_name);
-              TSHandleMLocRelease(req_buf, TS_NULL_MLOC, req_loc);
-            }
-          }
+      int allowed = !TSHttpTxnArgGet(txnp, arg_idx_url_disallowed);
+      if (allowed && gzip_transformable(txnp, 1, hc, &compress_type)) {
+        gzip_transform_add(txnp, 1, hc, compress_type);
+      }
+    }
+    TSHttpTxnReenable(txnp, TS_EVENT_HTTP_CONTINUE);
+  } break;
 
-          int allowed = !TSHttpTxnArgGet(txnp, arg_idx_url_disallowed);
-          if ( allowed && gzip_transformable(txnp, 1, hc, &compress_type)) {
-            gzip_transform_add(txnp, 1, hc, compress_type);
-          }
+  case TS_EVENT_HTTP_SEND_REQUEST_HDR: {
+    HostConfiguration *hc = (HostConfiguration *)TSHttpTxnArgGet(txnp, arg_idx_host_configuration);
+    if (hc != NULL) {
+      if (hc->remove_accept_encoding()) {
+        TSMBuffer req_buf;
+        TSMLoc req_loc;
+        if (TSHttpTxnServerReqGet(txnp, &req_buf, &req_loc) == TS_SUCCESS) {
+          hide_accept_encoding(txnp, req_buf, req_loc, global_hidden_header_name);
+          TSHandleMLocRelease(req_buf, TS_NULL_MLOC, req_loc);
         }
-        TSHttpTxnReenable(txnp, TS_EVENT_HTTP_CONTINUE);
       }
-      break;
+    }
+    TSHttpTxnReenable(txnp, TS_EVENT_HTTP_CONTINUE);
+  } break;
 
-    case TS_EVENT_HTTP_SEND_REQUEST_HDR:
-      {
-        HostConfiguration * hc = (HostConfiguration*)TSHttpTxnArgGet(txnp, arg_idx_host_configuration);
-        if (hc!=NULL) {
-          if (hc->remove_accept_encoding()) {
-            TSMBuffer req_buf;
-            TSMLoc req_loc;
-            if (TSHttpTxnServerReqGet(txnp, &req_buf, &req_loc) == TS_SUCCESS) {
-              hide_accept_encoding(txnp, req_buf, req_loc, global_hidden_header_name);
-              TSHandleMLocRelease(req_buf, TS_NULL_MLOC, req_loc);
-            }
-          }
-        }
-        TSHttpTxnReenable(txnp, TS_EVENT_HTTP_CONTINUE);
+  case TS_EVENT_HTTP_CACHE_LOOKUP_COMPLETE: {
+    int allowed = !TSHttpTxnArgGet(txnp, arg_idx_url_disallowed);
+    HostConfiguration *hc = (HostConfiguration *)TSHttpTxnArgGet(txnp, arg_idx_host_configuration);
+    if (hc != NULL) {
+      if (allowed && cache_transformable(txnp) && gzip_transformable(txnp, 0, hc, &compress_type)) {
+        gzip_transform_add(txnp, 0, hc, compress_type);
       }
-      break;
+    }
+    TSHttpTxnReenable(txnp, TS_EVENT_HTTP_CONTINUE);
+  } break;
 
-    case TS_EVENT_HTTP_CACHE_LOOKUP_COMPLETE:
-      {
-        int allowed = !TSHttpTxnArgGet(txnp, arg_idx_url_disallowed);
-        HostConfiguration * hc = (HostConfiguration*)TSHttpTxnArgGet(txnp, arg_idx_host_configuration);
-        if ( hc != NULL ) { 
-          if (allowed && cache_transformable(txnp) && gzip_transformable(txnp, 0, hc, &compress_type)) {
-            gzip_transform_add(txnp, 0, hc, compress_type);
-          }
-        }
-        TSHttpTxnReenable(txnp, TS_EVENT_HTTP_CONTINUE);
-      }
-      break;
-
-    default:
-      fatal("gzip transform unknown event");
+  default:
+    fatal("gzip transform unknown event");
   }
 
   return 0;
@@ -733,17 +730,18 @@ transform_plugin(TSCont /* contp ATS_UNUSED */, TSEvent event, void *edata)
 
 
 static void
-read_configuration(TSCont contp) {
-  const char * path = (const char *)TSContDataGet(contp);
-  Configuration * newconfig = Configuration::Parse(path);
+read_configuration(TSCont contp)
+{
+  const char *path = (const char *)TSContDataGet(contp);
+  Configuration *newconfig = Configuration::Parse(path);
 
-  Configuration * oldconfig =__sync_lock_test_and_set(&config, newconfig);
+  Configuration *oldconfig = __sync_lock_test_and_set(&config, newconfig);
   debug("config swapped,old config %p", oldconfig);
 
-  //FIXME: we have leaked.
-  //consider cloning or refcounting the configuration passed to the txn
-  //to make deleting the old configuration possible
-  //if (config != NULL )
+  // FIXME: we have leaked.
+  // consider cloning or refcounting the configuration passed to the txn
+  // to make deleting the old configuration possible
+  // if (config != NULL )
   //  delete config;
 }
 
@@ -762,9 +760,9 @@ TSPluginInit(int argc, const char *argv[])
 {
   string config_path;
 
-  if (argc > 2)  {
+  if (argc > 2) {
     fatal("the gzip plugin does not accept more than 1 plugin argument");
-  } else if (argc == 2) { 
+  } else if (argc == 2) {
     config_path = std::string(argv[1]);
   }
 
@@ -774,27 +772,24 @@ TSPluginInit(int argc, const char *argv[])
     fatal("The gzip plugin failed to register");
   }
 
-  //if (argc == 2) {
-  //  dictionary = load_dictionary(argv[1]);
-  //}
-
   if (TSHttpArgIndexReserve("gzip", "for remembering if the hook was set", &arg_idx_hooked) != TS_SUCCESS) {
     fatal("failed to reserve an argument index");
   }
   if (TSHttpArgIndexReserve("gzip", "for storing if compression is applicable", &arg_idx_host_configuration) != TS_SUCCESS) {
     fatal("failed to reserve an argument index");
   }
-  if (TSHttpArgIndexReserve("gzip", "for storing if compression is disallowed for this txn", &arg_idx_url_disallowed) != TS_SUCCESS) {
+  if (TSHttpArgIndexReserve("gzip", "for storing if compression is disallowed for this txn", &arg_idx_url_disallowed) !=
+      TS_SUCCESS) {
     fatal("failed to reserve an argument index");
   }
 
   global_hidden_header_name = init_hidden_header_name();
 
   TSCont management_contp = TSContCreate(management_update, NULL);
-  //fixme: never freed. there is no shutdown event?
-  char * p = (char*)TSmalloc(config_path.size()+1);
-  strcpy(p,config_path.c_str());
-  TSContDataSet(management_contp,(void*)p);
+  // fixme: never freed. there is no shutdown event?
+  char *p = (char *)TSmalloc(config_path.size() + 1);
+  strcpy(p, config_path.c_str());
+  TSContDataSet(management_contp, (void *)p);
   TSMgmtUpdateRegister(management_contp, TAG);
   read_configuration(management_contp);
 
