@@ -40,7 +40,7 @@ enum CondModifiers {
   COND_NOT = 4,
   COND_NOCASE = 8, // Not implemented
   COND_LAST = 16,
-  COND_CHAIN = 32  // Not implemented
+  COND_CHAIN = 32 // Not implemented
 };
 
 
@@ -50,14 +50,14 @@ enum CondModifiers {
 class Condition : public Statement
 {
 public:
-  Condition()
-    : _qualifier(""), _cond_op(MATCH_EQUAL), _matcher(NULL), _mods(COND_NONE)
+  Condition() : _qualifier(""), _cond_op(MATCH_EQUAL), _matcher(NULL), _mods(COND_NONE)
   {
     TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for Condition");
   }
 
   // Inline this, it's critical for speed (and only used twice)
-  bool do_eval(const Resources& res)
+  bool
+  do_eval(const Resources &res)
   {
     bool rt = eval(res);
 
@@ -66,11 +66,11 @@ public:
 
     if (_next) {
       if (_mods & COND_OR) {
-        return rt || (static_cast<Condition*>(_next)->do_eval(res));
+        return rt || (static_cast<Condition *>(_next)->do_eval(res));
       } else { // AND is the default
         // Short circuit if we're an AND and the first condition is FALSE.
         if (rt)
-          return static_cast<Condition*>(_next)->do_eval(res);
+          return static_cast<Condition *>(_next)->do_eval(res);
         else
           return false;
       }
@@ -81,29 +81,47 @@ public:
     return false; // Shouldn't happen.
   }
 
-  bool last() const {
+  bool
+  last() const
+  {
     return _mods & COND_LAST;
   }
 
   // Setters
-  virtual void set_qualifier(const std::string& q) { _qualifier = q; }
+  virtual void
+  set_qualifier(const std::string &q)
+  {
+    _qualifier = q;
+  }
 
   // Some getters
-  const Matcher* get_matcher() const { return _matcher; }
-  const MatcherOps get_cond_op() const { return _cond_op; }
-  const std::string get_qualifier() const { return _qualifier; }
+  const Matcher *
+  get_matcher() const
+  {
+    return _matcher;
+  }
+  const MatcherOps
+  get_cond_op() const
+  {
+    return _cond_op;
+  }
+  const std::string
+  get_qualifier() const
+  {
+    return _qualifier;
+  }
 
   // Virtual methods, has to be implemented by each conditional;
-  virtual void initialize(Parser& p);
-  virtual void append_value(std::string& s, const Resources& res) = 0;
+  virtual void initialize(Parser &p);
+  virtual void append_value(std::string &s, const Resources &res) = 0;
 
 protected:
   // Evaluate the condition
-  virtual bool eval(const Resources& res) = 0;
+  virtual bool eval(const Resources &res) = 0;
 
   std::string _qualifier;
   MatcherOps _cond_op;
-  Matcher* _matcher;
+  Matcher *_matcher;
 
 private:
   DISALLOW_COPY_AND_ASSIGN(Condition);
@@ -113,4 +131,3 @@ private:
 
 
 #endif // __CONDITION_H
-
