@@ -29,7 +29,7 @@
 
 // OperatorConfig
 void
-OperatorSetConfig::initialize(Parser& p)
+OperatorSetConfig::initialize(Parser &p)
 {
   Operator::initialize(p);
   _config = p.get_arg();
@@ -44,7 +44,7 @@ OperatorSetConfig::initialize(Parser& p)
 
 
 void
-OperatorSetConfig::exec(const Resources& res) const
+OperatorSetConfig::exec(const Resources &res) const
 {
   if (TS_CONFIG_NULL != _key) {
     switch (_type) {
@@ -73,7 +73,7 @@ OperatorSetConfig::exec(const Resources& res) const
 
 // OperatorSetStatus
 void
-OperatorSetStatus::initialize(Parser& p)
+OperatorSetStatus::initialize(Parser &p)
 {
   Operator::initialize(p);
 
@@ -101,7 +101,7 @@ OperatorSetStatus::initialize_hooks()
 
 
 void
-OperatorSetStatus::exec(const Resources& res) const
+OperatorSetStatus::exec(const Resources &res) const
 {
   if (res.bufp && res.hdr_loc) {
     TSHttpHdrStatusSet(res.bufp, res.hdr_loc, (TSHttpStatus)_status.get_int_value());
@@ -113,7 +113,7 @@ OperatorSetStatus::exec(const Resources& res) const
 
 // OperatorSetStatusReason
 void
-OperatorSetStatusReason::initialize(Parser& p)
+OperatorSetStatusReason::initialize(Parser &p)
 {
   Operator::initialize(p);
 
@@ -131,7 +131,7 @@ OperatorSetStatusReason::initialize_hooks()
 }
 
 void
-OperatorSetStatusReason::exec(const Resources& res) const
+OperatorSetStatusReason::exec(const Resources &res) const
 {
   if (res.bufp && res.hdr_loc) {
     std::string reason;
@@ -147,7 +147,7 @@ OperatorSetStatusReason::exec(const Resources& res) const
 
 // OperatorSetDestination
 void
-OperatorSetDestination::initialize(Parser& p)
+OperatorSetDestination::initialize(Parser &p)
 {
   Operator::initialize(p);
 
@@ -159,7 +159,7 @@ OperatorSetDestination::initialize(Parser& p)
 
 
 void
-OperatorSetDestination::exec(const Resources& res) const
+OperatorSetDestination::exec(const Resources &res) const
 {
   if (res._rri || (res.bufp && res.hdr_loc)) {
     std::string value;
@@ -180,13 +180,12 @@ OperatorSetDestination::exec(const Resources& res) const
 
     // Never set an empty destination value (I don't think that ever makes sense?)
     switch (_url_qual) {
-
     case URL_QUAL_HOST:
       _value.append_value(value, res);
       if (value.empty()) {
         TSDebug(PLUGIN_NAME, "Would set destination HOST to an empty value, skipping");
       } else {
-        const_cast<Resources&>(res).changed_url = true;
+        const_cast<Resources &>(res).changed_url = true;
         TSUrlHostSet(bufp, url_m_loc, value.c_str(), value.size());
         TSDebug(PLUGIN_NAME, "OperatorSetDestination::exec() invoked with HOST: %s", value.c_str());
       }
@@ -197,7 +196,7 @@ OperatorSetDestination::exec(const Resources& res) const
       if (value.empty()) {
         TSDebug(PLUGIN_NAME, "Would set destination PATH to an empty value, skipping");
       } else {
-        const_cast<Resources&>(res).changed_url = true;
+        const_cast<Resources &>(res).changed_url = true;
         TSUrlPathSet(bufp, url_m_loc, value.c_str(), value.size());
         TSDebug(PLUGIN_NAME, "OperatorSetDestination::exec() invoked with PATH: %s", value.c_str());
       }
@@ -208,17 +207,17 @@ OperatorSetDestination::exec(const Resources& res) const
       if (value.empty()) {
         TSDebug(PLUGIN_NAME, "Would set destination QUERY to an empty value, skipping");
       } else {
-        //1.6.4--Support for preserving QSA in case of set-destination
+        // 1.6.4--Support for preserving QSA in case of set-destination
         if (get_oper_modifiers() & OPER_QSA) {
           int query_len = 0;
-          const char* query = TSUrlHttpQueryGet(bufp, url_m_loc, &query_len);
+          const char *query = TSUrlHttpQueryGet(bufp, url_m_loc, &query_len);
           TSDebug(PLUGIN_NAME, "QSA mode, append original query string: %.*s", query_len, query);
-          //std::string connector = (value.find("?") == std::string::npos)? "?" : "&";
+          // std::string connector = (value.find("?") == std::string::npos)? "?" : "&";
           value.append("&");
           value.append(query, query_len);
         }
 
-        const_cast<Resources&>(res).changed_url = true;
+        const_cast<Resources &>(res).changed_url = true;
         TSUrlHttpQuerySet(bufp, url_m_loc, value.c_str(), value.size());
         TSDebug(PLUGIN_NAME, "OperatorSetDestination::exec() invoked with QUERY: %s", value.c_str());
       }
@@ -228,19 +227,41 @@ OperatorSetDestination::exec(const Resources& res) const
       if (_value.get_int_value() <= 0 || _value.get_int_value() > 0xFFFF) {
         TSDebug(PLUGIN_NAME, "Would set destination PORT to an invalid range, skipping");
       } else {
-        const_cast<Resources&>(res).changed_url = true;
+        const_cast<Resources &>(res).changed_url = true;
         TSUrlPortSet(bufp, url_m_loc, _value.get_int_value());
         TSDebug(PLUGIN_NAME, "OperatorSetDestination::exec() invoked with PORT: %d", _value.get_int_value());
       }
       break;
     case URL_QUAL_URL:
-      // TODO: Implement URL parser.
+      if (_value.empty()) {
+        TSDebug(PLUGIN_NAME, "Would set destination URL to an empty value, skipping");
+      } else {
+        const char *start = _value.get_value().c_str();
+        const char *end = _value.get_value().size() + start;
+        TSMLoc new_url_loc;
+        if (TSUrlCreate(bufp, &new_url_loc) == TS_SUCCESS && TSUrlParse(bufp, new_url_loc, &start, end) == TS_PARSE_DONE &&
+            TSHttpHdrUrlSet(bufp, res.hdr_loc, new_url_loc) == TS_SUCCESS) {
+          TSDebug(PLUGIN_NAME, "Set destination URL to %s", _value.get_value().c_str());
+        } else {
+          TSDebug(PLUGIN_NAME, "Failed to set URL %s", _value.get_value().c_str());
+        }
+      }
+      break;
+    case URL_QUAL_SCHEME:
+      if (_value.empty()) {
+        TSDebug(PLUGIN_NAME, "Would set destination SCHEME to an empty value, skipping");
+      } else {
+        TSUrlSchemeSet(bufp, url_m_loc, _value.get_value().c_str(), _value.get_value().length());
+        TSDebug(PLUGIN_NAME, "OperatorSetDestination::exec() invoked with SCHEME: %s", _value.get_value().c_str());
+      }
       break;
     default:
+      TSDebug(PLUGIN_NAME, "Set destination %i has no handler", _url_qual);
       break;
     }
   } else {
-    TSDebug(PLUGIN_NAME, "OperatorSetDestination::exec() unable to continue due to missing bufp=%p or hdr_loc=%p, rri=%p!", res.bufp, res.hdr_loc, res._rri);
+    TSDebug(PLUGIN_NAME, "OperatorSetDestination::exec() unable to continue due to missing bufp=%p or hdr_loc=%p, rri=%p!",
+            res.bufp, res.hdr_loc, res._rri);
   }
 }
 
@@ -248,7 +269,7 @@ OperatorSetDestination::exec(const Resources& res) const
 /// TODO and XXX: These currently only support when running as remap plugin.
 // OperatorSetRedirect
 void
-OperatorSetRedirect::initialize(Parser& p)
+OperatorSetRedirect::initialize(Parser &p)
 {
   Operator::initialize(p);
 
@@ -267,7 +288,7 @@ OperatorSetRedirect::initialize(Parser& p)
 
 
 void
-OperatorSetRedirect::exec(const Resources& res) const
+OperatorSetRedirect::exec(const Resources &res) const
 {
   if (res._rri) {
     if (res.bufp && res.hdr_loc) {
@@ -275,39 +296,44 @@ OperatorSetRedirect::exec(const Resources& res) const
 
       _location.append_value(value, res);
 
+      if (_location.need_expansion()) {
+        VariableExpander ve(value);
+        value = ve.expand(res);
+      }
+
       // Replace %{PATH} to original path
       size_t pos_path = 0;
 
       if ((pos_path = value.find("%{PATH}")) != std::string::npos) {
-          value.erase(pos_path, 7); // erase %{PATH} from the rewritten to url
-          int path_len = 0;
-          const char *path = TSUrlPathGet(res._rri->requestBufp, res._rri->requestUrl, &path_len);
-          if (path_len > 0) {
-            TSDebug(PLUGIN_NAME, "Find %%{PATH} in redirect url, replace it with: %.*s", path_len, path);
-            value.insert(pos_path, path, path_len);
-          }
+        value.erase(pos_path, 7); // erase %{PATH} from the rewritten to url
+        int path_len = 0;
+        const char *path = TSUrlPathGet(res._rri->requestBufp, res._rri->requestUrl, &path_len);
+        if (path_len > 0) {
+          TSDebug(PLUGIN_NAME, "Find %%{PATH} in redirect url, replace it with: %.*s", path_len, path);
+          value.insert(pos_path, path, path_len);
+        }
       }
 
       // Append the original query string
       int query_len = 0;
       const char *query = TSUrlHttpQueryGet(res._rri->requestBufp, res._rri->requestUrl, &query_len);
       if ((get_oper_modifiers() & OPER_QSA) && (query_len > 0)) {
-          TSDebug(PLUGIN_NAME, "QSA mode, append original query string: %.*s", query_len, query);
-          std::string connector = (value.find("?") == std::string::npos)? "?" : "&";
-          value.append(connector);
-          value.append(query, query_len);
+        TSDebug(PLUGIN_NAME, "QSA mode, append original query string: %.*s", query_len, query);
+        std::string connector = (value.find("?") == std::string::npos) ? "?" : "&";
+        value.append(connector);
+        value.append(query, query_len);
       }
 
-      TSHttpTxnSetHttpRetStatus(res.txnp,(TSHttpStatus)_status.get_int_value());
-      const_cast<Resources&>(res).changed_url = true;
+      TSHttpTxnSetHttpRetStatus(res.txnp, (TSHttpStatus)_status.get_int_value());
+      const_cast<Resources &>(res).changed_url = true;
       res._rri->redirect = 1;
 
-      //TSHttpHdrStatusSet(res.bufp, res.hdr_loc, (TSHttpStatus)_status.get_int_value());
+      // TSHttpHdrStatusSet(res.bufp, res.hdr_loc, (TSHttpStatus)_status.get_int_value());
       const char *start = value.c_str();
       const char *end = value.size() + start;
       TSUrlParse(res._rri->requestBufp, res._rri->requestUrl, &start, end);
-      TSDebug(PLUGIN_NAME, "OperatorSetRedirect::exec() invoked with destination=%s and status code=%d",
-              value.c_str(), _status.get_int_value());
+      TSDebug(PLUGIN_NAME, "OperatorSetRedirect::exec() invoked with destination=%s and status code=%d", value.c_str(),
+              _status.get_int_value());
     }
 
   } else {
@@ -318,7 +344,7 @@ OperatorSetRedirect::exec(const Resources& res) const
 
 // OperatorSetTimeoutOut
 void
-OperatorSetTimeoutOut::initialize(Parser& p)
+OperatorSetTimeoutOut::initialize(Parser &p)
 {
   Operator::initialize(p);
 
@@ -340,7 +366,7 @@ OperatorSetTimeoutOut::initialize(Parser& p)
 
 
 void
-OperatorSetTimeoutOut::exec(const Resources& res) const
+OperatorSetTimeoutOut::exec(const Resources &res) const
 {
   switch (_type) {
   case TO_OUT_ACTIVE:
@@ -370,7 +396,7 @@ OperatorSetTimeoutOut::exec(const Resources& res) const
 
 // OperatorSkipRemap
 void
-OperatorSkipRemap::initialize(Parser& p)
+OperatorSkipRemap::initialize(Parser &p)
 {
   Operator::initialize(p);
 
@@ -380,7 +406,7 @@ OperatorSkipRemap::initialize(Parser& p)
 }
 
 void
-OperatorSkipRemap::exec(const Resources& res) const
+OperatorSkipRemap::exec(const Resources &res) const
 {
   TSDebug(PLUGIN_NAME, "OperatorSkipRemap::exec() skipping remap: %s", _skip_remap ? "True" : "False");
   TSSkipRemappingSet(res.txnp, _skip_remap ? 1 : 0);
@@ -389,7 +415,7 @@ OperatorSkipRemap::exec(const Resources& res) const
 
 // OperatorRMHeader
 void
-OperatorRMHeader::exec(const Resources& res) const
+OperatorRMHeader::exec(const Resources &res) const
 {
   TSMLoc field_loc, tmp;
 
@@ -409,7 +435,7 @@ OperatorRMHeader::exec(const Resources& res) const
 
 // OperatorAddHeader
 void
-OperatorAddHeader::initialize(Parser& p)
+OperatorAddHeader::initialize(Parser &p)
 {
   OperatorHeaders::initialize(p);
 
@@ -417,7 +443,7 @@ OperatorAddHeader::initialize(Parser& p)
 }
 
 void
-OperatorAddHeader::exec(const Resources& res) const
+OperatorAddHeader::exec(const Resources &res) const
 {
   std::string value;
 
@@ -452,7 +478,7 @@ OperatorAddHeader::exec(const Resources& res) const
 
 // OperatorSetHeader
 void
-OperatorSetHeader::initialize(Parser& p)
+OperatorSetHeader::initialize(Parser &p)
 {
   OperatorHeaders::initialize(p);
 
@@ -460,7 +486,7 @@ OperatorSetHeader::initialize(Parser& p)
 }
 
 void
-OperatorSetHeader::exec(const Resources& res) const
+OperatorSetHeader::exec(const Resources &res) const
 {
   std::string value;
 
@@ -509,7 +535,8 @@ OperatorSetHeader::exec(const Resources& res) const
 
 // OperatorCounter
 void
-OperatorCounter::initialize(Parser& p) {
+OperatorCounter::initialize(Parser &p)
+{
   Operator::initialize(p);
 
   _counter_name = p.get_arg();
@@ -534,7 +561,7 @@ OperatorCounter::initialize(Parser& p) {
 }
 
 void
-OperatorCounter::exec(const Resources& /* ATS_UNUSED res */) const
+OperatorCounter::exec(const Resources & /* ATS_UNUSED res */) const
 {
   // Sanity
   if (_counter == TS_ERROR)
@@ -543,3 +570,28 @@ OperatorCounter::exec(const Resources& /* ATS_UNUSED res */) const
   TSDebug(PLUGIN_NAME, "OperatorCounter::exec() invoked on counter %s", _counter_name.c_str());
   TSStatIntIncrement(_counter, 1);
 }
+
+// OperatorSetConnDSCP
+void
+OperatorSetConnDSCP::initialize(Parser &p)
+{
+  Operator::initialize(p);
+
+  _ds_value.set_value(p.get_arg());
+}
+
+void
+OperatorSetConnDSCP::initialize_hooks()
+{
+  add_allowed_hook(TS_HTTP_READ_REQUEST_HDR_HOOK);
+  add_allowed_hook(TS_HTTP_SEND_RESPONSE_HDR_HOOK);
+  add_allowed_hook(TS_REMAP_PSEUDO_HOOK);
+}
+
+void
+OperatorSetConnDSCP::exec(const Resources &res) const
+{
+  if (res.txnp) {
+    TSHttpTxnClientPacketDscpSet(res.txnp, _ds_value.get_int_value());
+  }
+}
