@@ -43,19 +43,18 @@
 #define TCPI_PLUGIN_SUPPORTED 1
 #endif
 
-#define TCPI_HOOK_SSN_START     0x01u
-#define TCPI_HOOK_TXN_START     0x02u
+#define TCPI_HOOK_SSN_START 0x01u
+#define TCPI_HOOK_TXN_START 0x02u
 #define TCPI_HOOK_SEND_RESPONSE 0x04u
-#define TCPI_HOOK_SSN_CLOSE     0x08u
-#define TCPI_HOOK_TXN_CLOSE     0x10u
+#define TCPI_HOOK_SSN_CLOSE 0x08u
+#define TCPI_HOOK_TXN_CLOSE 0x10u
 
 // Log format headers. These are emitted once at the start of a log file. Note that we
 // carefully order the fields so the field ordering is compatible. This lets you change
 // the verbosity without breaking a perser that is moderately robust.
-static const char * tcpi_headers[] = {
-  "timestamp event client server rtt",
-  "timestamp event client server rtt rttvar last_sent last_recv "
-    "snd_ssthresh rcv_ssthresh unacked sacked lost retrans fackets",
+static const char *tcpi_headers[] = {
+  "timestamp event client server rtt", "timestamp event client server rtt rttvar last_sent last_recv "
+                                       "snd_ssthresh rcv_ssthresh unacked sacked lost retrans fackets",
 };
 
 struct Config {
@@ -63,10 +62,10 @@ struct Config {
   unsigned log_level;
   TSTextLogObject log;
 
-  Config() : sample(1000), log_level(1), log(NULL) {
-  }
+  Config() : sample(1000), log_level(1), log(NULL) {}
 
-  ~Config() {
+  ~Config()
+  {
     if (log) {
       TSTextLogObjectDestroy(log);
     }
@@ -74,33 +73,37 @@ struct Config {
 };
 
 union const_sockaddr_ptr {
-  const struct sockaddr * sa;
-  const struct sockaddr_in * in;
-  const struct sockaddr_in6 * in6;
+  const struct sockaddr *sa;
+  const struct sockaddr_in *in;
+  const struct sockaddr_in6 *in6;
 
-  const void * addr() const {
+  const void *
+  addr() const
+  {
     switch (sa->sa_family) {
-    case AF_INET: return &(in->sin_addr);
-    case AF_INET6: return &(in6->sin6_addr);
-    default: return NULL;
+    case AF_INET:
+      return &(in->sin_addr);
+    case AF_INET6:
+      return &(in6->sin6_addr);
+    default:
+      return NULL;
     }
   }
-
 };
 
 #if TCPI_PLUGIN_SUPPORTED
 
 static void
-log_tcp_info(Config * config, const char * event_name, TSHttpSsn ssnp)
+log_tcp_info(Config *config, const char *event_name, TSHttpSsn ssnp)
 {
-  char                client_str[INET6_ADDRSTRLEN];
-  char                server_str[INET6_ADDRSTRLEN];
-  const_sockaddr_ptr  client_addr;
-  const_sockaddr_ptr  server_addr;
+  char client_str[INET6_ADDRSTRLEN];
+  char server_str[INET6_ADDRSTRLEN];
+  const_sockaddr_ptr client_addr;
+  const_sockaddr_ptr server_addr;
 
-  struct tcp_info     info;
-  socklen_t           tcp_info_len = sizeof(info);
-  int                 fd;
+  struct tcp_info info;
+  socklen_t tcp_info_len = sizeof(info);
+  int fd;
 
   TSReleaseAssert(config->log != NULL);
 
@@ -129,54 +132,23 @@ log_tcp_info(Config * config, const char * event_name, TSHttpSsn ssnp)
 
   if (config->log_level == 2) {
 #if !defined(freebsd) || defined(__GLIBC__)
-    ret = TSTextLogObjectWrite(config->log, "%s %s %s %u %u %u %u %u %u %u %u %u %u %u %u",
-                     event_name,
-                     client_str,
-                     server_str,
-                     info.tcpi_rtt,
-                     info.tcpi_rttvar,
-                     info.tcpi_last_data_sent,
-                     info.tcpi_last_data_recv,
-                     info.tcpi_snd_cwnd,
-                     info.tcpi_snd_ssthresh,
-                     info.tcpi_rcv_ssthresh,
-                     info.tcpi_unacked,
-                     info.tcpi_sacked,
-                     info.tcpi_lost,
-                     info.tcpi_retrans,
-                     info.tcpi_fackets);
+    ret = TSTextLogObjectWrite(config->log, "%s %s %s %u %u %u %u %u %u %u %u %u %u %u %u", event_name, client_str, server_str,
+                               info.tcpi_rtt, info.tcpi_rttvar, info.tcpi_last_data_sent, info.tcpi_last_data_recv,
+                               info.tcpi_snd_cwnd, info.tcpi_snd_ssthresh, info.tcpi_rcv_ssthresh, info.tcpi_unacked,
+                               info.tcpi_sacked, info.tcpi_lost, info.tcpi_retrans, info.tcpi_fackets);
 #else
-    ret = TSTextLogObjectWrite(config->log, "%s %s %s %u %u %u %u %u %u %u %u %u %u %u %u",
-                     event_name,
-                     client_str,
-                     server_str,
-                     info.tcpi_rtt,
-                     info.tcpi_rttvar,
-                     info.__tcpi_last_data_sent,
-                     info.tcpi_last_data_recv,
-                     info.tcpi_snd_cwnd,
-                     info.tcpi_snd_ssthresh,
-                     info.__tcpi_rcv_ssthresh,
-                     info.__tcpi_unacked,
-                     info.__tcpi_sacked,
-                     info.__tcpi_lost,
-                     info.__tcpi_retrans,
-                     info.__tcpi_fackets);
+    ret = TSTextLogObjectWrite(config->log, "%s %s %s %u %u %u %u %u %u %u %u %u %u %u %u", event_name, client_str, server_str,
+                               info.tcpi_rtt, info.tcpi_rttvar, info.__tcpi_last_data_sent, info.tcpi_last_data_recv,
+                               info.tcpi_snd_cwnd, info.tcpi_snd_ssthresh, info.__tcpi_rcv_ssthresh, info.__tcpi_unacked,
+                               info.__tcpi_sacked, info.__tcpi_lost, info.__tcpi_retrans, info.__tcpi_fackets);
 #endif
   } else {
-    ret = TSTextLogObjectWrite(config->log, "%s %s %s %u",
-                     event_name,
-                     client_str,
-                     server_str,
-                     info.tcpi_rtt);
+    ret = TSTextLogObjectWrite(config->log, "%s %s %s %u", event_name, client_str, server_str, info.tcpi_rtt);
   }
 
-  // It's really not clear how we should handle logging failures. It a failure transient
-  // or persistent? Should we try to re-open the logs? How frequently should we do that?
   if (ret != TS_SUCCESS) {
-    TSError("[tcpinfo] log write failed, disabling logging");
-    TSTextLogObjectDestroy(config->log);
-    config->log = NULL;
+    // ToDo: This could be due to a failure, or logs full. Should we consider
+    // closing / reopening the log? If so, how often do we do that ?
   }
 }
 
@@ -195,8 +167,8 @@ tcp_info_hook(TSCont contp, TSEvent event, void *edata)
 {
   TSHttpSsn ssnp = NULL;
   TSHttpTxn txnp = NULL;
-  int       random = 0;
-  Config *  config = (Config *)TSContDataGet(contp);
+  int random = 0;
+  Config *config = (Config *)TSContDataGet(contp);
 
   const char *event_name;
   switch (event) {
@@ -227,8 +199,7 @@ tcp_info_hook(TSCont contp, TSEvent event, void *edata)
     return 0;
   }
 
-  TSDebug("tcpinfo", "logging hook called for %s (%s) with log object %p",
-      TSHttpEventNameLookup(event), event_name, config->log);
+  TSDebug("tcpinfo", "logging hook called for %s (%s) with log object %p", TSHttpEventNameLookup(event), event_name, config->log);
 
   if (config->log == NULL) {
     goto done;
@@ -241,6 +212,7 @@ tcp_info_hook(TSCont contp, TSEvent event, void *edata)
 
   // no need to run rand if we are always going log (100%)
   if (config->sample < 1000) {
+    // coverity[dont_call]
     random = rand() % 1000;
     TSDebug("tcpinfo", "random: %d, config->sample: %d", random, config->sample);
   }
@@ -261,9 +233,9 @@ done:
 }
 
 static bool
-parse_unsigned(const char * str, unsigned long& lval)
+parse_unsigned(const char *str, unsigned long &lval)
 {
-  char * end = NULL;
+  char *end = NULL;
 
   if (*str == '\0') {
     return false;
@@ -285,28 +257,29 @@ parse_unsigned(const char * str, unsigned long& lval)
 
 // Parse a comma-separated list of hook names into a hook bitmask.
 static unsigned
-parse_hook_list(const char * hook_list)
+parse_hook_list(const char *hook_list)
 {
   unsigned mask = 0;
-  char * tok;
-  char * str;
-  char * last;
+  char *tok;
+  char *str;
+  char *last;
 
-  const struct hookmask { const char * name; unsigned mask; } hooks[] = {
-    { "ssn_start", TCPI_HOOK_SSN_START },
-    { "txn_start", TCPI_HOOK_TXN_START },
-    { "send_resp_hdr", TCPI_HOOK_SEND_RESPONSE },
-    { "ssn_close", TCPI_HOOK_SSN_CLOSE },
-    { "txn_close", TCPI_HOOK_TXN_CLOSE },
-    { NULL, 0u }
-  };
+  const struct hookmask {
+    const char *name;
+    unsigned mask;
+  } hooks[] = {{"ssn_start", TCPI_HOOK_SSN_START},
+               {"txn_start", TCPI_HOOK_TXN_START},
+               {"send_resp_hdr", TCPI_HOOK_SEND_RESPONSE},
+               {"ssn_close", TCPI_HOOK_SSN_CLOSE},
+               {"txn_close", TCPI_HOOK_TXN_CLOSE},
+               {NULL, 0u}};
 
   str = TSstrdup(hook_list);
 
   for (tok = strtok_r(str, ",", &last); tok; tok = strtok_r(NULL, ",", &last)) {
     bool match = false;
 
-    for (const struct hookmask * m = hooks; m->name != NULL; ++m) {
+    for (const struct hookmask *m = hooks; m->name != NULL; ++m) {
       if (strcmp(m->name, tok) == 0) {
         mask |= m->mask;
         match = true;
@@ -324,26 +297,24 @@ parse_hook_list(const char * hook_list)
 }
 
 void
-TSPluginInit(int argc, const char * argv[])
+TSPluginInit(int argc, const char *argv[])
 {
   static const char usage[] = "tcpinfo.so [--log-file=PATH] [--log-level=LEVEL] [--hooks=LIST] [--sample-rate=COUNT]";
-  static const struct option longopts[] = {
-    { const_cast<char *>("sample-rate"), required_argument, NULL, 'r' },
-    { const_cast<char *>("log-file"), required_argument, NULL, 'f' },
-    { const_cast<char *>("log-level"), required_argument, NULL, 'l' },
-    { const_cast<char *>("hooks"), required_argument, NULL, 'h' },
-    { NULL, 0, NULL, 0 }
-  };
+  static const struct option longopts[] = {{const_cast<char *>("sample-rate"), required_argument, NULL, 'r'},
+                                           {const_cast<char *>("log-file"), required_argument, NULL, 'f'},
+                                           {const_cast<char *>("log-level"), required_argument, NULL, 'l'},
+                                           {const_cast<char *>("hooks"), required_argument, NULL, 'h'},
+                                           {NULL, 0, NULL, 0}};
 
   TSPluginRegistrationInfo info;
-  Config *  config = new Config();
-  const char *  filename = "tcpinfo";
-  TSCont    cont;
-  unsigned  hooks = 0;
+  Config *config = new Config();
+  const char *filename = "tcpinfo";
+  TSCont cont;
+  unsigned hooks = 0;
 
-  info.plugin_name = (char*)"tcpinfo";
-  info.vendor_name = (char*)"Apache Software Foundation";
-  info.support_email = (char*)"dev@trafficserver.apache.org";
+  info.plugin_name = (char *)"tcpinfo";
+  info.vendor_name = (char *)"Apache Software Foundation";
+  info.support_email = (char *)"dev@trafficserver.apache.org";
 
   if (TSPluginRegister(TS_SDK_VERSION_3_0, &info) != TS_SUCCESS) {
     TSError("[tcpinfo] plugin registration failed");
@@ -353,7 +324,7 @@ TSPluginInit(int argc, const char * argv[])
   for (;;) {
     unsigned long lval;
 
-    switch (getopt_long(argc, (char * const *)argv, "r:f:l:h:", longopts, NULL)) {
+    switch (getopt_long(argc, (char *const *)argv, "r:f:l:h:", longopts, NULL)) {
     case 'r':
       if (parse_unsigned(optarg, lval)) {
         config->sample = atoi(optarg);
@@ -375,9 +346,9 @@ TSPluginInit(int argc, const char * argv[])
       hooks = parse_hook_list(optarg);
       break;
     case -1:
-        goto init;
+      goto init;
     default:
-        TSError("[tcpinfo] usage: %s", usage);
+      TSError("[tcpinfo] usage: %s", usage);
     }
   }
 
@@ -427,5 +398,4 @@ init:
     TSHttpHookAdd(TS_HTTP_TXN_CLOSE_HOOK, cont);
     TSDebug("tcpinfo", "added hook to the close of the transaction");
   }
-
 }
