@@ -39,14 +39,13 @@ struct RequestData;
 
 const int CC_UNSET_TIME = -1;
 
-#define CACHE_CONTROL_TIMEOUT            (HRTIME_HOUR*1)
+#define CACHE_CONTROL_TIMEOUT (HRTIME_HOUR * 1)
 
 //   Use 10 second time for purify testing under low
 //     load to verify memory allocation
 //#define CACHE_CONTROL_TIMEOUT            (HRTIME_SECOND*10)
 
-enum CacheControlType
-{
+enum CacheControlType {
   CC_INVALID = 0,
   CC_REVALIDATE_AFTER,
   CC_NEVER_CACHE,
@@ -65,7 +64,6 @@ struct matcher_line;
 class CacheControlResult
 {
 public:
-
   inkcoreapi CacheControlResult();
   void Print();
 
@@ -100,25 +98,14 @@ public:
   int ignore_server_line;
 };
 
-inline
-CacheControlResult::CacheControlResult()
-  : revalidate_after(CC_UNSET_TIME),
-    pin_in_cache_for(CC_UNSET_TIME),
-    ttl_in_cache(CC_UNSET_TIME),
-    never_cache(false),
-    cluster_cache_local(false),
-    ignore_client_no_cache(false),
-    ignore_server_no_cache(false),
-    ignore_client_cc_max_age(true),
+inline CacheControlResult::CacheControlResult()
+  : revalidate_after(CC_UNSET_TIME), pin_in_cache_for(CC_UNSET_TIME), ttl_in_cache(CC_UNSET_TIME), never_cache(false),
+    cluster_cache_local(false), ignore_client_no_cache(false), ignore_server_no_cache(false), ignore_client_cc_max_age(true),
     cache_responses_to_cookies(-1), // do not change value
-    reval_line(-1),
-    never_line(-1),
-    pin_line(-1),
-    ttl_line(-1),
-    cluster_cache_local_line(-1),
-    ignore_client_line(-1),
+    reval_line(-1), never_line(-1), pin_line(-1), ttl_line(-1), cluster_cache_local_line(-1), ignore_client_line(-1),
     ignore_server_line(-1)
-{ }
+{
+}
 
 class CacheControlRecord : public ControlBase
 {
@@ -127,15 +114,14 @@ public:
   CacheControlType directive;
   int time_arg;
   int cache_responses_to_cookies;
-  char *Init(matcher_line * line_info);
-  inkcoreapi void UpdateMatch(CacheControlResult * result, RequestData * rdata);
+  config_parse_error Init(matcher_line *line_info);
+  inkcoreapi void UpdateMatch(CacheControlResult *result, RequestData *rdata);
   void Print();
 };
 
-inline
-CacheControlRecord::CacheControlRecord()
-  : ControlBase(), directive(CC_INVALID), time_arg(0) , cache_responses_to_cookies(-1)
-{ }
+inline CacheControlRecord::CacheControlRecord() : ControlBase(), directive(CC_INVALID), time_arg(0), cache_responses_to_cookies(-1)
+{
+}
 
 //
 // API to outside world
@@ -144,8 +130,8 @@ class URL;
 struct HttpConfigParams;
 struct OverridableHttpConfigParams;
 
-inkcoreapi void getCacheControl(CacheControlResult *result, HttpRequestData * rdata,
-                                OverridableHttpConfigParams *h_txn_conf, char *tag = NULL);
+inkcoreapi void getCacheControl(CacheControlResult *result, HttpRequestData *rdata, OverridableHttpConfigParams *h_txn_conf,
+                                char *tag = NULL);
 inkcoreapi bool getClusterCacheLocal(URL *url, char *hostname);
 inkcoreapi bool host_rule_in_CacheControlTable();
 inkcoreapi bool ip_rule_in_CacheControlTable();
