@@ -48,8 +48,6 @@
  *   Place all template instantiations at the bottom of the file
  ****************************************************************/
 
-
-
 // HttpRequestData accessors
 //   Can not be inlined due being virtual functions
 //
@@ -69,13 +67,13 @@ HttpRequestData::get_host()
   return hostname_str;
 }
 
-sockaddr const*
+sockaddr const *
 HttpRequestData::get_ip()
 {
   return &dest_ip.sa;
 }
 
-sockaddr const*
+sockaddr const *
 HttpRequestData::get_client_ip()
 {
   return &src_ip.sa;
@@ -85,20 +83,17 @@ HttpRequestData::get_client_ip()
  *   Begin class HostMatcher
  *************************************************************/
 
-template<class Data, class Result> HostMatcher<Data, Result>::HostMatcher(const char *name, const char *filename)
-  : data_array(NULL),
-    array_len(-1),
-    num_el(-1),
-    matcher_name(name),
-    file_name(filename)
+template <class Data, class Result>
+HostMatcher<Data, Result>::HostMatcher(const char *name, const char *filename)
+  : data_array(NULL), array_len(-1), num_el(-1), matcher_name(name), file_name(filename)
 {
   host_lookup = new HostLookup(name);
 }
 
-template<class Data, class Result> HostMatcher<Data, Result>::~HostMatcher()
+template <class Data, class Result> HostMatcher<Data, Result>::~HostMatcher()
 {
   delete host_lookup;
-  delete[]data_array;
+  delete[] data_array;
 }
 
 //
@@ -107,9 +102,10 @@ template<class Data, class Result> HostMatcher<Data, Result>::~HostMatcher()
 //
 //  Debugging Method
 //
-template<class Data, class Result> void HostMatcher<Data, Result>::Print()
+template <class Data, class Result>
+void
+HostMatcher<Data, Result>::Print()
 {
-
   printf("\tHost/Domain Matcher with %d elements\n", num_el);
   host_lookup->Print(PrintFunc);
 }
@@ -120,9 +116,11 @@ template<class Data, class Result> void HostMatcher<Data, Result>::Print()
 //
 //  Debugging Method
 //
-template<class Data, class Result> void HostMatcher<Data, Result>::PrintFunc(void *opaque_data)
+template <class Data, class Result>
+void
+HostMatcher<Data, Result>::PrintFunc(void *opaque_data)
 {
-  Data *d = (Data *) opaque_data;
+  Data *d = (Data *)opaque_data;
   d->Print();
 }
 
@@ -130,7 +128,9 @@ template<class Data, class Result> void HostMatcher<Data, Result>::PrintFunc(voi
 //
 //  Allocates the the HostLeaf and Data arrays
 //
-template<class Data, class Result> void HostMatcher<Data, Result>::AllocateSpace(int num_entries)
+template <class Data, class Result>
+void
+HostMatcher<Data, Result>::AllocateSpace(int num_entries)
 {
   // Should not have been allocated before
   ink_assert(array_len == -1);
@@ -148,7 +148,9 @@ template<class Data, class Result> void HostMatcher<Data, Result>::AllocateSpace
 //  Searches our tree and updates argresult for each element matching
 //    arg hostname
 //
-template<class Data, class Result> void HostMatcher<Data, Result>::Match(RequestData * rdata, Result * result)
+template <class Data, class Result>
+void
+HostMatcher<Data, Result>::Match(RequestData *rdata, Result *result)
 {
   void *opaque_ptr;
   Data *data_ptr;
@@ -166,7 +168,7 @@ template<class Data, class Result> void HostMatcher<Data, Result>::Match(Request
 
   while (r == true) {
     ink_assert(opaque_ptr != NULL);
-    data_ptr = (Data *) opaque_ptr;
+    data_ptr = (Data *)opaque_ptr;
     data_ptr->UpdateMatch(result, rdata);
 
     r = host_lookup->MatchNext(&s, &opaque_ptr);
@@ -174,7 +176,7 @@ template<class Data, class Result> void HostMatcher<Data, Result>::Match(Request
 }
 
 //
-// char* HostMatcher<Data,Result>::NewEntry(bool domain_record,
+// config_parse_error HostMatcher<Data,Result>::NewEntry(bool domain_record,
 //          char* match_data, char* match_info, int line_num)
 //
 //   Creates a new host/domain record
@@ -183,10 +185,12 @@ template<class Data, class Result> void HostMatcher<Data, Result>::Match(Request
 //   If not, returns a pointer to malloc allocated error string
 //     that the caller MUST DEALLOCATE
 //
-template<class Data, class Result> char *HostMatcher<Data, Result>::NewEntry(matcher_line * line_info)
+template <class Data, class Result>
+config_parse_error
+HostMatcher<Data, Result>::NewEntry(matcher_line *line_info)
 {
   Data *cur_d;
-  char *errBuf;
+  config_parse_error error = config_parse_error::ok();
   char *match_data;
 
   // Make sure space has been allocated
@@ -208,18 +212,17 @@ template<class Data, class Result> char *HostMatcher<Data, Result>::NewEntry(mat
 
   // Fill in the parameter info
   cur_d = data_array + num_el;
-  errBuf = cur_d->Init(line_info);
-
-  if (errBuf != NULL) {
+  error = cur_d->Init(line_info);
+  if (error) {
     // There was a problem so undo the effects this function
     memset(cur_d, 0, sizeof(Data));
-    return errBuf;
+  } else {
+    // Fill in the matching info
+    host_lookup->NewEntry(match_data, (line_info->type == MATCH_DOMAIN) ? true : false, cur_d);
+    num_el++;
   }
-  // Fill in the matching info
-  host_lookup->NewEntry(match_data, (line_info->type == MATCH_DOMAIN) ? true : false, cur_d);
 
-  num_el++;
-  return NULL;
+  return error;
 }
 
 /*************************************************************
@@ -229,10 +232,9 @@ template<class Data, class Result> char *HostMatcher<Data, Result>::NewEntry(mat
 //
 // UrlMatcher<Data,Result>::UrlMatcher()
 //
-template<class Data, class Result> UrlMatcher<Data, Result>::UrlMatcher(const char *name, const char *filename)
-  : url_ht(NULL),
-    num_el(-1),
-    matcher_name(name),
+template <class Data, class Result>
+UrlMatcher<Data, Result>::UrlMatcher(const char *name, const char *filename)
+  : url_ht(NULL), url_str(NULL), url_value(NULL), data_array(NULL), array_len(0), num_el(-1), matcher_name(name),
     file_name(filename)
 {
   url_ht = ink_hash_table_create(InkHashTableKeyType_String);
@@ -241,15 +243,15 @@ template<class Data, class Result> UrlMatcher<Data, Result>::UrlMatcher(const ch
 //
 // UrlMatcher<Data,Result>::~UrlMatcher()
 //
-template<class Data, class Result> UrlMatcher<Data, Result>::~UrlMatcher()
+template <class Data, class Result> UrlMatcher<Data, Result>::~UrlMatcher()
 {
   ink_hash_table_destroy(url_ht);
   for (int i = 0; i < num_el; i++) {
     ats_free(url_str[i]);
   }
-  delete[]url_str;
-  delete[]url_value;
-  delete[]data_array;
+  delete[] url_str;
+  delete[] url_value;
+  delete[] data_array;
 }
 
 //
@@ -257,7 +259,9 @@ template<class Data, class Result> UrlMatcher<Data, Result>::~UrlMatcher()
 //
 //   Debugging function
 //
-template<class Data, class Result> void UrlMatcher<Data, Result>::Print()
+template <class Data, class Result>
+void
+UrlMatcher<Data, Result>::Print()
 {
   printf("\tUrl Matcher with %d elements\n", num_el);
   for (int i = 0; i < num_el; i++) {
@@ -269,13 +273,15 @@ template<class Data, class Result> void UrlMatcher<Data, Result>::Print()
 //
 // void UrlMatcher<Data,Result>::AllocateSpace(int num_entries)
 //
-template<class Data, class Result> void UrlMatcher<Data, Result>::AllocateSpace(int num_entries)
+template <class Data, class Result>
+void
+UrlMatcher<Data, Result>::AllocateSpace(int num_entries)
 {
   // Should not have been allocated before
   ink_assert(array_len == -1);
 
   data_array = new Data[num_entries];
-  url_value = new int [num_entries];
+  url_value = new int[num_entries];
   url_str = new char *[num_entries];
   memset(url_str, 0, sizeof(char *) * num_entries);
   array_len = num_entries;
@@ -283,14 +289,16 @@ template<class Data, class Result> void UrlMatcher<Data, Result>::AllocateSpace(
 }
 
 //
-// char* UrlMatcher<Data,Result>::NewEntry(matcher_line* line_info)
+// config_parse_error UrlMatcher<Data,Result>::NewEntry(matcher_line* line_info)
 //
-template<class Data, class Result> char *UrlMatcher<Data, Result>::NewEntry(matcher_line * line_info)
+template <class Data, class Result>
+config_parse_error
+UrlMatcher<Data, Result>::NewEntry(matcher_line *line_info)
 {
   Data *cur_d;
-  char *errBuf;
   char *pattern;
   int *value;
+  config_parse_error error = config_parse_error::ok();
 
   // Make sure space has been allocated
   ink_assert(num_el >= 0);
@@ -305,28 +313,24 @@ template<class Data, class Result> char *UrlMatcher<Data, Result>::NewEntry(matc
   ink_assert(pattern != NULL);
 
   if (ink_hash_table_lookup(url_ht, pattern, (void **)&value)) {
-    errBuf = (char *)ats_malloc(1024 * sizeof(char));
-    *errBuf = '\0';
-    snprintf(errBuf, 1024, "%s url expression error(have exist) at line %d position",
-                 matcher_name, line_info->line_num);
-    return errBuf;
+    return config_parse_error("%s url expression error (have exist) at line %d position", matcher_name, line_info->line_num);
   }
-  
+
   // Remove our consumed label from the parsed line
   line_info->line[0][line_info->dest_entry] = 0;
   line_info->num_el--;
 
   // Fill in the parameter info
   cur_d = data_array + num_el;
-  errBuf = cur_d->Init(line_info);
-
-  if (errBuf == NULL) {
+  error = cur_d->Init(line_info);
+  if (error) {
     url_str[num_el] = ats_strdup(pattern);
     url_value[num_el] = num_el;
     ink_hash_table_insert(url_ht, url_str[num_el], (void *)&url_value[num_el]);
     num_el++;
   }
-  return errBuf;
+
+  return error;
 }
 
 //
@@ -335,11 +339,13 @@ template<class Data, class Result> char *UrlMatcher<Data, Result>::NewEntry(matc
 //   Coduncts a linear search through the regex array and
 //     updates arg result for each regex that matches arg URL
 //
-template<class Data, class Result> void UrlMatcher<Data, Result>::Match(RequestData * rdata, Result * result)
+template <class Data, class Result>
+void
+UrlMatcher<Data, Result>::Match(RequestData *rdata, Result *result)
 {
   char *url_str;
   int *value;
-  
+
   // Check to see there is any work to before we copy the
   //   URL
   if (num_el <= 0) {
@@ -354,7 +360,7 @@ template<class Data, class Result> void UrlMatcher<Data, Result>::Match(RequestD
     url_str = ats_strdup("");
   }
 
-  if (ink_hash_table_lookup(url_ht, url_str, (void **)&value)) { 
+  if (ink_hash_table_lookup(url_ht, url_str, (void **)&value)) {
     Debug("matcher", "%s Matched %s with url at line %d", matcher_name, url_str, data_array[*value].line_num);
     data_array[*value].UpdateMatch(result, rdata);
   }
@@ -365,29 +371,24 @@ template<class Data, class Result> void UrlMatcher<Data, Result>::Match(RequestD
 //
 // RegexMatcher<Data,Result>::RegexMatcher()
 //
-template<class Data, class Result> RegexMatcher<Data, Result>::RegexMatcher(const char *name, const char *filename)
-  : re_array(NULL),
-    re_str(NULL),
-    data_array(NULL),
-    array_len(-1),
-    num_el(-1),
-    matcher_name(name),
-    file_name(filename)
+template <class Data, class Result>
+RegexMatcher<Data, Result>::RegexMatcher(const char *name, const char *filename)
+  : re_array(NULL), re_str(NULL), data_array(NULL), array_len(-1), num_el(-1), matcher_name(name), file_name(filename)
 {
 }
 
 //
 // RegexMatcher<Data,Result>::~RegexMatcher()
 //
-template<class Data, class Result> RegexMatcher<Data, Result>::~RegexMatcher()
+template <class Data, class Result> RegexMatcher<Data, Result>::~RegexMatcher()
 {
   for (int i = 0; i < num_el; i++) {
     pcre_free(re_array[i]);
     ats_free(re_str[i]);
   }
-  delete[]re_str;
+  delete[] re_str;
   ats_free(re_array);
-  delete[]data_array;
+  delete[] data_array;
 }
 
 //
@@ -395,7 +396,9 @@ template<class Data, class Result> RegexMatcher<Data, Result>::~RegexMatcher()
 //
 //   Debugging function
 //
-template<class Data, class Result> void RegexMatcher<Data, Result>::Print()
+template <class Data, class Result>
+void
+RegexMatcher<Data, Result>::Print()
 {
   printf("\tRegex Matcher with %d elements\n", num_el);
   for (int i = 0; i < num_el; i++) {
@@ -407,13 +410,15 @@ template<class Data, class Result> void RegexMatcher<Data, Result>::Print()
 //
 // void RegexMatcher<Data,Result>::AllocateSpace(int num_entries)
 //
-template<class Data, class Result> void RegexMatcher<Data, Result>::AllocateSpace(int num_entries)
+template <class Data, class Result>
+void
+RegexMatcher<Data, Result>::AllocateSpace(int num_entries)
 {
   // Should not have been allocated before
   ink_assert(array_len == -1);
 
-  re_array = (pcre**)ats_malloc(sizeof(pcre*) * num_entries);
-  memset(re_array, 0, sizeof(pcre*) * num_entries);
+  re_array = (pcre **)ats_malloc(sizeof(pcre *) * num_entries);
+  memset(re_array, 0, sizeof(pcre *) * num_entries);
 
   data_array = new Data[num_entries];
 
@@ -425,15 +430,17 @@ template<class Data, class Result> void RegexMatcher<Data, Result>::AllocateSpac
 }
 
 //
-// char* RegexMatcher<Data,Result>::NewEntry(matcher_line* line_info)
+// config_parse_error RegexMatcher<Data,Result>::NewEntry(matcher_line* line_info)
 //
-template<class Data, class Result> char *RegexMatcher<Data, Result>::NewEntry(matcher_line * line_info)
+template <class Data, class Result>
+config_parse_error
+RegexMatcher<Data, Result>::NewEntry(matcher_line *line_info)
 {
   Data *cur_d;
-  char *errBuf;
   char *pattern;
-  const char *error;
+  const char *errptr;
   int erroffset;
+  config_parse_error error = config_parse_error::ok();
 
   // Make sure space has been allocated
   ink_assert(num_el >= 0);
@@ -448,14 +455,10 @@ template<class Data, class Result> char *RegexMatcher<Data, Result>::NewEntry(ma
   ink_assert(pattern != NULL);
 
   // Create the compiled regular expression
-  re_array[num_el] = pcre_compile(pattern, 0, &error, &erroffset, NULL);
+  re_array[num_el] = pcre_compile(pattern, 0, &errptr, &erroffset, NULL);
   if (!re_array[num_el]) {
-    errBuf = (char *)ats_malloc(1024 * sizeof(char));
-    *errBuf = '\0';
-    snprintf(errBuf, 1024, "%s regular expression error at line %d position %d : %s",
-                 matcher_name, line_info->line_num, erroffset, error);
-    re_array[num_el] = NULL;
-    return errBuf;
+    return config_parse_error("%s regular expression error at line %d position %d : %s", matcher_name, line_info->line_num,
+                              erroffset, errptr);
   }
   re_str[num_el] = ats_strdup(pattern);
 
@@ -465,19 +468,19 @@ template<class Data, class Result> char *RegexMatcher<Data, Result>::NewEntry(ma
 
   // Fill in the parameter info
   cur_d = data_array + num_el;
-  errBuf = cur_d->Init(line_info);
+  error = cur_d->Init(line_info);
 
-  if (errBuf == NULL) {
-    num_el++;
-  } else {
+  if (error) {
     // There was a problem so undo the effects this function
     ats_free(re_str[num_el]);
     re_str[num_el] = NULL;
     pcre_free(re_array[num_el]);
     re_array[num_el] = NULL;
+  } else {
+    num_el++;
   }
 
-  return errBuf;
+  return error;
 }
 
 //
@@ -486,7 +489,9 @@ template<class Data, class Result> char *RegexMatcher<Data, Result>::NewEntry(ma
 //   Coduncts a linear search through the regex array and
 //     updates arg result for each regex that matches arg URL
 //
-template<class Data, class Result> void RegexMatcher<Data, Result>::Match(RequestData * rdata, Result * result)
+template <class Data, class Result>
+void
+RegexMatcher<Data, Result>::Match(RequestData *rdata, Result *result)
 {
   char *url_str;
   int r;
@@ -510,7 +515,6 @@ template<class Data, class Result> void RegexMatcher<Data, Result>::Match(Reques
   // unescapifyStr(url_str);
 
   for (int i = 0; i < num_el; i++) {
-
     r = pcre_exec(re_array[i], NULL, url_str, strlen(url_str), 0, 0, NULL, 0);
     if (r > -1) {
       Debug("matcher", "%s Matched %s with regex at line %d", matcher_name, url_str, data_array[i].line_num);
@@ -519,7 +523,6 @@ template<class Data, class Result> void RegexMatcher<Data, Result>::Match(Reques
       // An error has occured
       Warning("Error [%d] matching regex at line %d.", r, data_array[i].line_num);
     } // else it's -1 which means no match was found.
-
   }
   ats_free(url_str);
 }
@@ -527,9 +530,9 @@ template<class Data, class Result> void RegexMatcher<Data, Result>::Match(Reques
 //
 // HostRegexMatcher<Data,Result>::HostRegexMatcher()
 //
-template<class Data, class Result>
+template <class Data, class Result>
 HostRegexMatcher<Data, Result>::HostRegexMatcher(const char *name, const char *filename)
-    : RegexMatcher <Data, Result>(name, filename)
+  : RegexMatcher<Data, Result>(name, filename)
 {
 }
 
@@ -539,7 +542,9 @@ HostRegexMatcher<Data, Result>::HostRegexMatcher(const char *name, const char *f
 //   Conducts a linear search through the regex array and
 //     updates arg result for each regex that matches arg host_regex
 //
-template<class Data, class Result> void HostRegexMatcher<Data, Result>::Match(RequestData * rdata, Result * result)
+template <class Data, class Result>
+void
+HostRegexMatcher<Data, Result>::Match(RequestData *rdata, Result *result)
 {
   const char *url_str;
   int r;
@@ -560,8 +565,8 @@ template<class Data, class Result> void HostRegexMatcher<Data, Result>::Match(Re
   for (int i = 0; i < this->num_el; i++) {
     r = pcre_exec(this->re_array[i], NULL, url_str, strlen(url_str), 0, 0, NULL, 0);
     if (r != -1) {
-      Debug("matcher", "%s Matched %s with regex at line %d",
-            const_cast<char*>(this->matcher_name), url_str, this->data_array[i].line_num);
+      Debug("matcher", "%s Matched %s with regex at line %d", const_cast<char *>(this->matcher_name), url_str,
+            this->data_array[i].line_num);
       this->data_array[i].UpdateMatch(result, rdata);
     } else {
       // An error has occured
@@ -573,27 +578,26 @@ template<class Data, class Result> void HostRegexMatcher<Data, Result>::Match(Re
 //
 // IpMatcher<Data,Result>::IpMatcher()
 //
-template<class Data, class Result> IpMatcher<Data, Result>::IpMatcher(const char *name, const char *filename)
-  : data_array(NULL),
-    array_len(-1),
-    num_el(-1),
-    matcher_name(name),
-    file_name(filename)
+template <class Data, class Result>
+IpMatcher<Data, Result>::IpMatcher(const char *name, const char *filename)
+  : data_array(NULL), array_len(-1), num_el(-1), matcher_name(name), file_name(filename)
 {
 }
 
 //
 // IpMatcher<Data,Result>::~IpMatcher()
 //
-template<class Data, class Result> IpMatcher<Data, Result>::~IpMatcher()
+template <class Data, class Result> IpMatcher<Data, Result>::~IpMatcher()
 {
-  delete[]data_array;
+  delete[] data_array;
 }
 
 //
 // void IpMatcher<Data,Result>::AllocateSpace(int num_entries)
 //
-template<class Data, class Result> void IpMatcher<Data, Result>::AllocateSpace(int num_entries)
+template <class Data, class Result>
+void
+IpMatcher<Data, Result>::AllocateSpace(int num_entries)
 {
   // Should not have been allocated before
   ink_assert(array_len == -1);
@@ -605,7 +609,7 @@ template<class Data, class Result> void IpMatcher<Data, Result>::AllocateSpace(i
 }
 
 //
-// char* IpMatcher<Data,Result>::NewEntry(matcher_line* line_info)
+// config_parse_error IpMatcher<Data,Result>::NewEntry(matcher_line* line_info)
 //
 //    Inserts a range the ip lookup table.
 //        Creates new table levels as needed
@@ -614,14 +618,15 @@ template<class Data, class Result> void IpMatcher<Data, Result>::AllocateSpace(i
 //     allocated error string which the CALLEE is responsible
 //     for deallocating
 //
-template<class Data, class Result> char *IpMatcher<Data, Result>::NewEntry(matcher_line * line_info)
+template <class Data, class Result>
+config_parse_error
+IpMatcher<Data, Result>::NewEntry(matcher_line *line_info)
 {
-
   Data *cur_d;
-  const char *errPtr;
-  char *errBuf;
+  const char *errptr;
   char *match_data;
   IpEndpoint addr1, addr2;
+  config_parse_error error = config_parse_error::ok();
 
   // Make sure space has been allocated
   ink_assert(num_el >= 0);
@@ -637,12 +642,9 @@ template<class Data, class Result> char *IpMatcher<Data, Result>::NewEntry(match
   ink_assert(match_data != NULL);
 
   // Extract the IP range
-  errPtr = ExtractIpRange(match_data, &addr1.sa, &addr2.sa);
-  if (errPtr != NULL) {
-    const size_t errorSize = 1024;
-    errBuf = (char *)ats_malloc(errorSize * sizeof(char));
-    snprintf(errBuf, errorSize, "%s %s at %s line %d", matcher_name, errPtr, file_name, line_info->line_num);
-    return errBuf;
+  errptr = ExtractIpRange(match_data, &addr1.sa, &addr2.sa);
+  if (errptr != NULL) {
+    return config_parse_error("%s %s at %s line %d", matcher_name, errptr, file_name, line_info->line_num);
   }
 
   // Remove our consumed label from the parsed line
@@ -651,48 +653,45 @@ template<class Data, class Result> char *IpMatcher<Data, Result>::NewEntry(match
 
   // Fill in the parameter info
   cur_d = data_array + num_el;
-  errBuf = cur_d->Init(line_info);
-  if (errBuf != NULL) {
-    return errBuf;
+  error = cur_d->Init(line_info);
+  if (!error) {
+    ip_map.mark(&addr1.sa, &addr2.sa, cur_d);
+    ++num_el;
   }
 
-  ip_map.mark(&addr1.sa, &addr2.sa, cur_d);
-
-  ++num_el;
-  return NULL;
+  return error;
 }
 
 //
 // void IpMatcherData,Result>::Match(in_addr_t addr, RequestData* rdata, Result* result)
 //
-template<class Data, class Result>
-void IpMatcher<Data, Result>::Match(sockaddr const* addr, RequestData * rdata, Result * result)
+template <class Data, class Result>
+void
+IpMatcher<Data, Result>::Match(sockaddr const *addr, RequestData *rdata, Result *result)
 {
-  void* raw;
+  void *raw;
   if (ip_map.contains(addr, &raw)) {
-    Data *cur = static_cast<Data*>(raw);
+    Data *cur = static_cast<Data *>(raw);
     ink_assert(cur != 0);
     cur->UpdateMatch(result, rdata);
   }
 }
 
 
-template<class Data, class Result> void IpMatcher<Data, Result>::Print()
+template <class Data, class Result>
+void
+IpMatcher<Data, Result>::Print()
 {
   printf("\tIp Matcher with %d elements, %zu ranges.\n", num_el, ip_map.getCount());
-  for ( IpMap::iterator spot(ip_map.begin()), limit(ip_map.end()) ; spot != limit ; ++spot) {
+  for (IpMap::iterator spot(ip_map.begin()), limit(ip_map.end()); spot != limit; ++spot) {
     char b1[INET6_ADDRSTRLEN], b2[INET6_ADDRSTRLEN];
-    printf("\tRange %s - %s ",
-      ats_ip_ntop(spot->min(), b1, sizeof b1),
-      ats_ip_ntop(spot->max(), b2, sizeof b2)
-    );
-    static_cast<Data*>(spot->data())->Print();
+    printf("\tRange %s - %s ", ats_ip_ntop(spot->min(), b1, sizeof b1), ats_ip_ntop(spot->max(), b2, sizeof b2));
+    static_cast<Data *>(spot->data())->Print();
   }
 }
 
-template<class Data, class Result>
-ControlMatcher<Data, Result>::ControlMatcher(const char *file_var, const char *name, const matcher_tags * tags,
-                                             int flags_in)
+template <class Data, class Result>
+ControlMatcher<Data, Result>::ControlMatcher(const char *file_var, const char *name, const matcher_tags *tags, int flags_in)
 {
   flags = flags_in;
   ink_assert(flags & (ALLOW_HOST_TABLE | ALLOW_REGEX_TABLE | ALLOW_URL_TABLE | ALLOW_IP_TABLE));
@@ -704,7 +703,7 @@ ControlMatcher<Data, Result>::ControlMatcher(const char *file_var, const char *n
   config_file_path[0] = '\0';
 
   if (!(flags & DONT_BUILD_TABLE)) {
-    xptr<char> config_path(RecConfigReadConfigPath(file_var));
+    ats_scoped_str config_path(RecConfigReadConfigPath(file_var));
 
     ink_release_assert(config_path);
     ink_strlcpy(config_file_path, config_path, sizeof(config_file_path));
@@ -723,9 +722,8 @@ ControlMatcher<Data, Result>::ControlMatcher(const char *file_var, const char *n
   }
 }
 
-template<class Data, class Result> ControlMatcher<Data, Result>::~ControlMatcher()
+template <class Data, class Result> ControlMatcher<Data, Result>::~ControlMatcher()
 {
-
   delete reMatch;
   delete urlMatch;
   delete hostMatch;
@@ -737,7 +735,9 @@ template<class Data, class Result> ControlMatcher<Data, Result>::~ControlMatcher
 //
 //   Debugging method
 //
-template<class Data, class Result> void ControlMatcher<Data, Result>::Print()
+template <class Data, class Result>
+void
+ControlMatcher<Data, Result>::Print()
 {
   printf("Control Matcher Table: %s\n", matcher_name);
   if (hostMatch != NULL) {
@@ -763,7 +763,9 @@ template<class Data, class Result> void ControlMatcher<Data, Result>::Print()
 //
 //   Queries each table for the Result*
 //
-template<class Data, class Result> void ControlMatcher<Data, Result>::Match(RequestData * rdata, Result * result)
+template <class Data, class Result>
+void
+ControlMatcher<Data, Result>::Match(RequestData *rdata, Result *result)
 {
   if (hostMatch != NULL) {
     hostMatch->Match(rdata, result);
@@ -782,14 +784,14 @@ template<class Data, class Result> void ControlMatcher<Data, Result>::Match(Requ
   }
 }
 
-int fstat_wrapper(int fd, struct stat *s);
-
 // int ControlMatcher::BuildTable() {
 //
 //    Reads the cache.config file and build the records array
 //      from it
 //
-template<class Data, class Result> int ControlMatcher<Data, Result>::BuildTableFromString(char *file_buf)
+template <class Data, class Result>
+int
+ControlMatcher<Data, Result>::BuildTableFromString(char *file_buf)
 {
   // Table build locals
   Tokenizer bufTok("\n");
@@ -802,8 +804,6 @@ template<class Data, class Result> int ControlMatcher<Data, Result>::BuildTableF
   int second_pass = 0;
   int numEntries = 0;
   bool alarmAlready = false;
-  char errBuf[1024];
-  const char *errPtr = NULL;
 
   // type counts
   int hostDomain = 0;
@@ -819,7 +819,6 @@ template<class Data, class Result> int ControlMatcher<Data, Result>::BuildTableF
   // First get the number of entries
   tmp = bufTok.iterFirst(&i_state);
   while (tmp != NULL) {
-
     line_num++;
 
     // skip all blank spaces at beginning of line
@@ -828,19 +827,18 @@ template<class Data, class Result> int ControlMatcher<Data, Result>::BuildTableF
     }
 
     if (*tmp != '#' && *tmp != '\0') {
+      const char *errptr;
 
       current = (matcher_line *)ats_malloc(sizeof(matcher_line));
-      errPtr = parseConfigLine((char *) tmp, current, config_tags);
+      errptr = parseConfigLine((char *)tmp, current, config_tags);
 
-      if (errPtr != NULL) {
+      if (errptr != NULL) {
         if (config_tags != &socks_server_tags) {
-          snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry at line %d : %s",
-                   matcher_name, config_file_path, line_num, errPtr);
-          SignalError(errBuf, alarmAlready);
+          config_parse_error error("%s discarding %s entry at line %d : %s", matcher_name, config_file_path, line_num, errptr);
+          SignalError(error.get(), alarmAlready);
         }
         ats_free(current);
       } else {
-
         // Line parsed ok.  Figure out what the destination
         //  type is and link it into our list
         numEntries++;
@@ -887,59 +885,58 @@ template<class Data, class Result> int ControlMatcher<Data, Result>::BuildTableF
   }
   // Now allocate space for the record pointers
   if ((flags & ALLOW_REGEX_TABLE) && regex > 0) {
-    reMatch = new RegexMatcher<Data, Result> (matcher_name, config_file_path);
+    reMatch = new RegexMatcher<Data, Result>(matcher_name, config_file_path);
     reMatch->AllocateSpace(regex);
   }
 
   if ((flags & ALLOW_URL_TABLE) && url > 0) {
-    urlMatch = new UrlMatcher<Data, Result> (matcher_name, config_file_path);
+    urlMatch = new UrlMatcher<Data, Result>(matcher_name, config_file_path);
     urlMatch->AllocateSpace(url);
   }
 
   if ((flags & ALLOW_HOST_TABLE) && hostDomain > 0) {
-    hostMatch = new HostMatcher<Data, Result> (matcher_name, config_file_path);
+    hostMatch = new HostMatcher<Data, Result>(matcher_name, config_file_path);
     hostMatch->AllocateSpace(hostDomain);
   }
 
   if ((flags & ALLOW_IP_TABLE) && ip > 0) {
-    ipMatch = new IpMatcher<Data, Result> (matcher_name, config_file_path);
+    ipMatch = new IpMatcher<Data, Result>(matcher_name, config_file_path);
     ipMatch->AllocateSpace(ip);
   }
 
   if ((flags & ALLOW_HOST_REGEX_TABLE) && hostregex > 0) {
-    hrMatch = new HostRegexMatcher<Data, Result> (matcher_name, config_file_path);
+    hrMatch = new HostRegexMatcher<Data, Result>(matcher_name, config_file_path);
     hrMatch->AllocateSpace(hostregex);
   }
   // Traverse the list and build the records table
   current = first;
   while (current != NULL) {
+    config_parse_error error = config_parse_error::ok();
+
     second_pass++;
     if ((flags & ALLOW_HOST_TABLE) && current->type == MATCH_DOMAIN) {
-      errPtr = hostMatch->NewEntry(current);
+      error = hostMatch->NewEntry(current);
     } else if ((flags & ALLOW_HOST_TABLE) && current->type == MATCH_HOST) {
-      errPtr = hostMatch->NewEntry(current);
+      error = hostMatch->NewEntry(current);
     } else if ((flags & ALLOW_REGEX_TABLE) && current->type == MATCH_REGEX) {
-      errPtr = reMatch->NewEntry(current);
+      error = reMatch->NewEntry(current);
     } else if ((flags & ALLOW_URL_TABLE) && current->type == MATCH_URL) {
-      errPtr = urlMatch->NewEntry(current);
+      error = urlMatch->NewEntry(current);
     } else if ((flags & ALLOW_IP_TABLE) && current->type == MATCH_IP) {
-      errPtr = ipMatch->NewEntry(current);
+      error = ipMatch->NewEntry(current);
     } else if ((flags & ALLOW_HOST_REGEX_TABLE) && current->type == MATCH_HOST_REGEX) {
-      errPtr = hrMatch->NewEntry(current);
+      error = hrMatch->NewEntry(current);
     } else {
-      errPtr = NULL;
-      snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry with unknown type at line %d",
-               matcher_name, config_file_path, current->line_num);
-      SignalError(errBuf, alarmAlready);
+      error = config_parse_error("%s discarding %s entry with unknown type at line %d", matcher_name, config_file_path,
+                                 current->line_num);
     }
 
     // Check to see if there was an error in creating
     //   the NewEntry
-    if (errPtr != NULL) {
-      SignalError(errPtr, alarmAlready);
-      //ats_free(errPtr); // XXX - why are we trying to free
-      errPtr = NULL;
+    if (error) {
+      SignalError(error.get(), alarmAlready);
     }
+
     // Deallocate the parsing structure
     last = current;
     current = current->next;
@@ -954,7 +951,9 @@ template<class Data, class Result> int ControlMatcher<Data, Result>::BuildTableF
   return numEntries;
 }
 
-template<class Data, class Result> int ControlMatcher<Data, Result>::BuildTable()
+template <class Data, class Result>
+int
+ControlMatcher<Data, Result>::BuildTable()
 {
   // File I/O Locals
   char *file_buf;
