@@ -27,32 +27,23 @@
 #include "HTTP.h"
 #include "PluginVC.h"
 
-static const char *http_method[] = {
-  "NONE",
-  "GET",
-  "POST",
-  "CONNECT",
-  "DELETE",
-  "HEAD",
-  "PURGE",
-  "PUT",
-  "OPTIONS",
-  "TRACE",
-  "LAST",
-};
-
 #define DEBUG_TAG "FetchSM"
 #define FETCH_LOCK_RETRY_TIME HRTIME_MSECONDS(10)
 
-ClassAllocator < FetchSM > FetchSMAllocator("FetchSMAllocator");
+ClassAllocator<FetchSM> FetchSMAllocator("FetchSMAllocator");
 void
 FetchSM::cleanUp()
 {
   Debug(DEBUG_TAG, "[%s] calling cleanup", __FUNCTION__);
 
+  if (!ink_atomic_cas(&destroyed, false, true)) {
+    Debug(DEBUG_TAG, "Error: Double delete on FetchSM, this:%p", this);
+    return;
+  }
+
   if (resp_is_chunked > 0 && (fetch_flags & TS_FETCH_FLAGS_DECHUNK)) {
     chunked_handler.clear();
-   }
+  }
 
   free_MIOBuffer(req_buffer);
   free_MIOBuffer(resp_buffer);
@@ -68,18 +59,32 @@ FetchSM::cleanUp()
 void
 FetchSM::httpConnect()
 {
-  PluginIdentity* pi = dynamic_cast<PluginIdentity*>(contp);
-  char const* tag = pi ? pi->getPluginTag() : "fetchSM";
+  PluginIdentity *pi = dynamic_cast<PluginIdentity *>(contp);
+  char const *tag = pi ? pi->getPluginTag() : "fetchSM";
   int64_t id = pi ? pi->getPluginId() : 0;
 
   Debug(DEBUG_TAG, "[%s] calling httpconnect write", __FUNCTION__);
-  http_vc = reinterpret_cast<PluginVC*>(TSHttpConnectWithPluginId(&_addr.sa, tag, id));
+  http_vc = reinterpret_cast<PluginVC *>(TSHttpConnectWithPluginId(&_addr.sa, tag, id));
+
+  /*
+   * TS-2906: We need a way to unset internal request when using FetchSM, the use case for this
+   * is SPDY when it creates outgoing requests it uses FetchSM and the outgoing requests
+   * are spawned via SPDY SYN packets which are definitely not internal requests.
+   */
+  if (!is_internal_request) {
+    PluginVC *other_side = reinterpret_cast<PluginVC *>(http_vc)->get_other_side();
+    if (other_side != NULL) {
+      other_side->set_is_internal_request(false);
+    }
+  }
 
   read_vio = http_vc->do_io_read(this, INT64_MAX, resp_buffer);
   write_vio = http_vc->do_io_write(this, getReqLen() + req_content_length, req_reader);
 }
 
-char* FetchSM::resp_get(int *length) {
+char *
+FetchSM::resp_get(int *length)
+{
   *length = client_bytes;
   return client_response;
 }
@@ -89,11 +94,11 @@ FetchSM::InvokePlugin(int event, void *data)
 {
   EThread *mythread = this_ethread();
 
-  MUTEX_TAKE_LOCK(contp->mutex,mythread);
+  MUTEX_TAKE_LOCK(contp->mutex, mythread);
 
-  int ret = contp->handleEvent(event,data);
+  int ret = contp->handleEvent(event, data);
 
-  MUTEX_UNTAKE_LOCK(contp->mutex,mythread);
+  MUTEX_UNTAKE_LOCK(contp->mutex, mythread);
 
   return ret;
 }
@@ -107,14 +112,13 @@ FetchSM::has_body()
   if (!header_done)
     return false;
 
+  if (is_method_head)
+    return false;
   //
   // The following code comply with HTTP/1.1:
   // http://www.w3.org/Protocols/rfc2616/rfc2616-sec4.html#sec4.4
   //
 
-  if (req_method == TS_FETCH_METHOD_HEAD)
-    return false;
-
   hdr = &client_response_hdr;
 
   status_code = hdr->status_get();
@@ -124,6 +128,9 @@ FetchSM::has_body()
   if (check_chunked())
     return true;
 
+  if (check_connection_close())
+    return true;
+
   resp_content_length = hdr->value_get_int64(MIME_FIELD_CONTENT_LENGTH, MIME_LEN_CONTENT_LENGTH);
   if (!resp_content_length)
     return false;
@@ -135,7 +142,7 @@ bool
 FetchSM::check_body_done()
 {
   if (!check_chunked()) {
-    if (resp_content_length == resp_recived_body_len + resp_reader->read_avail())
+    if (resp_content_length == resp_received_body_len + resp_reader->read_avail())
       return true;
 
     return false;
@@ -148,42 +155,60 @@ FetchSM::check_body_done()
 }
 
 bool
-FetchSM::check_chunked()
+FetchSM::check_for_field_value(char const *name, size_t name_len, char const *value, size_t value_len)
 {
-  int ret;
+  bool zret = false; // not found.
   StrList slist;
   HTTPHdr *hdr = &client_response_hdr;
-
-  if (resp_is_chunked >= 0)
-    return resp_is_chunked;
+  int ret = hdr->value_get_comma_list(name, name_len, &slist);
 
   ink_release_assert(header_done);
 
-  resp_is_chunked = 0;
-  ret = hdr->value_get_comma_list(MIME_FIELD_TRANSFER_ENCODING,
-                                  MIME_LEN_TRANSFER_ENCODING, &slist);
   if (ret) {
     for (Str *f = slist.head; f != NULL; f = f->next) {
-      if (f->len == 0)
-        continue;
-
-      size_t len = sizeof("chunked") - 1;
-      len = len > f->len ? f->len : len;
-      if (!strncasecmp(f->str, "chunked", len)) {
-        resp_is_chunked = 1;
-        if (fetch_flags & TS_FETCH_FLAGS_DECHUNK) {
-          ChunkedHandler *ch = &chunked_handler;
-          ch->init_by_action(resp_reader, ChunkedHandler::ACTION_DECHUNK);
-          ch->dechunked_reader = ch->dechunked_buffer->alloc_reader();
-          ch->state = ChunkedHandler::CHUNK_READ_SIZE;
-          resp_reader->dealloc();
-        }
-        return true;
+      if (f->len == value_len && 0 == strncasecmp(f->str, value, value_len)) {
+        Debug(DEBUG_TAG, "[%s] field '%.*s', value '%.*s'", __FUNCTION__, static_cast<int>(name_len), name,
+              static_cast<int>(value_len), value);
+        zret = true;
+        break;
       }
     }
   }
+  return zret;
+}
 
-  return resp_is_chunked;
+bool
+FetchSM::check_chunked()
+{
+  static char const CHUNKED_TEXT[] = "chunked";
+  static size_t const CHUNKED_LEN = sizeof(CHUNKED_TEXT) - 1;
+
+  if (resp_is_chunked < 0) {
+    resp_is_chunked = static_cast<int>(
+      this->check_for_field_value(MIME_FIELD_TRANSFER_ENCODING, MIME_LEN_TRANSFER_ENCODING, CHUNKED_TEXT, CHUNKED_LEN));
+
+    if (resp_is_chunked && (fetch_flags & TS_FETCH_FLAGS_DECHUNK)) {
+      ChunkedHandler *ch = &chunked_handler;
+      ch->init_by_action(resp_reader, ChunkedHandler::ACTION_DECHUNK);
+      ch->dechunked_reader = ch->dechunked_buffer->alloc_reader();
+      ch->state = ChunkedHandler::CHUNK_READ_SIZE;
+      resp_reader->dealloc();
+    }
+  }
+  return resp_is_chunked > 0;
+}
+
+bool
+FetchSM::check_connection_close()
+{
+  static char const CLOSE_TEXT[] = "close";
+  static size_t const CLOSE_LEN = sizeof(CLOSE_TEXT) - 1;
+
+  if (resp_received_close < 0) {
+    resp_received_close =
+      static_cast<int>(this->check_for_field_value(MIME_FIELD_CONNECTION, MIME_LEN_CONNECTION, CLOSE_TEXT, CLOSE_LEN));
+  }
+  return resp_received_close > 0;
 }
 
 int
@@ -206,10 +231,11 @@ FetchSM::dechunk_body()
 }
 
 void
-FetchSM::InvokePluginExt(int error_event)
+FetchSM::InvokePluginExt(int fetch_event)
 {
   int event;
   EThread *mythread = this_ethread();
+  bool read_complete_event = (fetch_event == TS_EVENT_VCONN_READ_COMPLETE) || (fetch_event == TS_EVENT_VCONN_EOS);
 
   //
   // Increasing *recursion* to prevent
@@ -224,38 +250,60 @@ FetchSM::InvokePluginExt(int error_event)
   if (!contp)
     goto out;
 
-  if (error_event) {
-    contp->handleEvent(error_event, this);
+  if (fetch_event && !read_complete_event) {
+    contp->handleEvent(fetch_event, this);
     goto out;
   }
 
   if (!has_sent_header) {
-    contp->handleEvent(TS_FETCH_EVENT_EXT_HEAD_DONE, this);
-    has_sent_header = true;
+    if (fetch_event != TS_EVENT_VCONN_EOS) {
+      contp->handleEvent(TS_FETCH_EVENT_EXT_HEAD_DONE, this);
+      has_sent_header = true;
+    } else {
+      contp->handleEvent(fetch_event, this);
+      goto out;
+    }
   }
 
+  // TS-3112: always check 'contp' after handleEvent()
+  // since handleEvent effectively calls the plugin (or SPDY layer)
+  // which may call TSFetchDestroy in error conditions.
+  // TSFetchDestroy sets contp to NULL, but, doesn't destroy FetchSM yet,
+  // since, it¹s in a tight loop protected by 'recursion' counter.
+  // When handleEvent returns, 'recursion' is decremented and contp is
+  // already null, so, FetchSM gets destroyed.
+  if (!contp)
+    goto out;
+
   if (!has_body()) {
     contp->handleEvent(TS_FETCH_EVENT_EXT_BODY_DONE, this);
     goto out;
   }
 
-  Debug(DEBUG_TAG, "[%s] chunked:%d, content_len: %" PRId64 ", recived_len: %" PRId64 ", avail: %" PRId64 "\n",
-        __FUNCTION__, resp_is_chunked, resp_content_length, resp_recived_body_len,
+  Debug(DEBUG_TAG, "[%s] chunked:%d, content_len: %" PRId64 ", received_len: %" PRId64 ", avail: %" PRId64 "\n", __FUNCTION__,
+        resp_is_chunked, resp_content_length, resp_received_body_len,
         resp_is_chunked > 0 ? chunked_handler.chunked_reader->read_avail() : resp_reader->read_avail());
 
   if (resp_is_chunked > 0) {
-    if (!chunked_handler.chunked_reader->read_avail())
+    if (!chunked_handler.chunked_reader->read_avail()) {
+      if (read_complete_event) {
+        contp->handleEvent(TS_FETCH_EVENT_EXT_BODY_DONE, this);
+      }
       goto out;
+    }
   } else if (!resp_reader->read_avail()) {
-      goto out;
+    if (read_complete_event) {
+      contp->handleEvent(TS_FETCH_EVENT_EXT_BODY_DONE, this);
+    }
+    goto out;
   }
 
   if (!check_chunked()) {
-    if (!check_body_done())
+    if (!check_body_done() && !read_complete_event)
       contp->handleEvent(TS_FETCH_EVENT_EXT_BODY_READY, this);
     else
       contp->handleEvent(TS_FETCH_EVENT_EXT_BODY_DONE, this);
-  } else if (fetch_flags & TS_FETCH_FLAGS_DECHUNK){
+  } else if (fetch_flags & TS_FETCH_FLAGS_DECHUNK) {
     do {
       if (chunked_handler.state == ChunkedHandler::CHUNK_FLOW_CONTROL) {
         chunked_handler.state = ChunkedHandler::CHUNK_READ_SIZE_START;
@@ -268,8 +316,13 @@ FetchSM::InvokePluginExt(int error_event)
       }
 
       contp->handleEvent(event, this);
+
+      // contp may be null after handleEvent
+      if (!contp)
+        goto out;
+
     } while (chunked_handler.state == ChunkedHandler::CHUNK_FLOW_CONTROL);
-  } else if (check_body_done()){
+  } else if (check_body_done()) {
     contp->handleEvent(TS_FETCH_EVENT_EXT_BODY_DONE, this);
   } else {
     contp->handleEvent(TS_FETCH_EVENT_EXT_BODY_READY, this);
@@ -297,20 +350,21 @@ FetchSM::get_info_from_buffer(IOBufferReader *the_reader)
 
   if (!reader) {
     client_bytes = 0;
-    return ;
+    return;
   }
 
   read_avail = reader->read_avail();
-  Debug(DEBUG_TAG, "[%s] total avail %" PRId64 , __FUNCTION__, read_avail);
+  Debug(DEBUG_TAG, "[%s] total avail %" PRId64, __FUNCTION__, read_avail);
   if (!read_avail) {
     client_bytes = 0;
     return;
   }
 
-  info = (char *)ats_malloc(sizeof(char) * (read_avail+1));
+  info = (char *)ats_malloc(sizeof(char) * (read_avail + 1));
   client_response = info;
 
-  if (!check_chunked()) {
+  // To maintain backwards compatability we don't allow chunking when it's not streaming.
+  if (!(fetch_flags & TS_FETCH_FLAGS_STREAM) || !check_chunked()) {
     /* Read the data out of the reader */
     while (read_avail > 0) {
       if (reader->block != NULL)
@@ -373,34 +427,49 @@ FetchSM::process_fetch_read(int event)
   Debug(DEBUG_TAG, "[%s] I am here read", __FUNCTION__);
   int64_t bytes;
   int bytes_used;
+  int64_t total_bytes_copied = 0;
 
   switch (event) {
   case TS_EVENT_VCONN_READ_READY:
-    bytes = resp_reader->read_avail();
-    Debug(DEBUG_TAG, "[%s] number of bytes in read ready %" PRId64, __FUNCTION__, bytes);
+    // duplicate the bytes for backward compatibility with TSFetchUrl()
+    if (!(fetch_flags & TS_FETCH_FLAGS_STREAM)) {
+      bytes = resp_reader->read_avail();
+      Debug(DEBUG_TAG, "[%s] number of bytes in read ready %" PRId64, __FUNCTION__, bytes);
+
+      while (total_bytes_copied < bytes) {
+        int64_t actual_bytes_copied;
+        actual_bytes_copied = resp_buffer->write(resp_reader, bytes, 0);
+        Debug(DEBUG_TAG, "[%s] copied %" PRId64 " bytes", __FUNCTION__, actual_bytes_copied);
+        if (actual_bytes_copied <= 0) {
+          break;
+        }
+        total_bytes_copied += actual_bytes_copied;
+      }
+      Debug(DEBUG_TAG, "[%s] total copied %" PRId64 " bytes", __FUNCTION__, total_bytes_copied);
+      resp_reader->consume(total_bytes_copied);
+    }
+
     if (header_done == 0 && ((fetch_flags & TS_FETCH_FLAGS_STREAM) || callback_options == AFTER_HEADER)) {
       if (client_response_hdr.parse_resp(&http_parser, resp_reader, &bytes_used, 0) == PARSE_DONE) {
         header_done = 1;
         if (fetch_flags & TS_FETCH_FLAGS_STREAM)
           return InvokePluginExt();
         else
-          InvokePlugin( callback_events.success_event_id, (void *) &client_response_hdr);
+          InvokePlugin(callback_events.success_event_id, (void *)&client_response_hdr);
       }
     } else {
       if (fetch_flags & TS_FETCH_FLAGS_STREAM)
         return InvokePluginExt();
-      else
-        InvokePlugin(TS_FETCH_EVENT_EXT_BODY_READY, this);
     }
     read_vio->reenable();
     break;
   case TS_EVENT_VCONN_READ_COMPLETE:
   case TS_EVENT_VCONN_EOS:
     if (fetch_flags & TS_FETCH_FLAGS_STREAM)
-      return InvokePluginExt();
-    if(callback_options == AFTER_HEADER || callback_options == AFTER_BODY) {
+      return InvokePluginExt(event);
+    if (callback_options == AFTER_HEADER || callback_options == AFTER_BODY) {
       get_info_from_buffer(resp_reader);
-      InvokePlugin( callback_events.success_event_id, (void *) this);
+      InvokePlugin(callback_events.success_event_id, (void *)this);
     }
     Debug(DEBUG_TAG, "[%s] received EOS", __FUNCTION__);
     cleanUp();
@@ -409,7 +478,7 @@ FetchSM::process_fetch_read(int event)
   default:
     if (fetch_flags & TS_FETCH_FLAGS_STREAM)
       return InvokePluginExt(event);
-    InvokePlugin( callback_events.failure_event_id, NULL);
+    InvokePlugin(callback_events.failure_event_id, NULL);
     cleanUp();
     break;
   }
@@ -428,12 +497,12 @@ FetchSM::process_fetch_write(int event)
     // of input data, we have to continue reenabling until all data is
     // read (we have already written all the data to the buffer)
     if (req_reader->read_avail() > 0)
-      ((PluginVC *) http_vc)->reenable(write_vio);
+      ((PluginVC *)http_vc)->reenable(write_vio);
     break;
   case TS_EVENT_ERROR:
     if (fetch_flags & TS_FETCH_FLAGS_STREAM)
       return InvokePluginExt(event);
-    InvokePlugin( callback_events.failure_event_id, NULL);
+    InvokePlugin(callback_events.failure_event_id, NULL);
     cleanUp();
   default:
     break;
@@ -454,16 +523,15 @@ FetchSM::fetch_handler(int event, void *edata)
       InvokePluginExt(event);
       return 1;
     }
-    InvokePlugin( callback_events.failure_event_id, NULL);
+    InvokePlugin(callback_events.failure_event_id, NULL);
     cleanUp();
   }
   return 1;
 }
 
 void
-FetchSM::ext_init(Continuation *cont, TSFetchMethod method,
-                  const char *url, const char *version,
-                  const sockaddr *client_addr, int flags)
+FetchSM::ext_init(Continuation *cont, const char *method, const char *url, const char *version, const sockaddr *client_addr,
+                  int flags)
 {
   init_comm();
 
@@ -481,6 +549,9 @@ FetchSM::ext_init(Continuation *cont, TSFetchMethod method,
   // Enable stream IO automatically.
   //
   fetch_flags = (TS_FETCH_FLAGS_STREAM | flags);
+  if (fetch_flags & TS_FETCH_FLAGS_NOT_INTERNAL_REQUEST) {
+    set_internal_request(false);
+  }
 
   //
   // These options are not used when enable
@@ -489,21 +560,23 @@ FetchSM::ext_init(Continuation *cont, TSFetchMethod method,
   memset(&callback_options, 0, sizeof(callback_options));
   memset(&callback_events, 0, sizeof(callback_events));
 
-  req_method = method;
-  req_buffer->write(http_method[method], strlen(http_method[method]));
+  int method_len = strlen(method);
+  req_buffer->write(method, method_len);
   req_buffer->write(" ", 1);
   req_buffer->write(url, strlen(url));
   req_buffer->write(" ", 1);
   req_buffer->write(version, strlen(version));
   req_buffer->write("\r\n", 2);
+
+  if ((method_len == HTTP_LEN_HEAD) && !memcmp(method, HTTP_METHOD_HEAD, HTTP_LEN_HEAD)) {
+    is_method_head = true;
+  }
 }
 
 void
-FetchSM::ext_add_header(const char *name, int name_len,
-                        const char *value, int value_len)
+FetchSM::ext_add_header(const char *name, int name_len, const char *value, int value_len)
 {
-  if (TS_MIME_LEN_CONTENT_LENGTH == name_len &&
-      !strncasecmp(TS_MIME_FIELD_CONTENT_LENGTH, name, name_len)) {
+  if (TS_MIME_LEN_CONTENT_LENGTH == name_len && !strncasecmp(TS_MIME_FIELD_CONTENT_LENGTH, name, name_len)) {
     req_content_length = atoll(value);
   }
 
@@ -514,7 +587,7 @@ FetchSM::ext_add_header(const char *name, int name_len,
 }
 
 void
-FetchSM::ext_lanuch()
+FetchSM::ext_launch()
 {
   req_buffer->write("\r\n", 2);
   httpConnect();
@@ -523,27 +596,15 @@ FetchSM::ext_lanuch()
 void
 FetchSM::ext_write_data(const void *data, size_t len)
 {
-  bool writeReady = (header_done ||
-		    (req_method == TS_FETCH_METHOD_POST) ||
-		    (req_method == TS_FETCH_METHOD_PUT));
-
-  if (writeReady && (fetch_flags & TS_FETCH_FLAGS_NEWLOCK)) {
+  if (fetch_flags & TS_FETCH_FLAGS_NEWLOCK) {
     MUTEX_TAKE_LOCK(mutex, this_ethread());
   }
-
   req_buffer->write(data, len);
 
-  //
-  // Before header_done, FetchSM may not
-  // be initialized.
-  //
-  if (writeReady) {
-    Debug(DEBUG_TAG, "[%s] re-enabling write_vio, header_done %u, req_method %u", __FUNCTION__, header_done, req_method);
-    write_vio->reenable();
-    fetch_handler(TS_EVENT_VCONN_WRITE_READY, write_vio);
-  }
+  Debug(DEBUG_TAG, "[%s] re-enabling write_vio, header_done %u", __FUNCTION__, header_done);
+  write_vio->reenable();
 
-  if (writeReady && (fetch_flags & TS_FETCH_FLAGS_NEWLOCK)) {
+  if (fetch_flags & TS_FETCH_FLAGS_NEWLOCK) {
     MUTEX_UNTAKE_LOCK(mutex, this_ethread());
   }
 }
@@ -558,7 +619,7 @@ FetchSM::ext_read_data(char *buf, size_t len)
 
   if (fetch_flags & TS_FETCH_FLAGS_NEWLOCK) {
     MUTEX_TRY_LOCK(lock, mutex, this_ethread());
-    if (!lock)
+    if (!lock.is_locked())
       return 0;
   }
 
@@ -566,7 +627,7 @@ FetchSM::ext_read_data(char *buf, size_t len)
     return 0;
 
   if (check_chunked() && (fetch_flags & TS_FETCH_FLAGS_DECHUNK))
-    reader = (tsapi_bufferreader*)chunked_handler.dechunked_reader;
+    reader = (tsapi_bufferreader *)chunked_handler.dechunked_reader;
   else
     reader = (TSIOBufferReader)resp_reader;
 
@@ -574,7 +635,6 @@ FetchSM::ext_read_data(char *buf, size_t len)
   blk = TSIOBufferReaderStart(reader);
 
   while (blk) {
-
     wavail = len - already;
 
     next_blk = TSIOBufferBlockNext(blk);
@@ -591,7 +651,7 @@ FetchSM::ext_read_data(char *buf, size_t len)
     blk = next_blk;
   }
 
-  resp_recived_body_len += already;
+  resp_received_body_len += already;
   TSIOBufferReaderConsume(reader, already);
 
   read_vio->reenable();
@@ -608,7 +668,7 @@ FetchSM::ext_destroy()
 
   if (fetch_flags & TS_FETCH_FLAGS_NEWLOCK) {
     MUTEX_TRY_LOCK(lock, mutex, this_ethread());
-    if (!lock) {
+    if (!lock.is_locked()) {
       eventProcessor.schedule_in(this, FETCH_LOCK_RETRY_TIME);
       return;
     }
@@ -623,7 +683,7 @@ FetchSM::ext_set_user_data(void *data)
   user_data = data;
 }
 
-void*
+void *
 FetchSM::ext_get_user_data()
 {
   return user_data;
