@@ -34,7 +34,7 @@
 
 #include "P_Net.h"
 #include "P_Cache.h"
-#define  ET_ICP ET_CALL
+#define ET_ICP ET_CALL
 #include "URL.h"
 #include "ICPevents.h"
 #include "ICPProcessor.h"
@@ -44,7 +44,7 @@
 //*********************************************************************
 // ICP Configurables
 //*********************************************************************
-#define ICP_DEBUG	1
+#define ICP_DEBUG 1
 
 
 //*********************************************************************
@@ -53,8 +53,7 @@
 // Message protocol definitions as defined by RFC 2186
 // "Internet Cache Protocol (ICP), version 2".
 //*********************************************************************
-typedef struct ICPMsgHeader
-{
+typedef struct ICPMsgHeader {
   uint8_t opcode;
   uint8_t version;
   uint16_t msglen;
@@ -67,116 +66,108 @@ typedef struct ICPMsgHeader
 //-----------------------
 // opcode definitions
 //-----------------------
-typedef enum
-{
-  ICP_OP_INVALID,               // 00
-  ICP_OP_QUERY,                 // 01
-  ICP_OP_HIT,                   // 02
-  ICP_OP_MISS,                  // 03
-  ICP_OP_ERR,                   // 04
+typedef enum {
+  ICP_OP_INVALID, // 00
+  ICP_OP_QUERY,   // 01
+  ICP_OP_HIT,     // 02
+  ICP_OP_MISS,    // 03
+  ICP_OP_ERR,     // 04
   //
-  ICP_OP_UNUSED5,               // 05 unused
-  ICP_OP_UNUSED6,               // 06 unused
-  ICP_OP_UNUSED7,               // 07 unused
-  ICP_OP_UNUSED8,               // 08 unused
-  ICP_OP_UNUSED9,               // 09 unused
+  ICP_OP_UNUSED5, // 05 unused
+  ICP_OP_UNUSED6, // 06 unused
+  ICP_OP_UNUSED7, // 07 unused
+  ICP_OP_UNUSED8, // 08 unused
+  ICP_OP_UNUSED9, // 09 unused
   //
-  ICP_OP_SECHO,                 // 10
-  ICP_OP_DECHO,                 // 11
+  ICP_OP_SECHO, // 10
+  ICP_OP_DECHO, // 11
   //
-  ICP_OP_UNUSED12,              // 12 unused
-  ICP_OP_UNUSED13,              // 13 unused
-  ICP_OP_UNUSED14,              // 14 unused
-  ICP_OP_UNUSED15,              // 15 unused
-  ICP_OP_UNUSED16,              // 16 unused
-  ICP_OP_UNUSED17,              // 17 unused
-  ICP_OP_UNUSED18,              // 18 unused
-  ICP_OP_UNUSED19,              // 19 unused
-  ICP_OP_UNUSED20,              // 20 unused
+  ICP_OP_UNUSED12, // 12 unused
+  ICP_OP_UNUSED13, // 13 unused
+  ICP_OP_UNUSED14, // 14 unused
+  ICP_OP_UNUSED15, // 15 unused
+  ICP_OP_UNUSED16, // 16 unused
+  ICP_OP_UNUSED17, // 17 unused
+  ICP_OP_UNUSED18, // 18 unused
+  ICP_OP_UNUSED19, // 19 unused
+  ICP_OP_UNUSED20, // 20 unused
   //
-  ICP_OP_MISS_NOFETCH,          // 21
-  ICP_OP_DENIED,                // 22
-  ICP_OP_HIT_OBJ,               // 23
-  ICP_OP_END_OF_OPS             // 24 mark end of opcodes
+  ICP_OP_MISS_NOFETCH, // 21
+  ICP_OP_DENIED,       // 22
+  ICP_OP_HIT_OBJ,      // 23
+  ICP_OP_END_OF_OPS    // 24 mark end of opcodes
 } ICPopcode_t;
 
-#define ICP_OP_LAST		(ICP_OP_END_OF_OPS - 1)
+#define ICP_OP_LAST (ICP_OP_END_OF_OPS - 1)
 
 //-----------------------
 // version definitions
 //-----------------------
-#define ICP_VERSION_1		1
-#define ICP_VERSION_2		2
-#define ICP_VERSION_3		3
-#define ICP_VERSION		ICP_VERSION_2
+#define ICP_VERSION_1 1
+#define ICP_VERSION_2 2
+#define ICP_VERSION_3 3
+#define ICP_VERSION ICP_VERSION_2
 
 //--------------------------
 // optionflags definitions
 //--------------------------
-#define ICP_FLAG_HIT_OBJ 	0x80000000ul
-#define ICP_FLAG_SRC_RTT 	0x40000000ul
+#define ICP_FLAG_HIT_OBJ 0x80000000ul
+#define ICP_FLAG_SRC_RTT 0x40000000ul
 
 //-----------------
 // ICP Constants
 //-----------------
-#define MAX_ICP_MSGSIZE		   (16 * 1024)
-#define MAX_ICP_MSG_PAYLOAD_SIZE   (MAX_ICP_MSGSIZE - sizeof(ICPmsgHdr_t))
+#define MAX_ICP_MSGSIZE (16 * 1024)
+#define MAX_ICP_MSG_PAYLOAD_SIZE (MAX_ICP_MSGSIZE - sizeof(ICPmsgHdr_t))
 #define MAX_ICP_QUERY_PAYLOAD_SIZE (MAX_ICP_MSG_PAYLOAD_SIZE - sizeof(uint32_t))
-#define MAX_DEFINED_PEERS	   64
+#define MAX_DEFINED_PEERS 64
 #define MSG_IOVECS 16
 
 //------------
 // ICP Data
 //------------
-typedef struct ICPData
-{
-  char *URL;                    // null terminated
+typedef struct ICPData {
+  char *URL; // null terminated
 } ICPData_t;
 
 //-------------
 // ICP Query
 //-------------
-typedef struct ICPQuery
-{
+typedef struct ICPQuery {
   uint32_t rhostid;
-  char *URL;                    // null terminated (outgoing)
+  char *URL; // null terminated (outgoing)
 } ICPQuery_t;
 
 //------------
 // ICP Hit
 //------------
-typedef struct ICPHit
-{
-  char *URL;                    // null terminated
+typedef struct ICPHit {
+  char *URL; // null terminated
 } ICPHit_t;
 
 //------------
 // ICP Miss
 //------------
-typedef struct ICPMiss
-{
-  char *URL;                    // null terminated
+typedef struct ICPMiss {
+  char *URL; // null terminated
 } ICPMiss_t;
 
 //------------------
 // ICP Hit Object
 //------------------
-typedef struct ICPHitObj
-{
-  char *URL;                    // null terminated
-  char *p_objsize;              // byte aligned uint16_t immediately follows URL null
-  uint16_t objsize;               // decoded object size
-  char *data;                   // object data
+typedef struct ICPHitObj {
+  char *URL;        // null terminated
+  char *p_objsize;  // byte aligned uint16_t immediately follows URL null
+  uint16_t objsize; // decoded object size
+  char *data;       // object data
 } ICPHitObj_t;
 
 //------------------------
 // ICP message descriptor
 //------------------------
-typedef struct ICPMsg
-{
+typedef struct ICPMsg {
   ICPMsgHdr_t h;
-  union
-  {
+  union {
     ICPData_t data;
     ICPQuery_t query;
     ICPHit_t hit;
@@ -196,13 +187,12 @@ class ICPHandlerCont;
 class ICPPeerReadCont;
 class ICPRequestCont;
 
-typedef enum
-{
+typedef enum {
   PEER_NONE = 0,
   PEER_PARENT = 1,
   PEER_SIBLING = 2,
   PEER_LOCAL = 3,
-  PEER_MULTICAST = 4
+  PEER_MULTICAST = 4,
 } PeerType_t;
 
 #if !defined(USE_CAS_FOR_ATOMICLOCK)
@@ -216,10 +206,10 @@ public:
   void Unlock();
 
 private:
-    Ptr<ProxyMutex> _mutex;
+  Ptr<ProxyMutex> _mutex;
 };
 
-#else // USE_CAS_FOR_ATOMICLOCK
+#else  // USE_CAS_FOR_ATOMICLOCK
 class AtomicLock
 {
 public:
@@ -230,8 +220,10 @@ public:
   void Unlock();
 
 private:
-  enum
-  { UNLOCKED = 0, LOCKED = 1 };
+  enum {
+    UNLOCKED = 0,
+    LOCKED = 1,
+  };
   int32_t _lock_word;
 };
 #endif // USE_CAS_FOR_ATOMICLOCK
@@ -244,48 +236,55 @@ class ICPConfigData
   friend class ICPConfiguration;
 
 public:
-    ICPConfigData():_icp_enabled(0), _icp_port(0), _icp_interface(0),
-    _multicast_enabled(0), _icp_query_timeout(0), _cache_lookup_local(0),
-    _stale_lookup(0), _reply_to_unknown_peer(0), _default_reply_port(0)
+  ICPConfigData()
+    : _icp_enabled(0), _icp_port(0), _icp_interface(0), _multicast_enabled(0), _icp_query_timeout(0), _cache_lookup_local(0),
+      _stale_lookup(0), _reply_to_unknown_peer(0), _default_reply_port(0)
   {
   }
-   ~ICPConfigData()
-  {
-  }                             // Note: _icp_interface freed prior to delete
+  ~ICPConfigData() {} // Note: _icp_interface freed prior to delete
   inline int operator==(ICPConfigData &);
-  inline int ICPconfigured()
+  inline int
+  ICPconfigured()
   {
     return _icp_enabled;
   }
-  inline int ICPport()
+  inline int
+  ICPport()
   {
     return _icp_port;
   }
-  inline char *ICPinterface()
+  inline char *
+  ICPinterface()
   {
     return _icp_interface;
   }
-  inline int ICPmulticastConfigured()
+  inline int
+  ICPmulticastConfigured()
   {
     return _multicast_enabled;
   }
-  inline int ICPqueryTimeout()
+  inline int
+  ICPqueryTimeout()
   {
     return _icp_query_timeout;
   }
-  inline int ICPLocalCacheLookup()
+  inline int
+  ICPLocalCacheLookup()
   {
     return _cache_lookup_local;
   }
-  inline int ICPStaleLookup()
+  inline int
+  ICPStaleLookup()
   {
     return _stale_lookup;
   }
-  inline int ICPReplyToUnknownPeer()
+  inline int
+  ICPReplyToUnknownPeer()
   {
     return _reply_to_unknown_peer;
   }
-  inline int ICPDefaultReplyPort()
+  inline int
+  ICPDefaultReplyPort()
   {
     return _default_reply_port;
   }
@@ -294,7 +293,7 @@ private:
   //---------------------------------------------------------
   // ICP Configuration data derived from "records.config"
   //---------------------------------------------------------
-  int _icp_enabled;             // see ICP_MODE_XXX defines
+  int _icp_enabled; // see ICP_MODE_XXX defines
   int _icp_port;
   char *_icp_interface;
   int _multicast_enabled;
@@ -314,62 +313,68 @@ class PeerConfigData
   friend class ICPProcessor;
 
 public:
-    PeerConfigData();
-    PeerConfigData(int ctype, IpAddr const& ip_addr, int proxy_port, int icp_port)
-      : _ctype(ctype), _ip_addr(ip_addr),
-      _proxy_port(proxy_port), _icp_port(icp_port), _mc_member(0), _mc_ttl(0),
+  PeerConfigData();
+  PeerConfigData(int ctype, IpAddr const &ip_addr, int proxy_port, int icp_port)
+    : _ctype(ctype), _ip_addr(ip_addr), _proxy_port(proxy_port), _icp_port(icp_port), _mc_member(0), _mc_ttl(0),
       _my_ip_addr(ip_addr)
   {
     _hostname[0] = 0;
   }
-   ~PeerConfigData()
-  {
-  }
+  ~PeerConfigData() {}
   bool operator==(PeerConfigData &);
-  inline const char *GetHostname()
+  inline const char *
+  GetHostname()
   {
     return _hostname;
   }
-  inline int GetCType()
+  inline int
+  GetCType()
   {
     return _ctype;
   }
-  inline IpAddr const& GetIPAddr()
+  inline IpAddr const &
+  GetIPAddr()
   {
     return _my_ip_addr;
   }
-  inline int GetProxyPort()
+  inline int
+  GetProxyPort()
   {
     return _proxy_port;
   }
-  inline int GetICPPort()
+  inline int
+  GetICPPort()
   {
     return _icp_port;
   }
-  inline int MultiCastMember()
+  inline int
+  MultiCastMember()
   {
     return _mc_member;
   }
-  inline IpAddr const& GetMultiCastIPAddr()
+  inline IpAddr const &
+  GetMultiCastIPAddr()
   {
     return _mc_ip_addr;
   }
-  inline int GetMultiCastTTL()
+  inline int
+  GetMultiCastTTL()
   {
     return _mc_ttl;
   }
 
   // Static member functions
   static PeerType_t CTypeToPeerType_t(int);
-  static int GetHostIPByName(char *, IpAddr&);
+  static int GetHostIPByName(char *, IpAddr &);
 
-  enum
-  { HOSTNAME_SIZE = 256 };
-  enum
-  { CTYPE_NONE = 0,
+  enum {
+    HOSTNAME_SIZE = 256,
+  };
+  enum {
+    CTYPE_NONE = 0,
     CTYPE_PARENT = 1,
     CTYPE_SIBLING = 2,
-    CTYPE_LOCAL = 3
+    CTYPE_LOCAL = 3,
   };
 
 private:
@@ -399,17 +404,16 @@ private:
 //  icp_config_change_callback(). Continuation started
 //  due to manager config callout or failure to acquire lock.
 //---------------------------------------------------------------
-class ICPConfigUpdateCont:public Continuation
+class ICPConfigUpdateCont : public Continuation
 {
 public:
   ICPConfigUpdateCont(void *data, void *value);
-   ~ICPConfigUpdateCont()
-  {
-  }
+  ~ICPConfigUpdateCont() {}
   int RetryICPconfigUpdate(int, Event *);
 
-  enum
-  { RETRY_INTERVAL = 10 };
+  enum {
+    RETRY_INTERVAL = 10,
+  };
 
 private:
   void *_data;
@@ -429,15 +433,15 @@ public:
   int PeerConfigChange();
   void UpdatePeerConfig();
 
-  inline ICPConfigData *globalConfig()
+  inline ICPConfigData *
+  globalConfig()
   {
     return _icp_cdata;
   }
-  inline PeerConfigData *indexToPeerConfigData(int index)
+  inline PeerConfigData *
+  indexToPeerConfigData(int index)
   {
     ink_assert(index <= MAX_DEFINED_PEERS);
-    // TODO coverity warning should be addressed with model for ink_assert
-    // coverity[overrun-local]
     return _peer_cdata[index];
   }
 
@@ -447,21 +451,25 @@ public:
   // ICP configuration callout for ET_ICP
   static void *icp_config_change_callback(void *, void *, int startup = 0);
 
-  inline int Lock()
+  inline int
+  Lock()
   {
     return _l.Lock();
   }
-  inline void Unlock()
+  inline void
+  Unlock()
   {
     _l.Unlock();
     return;
   }
-  inline int HaveLock()
+  inline int
+  HaveLock()
   {
     return _l.HaveLock();
   }
 
-  inline int ICPConfigCallouts()
+  inline int
+  ICPConfigCallouts()
   {
     return _icp_config_callouts;
   }
@@ -492,75 +500,84 @@ private:
 //------------------------------------------------------------------------
 
 // Peer state
-#define PEER_UP			   (1 << 0)
-#define PEER_MULTICAST_COUNT_EVENT (1 << 1)     // Member probe event active
-#define PEER_DYNAMIC 		   (1 << 2)     // Dynamically added, not in config
+#define PEER_UP (1 << 0)
+#define PEER_MULTICAST_COUNT_EVENT (1 << 1) // Member probe event active
+#define PEER_DYNAMIC (1 << 2)               // Dynamically added, not in config
 
 struct CacheVConnection;
 
-class Peer:public RefCountObj
+class Peer : public RefCountObj
 {
 public:
   Peer(PeerType_t, ICPProcessor *, bool dynamic_peer = false);
-  virtual ~ Peer()
-  {
-  }
+  virtual ~Peer() {}
   void LogRecvMsg(ICPMsg_t *, int);
 
   // Pure virtual functions
-  virtual sockaddr* GetIP() = 0;
-  virtual Action *SendMsg_re(Continuation *, void *, struct msghdr *, struct sockaddr const* to) = 0;
+  virtual sockaddr *GetIP() = 0;
+  virtual Action *SendMsg_re(Continuation *, void *, struct msghdr *, struct sockaddr const *to) = 0;
   virtual Action *RecvFrom_re(Continuation *, void *, IOBufferBlock *, int, struct sockaddr *, socklen_t *) = 0;
   virtual int GetRecvFD() = 0;
   virtual int GetSendFD() = 0;
   virtual int ExpectedReplies(BitMap *) = 0;
   virtual int ValidSender(sockaddr *) = 0;
-  virtual void LogSendMsg(ICPMsg_t *, sockaddr const*) = 0;
+  virtual void LogSendMsg(ICPMsg_t *, sockaddr const *) = 0;
   virtual int IsOnline() = 0;
   virtual Connection *GetSendChan() = 0;
   virtual Connection *GetRecvChan() = 0;
-  virtual int ExtToIntRecvSockAddr(sockaddr const*, sockaddr *) = 0;
+  virtual int ExtToIntRecvSockAddr(sockaddr const *, sockaddr *) = 0;
 
-  enum
-  { OFFLINE_THRESHOLD = 20 };
+  enum {
+    OFFLINE_THRESHOLD = 20,
+  };
 
-  inline PeerType_t GetType()
+  inline PeerType_t
+  GetType()
   {
     return _type;
   }
-  inline int GetPeerID()
+  inline int
+  GetPeerID()
   {
     return _id;
   }
-  inline void SetPeerID(int newid)
+  inline void
+  SetPeerID(int newid)
   {
     _id = newid;
   }
-  inline void SetNext(Peer * p)
+  inline void
+  SetNext(Peer *p)
   {
     _next = p;
   }
-  inline Peer *GetNext()
+  inline Peer *
+  GetNext()
   {
     return _next;
   }
-  inline bool shouldStartRead()
+  inline bool
+  shouldStartRead()
   {
     return !notFirstRead;
   }
-  inline void startingRead()
+  inline void
+  startingRead()
   {
     notFirstRead = 1;
   }
-  inline void cancelRead()
+  inline void
+  cancelRead()
   {
     notFirstRead = 0;
   }
-  inline bool readActive()
+  inline bool
+  readActive()
   {
     return (readAction != NULL);
   }
-  inline bool isUp()
+  inline bool
+  isUp()
   {
     return (_state & PEER_UP);
   }
@@ -570,13 +587,13 @@ public:
   Ptr<IOBufferBlock> buf;
   IpEndpoint fromaddr;
   socklen_t fromaddrlen;
-  int notFirstRead;             // priming the reads
-  Action *readAction;           // outstanding read
-  Action *writeAction;          // outstanding write
+  int notFirstRead;    // priming the reads
+  Action *readAction;  // outstanding read
+  Action *writeAction; // outstanding write
 
 protected:
   PeerType_t _type;
-  int _id;                      // handle for this peer
+  int _id; // handle for this peer
   Peer *_next;
   ICPProcessor *_ICPpr;
 
@@ -588,22 +605,21 @@ protected:
   //-------------------
   // Peer Statistics
   //-------------------
-  struct PeerStats
-  {
+  struct PeerStats {
     ink_hrtime last_send;
     ink_hrtime last_receive;
     int sent[ICP_OP_LAST + 1];
     int recv[ICP_OP_LAST + 1];
     int total_sent;
     int total_received;
-    int dropped_replies;        // arrived after timeout
+    int dropped_replies; // arrived after timeout
   } _stats;
 };
 
 //------------------------------------------------
 // Class ParentSiblingPeer (derived from Peer)
 //------------------------------------------------
-class ParentSiblingPeer:public Peer
+class ParentSiblingPeer : public Peer
 {
 public:
   ParentSiblingPeer(PeerType_t, PeerConfigData *, ICPProcessor *, bool dynamic_peer = false);
@@ -614,81 +630,86 @@ public:
   }
   int GetProxyPort();
   int GetICPPort();
-  virtual sockaddr* GetIP();
-  virtual Action *SendMsg_re(Continuation *, void *, struct msghdr *, struct sockaddr const* to);
+  virtual sockaddr *GetIP();
+  virtual Action *SendMsg_re(Continuation *, void *, struct msghdr *, struct sockaddr const *to);
   virtual Action *RecvFrom_re(Continuation *, void *, IOBufferBlock *, int, struct sockaddr *, socklen_t *);
   virtual int GetRecvFD();
   virtual int GetSendFD();
   virtual int ExpectedReplies(BitMap *);
-  virtual int ValidSender(struct sockaddr*);
-  virtual void LogSendMsg(ICPMsg_t *, sockaddr const*);
-  virtual int ExtToIntRecvSockAddr(sockaddr const* in, sockaddr* out);
-  inline virtual int IsOnline()
+  virtual int ValidSender(struct sockaddr *);
+  virtual void LogSendMsg(ICPMsg_t *, sockaddr const *);
+  virtual int ExtToIntRecvSockAddr(sockaddr const *in, sockaddr *out);
+  inline virtual int
+  IsOnline()
   {
     return 1;
   }
-  inline virtual Connection *GetSendChan()
+  inline virtual Connection *
+  GetSendChan()
   {
     return &_chan;
   }
-  inline virtual Connection *GetRecvChan()
+  inline virtual Connection *
+  GetRecvChan()
   {
     return &_chan;
   }
-  inline PeerConfigData *GetConfig()
+  inline PeerConfigData *
+  GetConfig()
   {
     return _pconfig;
   }
-  inline Connection *GetChan()
+  inline Connection *
+  GetChan()
   {
     return &_chan;
   }
 
 private:
   // Class data declarations
-  PeerConfigData * _pconfig;    // associated config data
-  IpEndpoint _ip; ///< Cache for GetIP().
+  PeerConfigData *_pconfig; // associated config data
+  IpEndpoint _ip;           ///< Cache for GetIP().
   Connection _chan;
 };
 
 //------------------------------------------------
 // Class MultiCastPeer (derived from Peer)
 //------------------------------------------------
-class MultiCastPeer:public Peer
+class MultiCastPeer : public Peer
 {
 public:
-  MultiCastPeer(IpAddr const&, uint16_t, int, ICPProcessor *);
-  ~MultiCastPeer()
-  {
-  }
+  MultiCastPeer(IpAddr const &, uint16_t, int, ICPProcessor *);
+  ~MultiCastPeer() {}
   int GetTTL();
-  int AddMultiCastChild(Peer * P);
+  int AddMultiCastChild(Peer *P);
   /** Find the multicast child peer with IP address @a ip on @a port.
       If @a port is 0 the port is not checked.
   */
-  Peer *FindMultiCastChild(
-    IpAddr const& ip, ///< IP address.
-    uint16_t port = 0 ///< Port (host order).
-  );
+  Peer *FindMultiCastChild(IpAddr const &ip, ///< IP address.
+                           uint16_t port = 0 ///< Port (host order).
+                           );
 
-  virtual sockaddr* GetIP();
-  virtual Action *SendMsg_re(Continuation *, void *, struct msghdr *, struct sockaddr const* to);
+  virtual sockaddr *GetIP();
+  virtual Action *SendMsg_re(Continuation *, void *, struct msghdr *, struct sockaddr const *to);
   virtual Action *RecvFrom_re(Continuation *, void *, IOBufferBlock *, int, struct sockaddr *, socklen_t *);
   virtual int GetRecvFD();
   virtual int GetSendFD();
   virtual int ExpectedReplies(BitMap *);
-  virtual int ValidSender(struct sockaddr*);
-  virtual void LogSendMsg(ICPMsg_t *, sockaddr const*);
+  virtual int ValidSender(struct sockaddr *);
+  virtual void LogSendMsg(ICPMsg_t *, sockaddr const *);
   virtual int IsOnline();
-  inline virtual Connection *GetRecvChan()
+  inline virtual Connection *
+  GetRecvChan()
   {
     return &_recv_chan;
   }
-  inline virtual Connection *GetSendChan()
+  inline virtual Connection *
+  GetSendChan()
   {
     return &_send_chan;
   }
-  inline virtual int ExtToIntRecvSockAddr(sockaddr const* in, sockaddr* out)
+  inline virtual int
+  ExtToIntRecvSockAddr(sockaddr const *in, sockaddr *out)
   {
     Peer *P = FindMultiCastChild(IpAddr(in));
     if (P) {
@@ -709,13 +730,12 @@ private:
   //---------------------------
   IpEndpoint _mc_ip;
   int _mc_ttl;
-  struct multicast_data
-  {
-    double avg_members;         // running avg of multicast responders
-    int defined_members;        // as specified in icp.config
-    int n_count_events;         // responder count events
-    int count_event_reqno;      // reqno associated with count event
-    int expected_replies;       // current expected responders on multicast
+  struct multicast_data {
+    double avg_members;    // running avg of multicast responders
+    int defined_members;   // as specified in icp.config
+    int n_count_events;    // responder count events
+    int count_event_reqno; // reqno associated with count event
+    int expected_replies;  // current expected responders on multicast
   } _mc;
 };
 
@@ -726,15 +746,15 @@ class BitMap
 {
 public:
   BitMap(int);
-   ~BitMap();
+  ~BitMap();
   void SetBit(int);
   void ClearBit(int);
   int IsBitSet(int);
 
 private:
-  enum
-  { STATIC_BITMAP_BYTE_SIZE = 16,
-    BITS_PER_BYTE = 8
+  enum {
+    STATIC_BITMAP_BYTE_SIZE = 16,
+    BITS_PER_BYTE = 8,
   };
   char _static_bitmap[STATIC_BITMAP_BYTE_SIZE];
   char *_bitmap;
@@ -752,67 +772,79 @@ class ICPProcessor
   friend class ICPRequestCont;  // Outgoing ICP request handler
 
 public:
-    ICPProcessor();
-   ~ICPProcessor();
+  ICPProcessor();
+  ~ICPProcessor();
 
   // Exported interfaces for other subsystems
   void start();
   Action *ICPQuery(Continuation *, URL *);
 
   // Exported interfaces to other ICP classes
-  typedef enum
-  {
+  typedef enum {
     RC_RECONFIG,
     RC_ENABLE_ICP,
-    RC_DONE
+    RC_DONE,
   } ReconfigState_t;
   ReconfigState_t ReconfigureStateMachine(ReconfigState_t, int, int);
 
-  Peer *FindPeer(IpAddr const& ip, uint16_t port = 0);
-  Peer *FindPeer(IpEndpoint const& ip) {
+  Peer *FindPeer(IpAddr const &ip, uint16_t port = 0);
+  Peer *
+  FindPeer(IpEndpoint const &ip)
+  {
     return this->FindPeer(IpAddr(&ip), ats_ip_port_host_order(&ip));
   }
-  Peer *FindPeer(sockaddr const* ip) {
+  Peer *
+  FindPeer(sockaddr const *ip)
+  {
     return this->FindPeer(IpAddr(ip), ats_ip_port_host_order(ip));
   }
 
-  inline Peer *GetLocalPeer()
+  inline Peer *
+  GetLocalPeer()
   {
     return _LocalPeer;
   }
-  inline Peer *IdToPeer(int id)
+  inline Peer *
+  IdToPeer(int id)
   {
     return _PeerList[id];
   }
-  inline ICPConfiguration *GetConfig()
+  inline ICPConfiguration *
+  GetConfig()
   {
     return _ICPConfig;
   }
 
-  inline int GetFreePeers()
+  inline int
+  GetFreePeers()
   {
     return PEER_LIST_SIZE - (_nPeerList + 1);
   }
-  inline int GetFreeSendPeers()
+  inline int
+  GetFreeSendPeers()
   {
     return SEND_PEER_LIST_SIZE - (_nSendPeerList + 1);
   }
-  inline int GetFreeRecvPeers()
+  inline int
+  GetFreeRecvPeers()
   {
     return RECV_PEER_LIST_SIZE - (_nRecvPeerList + 1);
   }
 
 private:
-  inline int Lock()
+  inline int
+  Lock()
   {
     return _l->Lock();
   }
-  inline void Unlock()
+  inline void
+  Unlock()
   {
     _l->Unlock();
     return;
   }
-  inline int HaveLock()
+  inline int
+  HaveLock()
   {
     return _l->HaveLock();
   }
@@ -823,84 +855,101 @@ private:
   int Reconfigure(int, int);
   void InitICPStatCallbacks();
 
-  inline void DisableICPQueries()
+  inline void
+  DisableICPQueries()
   {
     _AllowIcpQueries = 0;
   }
-  inline void EnableICPQueries()
+  inline void
+  EnableICPQueries()
   {
     _AllowIcpQueries = 1;
   }
-  inline int AllowICPQueries()
+  inline int
+  AllowICPQueries()
   {
     return _AllowIcpQueries;
   }
-  inline int PendingQuery()
+  inline int
+  PendingQuery()
   {
     return _PendingIcpQueries;
   }
-  inline void IncPendingQuery()
+  inline void
+  IncPendingQuery()
   {
     _PendingIcpQueries++;
   }
-  inline void DecPendingQuery()
+  inline void
+  DecPendingQuery()
   {
     _PendingIcpQueries--;
   }
 
-  Peer *GenericFindListPeer(IpAddr const&, uint16_t, int, Ptr<Peer> *);
-  Peer *FindSendListPeer(IpAddr const&, uint16_t);
-  Peer *FindRecvListPeer(IpAddr const&, uint16_t);
+  Peer *GenericFindListPeer(IpAddr const &, uint16_t, int, Ptr<Peer> *);
+  Peer *FindSendListPeer(IpAddr const &, uint16_t);
+  Peer *FindRecvListPeer(IpAddr const &, uint16_t);
   int AddPeer(Peer *);
   int AddPeerToSendList(Peer *);
   int AddPeerToRecvList(Peer *);
   int AddPeerToParentList(Peer *);
 
-  inline int GetSendPeers()
+  inline int
+  GetSendPeers()
   {
     return _nSendPeerList + 1;
   }
-  inline Peer *GetNthSendPeer(int n, int bias)
+  inline Peer *
+  GetNthSendPeer(int n, int bias)
   {
     return _SendPeerList[(bias + n) % (_nSendPeerList + 1)];
   }
 
-  inline int GetRecvPeers()
+  inline int
+  GetRecvPeers()
   {
     return _nRecvPeerList + 1;
   }
-  inline Peer *GetNthRecvPeer(int n, int bias)
+  inline Peer *
+  GetNthRecvPeer(int n, int bias)
   {
     return _RecvPeerList[(bias + n) % (_nRecvPeerList + 1)];
   }
 
-  inline int GetStartingSendPeerBias()
+  inline int
+  GetStartingSendPeerBias()
   {
     return ++_curSendPeer;
   }
-  inline int GetStartingRecvPeerBias()
+  inline int
+  GetStartingRecvPeerBias()
   {
     return ++_curRecvPeer;
   }
 
-  inline int GetParentPeers()
+  inline int
+  GetParentPeers()
   {
     return _nParentPeerList + 1;
   }
-  inline Peer *GetNthParentPeer(int n, int bias)
+  inline Peer *
+  GetNthParentPeer(int n, int bias)
   {
     return _ParentPeerList[(bias + n) % (_nParentPeerList + 1)];
   }
-  inline int GetStartingParentPeerBias()
+  inline int
+  GetStartingParentPeerBias()
   {
     return ++_curParentPeer;
   }
 
-  inline void SetLastRecvPeerBias(int b)
+  inline void
+  SetLastRecvPeerBias(int b)
   {
     _last_recv_peer_bias = b;
   }
-  inline int GetLastRecvPeerBias()
+  inline int
+  GetLastRecvPeerBias()
   {
     return _last_recv_peer_bias;
   }
@@ -909,7 +958,7 @@ private:
 
 private:
   // Class data declarations
-  AtomicLock * _l;
+  AtomicLock *_l;
   int _Initialized;
   int _AllowIcpQueries;
   int _PendingIcpQueries;
@@ -920,8 +969,7 @@ private:
   Event *_PeriodicEvent;
   Event *_ICPHandlerEvent;
 
-  enum
-  {
+  enum {
     PEER_LIST_SIZE = 2 * MAX_DEFINED_PEERS,
     SEND_PEER_LIST_SIZE = 2 * MAX_DEFINED_PEERS,
     RECV_PEER_LIST_SIZE = 2 * MAX_DEFINED_PEERS,
@@ -930,44 +978,44 @@ private:
   };
 
   // All Peer elements
-  int _nPeerList;               // valid PeerList[] entries - 1
+  int _nPeerList; // valid PeerList[] entries - 1
   Ptr<Peer> _PeerList[PEER_LIST_SIZE];
   Ptr<Peer> _LocalPeer;
 
   // Peers which are targets of ICP queries
-  int _curSendPeer;             // index bias for SendPeerList[]
-  int _nSendPeerList;           // valid SendPeerList[] entries - 1
+  int _curSendPeer;   // index bias for SendPeerList[]
+  int _nSendPeerList; // valid SendPeerList[] entries - 1
   Ptr<Peer> _SendPeerList[SEND_PEER_LIST_SIZE];
 
   // List of Peers whom we issue reads from
-  int _curRecvPeer;             // index bias for RecvPeerList[]
-  int _nRecvPeerList;           // valid RecvPeerList[] entries - 1
+  int _curRecvPeer;   // index bias for RecvPeerList[]
+  int _nRecvPeerList; // valid RecvPeerList[] entries - 1
   Ptr<Peer> _RecvPeerList[RECV_PEER_LIST_SIZE];
 
   // Peers on SendPeerList which are "parent" peers
-  int _curParentPeer;           // index bias for ParentPeerList[]
-  int _nParentPeerList;         // valid ParentPeerList[] entries - 1
+  int _curParentPeer;   // index bias for ParentPeerList[]
+  int _nParentPeerList; // valid ParentPeerList[] entries - 1
   Ptr<Peer> _ParentPeerList[PARENT_PEER_LIST_SIZE];
 
   // Peer ID to Poll descriptor index map
   int _ValidPollData;
   int _PeerIDtoPollIndex[PEER_ID_POLL_INDEX_SIZE];
-  int _last_recv_peer_bias;     // bias used to build last poll data
+  int _last_recv_peer_bias; // bias used to build last poll data
 };
 
 //-----------------------------------------------------------------
 // PeriodicCont -- Abstract base class for periodic ICP processor
 //                 continuations
 //-----------------------------------------------------------------
-class PeriodicCont:public Continuation
+class PeriodicCont : public Continuation
 {
 public:
-  PeriodicCont(ICPProcessor * p);
-  virtual ~ PeriodicCont();
+  PeriodicCont(ICPProcessor *p);
+  virtual ~PeriodicCont();
   virtual int PeriodicEvent(int, Event *) = 0;
 
 protected:
-    ICPProcessor * _ICPpr;
+  ICPProcessor *_ICPpr;
 };
 
 //---------------------------------------------------------------
@@ -975,17 +1023,17 @@ protected:
 //   Periodicly look for ICP configuration updates and if
 //   updates exist schedule ICP reconfiguration.
 //---------------------------------------------------------------
-class ICPPeriodicCont:public PeriodicCont
+class ICPPeriodicCont : public PeriodicCont
 {
 public:
-  enum
-  { PERIODIC_INTERVAL = 5000 };
-  enum
-  { RETRY_INTERVAL_MSECS = 10 };
-    ICPPeriodicCont(ICPProcessor *);
-   ~ICPPeriodicCont()
-  {
-  }
+  enum {
+    PERIODIC_INTERVAL = 5000,
+  };
+  enum {
+    RETRY_INTERVAL_MSECS = 10,
+  };
+  ICPPeriodicCont(ICPProcessor *);
+  ~ICPPeriodicCont() {}
   virtual int PeriodicEvent(int, Event *);
   int DoReconfigAction(int, Event *);
 
@@ -998,25 +1046,21 @@ private:
 //-----------------------------------------------------------------
 // ICPHandlerCont -- Periodic for incoming message processing
 //-----------------------------------------------------------------
-class ICPHandlerCont:public PeriodicCont
+class ICPHandlerCont : public PeriodicCont
 {
 public:
-  enum
-  {
-    ICP_HANDLER_INTERVAL = 10
+  enum {
+    ICP_HANDLER_INTERVAL = 10,
   };
-    ICPHandlerCont(ICPProcessor *);
-   ~ICPHandlerCont()
-  {
-  }
+  ICPHandlerCont(ICPProcessor *);
+  ~ICPHandlerCont() {}
   virtual int PeriodicEvent(int, Event *);
   virtual int TossEvent(int, Event *);
 
 #ifdef DEBUG_ICP
-  // state history
+// state history
 #define MAX_ICP_HISTORY 20
-  struct statehistory
-  {
+  struct statehistory {
     int event;
     int newstate;
     char *file;
@@ -1025,15 +1069,15 @@ public:
   statehistory _history[MAX_ICP_HISTORY];
   int _nhistory;
 
-#define RECORD_ICP_STATE_CHANGE(peerreaddata,event_,newstate_) \
-    peerreaddata->_history[peerreaddata->_nhistory].event = event_; \
-    peerreaddata->_history[peerreaddata->_nhistory].newstate = newstate_; \
-    peerreaddata->_history[peerreaddata->_nhistory].file = __FILE__; \
-    peerreaddata->_history[peerreaddata->_nhistory].line = __LINE__; \
-    peerreaddata->_nhistory = (peerreaddata->_nhistory + 1) % MAX_ICP_HISTORY;
+#define RECORD_ICP_STATE_CHANGE(peerreaddata, event_, newstate_)        \
+  peerreaddata->_history[peerreaddata->_nhistory].event = event_;       \
+  peerreaddata->_history[peerreaddata->_nhistory].newstate = newstate_; \
+  peerreaddata->_history[peerreaddata->_nhistory].file = __FILE__;      \
+  peerreaddata->_history[peerreaddata->_nhistory].line = __LINE__;      \
+  peerreaddata->_nhistory = (peerreaddata->_nhistory + 1) % MAX_ICP_HISTORY;
 
 #else
-#define RECORD_ICP_STATE_CHANGE(x,y,z)
+#define RECORD_ICP_STATE_CHANGE(x, y, z)
 #endif
 
   static int64_t ICPDataBuf_IOBuffer_sizeindex;
@@ -1042,11 +1086,10 @@ public:
 //------------------------------------------------------------------
 // ICPPeerReadCont -- ICP incoming message processing state machine
 //------------------------------------------------------------------
-class ICPPeerReadCont:public Continuation
+class ICPPeerReadCont : public Continuation
 {
 public:
-  typedef enum
-  {
+  typedef enum {
     READ_ACTIVE,
     READ_DATA,
     READ_DATA_DONE,
@@ -1067,15 +1110,15 @@ public:
   public:
     PeerReadData();
     void init();
-     ~PeerReadData();
+    ~PeerReadData();
     void reset(int full_reset = 0);
 
     ink_hrtime _start_time;
     ICPPeerReadCont *_mycont;
-      Ptr<Peer> _peer;
+    Ptr<Peer> _peer;
     PeerReadState_t _next_state;
     int _cache_lookup_local;
-      Ptr<IOBufferBlock> _buf;       // the buffer with the ICP message in it
+    Ptr<IOBufferBlock> _buf; // the buffer with the ICP message in it
     ICPMsg_t *_rICPmsg;
     int _rICPmsg_len;
     IpEndpoint _sender; // sender of rICPmsg
@@ -1088,9 +1131,9 @@ public:
     struct iovec _iov[MSG_IOVECS];
   };
 
-    ICPPeerReadCont();
+  ICPPeerReadCont();
   void init(ICPProcessor *, Peer *, int);
-   ~ICPPeerReadCont();
+  ~ICPPeerReadCont();
   void reset(int full_reset = 0);
   int ICPPeerReadEvent(int, Event *);
   int ICPPeerQueryCont(int, Event *);
@@ -1098,8 +1141,9 @@ public:
   int StaleCheck(int, Event *);
   int PeerReadStateMachine(PeerReadData *, Event *);
 
-  enum
-  { RETRY_INTERVAL = 10 };
+  enum {
+    RETRY_INTERVAL = 10,
+  };
 
   // Freshness specific data
   CacheVConnection *_object_vc;
@@ -1109,7 +1153,7 @@ public:
 
 private:
   // Class data
-    ICPProcessor * _ICPpr;
+  ICPProcessor *_ICPpr;
   PeerReadData *_state;
   ink_hrtime _start_time;
   int _recursion_depth;
@@ -1118,32 +1162,37 @@ private:
 //----------------------------------------------------------------------
 // ICPRequestCont -- ICP Request continuation  (Outgoing ICP requests)
 //----------------------------------------------------------------------
-class ICPRequestCont:public Continuation
+class ICPRequestCont : public Continuation
 {
   friend class ICPProcessor;
 
 public:
-    ICPRequestCont(ICPProcessor * i = 0, Continuation * c = 0, URL * u = 0);
-   ~ICPRequestCont();
-  void *operator  new(size_t size, void *mem);
-  void operator  delete(void *mem);
-  inline void SetRequestStartTime()
+  ICPRequestCont(ICPProcessor *i = 0, Continuation *c = 0, URL *u = 0);
+  ~ICPRequestCont();
+  void *operator new(size_t size, void *mem);
+  void operator delete(void *mem);
+  inline void
+  SetRequestStartTime()
   {
     _start_time = ink_get_hrtime();
   }
-  inline ink_hrtime GetRequestStartTime()
+  inline ink_hrtime
+  GetRequestStartTime()
   {
     return _start_time;
   }
-  inline class Action *GetActionPtr()
+  inline class Action *
+  GetActionPtr()
   {
     return &_act;
   }
 
-  enum
-  { RETRY_INTERVAL = 10 };
-  enum
-  { ICP_REQUEST_HASH_SIZE = 1024 };
+  enum {
+    RETRY_INTERVAL = 10,
+  };
+  enum {
+    ICP_REQUEST_HASH_SIZE = 1024,
+  };
 
   //***********************************************************************
   // ICPPeerReadCont::PeerReadStateMachine() to
@@ -1152,8 +1201,7 @@ public:
   //     ICPRequestEvent(ICP_RESPONSE_MESSAGE, ICPRequestEventArgs_t *)
   //
   //***********************************************************************
-  typedef struct ICPRequestEventArgs
-  {
+  typedef struct ICPRequestEventArgs {
     ICPMsg_t *rICPmsg;
     int rICPmsg_len;
     Peer *peer;
@@ -1164,9 +1212,8 @@ public:
 
   // Static member functions
   static void NetToHostICPMsg(ICPMsg_t *, ICPMsg_t *);
-  static int BuildICPMsg(ICPopcode_t op, unsigned int sequence_number,
-                         int optflags, int optdata, int shostid,
-                         void *data, int datalen, struct msghdr *mhdr, struct iovec *iov, ICPMsg_t * icpmsg);
+  static int BuildICPMsg(ICPopcode_t op, unsigned int sequence_number, int optflags, int optdata, int shostid, void *data,
+                         int datalen, struct msghdr *mhdr, struct iovec *iov, ICPMsg_t *icpmsg);
 
   static unsigned int ICPReqSeqNumber();
   static int ICPRequestHash(unsigned int);
@@ -1175,8 +1222,7 @@ public:
   static int RemoveICPRequest(unsigned int);
 
 private:
-  typedef enum
-  {
+  typedef enum {
     ICP_START,
     ICP_OFF_TERMINATE,
     ICP_QUEUE_REQUEST,
@@ -1211,7 +1257,7 @@ private:
 
   // outstanding actions
   int npending_actions;
-  DynArray<Action *>*pendingActions;
+  DynArray<Action *> *pendingActions;
 
   ICPMsg_t _ICPmsg;
   struct msghdr _sendMsgHdr;
@@ -1227,25 +1273,22 @@ private:
 
 extern ClassAllocator<ICPRequestCont> ICPRequestCont_allocator;
 
-typedef int (*PluginFreshnessCalcFunc) (void *contp);
+typedef int (*PluginFreshnessCalcFunc)(void *contp);
 extern PluginFreshnessCalcFunc pluginFreshnessCalcFunc;
 
-inline void *
-ICPRequestCont::operator new(size_t /* size ATS_UNUSED */, void *mem)
+inline void *ICPRequestCont::operator new(size_t /* size ATS_UNUSED */, void *mem)
 {
   return mem;
 }
 
-inline void
-ICPRequestCont::operator delete(void *mem)
+inline void ICPRequestCont::operator delete(void *mem)
 {
-  ICPRequestCont_allocator.free((ICPRequestCont *) mem);
+  ICPRequestCont_allocator.free((ICPRequestCont *)mem);
 }
 
 extern struct RecRawStatBlock *icp_rsb;
 
-enum
-{
+enum {
   icp_stat_def,
   config_mgmt_callouts_stat,
   reconfig_polls_stat,
@@ -1283,24 +1326,19 @@ enum
   icp_stat_count
 };
 
-#define ICP_EstablishStaticConfigInteger(_ix,_n) \
-  	REC_EstablishStaticConfigInt32(_ix,_n)
+#define ICP_EstablishStaticConfigInteger(_ix, _n) REC_EstablishStaticConfigInt32(_ix, _n)
 
-#define ICP_EstablishStaticConfigStringAlloc(_ix, n) \
-	REC_EstablishStaticConfigStringAlloc(_ix, n)
+#define ICP_EstablishStaticConfigStringAlloc(_ix, n) REC_EstablishStaticConfigStringAlloc(_ix, n)
 
-#define ICP_INCREMENT_DYN_STAT(x) \
-        RecIncrRawStat(icp_rsb, mutex->thread_holding, (int) x, 1)
-#define ICP_DECREMENT_DYN_STAT(x) \
-        RecIncrRawStat(icp_rsb, mutex->thread_holding, (int) x, -1)
-#define ICP_SUM_DYN_STAT(x, y) \
-        RecIncrRawStat(icp_rsb, mutex->thread_holding, (int) x, (y))
-#define ICP_READ_DYN_STAT(x, C, S) \
-        RecGetRawStatCount(icp_rsb, (int) x, &C); \
-        RecGetRawStatSum(icp_rsb, (int) x, &S);
+#define ICP_INCREMENT_DYN_STAT(x) RecIncrRawStat(icp_rsb, mutex->thread_holding, (int)x, 1)
+#define ICP_DECREMENT_DYN_STAT(x) RecIncrRawStat(icp_rsb, mutex->thread_holding, (int)x, -1)
+#define ICP_SUM_DYN_STAT(x, y) RecIncrRawStat(icp_rsb, mutex->thread_holding, (int)x, (y))
+#define ICP_READ_DYN_STAT(x, C, S)         \
+  RecGetRawStatCount(icp_rsb, (int)x, &C); \
+  RecGetRawStatSum(icp_rsb, (int)x, &S);
 
-#define ICP_ReadConfigString 	      REC_ReadConfigString
-#define ICP_RegisterConfigUpdateFunc  REC_RegisterConfigUpdateFunc
+#define ICP_ReadConfigString REC_ReadConfigString
+#define ICP_RegisterConfigUpdateFunc REC_RegisterConfigUpdateFunc
 
 
 // End of ICP.h
