@@ -41,14 +41,14 @@
 
 enum AclOp {
   ACL_OP_ALLOW, ///< Allow access.
-  ACL_OP_DENY, ///< Deny access.
+  ACL_OP_DENY,  ///< Deny access.
 };
 
 const AclRecord IpAllow::ALL_METHOD_ACL(AclRecord::ALL_METHOD_MASK);
 
 int IpAllow::configid = 0;
 
-static ConfigUpdateHandler<IpAllow> * ipAllowUpdate;
+static ConfigUpdateHandler<IpAllow> *ipAllowUpdate;
 
 //
 //   Begin API functions
@@ -85,7 +85,7 @@ IpAllow::acquire()
 }
 
 void
-IpAllow::release(IpAllow * lookup)
+IpAllow::release(IpAllow *lookup)
 {
   configProcessor.release(configid, lookup);
 }
@@ -95,14 +95,9 @@ IpAllow::release(IpAllow * lookup)
 //
 
 
-IpAllow::IpAllow(
-  const char *config_var,
-  const char *name,
-  const char *action_val
-) : module_name(name),
-    action(action_val)
+IpAllow::IpAllow(const char *config_var, const char *name, const char *action_val) : module_name(name), action(action_val)
 {
-  xptr<char> config_path(RecConfigReadConfigPath(config_var));
+  ats_scoped_str config_path(RecConfigReadConfigPath(config_var));
 
   config_file_path[0] = '\0';
   ink_release_assert(config_path);
@@ -115,20 +110,16 @@ IpAllow::~IpAllow()
 }
 
 void
-IpAllow::Print() {
+IpAllow::Print()
+{
   std::ostringstream s;
   s << _map.getCount() << " ACL entries";
   s << '.';
-  for ( IpMap::iterator spot(_map.begin()), limit(_map.end())
-      ; spot != limit
-      ; ++spot
-  ) {
+  for (IpMap::iterator spot(_map.begin()), limit(_map.end()); spot != limit; ++spot) {
     char text[INET6_ADDRSTRLEN];
-    AclRecord const* ar = static_cast<AclRecord const*>(spot->data());
+    AclRecord const *ar = static_cast<AclRecord const *>(spot->data());
 
-    s << std::endl << "  Line " << ar->_src_line << ": "
-      << ats_ip_ntop(spot->min(), text, sizeof text)
-      ;
+    s << std::endl << "  Line " << ar->_src_line << ": " << ats_ip_ntop(spot->min(), text, sizeof text);
     if (0 != ats_ip_addr_cmp(spot->min(), spot->max())) {
       s << " - " << ats_ip_ntop(spot->max(), text, sizeof text);
     }
@@ -139,9 +130,9 @@ IpAllow::Print() {
     } else if (0 == mask) {
       s << "NONE";
     } else {
-      bool leader = false; // need leading vbar?
+      bool leader = false;    // need leading vbar?
       uint32_t test_mask = 1; // mask for current method.
-      for ( int i = 0 ; i < HTTP_WKSIDX_METHODS_CNT ; ++i, test_mask<<=1 ) {
+      for (int i = 0; i < HTTP_WKSIDX_METHODS_CNT; ++i, test_mask <<= 1) {
         if (mask & test_mask) {
           if (leader)
             s << '|';
@@ -153,8 +144,8 @@ IpAllow::Print() {
     if (!ar->_nonstandard_methods.empty()) {
       s << " nonstandard method=";
       bool leader = false; // need leading vbar?
-      for (AclRecord::MethodSet::iterator iter = ar->_nonstandard_methods.begin(),
-             end = ar->_nonstandard_methods.end(); iter != end; ++iter) {
+      for (AclRecord::MethodSet::iterator iter = ar->_nonstandard_methods.begin(), end = ar->_nonstandard_methods.end();
+           iter != end; ++iter) {
         if (leader) {
           s << '|';
         }
@@ -192,7 +183,6 @@ IpAllow::BuildTable()
 
   line = tokLine(file_buf, &tok_state);
   while (line != NULL) {
-
     ++line_num;
 
     // skip all blank spaces at beginning of line
@@ -201,22 +191,19 @@ IpAllow::BuildTable()
     }
 
     if (*line != '\0' && *line != '#') {
-
       errPtr = parseConfigLine(line, &line_info, &ip_allow_tags);
 
       if (errPtr != NULL) {
-        snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry at line %d : %s",
-                 module_name, config_file_path, line_num, errPtr);
+        snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry at line %d : %s", module_name, config_file_path, line_num, errPtr);
         SignalError(errBuf, alarmAlready);
       } else {
-
         ink_assert(line_info.type == MATCH_IP);
 
         errPtr = ExtractIpRange(line_info.line[1][line_info.dest_entry], &addr1.sa, &addr2.sa);
 
         if (errPtr != NULL) {
-          snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry at line %d : %s",
-                   module_name, config_file_path, line_num, errPtr);
+          snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry at line %d : %s", module_name, config_file_path, line_num,
+                   errPtr);
           SignalError(errBuf, alarmAlready);
         } else {
           // INKqa05845
@@ -254,7 +241,7 @@ IpAllow::BuildTable()
                 // Parse method="GET|HEAD"
                 for (method_name = strtok_r(val, "|", &sep_ptr); method_name != NULL; method_name = strtok_r(NULL, "|", &sep_ptr)) {
                   if (strcasecmp(method_name, "ALL") == 0) {
-                    method_found = false;  // in case someone does method=GET|ALL
+                    method_found = false; // in case someone does method=GET|ALL
                     break;
                   } else {
                     int method_name_len = strlen(method_name);
@@ -288,12 +275,10 @@ IpAllow::BuildTable()
             _acls.push_back(AclRecord(acl_method_mask, line_num, nonstandard_methods, deny_nonstandard_methods));
             // Color with index because at this point the address
             // is volatile.
-            _map.fill(
-              &addr1, &addr2,
-              reinterpret_cast<void*>(_acls.length()-1)
-            );
+            _map.fill(&addr1, &addr2, reinterpret_cast<void *>(_acls.length() - 1));
           } else {
-            snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry at line %d : %s", module_name, config_file_path, line_num, "Invalid action/method specified");        //changed by YTS Team, yamsat bug id -59022
+            snprintf(errBuf, sizeof(errBuf), "%s discarding %s entry at line %d : %s", module_name, config_file_path, line_num,
+                     "Invalid action/method specified"); // changed by YTS Team, yamsat bug id -59022
             SignalError(errBuf, alarmAlready);
           }
         }
@@ -307,10 +292,7 @@ IpAllow::BuildTable()
     Warning("%s No entries in %s. All IP Addresses will be blocked", module_name, config_file_path);
   } else {
     // convert the coloring from indices to pointers.
-    for ( IpMap::iterator spot(_map.begin()), limit(_map.end())
-        ; spot != limit
-        ; ++spot
-    ) {
+    for (IpMap::iterator spot(_map.begin()), limit(_map.end()); spot != limit; ++spot) {
       spot->setData(&_acls[reinterpret_cast<size_t>(spot->data())]);
     }
   }
