@@ -37,28 +37,28 @@
 #include "P_Cache.h"
 #include "I_Tasks.h"
 
+/* Some defines that might be candidates for configurable settings later.
+ */
+#define HTTP_SSN_TXN_MAX_USER_ARG 16 /* max number of user arguments for Transactions and Sessions */
 
-typedef enum
-  {
-    OVERRIDABLE_TYPE_NULL = 0,
-    OVERRIDABLE_TYPE_INT,
-    OVERRIDABLE_TYPE_FLOAT,
-    OVERRIDABLE_TYPE_STRING,
-    OVERRIDABLE_TYPE_BYTE
-  } OverridableDataType;
+typedef enum {
+  OVERRIDABLE_TYPE_NULL = 0,
+  OVERRIDABLE_TYPE_INT,
+  OVERRIDABLE_TYPE_FLOAT,
+  OVERRIDABLE_TYPE_STRING,
+  OVERRIDABLE_TYPE_BYTE
+} OverridableDataType;
 typedef int8_t TSMgmtByte; // Not for external use
 
 /* ****** Cache Structure ********* */
 
 // For memory corruption detection
-enum CacheInfoMagic
-{
+enum CacheInfoMagic {
   CACHE_INFO_MAGIC_ALIVE = 0xfeedbabe,
-  CACHE_INFO_MAGIC_DEAD = 0xdeadbeef
+  CACHE_INFO_MAGIC_DEAD = 0xdeadbeef,
 };
 
-struct CacheInfo
-{
+struct CacheInfo {
   INK_MD5 cache_key;
   CacheFragType frag_type;
   char *hostname;
@@ -66,7 +66,7 @@ struct CacheInfo
   time_t pin_in_cache;
   CacheInfoMagic magic;
 
-    CacheInfo()
+  CacheInfo()
   {
     frag_type = CACHE_FRAG_TYPE_NONE;
     hostname = NULL;
@@ -78,16 +78,15 @@ struct CacheInfo
 
 class FileImpl
 {
-  enum
-  {
+  enum {
     CLOSED = 0,
     READ = 1,
-    WRITE = 2
+    WRITE = 2,
   };
 
 public:
-    FileImpl();
-   ~FileImpl();
+  FileImpl();
+  ~FileImpl();
 
   int fopen(const char *filename, const char *mode);
   void fclose();
@@ -105,30 +104,31 @@ public:
 };
 
 
-struct INKConfigImpl:public ConfigInfo
-{
+struct INKConfigImpl : public ConfigInfo {
   void *mdata;
   TSConfigDestroyFunc m_destroy_func;
 
-    virtual ~ INKConfigImpl()
-  {
-    m_destroy_func(mdata);
-  }
+  virtual ~INKConfigImpl() { m_destroy_func(mdata); }
 };
 
-struct HttpAltInfo
-{
+struct HttpAltInfo {
   HTTPHdr m_client_req;
   HTTPHdr m_cached_req;
   HTTPHdr m_cached_resp;
   float m_qvalue;
 };
 
+enum APIHookScope {
+  API_HOOK_SCOPE_NONE,
+  API_HOOK_SCOPE_GLOBAL,
+  API_HOOK_SCOPE_LOCAL,
+};
+
 /// A single API hook that can be invoked.
 class APIHook
 {
 public:
-  INKContInternal * m_cont;
+  INKContInternal *m_cont;
   int invoke(int event, void *edata);
   APIHook *next() const;
   LINK(APIHook, m_link);
@@ -138,12 +138,12 @@ public:
 class APIHooks
 {
 public:
-  void prepend(INKContInternal * cont);
-  void append(INKContInternal * cont);
-  APIHook *get();
+  void prepend(INKContInternal *cont);
+  void append(INKContInternal *cont);
+  APIHook *get() const;
   void clear();
   bool is_empty() const;
-  void invoke(int event, void* data);
+  void invoke(int event, void *data);
 
 private:
   Que(APIHook, m_link) m_hooks;
@@ -156,8 +156,9 @@ APIHooks::is_empty() const
 }
 
 inline void
-APIHooks::invoke(int event, void* data) {
-  for ( APIHook* hook = m_hooks.head ; NULL != hook ; hook = hook->next())
+APIHooks::invoke(int event, void *data)
+{
+  for (APIHook *hook = m_hooks.head; NULL != hook; hook = hook->next())
     hook->invoke(event, data);
 }
 
@@ -170,29 +171,28 @@ APIHooks::invoke(int event, void* data) {
     @note The minimum value for a hook ID is zero. Therefore the template parameter @a N_ID should be one more than the
     maximum hook ID so the valid ids are 0..(N-1) in the standard C array style.
  */
-template <
-  typename ID, ///< Type of hook ID
-  ID N ///< Number of hooks
->
+template <typename ID, ///< Type of hook ID
+          ID N         ///< Number of hooks
+          >
 class FeatureAPIHooks
 {
 public:
-  FeatureAPIHooks(); ///< Constructor (empty container).
+  FeatureAPIHooks();  ///< Constructor (empty container).
   ~FeatureAPIHooks(); ///< Destructor.
 
   /// Remove all hooks.
   void clear();
   /// Add the hook @a cont to the front of the hooks for @a id.
-  void prepend(ID id, INKContInternal * cont);
+  void prepend(ID id, INKContInternal *cont);
   /// Add the hook @a cont to the end of the hooks for @a id.
-  void append(ID id, INKContInternal * cont);
+  void append(ID id, INKContInternal *cont);
   /// Get the list of hooks for @a id.
-  APIHook *get(ID id);
+  APIHook *get(ID id) const;
   /// @return @c true if @a id is a valid id, @c false otherwise.
   static bool is_valid(ID id);
 
   /// Invoke the callbacks for the hook @a id.
-  void invoke(ID id, int event, void* data);
+  void invoke(ID id, int event, void *data);
 
   /// Fast check for any hooks in this container.
   ///
@@ -210,21 +210,18 @@ private:
   APIHooks m_hooks[N];
 };
 
-template < typename ID, ID N >
-FeatureAPIHooks<ID,N>::FeatureAPIHooks():
-hooks_p(false)
+template <typename ID, ID N> FeatureAPIHooks<ID, N>::FeatureAPIHooks() : hooks_p(false)
 {
 }
 
-template < typename ID, ID N >
-FeatureAPIHooks<ID,N>::~FeatureAPIHooks()
+template <typename ID, ID N> FeatureAPIHooks<ID, N>::~FeatureAPIHooks()
 {
   this->clear();
 }
 
-template < typename ID, ID N >
+template <typename ID, ID N>
 void
-FeatureAPIHooks<ID,N>::clear()
+FeatureAPIHooks<ID, N>::clear()
 {
   for (int i = 0; i < N; ++i) {
     m_hooks[i].clear();
@@ -232,46 +229,52 @@ FeatureAPIHooks<ID,N>::clear()
   hooks_p = false;
 }
 
-template < typename ID, ID N >
+template <typename ID, ID N>
 void
-FeatureAPIHooks<ID,N>::prepend(ID id, INKContInternal *cont)
+FeatureAPIHooks<ID, N>::prepend(ID id, INKContInternal *cont)
 {
-  hooks_p = true;
-  m_hooks[id].prepend(cont);
+  if (likely(is_valid(id))) {
+    hooks_p = true;
+    m_hooks[id].prepend(cont);
+  }
 }
 
-template < typename ID, ID N >
+template <typename ID, ID N>
 void
-FeatureAPIHooks<ID,N>::append(ID id, INKContInternal *cont)
+FeatureAPIHooks<ID, N>::append(ID id, INKContInternal *cont)
 {
-  hooks_p = true;
-  m_hooks[id].append(cont);
+  if (likely(is_valid(id))) {
+    hooks_p = true;
+    m_hooks[id].append(cont);
+  }
 }
 
-template < typename ID, ID N >
+template <typename ID, ID N>
 APIHook *
-FeatureAPIHooks<ID,N>::get(ID id)
+FeatureAPIHooks<ID, N>::get(ID id) const
 {
-  return m_hooks[id].get();
+  return likely(is_valid(id)) ? m_hooks[id].get() : NULL;
 }
 
-template < typename ID, ID N >
+template <typename ID, ID N>
 void
-FeatureAPIHooks<ID,N>::invoke(ID id, int event, void* data)
+FeatureAPIHooks<ID, N>::invoke(ID id, int event, void *data)
 {
-  m_hooks[id].invoke(event, data);
+  if (likely(is_valid(id))) {
+    m_hooks[id].invoke(event, data);
+  }
 }
 
-template < typename ID, ID N >
+template <typename ID, ID N>
 bool
-FeatureAPIHooks<ID,N>::has_hooks() const
+FeatureAPIHooks<ID, N>::has_hooks() const
 {
   return hooks_p;
 }
 
-template < typename ID, ID N >
+template <typename ID, ID N>
 bool
-FeatureAPIHooks<ID,N>::is_valid(ID id)
+FeatureAPIHooks<ID, N>::is_valid(ID id)
 {
   return 0 <= id && id < N;
 }
@@ -280,25 +283,36 @@ class HttpAPIHooks : public FeatureAPIHooks<TSHttpHookID, TS_HTTP_LAST_HOOK>
 {
 };
 
+typedef enum {
+  TS_SSL_INTERNAL_FIRST_HOOK,
+  TS_VCONN_PRE_ACCEPT_INTERNAL_HOOK = TS_SSL_INTERNAL_FIRST_HOOK,
+  TS_SSL_CERT_INTERNAL_HOOK,
+  TS_SSL_INTERNAL_LAST_HOOK
+} TSSslHookInternalID;
+
+class SslAPIHooks : public FeatureAPIHooks<TSSslHookInternalID, TS_SSL_INTERNAL_LAST_HOOK>
+{
+};
+
 class LifecycleAPIHooks : public FeatureAPIHooks<TSLifecycleHookID, TS_LIFECYCLE_LAST_HOOK>
 {
 };
 
 
-class ConfigUpdateCallback:public Continuation
+class ConfigUpdateCallback : public Continuation
 {
 public:
-  ConfigUpdateCallback(INKContInternal * contp)
-    : Continuation(contp->mutex), m_cont(contp)
+  ConfigUpdateCallback(INKContInternal *contp) : Continuation(contp->mutex), m_cont(contp)
   {
     SET_HANDLER(&ConfigUpdateCallback::event_handler);
   }
 
-  int event_handler(int, void *)
+  int
+  event_handler(int, void *)
   {
     if (m_cont->mutex != NULL) {
       MUTEX_TRY_LOCK(trylock, m_cont->mutex, this_ethread());
-      if (!trylock) {
+      if (!trylock.is_locked()) {
         eventProcessor.schedule_in(this, HRTIME_MSECONDS(10), ET_TASK);
       } else {
         m_cont->handleEvent(TS_EVENT_MGMT_UPDATE, NULL);
@@ -322,18 +336,19 @@ public:
   ConfigUpdateCbTable();
   ~ConfigUpdateCbTable();
 
-  void insert(INKContInternal * contp, const char *name);
+  void insert(INKContInternal *contp, const char *name);
   void invoke(const char *name);
-  void invoke(INKContInternal * contp);
+  void invoke(INKContInternal *contp);
 
 private:
-    InkHashTable * cb_table;
+  InkHashTable *cb_table;
 };
 
 void api_init();
 
 extern HttpAPIHooks *http_global_hooks;
-extern LifecycleAPIHooks* lifecycle_hooks;
+extern LifecycleAPIHooks *lifecycle_hooks;
+extern SslAPIHooks *ssl_hooks;
 extern ConfigUpdateCbTable *global_config_cbs;
 
 #endif /* __INK_API_INTERNAL_H__ */
