@@ -22,13 +22,8 @@
  */
 
 #include <stdio.h>
-// XXX: HP-UX ??? Not part of configure supported hosts
-#if defined(hpux)
-#include <dl.h>
-#endif
 #include "ink_platform.h"
 #include "ink_file.h"
-#include "Compatability.h"
 #include "ParseRules.h"
 #include "I_RecCore.h"
 #include "I_Layout.h"
@@ -37,19 +32,9 @@
 #include "Plugin.h"
 #include "ink_cap.h"
 
-// HPUX:
-//   LD_SHAREDCMD=ld -b
-// SGI:
-//   LD_SHAREDCMD=ld -shared
-// OSF:
-//   LD_SHAREDCMD=ld -shared -all -expect_unresolved "*"
-// Solaris:
-//   LD_SHAREDCMD=ld -G
-
-
 static const char *plugin_dir = ".";
 
-typedef void (*init_func_t) (int argc, char *argv[]);
+typedef void (*init_func_t)(int argc, char *argv[]);
 
 // Plugin registration vars
 //
@@ -66,30 +51,13 @@ DLL<PluginRegInfo> plugin_reg_list;
 PluginRegInfo *plugin_reg_current = NULL;
 
 PluginRegInfo::PluginRegInfo()
-  : plugin_registered(false), plugin_path(NULL), sdk_version(PLUGIN_SDK_VERSION_UNKNOWN),
-    plugin_name(NULL), vendor_name(NULL), support_email(NULL)
-{ }
-
-static void *
-dll_open(const char *path)
+  : plugin_registered(false), plugin_path(NULL), sdk_version(PLUGIN_SDK_VERSION_UNKNOWN), plugin_name(NULL), vendor_name(NULL),
+    support_email(NULL)
 {
-  return (void *) dlopen(path, RTLD_NOW);
 }
 
-static void *
-dll_findsym(void *dlp, const char *name)
-{
-  return (void *) dlsym(dlp, name);
-}
-
-static char *
-dll_error(void * /* dlp ATS_UNUSED */)
-{
-  return (char *) dlerror();
-}
-
-static void
-plugin_load(int argc, char *argv[])
+static bool
+plugin_load(int argc, char *argv[], bool validateOnly)
 {
   char path[PATH_NAME_MAX + 1];
   void *handle;
@@ -97,7 +65,7 @@ plugin_load(int argc, char *argv[])
   PluginRegInfo *plugin_reg_temp;
 
   if (argc < 1) {
-    return;
+    return true;
   }
   ink_filepath_make(path, sizeof(path), plugin_dir, argv[0]);
 
@@ -114,13 +82,18 @@ plugin_load(int argc, char *argv[])
   // elevate the access to read files as root if compiled with capabilities, if not
   // change the effective user to root
   {
+#if TS_USE_POSIX_CAP
     uint32_t elevate_access = 0;
     REC_ReadConfigInteger(elevate_access, "proxy.config.plugin.load_elevated");
     ElevateAccess access(elevate_access != 0);
+#endif /* TS_USE_POSIX_CAP */
 
-    handle = dll_open(path);
+    handle = dlopen(path, RTLD_NOW);
     if (!handle) {
-      Fatal("unable to load '%s': %s", path, dll_error(handle));
+      if (validateOnly) {
+        return false;
+      }
+      Fatal("unable to load '%s': %s", path, dlerror());
     }
 
     // Allocate a new registration structure for the
@@ -129,9 +102,13 @@ plugin_load(int argc, char *argv[])
     plugin_reg_current = new PluginRegInfo;
     plugin_reg_current->plugin_path = ats_strdup(path);
 
-    init = (init_func_t) dll_findsym(handle, "TSPluginInit");
+    init = (init_func_t)dlsym(handle, "TSPluginInit");
     if (!init) {
-      Fatal("unable to find TSPluginInit function '%s': %s", path, dll_error(handle));
+      if (validateOnly) {
+        return false;
+      }
+      Fatal("unable to find TSPluginInit function in '%s': %s", path, dlerror());
+      return false; // this line won't get called since Fatal brings down ATS
     }
 
     init(argc, argv);
@@ -139,6 +116,8 @@ plugin_load(int argc, char *argv[])
 
   plugin_reg_list.push(plugin_reg_current);
   plugin_reg_current = NULL;
+
+  return true;
 }
 
 static char *
@@ -148,7 +127,7 @@ plugin_expand(char *arg)
   char *str = NULL;
 
   if (*arg != '$') {
-    return (char *) NULL;
+    return (char *)NULL;
   }
   // skip the $ character
   arg += 1;
@@ -158,48 +137,44 @@ plugin_expand(char *arg)
   }
 
   switch (data_type) {
-  case RECD_STRING:
-    {
-      RecString str_val;
-      if (RecGetRecordString_Xmalloc(arg, &str_val) != REC_ERR_OKAY) {
-        goto not_found;
-      }
-      return (char *) str_val;
-      break;
+  case RECD_STRING: {
+    RecString str_val;
+    if (RecGetRecordString_Xmalloc(arg, &str_val) != REC_ERR_OKAY) {
+      goto not_found;
     }
-  case RECD_FLOAT:
-    {
-      RecFloat float_val;
-      if (RecGetRecordFloat(arg, &float_val) != REC_ERR_OKAY) {
-        goto not_found;
-      }
-      str = (char *)ats_malloc(128);
-      snprintf(str, 128, "%f", (float) float_val);
-      return str;
-      break;
+    return (char *)str_val;
+    break;
+  }
+  case RECD_FLOAT: {
+    RecFloat float_val;
+    if (RecGetRecordFloat(arg, &float_val) != REC_ERR_OKAY) {
+      goto not_found;
     }
-  case RECD_INT:
-    {
-      RecInt int_val;
-      if (RecGetRecordInt(arg, &int_val) != REC_ERR_OKAY) {
-        goto not_found;
-      }
-      str = (char *)ats_malloc(128);
-      snprintf(str, 128, "%ld", (long int) int_val);
-      return str;
-      break;
+    str = (char *)ats_malloc(128);
+    snprintf(str, 128, "%f", (float)float_val);
+    return str;
+    break;
+  }
+  case RECD_INT: {
+    RecInt int_val;
+    if (RecGetRecordInt(arg, &int_val) != REC_ERR_OKAY) {
+      goto not_found;
     }
-  case RECD_COUNTER:
-    {
-      RecCounter count_val;
-      if (RecGetRecordCounter(arg, &count_val) != REC_ERR_OKAY) {
-        goto not_found;
-      }
-      str = (char *)ats_malloc(128);
-      snprintf(str, 128, "%ld", (long int) count_val);
-      return str;
-      break;
+    str = (char *)ats_malloc(128);
+    snprintf(str, 128, "%ld", (long int)int_val);
+    return str;
+    break;
+  }
+  case RECD_COUNTER: {
+    RecCounter count_val;
+    if (RecGetRecordCounter(arg, &count_val) != REC_ERR_OKAY) {
+      goto not_found;
     }
+    str = (char *)ats_malloc(128);
+    snprintf(str, 128, "%ld", (long int)count_val);
+    return str;
+    break;
+  }
   default:
     goto not_found;
     break;
@@ -211,29 +186,31 @@ not_found:
   return NULL;
 }
 
-void
-plugin_init(void)
+bool
+plugin_init(bool validateOnly)
 {
-  char path[PATH_NAME_MAX + 1];
+  ats_scoped_str path;
   char line[1024], *p;
   char *argv[64];
   char *vars[64];
   int argc;
   int fd;
   int i;
+  bool retVal = true;
   static bool INIT_ONCE = true;
 
   if (INIT_ONCE) {
     api_init();
+    TSConfigDirGet();
     plugin_dir = TSPluginDirGet();
     INIT_ONCE = false;
   }
 
-  Layout::get()->relative_to(path, sizeof(path), Layout::get()->sysconfdir, "plugin.config");
+  path = RecConfigReadConfigPath(NULL, "plugin.config");
   fd = open(path, O_RDONLY);
   if (fd < 0) {
-    Warning("unable to open plugin config file '%s': %d, %s", path, errno, strerror(errno));
-    return;
+    Warning("unable to open plugin config file '%s': %d, %s", (const char *)path, errno, strerror(errno));
+    return false;
   }
 
   while (ink_file_fd_readline(fd, sizeof(line) - 1, line) > 0) {
@@ -251,7 +228,7 @@ plugin_init(void)
       while (*p && ParseRules::is_wslfcr(*p))
         ++p;
       if ((*p == '\0') || (*p == '#'))
-        break;                  // EOL
+        break; // EOL
 
       if (*p == '\"') {
         p += 1;
@@ -285,12 +262,12 @@ plugin_init(void)
       }
     }
 
-    plugin_load(argc, argv);
+    retVal = plugin_load(argc, argv, validateOnly);
 
     for (i = 0; i < argc; i++)
       ats_free(vars[i]);
   }
 
   close(fd);
+  return retVal;
 }
-
