@@ -46,7 +46,7 @@
    sides, in additional this VC's lock.  Additionally, issues like
    watermarks are very hard to deal with.  Since we try to
    to move data by IOBufferData references the efficiency penalty shouldn't
-   be too bad and if it is a big pentaly, a brave soul can reimplement
+   be too bad and if it is a big penalty, a brave soul can reimplement
    to move the data directly without the intermediate buffer.
 
    Locking is difficult issue for this multi-headed beast.  In each
@@ -54,7 +54,7 @@
    the lock from the state machine using the PluginVC.  The read side
    lock & the write side lock must be the same.  The regular net processor has
    this constraint as well.  In order to handle scheduling of retry events cleanly,
-   we have two event poitners, one for each lock.  sm_lock_retry_event can only
+   we have two event pointers, one for each lock.  sm_lock_retry_event can only
    be changed while holding the using state machine's lock and
    core_lock_retry_event can only be manipulated while holding the PluginVC's
    lock.  On entry to PluginVC::main_handler, we obtain all the locks
@@ -64,7 +64,7 @@
    exclusively in the later parts of the handler and we will
    be free from do_io or reenable calls on the PluginVC.
 
-   The assumption is made (conistant with IO Core spec) that any close,
+   The assumption is made (consistent with IO Core spec) that any close,
    shutdown, reenable, or do_io_{read,write) operation is done by the callee
    while holding the lock for that side of the operation.
 
@@ -80,21 +80,18 @@
 #define PVC_DEFAULT_MAX_BYTES 32768
 #define MIN_BLOCK_TRANSFER_BYTES 128
 
-#define EVENT_PTR_LOCKED (void*) 0x1
-#define EVENT_PTR_CLOSED (void*) 0x2
+#define EVENT_PTR_LOCKED (void *)0x1
+#define EVENT_PTR_CLOSED (void *)0x2
 
-#define PVC_TYPE    ((vc_type == PLUGIN_VC_ACTIVE) ? "Active" : "Passive")
-#define PVC_ID      (core_obj? core_obj->id : (unsigned)-1)
+#define PVC_TYPE ((vc_type == PLUGIN_VC_ACTIVE) ? "Active" : "Passive")
 
-PluginVC::PluginVC():
-NetVConnection(),
-magic(PLUGIN_VC_MAGIC_ALIVE), vc_type(PLUGIN_VC_UNKNOWN), core_obj(NULL),
-other_side(NULL), read_state(), write_state(),
-need_read_process(false), need_write_process(false),
-closed(false), sm_lock_retry_event(NULL), core_lock_retry_event(NULL),
-deletable(false), reentrancy_count(0), active_timeout(0), active_event(NULL),
-inactive_timeout(0), inactive_timeout_at(0), inactive_event(NULL)
+PluginVC::PluginVC(PluginVCCore *core_obj)
+  : NetVConnection(), magic(PLUGIN_VC_MAGIC_ALIVE), vc_type(PLUGIN_VC_UNKNOWN), core_obj(core_obj), other_side(NULL), read_state(),
+    write_state(), need_read_process(false), need_write_process(false), closed(false), sm_lock_retry_event(NULL),
+    core_lock_retry_event(NULL), deletable(false), reentrancy_count(0), active_timeout(0), active_event(NULL), inactive_timeout(0),
+    inactive_timeout_at(0), inactive_event(NULL), plugin_tag(NULL), plugin_id(0)
 {
+  ink_assert(core_obj != NULL);
   SET_HANDLER(&PluginVC::main_handler);
 }
 
@@ -106,15 +103,14 @@ PluginVC::~PluginVC()
 int
 PluginVC::main_handler(int event, void *data)
 {
-
-  Debug("pvc_event", "[%u] %s: Received event %d", PVC_ID, PVC_TYPE, event);
+  Debug("pvc_event", "[%u] %s: Received event %d", core_obj->id, PVC_TYPE, event);
 
   ink_release_assert(event == EVENT_INTERVAL || event == EVENT_IMMEDIATE);
   ink_release_assert(magic == PLUGIN_VC_MAGIC_ALIVE);
   ink_assert(!deletable);
   ink_assert(data != NULL);
 
-  Event *call_event = (Event *) data;
+  Event *call_event = (Event *)data;
   EThread *my_ethread = mutex->thread_holding;
   ink_release_assert(my_ethread != NULL);
 
@@ -190,10 +186,10 @@ PluginVC::main_handler(int event, void *data)
   reentrancy_count++;
 
   if (call_event == active_event) {
-    process_timeout(call_event, VC_EVENT_ACTIVE_TIMEOUT, &active_event);
+    process_timeout(&active_event, VC_EVENT_ACTIVE_TIMEOUT);
   } else if (call_event == inactive_event) {
     if (inactive_timeout_at && inactive_timeout_at < ink_get_hrtime()) {
-      process_timeout(call_event, VC_EVENT_INACTIVITY_TIMEOUT, &inactive_event);
+      process_timeout(&inactive_event, VC_EVENT_INACTIVITY_TIMEOUT);
       call_event->cancel();
     }
   } else {
@@ -211,7 +207,6 @@ PluginVC::main_handler(int event, void *data)
     if (need_write_process && !closed) {
       process_write_side(false);
     }
-
   }
 
   reentrancy_count--;
@@ -231,9 +226,8 @@ PluginVC::main_handler(int event, void *data)
 }
 
 VIO *
-PluginVC::do_io_read(Continuation * c, int64_t nbytes, MIOBuffer * buf)
+PluginVC::do_io_read(Continuation *c, int64_t nbytes, MIOBuffer *buf)
 {
-
   ink_assert(!closed);
   ink_assert(magic == PLUGIN_VC_MAGIC_ALIVE);
 
@@ -249,10 +243,10 @@ PluginVC::do_io_read(Continuation * c, int64_t nbytes, MIOBuffer * buf)
   read_state.vio._cont = c;
   read_state.vio.nbytes = nbytes;
   read_state.vio.ndone = 0;
-  read_state.vio.vc_server = (VConnection *) this;
+  read_state.vio.vc_server = (VConnection *)this;
   read_state.vio.op = VIO::READ;
 
-  Debug("pvc", "[%u] %s: do_io_read for %" PRId64" bytes", PVC_ID, PVC_TYPE, nbytes);
+  Debug("pvc", "[%u] %s: do_io_read for %" PRId64 " bytes", core_obj->id, PVC_TYPE, nbytes);
 
   // Since reentrant callbacks are not allowed on from do_io
   //   functions schedule ourselves get on a different stack
@@ -263,9 +257,8 @@ PluginVC::do_io_read(Continuation * c, int64_t nbytes, MIOBuffer * buf)
 }
 
 VIO *
-PluginVC::do_io_write(Continuation * c, int64_t nbytes, IOBufferReader * abuffer, bool owner)
+PluginVC::do_io_write(Continuation *c, int64_t nbytes, IOBufferReader *abuffer, bool owner)
 {
-
   ink_assert(!closed);
   ink_assert(magic == PLUGIN_VC_MAGIC_ALIVE);
 
@@ -278,14 +271,14 @@ PluginVC::do_io_write(Continuation * c, int64_t nbytes, IOBufferReader * abuffer
 
   // Note: we set vio.op last because process_write_side looks at it to
   //  tell if the VConnection is active.
-  write_state.vio.mutex = c->mutex;
+  write_state.vio.mutex = c ? c->mutex : this->mutex;
   write_state.vio._cont = c;
   write_state.vio.nbytes = nbytes;
   write_state.vio.ndone = 0;
-  write_state.vio.vc_server = (VConnection *) this;
+  write_state.vio.vc_server = (VConnection *)this;
   write_state.vio.op = VIO::WRITE;
 
-  Debug("pvc", "[%u] %s: do_io_write for %" PRId64" bytes", PVC_ID, PVC_TYPE, nbytes);
+  Debug("pvc", "[%u] %s: do_io_write for %" PRId64 " bytes", core_obj->id, PVC_TYPE, nbytes);
 
   // Since reentrant callbacks are not allowed on from do_io
   //   functions schedule ourselves get on a different stack
@@ -296,14 +289,13 @@ PluginVC::do_io_write(Continuation * c, int64_t nbytes, IOBufferReader * abuffer
 }
 
 void
-PluginVC::reenable(VIO * vio)
+PluginVC::reenable(VIO *vio)
 {
-
   ink_assert(!closed);
   ink_assert(magic == PLUGIN_VC_MAGIC_ALIVE);
   ink_assert(vio->mutex->thread_holding == this_ethread());
 
-  Debug("pvc", "[%u] %s: reenable %s", PVC_ID, PVC_TYPE, (vio->op == VIO::WRITE) ? "Write" : "Read");
+  Debug("pvc", "[%u] %s: reenable %s", core_obj->id, PVC_TYPE, (vio->op == VIO::WRITE) ? "Write" : "Read");
 
   if (vio->op == VIO::WRITE) {
     ink_assert(vio == &write_state.vio);
@@ -317,17 +309,16 @@ PluginVC::reenable(VIO * vio)
 }
 
 void
-PluginVC::reenable_re(VIO * vio)
+PluginVC::reenable_re(VIO *vio)
 {
-
   ink_assert(!closed);
   ink_assert(magic == PLUGIN_VC_MAGIC_ALIVE);
   ink_assert(vio->mutex->thread_holding == this_ethread());
 
-  Debug("pvc", "[%u] %s: reenable_re %s", PVC_ID, PVC_TYPE, (vio->op == VIO::WRITE) ? "Write" : "Read");
+  Debug("pvc", "[%u] %s: reenable_re %s", core_obj->id, PVC_TYPE, (vio->op == VIO::WRITE) ? "Write" : "Read");
 
   MUTEX_TRY_LOCK(lock, this->mutex, this_ethread());
-  if (!lock) {
+  if (!lock.is_locked()) {
     if (vio->op == VIO::WRITE) {
       need_write_process = true;
     } else {
@@ -365,7 +356,7 @@ PluginVC::do_io_close(int /* flag ATS_UNUSED */)
   ink_assert(closed == false);
   ink_assert(magic == PLUGIN_VC_MAGIC_ALIVE);
 
-  Debug("pvc", "[%u] %s: do_io_close", PVC_ID, PVC_TYPE);
+  Debug("pvc", "[%u] %s: do_io_close", core_obj->id, PVC_TYPE);
 
   if (reentrancy_count > 0) {
     // Do nothing since dealloacting ourselves
@@ -378,7 +369,7 @@ PluginVC::do_io_close(int /* flag ATS_UNUSED */)
 
   MUTEX_TRY_LOCK(lock, mutex, this_ethread());
 
-  if (!lock) {
+  if (!lock.is_locked()) {
     setup_event_cb(PVC_LOCK_RETRY_TIME, &sm_lock_retry_event);
     closed = true;
     return;
@@ -392,7 +383,6 @@ PluginVC::do_io_close(int /* flag ATS_UNUSED */)
 void
 PluginVC::do_io_shutdown(ShutdownHowTo_t howto)
 {
-
   ink_assert(!closed);
   ink_assert(magic == PLUGIN_VC_MAGIC_ALIVE);
 
@@ -427,9 +417,8 @@ PluginVC::do_io_shutdown(ShutdownHowTo_t howto)
 // Returns number of bytes transfered
 //
 int64_t
-PluginVC::transfer_bytes(MIOBuffer * transfer_to, IOBufferReader * transfer_from, int64_t act_on)
+PluginVC::transfer_bytes(MIOBuffer *transfer_to, IOBufferReader *transfer_from, int64_t act_on)
 {
-
   int64_t total_added = 0;
 
   ink_assert(act_on <= transfer_from->read_avail());
@@ -478,7 +467,6 @@ PluginVC::transfer_bytes(MIOBuffer * transfer_to, IOBufferReader * transfer_from
 void
 PluginVC::process_write_side(bool other_side_call)
 {
-
   ink_assert(!deletable);
   ink_assert(magic == PLUGIN_VC_MAGIC_ALIVE);
 
@@ -493,15 +481,15 @@ PluginVC::process_write_side(bool other_side_call)
   EThread *my_ethread = mutex->thread_holding;
   ink_assert(my_ethread != NULL);
   MUTEX_TRY_LOCK(lock, write_state.vio.mutex, my_ethread);
-  if (!lock) {
-    Debug("pvc_event", "[%u] %s: process_write_side lock miss, retrying", PVC_ID, PVC_TYPE);
+  if (!lock.is_locked()) {
+    Debug("pvc_event", "[%u] %s: process_write_side lock miss, retrying", core_obj->id, PVC_TYPE);
 
     need_write_process = true;
     setup_event_cb(PVC_LOCK_RETRY_TIME, &core_lock_retry_event);
     return;
   }
 
-  Debug("pvc", "[%u] %s: process_write_side", PVC_ID, PVC_TYPE);
+  Debug("pvc", "[%u] %s: process_write_side", core_obj->id, PVC_TYPE);
   need_write_process = false;
 
 
@@ -515,7 +503,7 @@ PluginVC::process_write_side(bool other_side_call)
   int64_t bytes_avail = reader->read_avail();
   int64_t act_on = MIN(bytes_avail, ntodo);
 
-  Debug("pvc", "[%u] %s: process_write_side; act_on %" PRId64"", PVC_ID, PVC_TYPE, act_on);
+  Debug("pvc", "[%u] %s: process_write_side; act_on %" PRId64 "", core_obj->id, PVC_TYPE, act_on);
 
   if (other_side->closed || other_side->read_state.shutdown) {
     write_state.vio._cont->handleEvent(VC_EVENT_ERROR, &write_state.vio);
@@ -535,7 +523,7 @@ PluginVC::process_write_side(bool other_side_call)
   //
   int64_t buf_space = PVC_DEFAULT_MAX_BYTES - core_buffer->max_read_avail();
   if (buf_space <= 0) {
-    Debug("pvc", "[%u] %s: process_write_side no buffer space", PVC_ID, PVC_TYPE);
+    Debug("pvc", "[%u] %s: process_write_side no buffer space", core_obj->id, PVC_TYPE);
     return;
   }
   act_on = MIN(act_on, buf_space);
@@ -545,13 +533,13 @@ PluginVC::process_write_side(bool other_side_call)
     // Couldn't actually get the buffer space.  This only
     //   happens on small transfers with the above
     //   PVC_DEFAULT_MAX_BYTES factor doesn't apply
-    Debug("pvc", "[%u] %s: process_write_side out of buffer space", PVC_ID, PVC_TYPE);
+    Debug("pvc", "[%u] %s: process_write_side out of buffer space", core_obj->id, PVC_TYPE);
     return;
   }
 
   write_state.vio.ndone += added;
 
-  Debug("pvc", "[%u] %s: process_write_side; added %" PRId64"", PVC_ID, PVC_TYPE, added);
+  Debug("pvc", "[%u] %s: process_write_side; added %" PRId64 "", core_obj->id, PVC_TYPE, added);
 
   if (write_state.vio.ntodo() == 0) {
     write_state.vio._cont->handleEvent(VC_EVENT_WRITE_COMPLETE, &write_state.vio);
@@ -583,44 +571,48 @@ PluginVC::process_write_side(bool other_side_call)
 void
 PluginVC::process_read_side(bool other_side_call)
 {
-
   ink_assert(!deletable);
   ink_assert(magic == PLUGIN_VC_MAGIC_ALIVE);
 
   // TODO: Never used??
-  //MIOBuffer *core_buffer;
+  // MIOBuffer *core_buffer;
 
   IOBufferReader *core_reader;
 
   if (vc_type == PLUGIN_VC_ACTIVE) {
-    //core_buffer = core_obj->p_to_a_buffer;
+    // core_buffer = core_obj->p_to_a_buffer;
     core_reader = core_obj->p_to_a_reader;
   } else {
     ink_assert(vc_type == PLUGIN_VC_PASSIVE);
-    //core_buffer = core_obj->a_to_p_buffer;
+    // core_buffer = core_obj->a_to_p_buffer;
     core_reader = core_obj->a_to_p_reader;
   }
 
   need_read_process = false;
 
-  if (read_state.vio.op != VIO::READ || closed || read_state.shutdown) {
+  if (read_state.vio.op != VIO::READ || closed) {
     return;
   }
   // Acquire the lock of the read side continuation
   EThread *my_ethread = mutex->thread_holding;
   ink_assert(my_ethread != NULL);
   MUTEX_TRY_LOCK(lock, read_state.vio.mutex, my_ethread);
-  if (!lock) {
-    Debug("pvc_event", "[%u] %s: process_read_side lock miss, retrying", PVC_ID, PVC_TYPE);
+  if (!lock.is_locked()) {
+    Debug("pvc_event", "[%u] %s: process_read_side lock miss, retrying", core_obj->id, PVC_TYPE);
 
     need_read_process = true;
     setup_event_cb(PVC_LOCK_RETRY_TIME, &core_lock_retry_event);
     return;
   }
 
-  Debug("pvc", "[%u] %s: process_read_side", PVC_ID, PVC_TYPE);
+  Debug("pvc", "[%u] %s: process_read_side", core_obj->id, PVC_TYPE);
   need_read_process = false;
 
+  // Check read_state.shutdown after the lock has been obtained.
+  if (read_state.shutdown) {
+    return;
+  }
+
   // Check the state of our read buffer as well as ntodo
   int64_t ntodo = read_state.vio.ntodo();
   if (ntodo == 0) {
@@ -630,7 +622,7 @@ PluginVC::process_read_side(bool other_side_call)
   int64_t bytes_avail = core_reader->read_avail();
   int64_t act_on = MIN(bytes_avail, ntodo);
 
-  Debug("pvc", "[%u] %s: process_read_side; act_on %" PRId64"", PVC_ID, PVC_TYPE, act_on);
+  Debug("pvc", "[%u] %s: process_read_side; act_on %" PRId64 "", core_obj->id, PVC_TYPE, act_on);
 
   if (act_on <= 0) {
     if (other_side->closed || other_side->write_state.shutdown) {
@@ -647,7 +639,7 @@ PluginVC::process_read_side(bool other_side_call)
   water_mark = MAX(water_mark, PVC_DEFAULT_MAX_BYTES);
   int64_t buf_space = water_mark - output_buffer->max_read_avail();
   if (buf_space <= 0) {
-    Debug("pvc", "[%u] %s: process_read_side no buffer space", PVC_ID, PVC_TYPE);
+    Debug("pvc", "[%u] %s: process_read_side no buffer space", core_obj->id, PVC_TYPE);
     return;
   }
   act_on = MIN(act_on, buf_space);
@@ -657,13 +649,13 @@ PluginVC::process_read_side(bool other_side_call)
     // Couldn't actually get the buffer space.  This only
     //   happens on small transfers with the above
     //   PVC_DEFAULT_MAX_BYTES factor doesn't apply
-    Debug("pvc", "[%u] %s: process_read_side out of buffer space", PVC_ID, PVC_TYPE);
+    Debug("pvc", "[%u] %s: process_read_side out of buffer space", core_obj->id, PVC_TYPE);
     return;
   }
 
   read_state.vio.ndone += added;
 
-  Debug("pvc", "[%u] %s: process_read_side; added %" PRId64"", PVC_ID, PVC_TYPE, added);
+  Debug("pvc", "[%u] %s: process_read_side; added %" PRId64 "", core_obj->id, PVC_TYPE, added);
 
   if (read_state.vio.ntodo() == 0) {
     read_state.vio._cont->handleEvent(VC_EVENT_READ_COMPLETE, &read_state.vio);
@@ -694,10 +686,9 @@ PluginVC::process_read_side(bool other_side_call)
 void
 PluginVC::process_close()
 {
-
   ink_assert(magic == PLUGIN_VC_MAGIC_ALIVE);
 
-  Debug("pvc", "[%u] %s: process_close", PVC_ID, PVC_TYPE);
+  Debug("pvc", "[%u] %s: process_close", core_obj->id, PVC_TYPE);
 
   if (!deletable) {
     deletable = true;
@@ -736,11 +727,11 @@ PluginVC::process_close()
   core_obj->attempt_delete();
 }
 
-// void PluginVC::process_timeout(Event* e, int event_to_send, Event** our_eptr)
+// void PluginVC::process_timeout(Event** e, int event_to_send, Event** our_eptr)
 //
 //   Handles sending timeout event to the VConnection.  e is the event we got
-//     which indicats the timeout.  event_to_send is the event to the
-//     vc user.  Our_eptr is a pointer our event either inactive_event,
+//     which indicates the timeout.  event_to_send is the event to the
+//     vc user.  e is a pointer to either inactive_event,
 //     or active_event.  If we successfully send the timeout to vc user,
 //     we clear the pointer, otherwise we reschedule it.
 //
@@ -748,29 +739,28 @@ PluginVC::process_close()
 //      touch any state after making the call back
 //
 void
-PluginVC::process_timeout(Event * e, int event_to_send, Event ** our_eptr)
+PluginVC::process_timeout(Event **e, int event_to_send)
 {
-
-  ink_assert(e = *our_eptr);
+  ink_assert(*e == inactive_event || *e == active_event);
 
   if (read_state.vio.op == VIO::READ && !read_state.shutdown && read_state.vio.ntodo() > 0) {
-    MUTEX_TRY_LOCK(lock, read_state.vio.mutex, e->ethread);
-    if (!lock) {
-      e->schedule_in(PVC_LOCK_RETRY_TIME);
+    MUTEX_TRY_LOCK(lock, read_state.vio.mutex, (*e)->ethread);
+    if (!lock.is_locked()) {
+      (*e)->schedule_in(PVC_LOCK_RETRY_TIME);
       return;
     }
-    *our_eptr = NULL;
+    *e = NULL;
     read_state.vio._cont->handleEvent(event_to_send, &read_state.vio);
   } else if (write_state.vio.op == VIO::WRITE && !write_state.shutdown && write_state.vio.ntodo() > 0) {
-    MUTEX_TRY_LOCK(lock, write_state.vio.mutex, e->ethread);
-    if (!lock) {
-      e->schedule_in(PVC_LOCK_RETRY_TIME);
+    MUTEX_TRY_LOCK(lock, write_state.vio.mutex, (*e)->ethread);
+    if (!lock.is_locked()) {
+      (*e)->schedule_in(PVC_LOCK_RETRY_TIME);
       return;
     }
-    *our_eptr = NULL;
+    *e = NULL;
     write_state.vio._cont->handleEvent(event_to_send, &write_state.vio);
   } else {
-    *our_eptr = NULL;
+    *e = NULL;
   }
 }
 
@@ -778,8 +768,8 @@ void
 PluginVC::update_inactive_time()
 {
   if (inactive_event && inactive_timeout) {
-    //inactive_event->cancel();
-    //inactive_event = eventProcessor.schedule_in(this, inactive_timeout);
+    // inactive_event->cancel();
+    // inactive_event = eventProcessor.schedule_in(this, inactive_timeout);
     inactive_timeout_at = ink_get_hrtime() + inactive_timeout;
   }
 }
@@ -791,31 +781,23 @@ PluginVC::update_inactive_time()
 //      locking issues
 //
 void
-PluginVC::setup_event_cb(ink_hrtime in, Event ** e_ptr)
+PluginVC::setup_event_cb(ink_hrtime in, Event **e_ptr)
 {
-
   ink_assert(magic == PLUGIN_VC_MAGIC_ALIVE);
 
   if (*e_ptr == NULL) {
-
     // We locked the pointer so we can now allocate an event
     //   to call us back
     if (in == 0) {
-      if(this_ethread()->tt == REGULAR) {
-	 *e_ptr = this_ethread()->schedule_imm_local(this);
+      if (this_ethread()->tt == REGULAR) {
+        *e_ptr = this_ethread()->schedule_imm_local(this);
+      } else {
+        *e_ptr = eventProcessor.schedule_imm(this);
       }
-      else
-      {
-         *e_ptr = eventProcessor.schedule_imm(this);
-      }
-    } 
-    else 
-    {
-      if(this_ethread()->tt == REGULAR) {
-        *e_ptr = this_ethread()->schedule_in_local(this,in);
-      }
-      else
-      {
+    } else {
+      if (this_ethread()->tt == REGULAR) {
+        *e_ptr = this_ethread()->schedule_in_local(this, in);
+      } else {
         *e_ptr = eventProcessor.schedule_in(this, in);
       }
     }
@@ -882,6 +864,18 @@ PluginVC::get_inactivity_timeout()
   return inactive_timeout;
 }
 
+void
+PluginVC::add_to_keep_alive_lru()
+{
+  // do nothing
+}
+
+void
+PluginVC::remove_from_keep_alive_lru()
+{
+  // do nothing
+}
+
 SOCKET
 PluginVC::get_socket()
 {
@@ -893,10 +887,10 @@ PluginVC::set_local_addr()
 {
   if (vc_type == PLUGIN_VC_ACTIVE) {
     ats_ip_copy(&local_addr, &core_obj->active_addr_struct);
-//    local_addr = core_obj->active_addr_struct;
+    //    local_addr = core_obj->active_addr_struct;
   } else {
     ats_ip_copy(&local_addr, &core_obj->passive_addr_struct);
-//    local_addr = core_obj->passive_addr_struct;
+    //    local_addr = core_obj->passive_addr_struct;
   }
 }
 
@@ -931,20 +925,20 @@ PluginVC::get_data(int id, void *data)
   switch (id) {
   case PLUGIN_VC_DATA_LOCAL:
     if (vc_type == PLUGIN_VC_ACTIVE) {
-      *(void **) data = core_obj->active_data;
+      *(void **)data = core_obj->active_data;
     } else {
-      *(void **) data = core_obj->passive_data;
+      *(void **)data = core_obj->passive_data;
     }
     return true;
   case PLUGIN_VC_DATA_REMOTE:
     if (vc_type == PLUGIN_VC_ACTIVE) {
-      *(void **) data = core_obj->passive_data;
+      *(void **)data = core_obj->passive_data;
     } else {
-      *(void **) data = core_obj->active_data;
+      *(void **)data = core_obj->active_data;
     }
     return true;
   default:
-    *(void **) data = NULL;
+    *(void **)data = NULL;
     return false;
   }
 }
@@ -974,8 +968,7 @@ PluginVC::set_data(int id, void *data)
 
 // PluginVCCore
 
-vint32
-  PluginVCCore::nextid = 0;
+vint32 PluginVCCore::nextid = 0;
 
 PluginVCCore::~PluginVCCore()
 {
@@ -1018,7 +1011,6 @@ PluginVCCore::init()
 void
 PluginVCCore::destroy()
 {
-
   Debug("pvc", "[%u] Destroying PluginVCCore at %p", id, this);
 
   ink_assert(active_vc.closed == true || !connected);
@@ -1048,7 +1040,7 @@ PluginVCCore::destroy()
 }
 
 void
-PluginVCCore::set_accept_cont(Continuation * c)
+PluginVCCore::set_accept_cont(Continuation *c)
 {
   connect_to = c;
   // FIX ME - must return action
@@ -1057,7 +1049,6 @@ PluginVCCore::set_accept_cont(Continuation * c)
 PluginVC *
 PluginVCCore::connect()
 {
-
   // Make sure there is another end to connect to
   if (connect_to == NULL) {
     return NULL;
@@ -1070,9 +1061,8 @@ PluginVCCore::connect()
 }
 
 Action *
-PluginVCCore::connect_re(Continuation * c)
+PluginVCCore::connect_re(Continuation *c)
 {
-
   // Make sure there is another end to connect to
   if (connect_to == NULL) {
     return NULL;
@@ -1100,7 +1090,7 @@ PluginVCCore::state_send_accept_failed(int /* event ATS_UNUSED */, void * /* dat
 {
   MUTEX_TRY_LOCK(lock, connect_to->mutex, this_ethread());
 
-  if (lock) {
+  if (lock.is_locked()) {
     connect_to->handleEvent(NET_EVENT_ACCEPT_FAILED, NULL);
     destroy();
   } else {
@@ -1109,7 +1099,6 @@ PluginVCCore::state_send_accept_failed(int /* event ATS_UNUSED */, void * /* dat
   }
 
   return 0;
-
 }
 
 int
@@ -1117,7 +1106,7 @@ PluginVCCore::state_send_accept(int /* event ATS_UNUSED */, void * /* data ATS_U
 {
   MUTEX_TRY_LOCK(lock, connect_to->mutex, this_ethread());
 
-  if (lock) {
+  if (lock.is_locked()) {
     connect_to->handleEvent(NET_EVENT_ACCEPT, &passive_vc);
   } else {
     SET_HANDLER(&PluginVCCore::state_send_accept);
@@ -1135,7 +1124,6 @@ PluginVCCore::state_send_accept(int /* event ATS_UNUSED */, void * /* data ATS_U
 void
 PluginVCCore::attempt_delete()
 {
-
   if (active_vc.deletable) {
     if (passive_vc.deletable) {
       destroy();
@@ -1165,7 +1153,7 @@ PluginVCCore::set_passive_addr(in_addr_t ip, int port)
 }
 
 void
-PluginVCCore::set_passive_addr(sockaddr const* ip)
+PluginVCCore::set_passive_addr(sockaddr const *ip)
 {
   passive_addr_struct.assign(ip);
 }
@@ -1177,7 +1165,7 @@ PluginVCCore::set_active_addr(in_addr_t ip, int port)
 }
 
 void
-PluginVCCore::set_active_addr(sockaddr const* ip)
+PluginVCCore::set_active_addr(sockaddr const *ip)
 {
   active_addr_struct.assign(ip);
 }
@@ -1208,7 +1196,7 @@ PluginVCCore::set_plugin_id(int64_t id)
 }
 
 void
-PluginVCCore::set_plugin_tag(char const* tag)
+PluginVCCore::set_plugin_tag(char const *tag)
 {
   passive_vc.plugin_tag = active_vc.plugin_tag = tag;
 }
@@ -1220,13 +1208,13 @@ PluginVCCore::set_plugin_tag(char const* tag)
  **************************************************************/
 
 #if TS_HAS_TESTS
-class PVCTestDriver:public NetTestDriver
+class PVCTestDriver : public NetTestDriver
 {
 public:
   PVCTestDriver();
   ~PVCTestDriver();
 
-  void start_tests(RegressionTest * r_arg, int *pstatus_arg);
+  void start_tests(RegressionTest *r_arg, int *pstatus_arg);
   void run_next_test();
   int main_handler(int event, void *data);
 
@@ -1235,8 +1223,7 @@ private:
   unsigned completions_received;
 };
 
-PVCTestDriver::PVCTestDriver():
-NetTestDriver(), i(0), completions_received(0)
+PVCTestDriver::PVCTestDriver() : NetTestDriver(), i(0), completions_received(0)
 {
 }
 
@@ -1246,7 +1233,7 @@ PVCTestDriver::~PVCTestDriver()
 }
 
 void
-PVCTestDriver::start_tests(RegressionTest * r_arg, int *pstatus_arg)
+PVCTestDriver::start_tests(RegressionTest *r_arg, int *pstatus_arg)
 {
   mutex = new_ProxyMutex();
   MUTEX_TRY_LOCK(lock, mutex, this_ethread());
@@ -1262,7 +1249,6 @@ PVCTestDriver::start_tests(RegressionTest * r_arg, int *pstatus_arg)
 void
 PVCTestDriver::run_next_test()
 {
-
   unsigned a_index = i * 2;
   unsigned p_index = a_index + 1;
 
@@ -1304,7 +1290,7 @@ PVCTestDriver::main_handler(int /* event ATS_UNUSED */, void * /* data ATS_UNUSE
   return 0;
 }
 
-EXCLUSIVE_REGRESSION_TEST(PVC) (RegressionTest * t, int /* atype ATS_UNUSED */, int *pstatus)
+EXCLUSIVE_REGRESSION_TEST(PVC)(RegressionTest *t, int /* atype ATS_UNUSED */, int *pstatus)
 {
   PVCTestDriver *driver = new PVCTestDriver;
   driver->start_tests(t, pstatus);
