@@ -21,7 +21,7 @@
   limitations under the License.
  */
 
-#if !defined (_TestPreProc_h_)
+#if !defined(_TestPreProc_h_)
 #define _TestPreProc_h_
 
 class IOBuffer;
@@ -29,18 +29,19 @@ class IOBuffer;
 class RequestInput
 {
 public:
-  RequestInput(const char *str, IOBuffer * cb);
-   ~RequestInput();
+  RequestInput(const char *str, IOBuffer *cb);
+  ~RequestInput();
 
   void run();
-  bool isDone() const
+  bool
+  isDone() const
   {
     return (m_len == 0);
   }
 
 private:
-    RequestInput(const RequestInput &);
-    RequestInput & operator =(const RequestInput &);
+  RequestInput(const RequestInput &);
+  RequestInput &operator=(const RequestInput &);
 
 
   char *m_sp;
