@@ -39,20 +39,17 @@
 /////////////////////////////////////////////////////////
 // Update subsystem specific events
 /////////////////////////////////////////////////////////
-#define UPDATE_EVENT_SUCCESS 		(UPDATE_EVENT_EVENTS_START+0)
-#define UPDATE_EVENT_SUCCESS_NOACTION 	(UPDATE_EVENT_EVENTS_START+1)
-#define UPDATE_EVENT_FAILED		(UPDATE_EVENT_EVENTS_START+2)
+#define UPDATE_EVENT_SUCCESS (UPDATE_EVENT_EVENTS_START + 0)
+#define UPDATE_EVENT_SUCCESS_NOACTION (UPDATE_EVENT_EVENTS_START + 1)
+#define UPDATE_EVENT_FAILED (UPDATE_EVENT_EVENTS_START + 2)
 
-#define MAX_UPDATE_EVENT		UPDATE_EVENT_FAILED
+#define MAX_UPDATE_EVENT UPDATE_EVENT_FAILED
 
-#define IS_UPDATE_EVENT(_e) \
-	( ( ((_e) >= UPDATE_EVENT_EVENTS_START) && \
-	    ((_e) <= MAX_UPDATE_EVENT) ) ? 1 : 0 )
+#define IS_UPDATE_EVENT(_e) ((((_e) >= UPDATE_EVENT_EVENTS_START) && ((_e) <= MAX_UPDATE_EVENT)) ? 1 : 0)
 
 extern RecRawStatBlock *update_rsb;
 
-enum
-{
+enum {
   update_successes_stat,
   update_no_actions_stat,
   update_fails_stat,
@@ -65,40 +62,47 @@ enum
 //////////////////////////////////////////////////////////////////////
 // UpdateConfigParams -- Global subsystem configuration parameters
 //////////////////////////////////////////////////////////////////////
-class UpdateConfigParams:public RefCountObj
+class UpdateConfigParams : public RefCountObj
 {
 public:
   UpdateConfigParams();
   UpdateConfigParams(UpdateConfigParams &);
   ~UpdateConfigParams();
-  UpdateConfigParams & operator=(UpdateConfigParams &);
+  UpdateConfigParams &operator=(UpdateConfigParams &);
   int operator==(UpdateConfigParams &);
 
-  int IsEnabled()
+  int
+  IsEnabled()
   {
     return _enabled;
   }
-  int ImmediateUpdate()
+  int
+  ImmediateUpdate()
   {
     return _immediate_update;
   }
-  int RetryCount()
+  int
+  RetryCount()
   {
     return _retry_count;
   }
-  int RetryInterval()
+  int
+  RetryInterval()
   {
     return _retry_interval;
   }
-  int ConcurrentUpdates()
+  int
+  ConcurrentUpdates()
   {
     return _concurrent_updates;
   }
-  int MaxUpdateSM()
+  int
+  MaxUpdateSM()
   {
     return _max_update_state_machines;
   }
-  int MaxMemoryUsageMB()
+  int
+  MaxMemoryUsageMB()
   {
     return _memory_use_in_mb;
   }
@@ -124,11 +128,13 @@ public:
   UpdateEntry();
   ~UpdateEntry();
 
-  enum
-  {
-    MIN_OFFSET_HOUR = 0, MAX_OFFSET_HOUR = 23,
-    MIN_INTERVAL = 0, MAX_INTERVAL = 86400,
-    MIN_DEPTH = 0, MAX_DEPTH = 128,
+  enum {
+    MIN_OFFSET_HOUR = 0,
+    MAX_OFFSET_HOUR = 23,
+    MIN_INTERVAL = 0,
+    MAX_INTERVAL = 86400,
+    MIN_DEPTH = 0,
+    MAX_DEPTH = 128,
     SECONDS_PER_HOUR = 3600,
     SECONDS_PER_MIN = 60
   };
@@ -187,13 +193,13 @@ public:
   int _scheme_index;
   int _update_event_status;
 
-    Ptr<UpdateConfigList> _indirect_list;
+  Ptr<UpdateConfigList> _indirect_list;
 };
 
 /////////////////////////////////////////////////////////////
 // UpdateConfigList -- Container for UpdateEntry objects
 /////////////////////////////////////////////////////////////
-class UpdateConfigList:public RefCountObj
+class UpdateConfigList : public RefCountObj
 {
 public:
   UpdateConfigList();
@@ -203,19 +209,20 @@ public:
   UpdateEntry *Remove();
   void AddPending(UpdateEntry *);
   UpdateEntry *RemovePending();
-  int Entries()
+  int
+  Entries()
   {
     return _entry_q_elements;
   }
-  int PendingEntries()
+  int
+  PendingEntries()
   {
     return _pending_q_elements;
   }
 
 public:
-  enum
-  {
-    HASH_TABLE_SIZE = 4096
+  enum {
+    HASH_TABLE_SIZE = 4096,
   };
   int _entry_q_elements;
   Queue<UpdateEntry> _entry_q;
@@ -238,7 +245,7 @@ public:
   int start();
 
 private:
-    UpdateConfigManager * _CM;
+  UpdateConfigManager *_CM;
   UpdateScheduler *_SCH;
 };
 
@@ -248,9 +255,9 @@ extern UpdateManager updateManager;
 // UpdateConfigManager -- Handle Update subsystem global configuration
 //                        and URL list updates
 //////////////////////////////////////////////////////////////////////////
-typedef int (UpdateConfigManager::*UpdateConfigManagerContHandler) (int, void *);
+typedef int (UpdateConfigManager::*UpdateConfigManagerContHandler)(int, void *);
 
-class UpdateConfigManager:public Continuation
+class UpdateConfigManager : public Continuation
 {
 public:
   UpdateConfigManager();
@@ -261,22 +268,24 @@ public:
 
   static int URL_list_update_callout(const char *name, RecDataT data_type, RecData data, void *cookie);
 
-  void SetFileName(char *f)
+  void
+  SetFileName(char *f)
   {
     _filename = f;
   }
-  char *GetFileName()
+  char *
+  GetFileName()
   {
     return _filename;
   }
 
-  int ProcessUpdate(int event, Event * e);
+  int ProcessUpdate(int event, Event *e);
   UpdateConfigList *BuildUpdateList();
   UpdateConfigList *ParseConfigFile(int);
   int GetDataLine(int, int, char *, int, int);
 
 private:
-  Event * _periodic_event;
+  Event *_periodic_event;
   char *_filename;
   Ptr<UpdateConfigParams> _CP;
   Ptr<UpdateConfigParams> _CP_actual;
@@ -286,54 +295,52 @@ private:
 ////////////////////////////////////////////////////////////////////////
 // UpdateScheduler -- Handle scheduling of UpdateEntry objects
 ////////////////////////////////////////////////////////////////////////
-typedef int (UpdateScheduler::*UpdateSchedulerContHandler) (int, void *);
+typedef int (UpdateScheduler::*UpdateSchedulerContHandler)(int, void *);
 
-class UpdateScheduler:public Continuation
+class UpdateScheduler : public Continuation
 {
 public:
-  UpdateScheduler(UpdateConfigManager * cm = NULL);
+  UpdateScheduler(UpdateConfigManager *cm = NULL);
   ~UpdateScheduler();
   int Init();
   int Init(UpdateScheduler *, UpdateEntry *, Ptr<UpdateConfigParams>);
 
   int ScheduleEvent(int, void *);
-  int Schedule(UpdateEntry * e = NULL);
+  int Schedule(UpdateEntry *e = NULL);
   int ChildExitEventHandler(int, Event *);
 
 private:
-    Event * _periodic_event;
+  Event *_periodic_event;
   int _recursive_update;
   UpdateConfigManager *_CM;
-    Ptr<UpdateConfigParams> _CP;
-    Ptr<UpdateConfigList> _CL;
+  Ptr<UpdateConfigParams> _CP;
+  Ptr<UpdateConfigList> _CL;
   int _schedule_event_callbacks;
   int _update_state_machines;
 
-  UpdateEntry *_base_EN;        // Entry from which recursive
+  UpdateEntry *_base_EN; // Entry from which recursive
   //   list was derived
-  UpdateScheduler *_parent_US;  // Parent which created us
+  UpdateScheduler *_parent_US; // Parent which created us
 };
 
 /////////////////////////////////////////////////////////////////
 // UpdateSM -- State machine which handles object update action
 /////////////////////////////////////////////////////////////////
 class UpdateSM;
-typedef int (UpdateSM::*UpdateSMContHandler) (int, void *);
+typedef int (UpdateSM::*UpdateSMContHandler)(int, void *);
 
-class UpdateSM:public Continuation
+class UpdateSM : public Continuation
 {
 public:
-  enum state_t
-  {
+  enum state_t {
     USM_INIT = 1,
     USM_PROCESS_URL,
     USM_PROCESS_URL_COMPLETION,
-    USM_EXIT
+    USM_EXIT,
   };
 
-  enum
-  {
-    N_SCHEMES = 1
+  enum {
+    N_SCHEMES = 1,
   };
 
   static int http_scheme(UpdateSM *);
@@ -345,27 +352,25 @@ public:
   int HandleSMEvent(int, Event *);
 
 public:
-  UpdateEntry * _EN;
+  UpdateEntry *_EN;
 
 private:
-  UpdateScheduler * _US;
+  UpdateScheduler *_US;
   Ptr<UpdateConfigParams> _CP;
   state_t _state;
   int _return_status;
   int _retries;
 };
 
-struct dispatch_entry
-{
+struct dispatch_entry {
   const char **scheme;
-  int (*func) (UpdateSM *);
+  int (*func)(UpdateSM *);
 };
 
 extern struct dispatch_entry scheme_dispatch_table[UpdateSM::N_SCHEMES];
 extern struct dispatch_entry scheme_post_dispatch_table[UpdateSM::N_SCHEMES];
 
-struct html_tag
-{
+struct html_tag {
   const char *tag;
   const char *attr;
 };
@@ -377,7 +382,7 @@ struct html_tag
 class ObjectReloadCont;
 class RecursiveHttpGet;
 
-typedef int (RecursiveHttpGet::*RecursiveHttpGetContHandler) (int, Event *);
+typedef int (RecursiveHttpGet::*RecursiveHttpGetContHandler)(int, Event *);
 
 class HtmlParser
 {
@@ -385,8 +390,7 @@ class HtmlParser
 public:
   static char default_zero_char;
 
-  enum scan_state_t
-  {
+  enum scan_state_t {
     SCAN_INIT = 1,
     SCAN_START,
     FIND_TAG_START,
@@ -404,25 +408,23 @@ public:
     TERMINATE_COPY_ATTR_VALUE
   };
 
-  enum
-  {
+  enum {
     MAX_TAG_NAME_LENGTH = 1024,
-    MAX_ATTR_NAME_LENGTH = 1024
+    MAX_ATTR_NAME_LENGTH = 1024,
   };
 
-    HtmlParser()
-  : _attr_matched(false), _url(0), _comment_end_ptr(0), _scan_state(SCAN_INIT),
-    _tag(&default_zero_char, 32), _attr(&default_zero_char, 32),
-    _attr_value(&default_zero_char, 32),
-    _attr_value_hash_char_index(-1), _attr_value_quoted(0),
-    _html_doc_base(&default_zero_char, 128),
-    _result(&default_zero_char, 128), allowable_html_tags(0), allowable_html_attrs(0)
-  { }
+  HtmlParser()
+    : _attr_matched(false), _url(0), _comment_end_ptr(0), _scan_state(SCAN_INIT), _tag(&default_zero_char, 32),
+      _attr(&default_zero_char, 32), _attr_value(&default_zero_char, 32), _attr_value_hash_char_index(-1), _attr_value_quoted(0),
+      _html_doc_base(&default_zero_char, 128), _result(&default_zero_char, 128), allowable_html_tags(0), allowable_html_attrs(0)
+  {
+  }
 
-   ~HtmlParser()
-  { }
+  ~HtmlParser() {}
 
-  void Init(char *url, struct html_tag *allowed_html_tags, struct html_tag *allowed_html_attrs = NULL) {
+  void
+  Init(char *url, struct html_tag *allowed_html_tags, struct html_tag *allowed_html_attrs = NULL)
+  {
     _url = url;
     allowable_html_tags = allowed_html_tags;
     allowable_html_attrs = allowed_html_attrs;
@@ -436,32 +438,31 @@ public:
   int ValidSupportedProtoScheme(char *);
   int ExtractURL(char **, char **);
   int ConstructURL(char **, char **);
-  DynArray<char>*MakeURL(char *, char *, int, int);
-  DynArray<char>*PrependString(const char *, int, char *, int);
+  DynArray<char> *MakeURL(char *, char *, int, int);
+  DynArray<char> *PrependString(const char *, int, char *, int);
   bool _attr_matched;
 
   char *_url;
   char *_comment_end_ptr;
   scan_state_t _scan_state;
-  DynArray<char>_tag;
-  DynArray<char>_attr;
-  DynArray<char>_attr_value;
-  intptr_t _attr_value_hash_char_index;      // '#' char loc
+  DynArray<char> _tag;
+  DynArray<char> _attr;
+  DynArray<char> _attr_value;
+  intptr_t _attr_value_hash_char_index; // '#' char loc
   unsigned char _attr_value_quoted;
-  DynArray<char>_html_doc_base;
-  DynArray<char>_result;
+  DynArray<char> _html_doc_base;
+  DynArray<char> _result;
 
   struct html_tag *allowable_html_tags;
   struct html_tag *allowable_html_attrs;
 };
 
-class RecursiveHttpGet:public Continuation
+class RecursiveHttpGet : public Continuation
 {
 public:
   RecursiveHttpGet();
   ~RecursiveHttpGet();
-  void Init(Continuation *, char *, char *, URL *, HTTPHdr *, int,
-            Ptr<UpdateConfigList>, struct html_tag *allowed_html_tags);
+  void Init(Continuation *, char *, char *, URL *, HTTPHdr *, int, Ptr<UpdateConfigList>, struct html_tag *allowed_html_tags);
   int RecursiveHttpGetEvent(int, Event *);
 
   int ExitEventHandler(int, Event *);
@@ -473,7 +474,7 @@ public:
   URL *_url_data;
   HTTPHdr *_http_hdr;
   int _recursion_depth;
-    Ptr<UpdateConfigList> _CL;
+  Ptr<UpdateConfigList> _CL;
   ObjectReloadCont *_OL;
   UpdateEntry *_group_link_head;
   int _active_child_state_machines;
@@ -485,9 +486,9 @@ public:
 // ObjectReloadCont -- Read given URL object via the local proxy port
 /////////////////////////////////////////////////////////////////////////
 class ObjectReloadCont;
-typedef int (ObjectReloadCont::*ObjectReloadContHandler) (int, void *);
+typedef int (ObjectReloadCont::*ObjectReloadContHandler)(int, void *);
 
-class ObjectReloadCont:public Continuation
+class ObjectReloadCont : public Continuation
 {
 public:
   ObjectReloadCont();
@@ -497,12 +498,11 @@ public:
   int ObjectReloadEvent(int, void *);
   int CallBackUser(int, void *);
 
-  enum state_t
-  {
+  enum state_t {
     START = 1,
     ATTEMPT_CONNECT,
     WRITING_URL,
-    READING_DATA
+    READING_DATA,
   };
 
   Continuation *_caller_cont;
@@ -517,7 +517,6 @@ public:
   VIO *_write_vio;
   VIO *_read_vio;
   int _read_event_callback;
-
 };
 
 extern ClassAllocator<ObjectReloadCont> ObjectReloadContAllocator;
