@@ -47,30 +47,27 @@ CongestionDB *theCongestionDB = NULL;
  * first try
  */
 
-class CongestionDBCont:public Continuation
+class CongestionDBCont : public Continuation
 {
 public:
   CongestionDBCont();
-  int GC(int event, Event * e);
+  int GC(int event, Event *e);
 
-  int get_congest_list(int event, Event * e);
+  int get_congest_list(int event, Event *e);
 
-  int get_congest_entry(int event, Event * e);
+  int get_congest_entry(int event, Event *e);
 
 
   Action m_action;
 
   // To save momery, use a union here
-  union
-  {
-    struct
-    {
+  union {
+    struct {
       MIOBuffer *m_iobuf;
       int m_CurPartitionID;
-      int m_list_format;        // format of list
+      int m_list_format; // format of list
     } list_info;
-    struct
-    {
+    struct {
       uint64_t m_key;
       char *m_hostname;
       IpEndpoint m_ip;
@@ -81,30 +78,26 @@ public:
 };
 
 // MACRO's to save typing
-#define CDBC_buf  data.list_info.m_iobuf
-#define CDBC_pid  data.list_info.m_CurPartitionID
-#define CDBC_lf   data.list_info.m_list_format
-#define CDBC_key  data.entry_info.m_key
+#define CDBC_buf data.list_info.m_iobuf
+#define CDBC_pid data.list_info.m_CurPartitionID
+#define CDBC_lf data.list_info.m_list_format
+#define CDBC_key data.entry_info.m_key
 #define CDBC_host data.entry_info.m_hostname
-#define CDBC_ip   data.entry_info.m_ip
+#define CDBC_ip data.entry_info.m_ip
 #define CDBC_rule data.entry_info.m_rule
-#define CDBC_ppE  data.entry_info.m_ppEntry
+#define CDBC_ppE data.entry_info.m_ppEntry
 
-inline CongestionDBCont::CongestionDBCont()
-:Continuation(NULL)
+inline CongestionDBCont::CongestionDBCont() : Continuation(NULL)
 {
   memset(&data, 0, sizeof(data));
 }
 
 //--------------------------------------------------------------
 // class allocators
-static
-  ClassAllocator <
-  CongestionDBCont >
-CongestionDBContAllocator("CongestionDBContAllocator");
+static ClassAllocator<CongestionDBCont> CongestionDBContAllocator("CongestionDBContAllocator");
 
 inline void
-Free_CongestionDBCont(CongestionDBCont * cont)
+Free_CongestionDBCont(CongestionDBCont *cont)
 {
   cont->m_action = NULL;
   cont->mutex = NULL;
@@ -114,7 +107,7 @@ Free_CongestionDBCont(CongestionDBCont * cont)
 ClassAllocator<CongestRequestParam> CongestRequestParamAllocator("CongestRequestParamAllocator");
 
 inline void
-Free_CongestRequestParam(CongestRequestParam * param)
+Free_CongestRequestParam(CongestRequestParam *param)
 {
   CongestRequestParamAllocator.free(param);
 }
@@ -126,8 +119,7 @@ Free_CongestRequestParam(CongestRequestParam * param)
  * CongestionDB(int tablesize)
  *  tablesize is the initial hashtable bucket number
  */
-static long
-  congestEntryGCTime = 0;
+static long congestEntryGCTime = 0;
 
 // Before the garbage collection of the congestion db, set the
 //  current GC time, CongestionEntry::usefulInfo(t) will use the
@@ -136,13 +128,13 @@ static long
 void
 preCongestEntryGC(void)
 {
-  congestEntryGCTime = (long) ink_hrtime_to_sec(ink_get_hrtime());
+  congestEntryGCTime = (long)ink_hrtime_to_sec(ink_get_hrtime());
 }
 
 // if the entry contains useful info, return false -- keep it
 // else return true -- delete it
 bool
-congestEntryGC(CongestionEntry * p)
+congestEntryGC(CongestionEntry *p)
 {
   if (!p->usefulInfo(congestEntryGCTime)) {
     p->put();
@@ -151,13 +143,12 @@ congestEntryGC(CongestionEntry * p)
   return false;
 }
 
-CongestionDB::CongestionDB(int tablesize)
-:CongestionTable(tablesize, &congestEntryGC, &preCongestEntryGC)
+CongestionDB::CongestionDB(int tablesize) : CongestionTable(tablesize, &congestEntryGC, &preCongestEntryGC)
 {
   ink_assert(tablesize > 0);
   todo_lists = new InkAtomicList[MT_HASHTABLE_PARTITIONS];
   for (int i = 0; i < MT_HASHTABLE_PARTITIONS; i++) {
-    ink_atomiclist_init(&todo_lists[i], "cong_todo_list", (uintptr_t) &((CongestRequestParam *) 0)->link);
+    ink_atomiclist_init(&todo_lists[i], "cong_todo_list", (uintptr_t) & ((CongestRequestParam *)0)->link);
   }
 }
 
@@ -167,17 +158,17 @@ CongestionDB::CongestionDB(int tablesize)
 
 CongestionDB::~CongestionDB()
 {
-  delete[]todo_lists;
+  delete[] todo_lists;
 }
 
 void
-CongestionDB::addRecord(uint64_t key, CongestionEntry * pEntry)
+CongestionDB::addRecord(uint64_t key, CongestionEntry *pEntry)
 {
   ink_assert(key == pEntry->m_key);
   pEntry->get();
   ProxyMutex *bucket_mutex = lock_for_key(key);
   MUTEX_TRY_LOCK(lock, bucket_mutex, this_ethread());
-  if (lock) {
+  if (lock.is_locked()) {
     RunTodoList(part_num(key));
     CongestionEntry *tmp = insert_entry(key, pEntry);
     if (tmp)
@@ -199,7 +190,7 @@ CongestionDB::removeAllRecords()
   for (int part = 0; part < MT_HASHTABLE_PARTITIONS; part++) {
     ProxyMutex *bucket_mutex = lock_for_key(part);
     MUTEX_TRY_LOCK(lock, bucket_mutex, this_ethread());
-    if (lock) {
+    if (lock.is_locked()) {
       RunTodoList(part);
       tmp = first_entry(part, &it);
       while (tmp) {
@@ -222,7 +213,7 @@ CongestionDB::removeRecord(uint64_t key)
   CongestionEntry *tmp;
   ProxyMutex *bucket_mutex = lock_for_key(key);
   MUTEX_TRY_LOCK(lock, bucket_mutex, this_ethread());
-  if (lock) {
+  if (lock.is_locked()) {
     RunTodoList(part_num(key));
     tmp = remove_entry(key);
     if (tmp)
@@ -237,7 +228,7 @@ CongestionDB::removeRecord(uint64_t key)
 
 // process one item in the to do list
 void
-CongestionDB::process(int buckId, CongestRequestParam * param)
+CongestionDB::process(int buckId, CongestRequestParam *param)
 {
   CongestionEntry *pEntry = NULL;
   switch (param->m_op) {
@@ -247,18 +238,17 @@ CongestionDB::process(int buckId, CongestRequestParam * param)
       pEntry->put();
     }
     break;
-  case CongestRequestParam::REMOVE_ALL_RECORDS:
-    {
-      CongestionEntry *tmp;
-      Iter it;
-      tmp = first_entry(param->m_key, &it);
-      while (tmp) {
-        remove_entry(param->m_key, &it);
-        tmp->put();
-        tmp = cur_entry(param->m_key, &it);
-      }
-      break;
+  case CongestRequestParam::REMOVE_ALL_RECORDS: {
+    CongestionEntry *tmp;
+    Iter it;
+    tmp = first_entry(param->m_key, &it);
+    while (tmp) {
+      remove_entry(param->m_key, &it);
+      tmp->put();
+      tmp = cur_entry(param->m_key, &it);
     }
+    break;
+  }
   case CongestRequestParam::REMOVE_RECORD:
     pEntry = remove_entry(param->m_key);
     if (pEntry)
@@ -276,8 +266,7 @@ void
 CongestionDB::RunTodoList(int buckId)
 {
   CongestRequestParam *param = NULL, *cur = NULL;
-  if ((param = (CongestRequestParam *)
-       ink_atomiclist_popall(&todo_lists[buckId])) != NULL) {
+  if ((param = (CongestRequestParam *)ink_atomiclist_popall(&todo_lists[buckId])) != NULL) {
     /* start the work at the end of the list */
     param->link.prev = NULL;
     while (param->link.next) {
@@ -304,7 +293,7 @@ CongestionDB::revalidateBucket(int buckId)
       remove_entry(buckId, &it);
       cur->put();
       // the next entry has been moved to the current pos
-      //because of the remove_entry
+      // because of the remove_entry
       cur = cur_entry(buckId, &it);
     } else
       cur = next_entry(buckId, &it);
@@ -325,7 +314,7 @@ CongestionDBCont::GC(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
       ProxyMutex *bucket_mutex = theCongestionDB->lock_for_key(CDBC_pid);
       {
         MUTEX_TRY_LOCK(lock, bucket_mutex, this_ethread());
-        if (lock) {
+        if (lock.is_locked()) {
           ink_hrtime now = ink_get_hrtime();
           now = ink_hrtime_to_sec(now);
           theCongestionDB->RunTodoList(CDBC_pid);
@@ -351,7 +340,7 @@ Ldone:
 }
 
 int
-CongestionDBCont::get_congest_list(int /* event ATS_UNUSED */, Event * e)
+CongestionDBCont::get_congest_list(int /* event ATS_UNUSED */, Event *e)
 {
   if (m_action.cancelled) {
     Free_CongestionDBCont(this);
@@ -361,7 +350,7 @@ CongestionDBCont::get_congest_list(int /* event ATS_UNUSED */, Event * e)
     ProxyMutex *bucket_mutex = theCongestionDB->lock_for_key(CDBC_pid);
     {
       MUTEX_TRY_LOCK(lock_bucket, bucket_mutex, this_ethread());
-      if (!lock_bucket) {
+      if (!lock_bucket.is_locked()) {
         e->schedule_in(SCHEDULE_CONGEST_CONT_INTERVAL);
         return EVENT_CONT;
       } else {
@@ -388,7 +377,7 @@ CongestionDBCont::get_congest_list(int /* event ATS_UNUSED */, Event * e)
 }
 
 int
-CongestionDBCont::get_congest_entry(int /* event ATS_UNUSED */, Event * e)
+CongestionDBCont::get_congest_entry(int /* event ATS_UNUSED */, Event *e)
 {
   Debug("congestion_control", "cont::get_congest_entry started");
 
@@ -400,7 +389,7 @@ CongestionDBCont::get_congest_entry(int /* event ATS_UNUSED */, Event * e)
   }
   ProxyMutex *bucket_mutex = theCongestionDB->lock_for_key(CDBC_key);
   MUTEX_TRY_LOCK(lock_bucket, bucket_mutex, this_ethread());
-  if (lock_bucket) {
+  if (lock_bucket.is_locked()) {
     theCongestionDB->RunTodoList(theCongestionDB->part_num(CDBC_key));
     *CDBC_ppE = theCongestionDB->lookup_entry(CDBC_key);
     if (*CDBC_ppE != NULL) {
@@ -451,7 +440,7 @@ revalidateCongestionDB()
     bucket_mutex = theCongestionDB->lock_for_key(i);
     {
       MUTEX_TRY_LOCK(lock_bucket, bucket_mutex, this_ethread());
-      if (lock_bucket) {
+      if (lock_bucket.is_locked()) {
         theCongestionDB->RunTodoList(i);
         theCongestionDB->revalidateBucket(i);
       } else {
@@ -465,7 +454,7 @@ revalidateCongestionDB()
 }
 
 Action *
-get_congest_entry(Continuation * cont, HttpRequestData * data, CongestionEntry ** ppEntry)
+get_congest_entry(Continuation *cont, HttpRequestData *data, CongestionEntry **ppEntry)
 {
   if (congestionControlEnabled != 1 && congestionControlEnabled != 2)
     return ACTION_RESULT_DONE;
@@ -475,28 +464,28 @@ get_congest_entry(Continuation * cont, HttpRequestData * data, CongestionEntry *
   Debug("congestion_control", "Control Matcher matched rule_num %d", p == NULL ? -1 : p->line_num);
   if (p == NULL)
     return ACTION_RESULT_DONE;
-// if the fail_window <= 0 and the max_connection == -1, then no congestion control
+  // if the fail_window <= 0 and the max_connection == -1, then no congestion control
   if (p->max_connection_failures <= 0 && p->max_connection < 0) {
     return ACTION_RESULT_DONE;
   }
-  uint64_t key = make_key((char *) data->get_host(), data->get_ip(), p);
+  uint64_t key = make_key((char *)data->get_host(), data->get_ip(), p);
   Debug("congestion_control", "Key = %" PRIu64 "", key);
 
   ProxyMutex *bucket_mutex = theCongestionDB->lock_for_key(key);
   MUTEX_TRY_LOCK(lock_bucket, bucket_mutex, this_ethread());
-  if (lock_bucket) {
+  if (lock_bucket.is_locked()) {
     theCongestionDB->RunTodoList(theCongestionDB->part_num(key));
     *ppEntry = theCongestionDB->lookup_entry(key);
     if (*ppEntry != NULL) {
       (*ppEntry)->get();
-      Debug("congestion_control", "get_congest_entry, found entry %p done", (void *) *ppEntry);
+      Debug("congestion_control", "get_congest_entry, found entry %p done", (void *)*ppEntry);
       return ACTION_RESULT_DONE;
     } else {
       // create a new entry and add it to the congestDB
       *ppEntry = new CongestionEntry(data->get_host(), data->get_ip(), p, key);
       (*ppEntry)->get();
       theCongestionDB->insert_entry(key, *ppEntry);
-      Debug("congestion_control", "get_congest_entry, new entry %p done", (void *) *ppEntry);
+      Debug("congestion_control", "get_congest_entry, new entry %p done", (void *)*ppEntry);
       return ACTION_RESULT_DONE;
     }
   } else {
@@ -505,7 +494,7 @@ get_congest_entry(Continuation * cont, HttpRequestData * data, CongestionEntry *
     Ccont->m_action = cont;
     Ccont->mutex = cont->mutex;
     Ccont->CDBC_key = key;
-    Ccont->CDBC_host = (char *) data->get_host();
+    Ccont->CDBC_host = (char *)data->get_host();
     ats_ip_copy(&Ccont->CDBC_ip.sa, data->get_ip());
     p->get();
     Ccont->CDBC_rule = p;
@@ -518,7 +507,7 @@ get_congest_entry(Continuation * cont, HttpRequestData * data, CongestionEntry *
 }
 
 Action *
-get_congest_list(Continuation * cont, MIOBuffer * buffer, int format)
+get_congest_list(Continuation *cont, MIOBuffer *buffer, int format)
 {
   if (theCongestionDB == NULL || (congestionControlEnabled != 1 && congestionControlEnabled != 2))
     return ACTION_RESULT_DONE;
@@ -526,7 +515,7 @@ get_congest_list(Continuation * cont, MIOBuffer * buffer, int format)
     ProxyMutex *bucket_mutex = theCongestionDB->lock_for_key(i);
     {
       MUTEX_TRY_LOCK(lock_bucket, bucket_mutex, this_ethread());
-      if (lock_bucket) {
+      if (lock_bucket.is_locked()) {
         theCongestionDB->RunTodoList(i);
         char buf[1024];
         Iter it;
@@ -588,7 +577,7 @@ remove_congested_entry(uint64_t key)
 //           message to the Raf
 //--------------------------------------------------------------
 void
-remove_congested_entry(char *buf, MIOBuffer * out_buffer)
+remove_congested_entry(char *buf, MIOBuffer *out_buffer)
 {
   const int MSG_LEN = 512;
   char msg[MSG_LEN + 1];
@@ -616,7 +605,7 @@ remove_congested_entry(char *buf, MIOBuffer * out_buffer)
   } else if (strncasecmp(buf, "ip=", 3) == 0) {
     IpEndpoint ip;
     memset(&ip, 0, sizeof(ip));
-    
+
     char *p = buf + 3;
     char *prefix = strchr(p, '/');
     int prelen = 0;
