@@ -41,9 +41,9 @@
  * table and can be easily retrived
  * also exercise the resizing of the table
  */
-EXCLUSIVE_REGRESSION_TEST(Congestion_HashTable) (RegressionTest * t, int /* atype ATS_UNUSED */, int *pstatus)
+EXCLUSIVE_REGRESSION_TEST(Congestion_HashTable)(RegressionTest *t, int /* atype ATS_UNUSED */, int *pstatus)
 {
-  MTHashTable<long, long>*htable = new MTHashTable<long, long>(4);
+  MTHashTable<long, long> *htable = new MTHashTable<long, long>(4);
   // add elements to the table;
   long i, count = 1 * 1024 * 1024;
   rprintf(t, "adding data into the hash table .", count);
@@ -97,7 +97,7 @@ EXCLUSIVE_REGRESSION_TEST(Congestion_HashTable) (RegressionTest * t, int /* atyp
   fprintf(stderr, "done\n");
 
   rprintf(t, "use iterator to list all the elements and delete half of them");
-  HashTableIteratorState<long, long>it;
+  HashTableIteratorState<long, long> it;
   int j, new_count = 0;
   for (j = 0; j < MT_HASHTABLE_PARTITIONS; j++) {
     int data = htable->first_entry(j, &it);
@@ -170,31 +170,28 @@ EXCLUSIVE_REGRESSION_TEST(Congestion_HashTable) (RegressionTest * t, int /* atyp
 /* register events into the FailHistory and the number of events
  * should be correct
  */
-struct CCFailHistoryTestCont: public Continuation
-{
-  enum
-  { FAIL_WINDOW = 300 };
-  enum
-  {
+struct CCFailHistoryTestCont : public Continuation {
+  enum {
+    FAIL_WINDOW = 300,
+  };
+  enum {
     SIMPLE_TEST,
     MULTIPLE_THREAD_TEST,
-    ROTATING_TEST
+    ROTATING_TEST,
   };
   int test_mode;
   int final_status;
   bool complete;
   RegressionTest *test;
-  int mainEvent(int event, Event * e);
-    CCFailHistoryTestCont()
-  : Continuation(new_ProxyMutex()),
-    test_mode(SIMPLE_TEST), final_status(0), complete(false), failEvents(NULL), entry(NULL)
+  int mainEvent(int event, Event *e);
+  CCFailHistoryTestCont()
+    : Continuation(new_ProxyMutex()), test_mode(SIMPLE_TEST), final_status(0), complete(false), failEvents(NULL), entry(NULL)
   {
   }
 
-  CCFailHistoryTestCont(Ptr<ProxyMutex> _mutex, RegressionTest * _test)
-  : Continuation(_mutex),
-    test_mode(SIMPLE_TEST),
-    final_status(REGRESSION_TEST_PASSED), complete(false), test(_test), failEvents(NULL), pending_action(NULL)
+  CCFailHistoryTestCont(Ptr<ProxyMutex> _mutex, RegressionTest *_test)
+    : Continuation(_mutex), test_mode(SIMPLE_TEST), final_status(REGRESSION_TEST_PASSED), complete(false), test(_test),
+      failEvents(NULL), pending_action(NULL)
   {
     SET_HANDLER(&CCFailHistoryTestCont::mainEvent);
     rule = new CongestionControlRecord;
@@ -204,7 +201,8 @@ struct CCFailHistoryTestCont: public Continuation
     entry = new CongestionEntry("dummy_host", 0, rule->pRecord, 0);
   }
 
-  ~CCFailHistoryTestCont() {
+  ~CCFailHistoryTestCont()
+  {
     if (pending_action) {
       pending_action->cancel();
     }
@@ -216,28 +214,25 @@ struct CCFailHistoryTestCont: public Continuation
   void init_events();
   void clear_events();
   int check_history(bool print);
-  int schedule_event(int event, Event * e);
+  int schedule_event(int event, Event *e);
 
-  struct FailEvents
-  {
+  struct FailEvents {
     time_t time;
-      Link<FailEvents> link;
+    Link<FailEvents> link;
   };
   InkAtomicList *failEvents;
   CongestionControlRecord *rule;
   CongestionEntry *entry;
   Action *pending_action;
-
 };
 
 void
 CCFailHistoryTestCont::clear_events()
 {
   if (failEvents) {
-    CCFailHistoryTestCont::FailEvents * events =
-      (CCFailHistoryTestCont::FailEvents *) ink_atomiclist_popall(failEvents);
+    CCFailHistoryTestCont::FailEvents *events = (CCFailHistoryTestCont::FailEvents *)ink_atomiclist_popall(failEvents);
     while (events != NULL) {
-      CCFailHistoryTestCont::FailEvents * next = events->link.next;
+      CCFailHistoryTestCont::FailEvents *next = events->link.next;
       delete events;
       events = next;
     }
@@ -252,10 +247,10 @@ CCFailHistoryTestCont::init_events()
   clear_events();
 
   failEvents = new InkAtomicList;
-  ink_atomiclist_init(failEvents, "failEvents", (uintptr_t) &((CCFailHistoryTestCont::FailEvents *) 0)->link);
+  ink_atomiclist_init(failEvents, "failEvents", (uintptr_t) & ((CCFailHistoryTestCont::FailEvents *)0)->link);
 
   int i, j;
-  CCFailHistoryTestCont::FailEvents * new_event = NULL;
+  CCFailHistoryTestCont::FailEvents *new_event = NULL;
 
   switch (test_mode) {
   case CCFailHistoryTestCont::ROTATING_TEST:
@@ -284,7 +279,7 @@ CCFailHistoryTestCont::schedule_event(int /* event ATS_UNUSED */, Event * /* e A
 {
   if (failEvents == NULL)
     return EVENT_DONE;
-  CCFailHistoryTestCont::FailEvents * f = (CCFailHistoryTestCont::FailEvents *) ink_atomiclist_pop(failEvents);
+  CCFailHistoryTestCont::FailEvents *f = (CCFailHistoryTestCont::FailEvents *)ink_atomiclist_pop(failEvents);
   if (f != NULL) {
     entry->failed_at(f->time);
     delete f;
@@ -304,10 +299,9 @@ CCFailHistoryTestCont::check_history(bool print)
       e += entry->m_history.bins[i];
       rprintf(test, "bucket %d => events %d , sum = %d\n", i, entry->m_history.bins[i], e);
     }
-    fprintf(stderr, "Events: %d, CurIndex: %d, LastEvent: %ld, HistLen: %d, BinLen: %d, Start: %ld\n",
-            entry->m_history.events,
-            entry->m_history.cur_index,
-            entry->m_history.last_event, entry->m_history.length, entry->m_history.bin_len, entry->m_history.start);
+    fprintf(stderr, "Events: %d, CurIndex: %d, LastEvent: %ld, HistLen: %d, BinLen: %d, Start: %ld\n", entry->m_history.events,
+            entry->m_history.cur_index, entry->m_history.last_event, entry->m_history.length, entry->m_history.bin_len,
+            entry->m_history.start);
     char buf[1024];
     entry->sprint(buf, 1024, 10);
     rprintf(test, "%s", buf);
@@ -323,7 +317,8 @@ CCFailHistoryTestCont::mainEvent(int /* event ATS_UNUSED */, Event * /* e ATS_UN
   test_mode = CCFailHistoryTestCont::SIMPLE_TEST;
   init_events();
   entry->init(rule->pRecord);
-  while (schedule_event(0, NULL) == EVENT_CONT);
+  while (schedule_event(0, NULL) == EVENT_CONT)
+    ;
   if (check_history(true) == 0) {
     final_status = REGRESSION_TEST_PASSED;
   } else {
@@ -334,7 +329,8 @@ CCFailHistoryTestCont::mainEvent(int /* event ATS_UNUSED */, Event * /* e ATS_UN
   test_mode = CCFailHistoryTestCont::ROTATING_TEST;
   init_events();
   entry->init(rule->pRecord);
-  while (schedule_event(0, NULL) == EVENT_CONT);
+  while (schedule_event(0, NULL) == EVENT_CONT)
+    ;
   if (check_history(true) == 0) {
     final_status = REGRESSION_TEST_PASSED;
   } else {
@@ -352,7 +348,7 @@ Ldone:
   return EVENT_CONT;
 }
 
-EXCLUSIVE_REGRESSION_TEST(Congestion_FailHistory) (RegressionTest * t, int /* atype ATS_UNUSED */, int *pstatus)
+EXCLUSIVE_REGRESSION_TEST(Congestion_FailHistory)(RegressionTest *t, int /* atype ATS_UNUSED */, int *pstatus)
 {
   CCFailHistoryTestCont *test = new CCFailHistoryTestCont(make_ptr(new_ProxyMutex()), t);
   eventProcessor.schedule_in(test, HRTIME_SECONDS(1));
@@ -366,28 +362,27 @@ EXCLUSIVE_REGRESSION_TEST(Congestion_FailHistory) (RegressionTest * t, int /* at
  * exercise the GC of the DB, remove entries from DB
  */
 
-struct CCCongestionDBTestCont: public Continuation
-{
+struct CCCongestionDBTestCont : public Continuation {
   int final_status;
   bool complete;
   RegressionTest *test;
 
-  int mainEvent(int event, Event * e);
+  int mainEvent(int event, Event *e);
 
   void init();
   int get_congest_list();
   CongestionControlRecord *rule;
   CongestionDB *db;
   int dbsize;
-  CongestionEntry *gen_CongestionEntry(sockaddr const* ip, int congested = 0);
+  CongestionEntry *gen_CongestionEntry(sockaddr const *ip, int congested = 0);
 
 
-    CCCongestionDBTestCont(Ptr<ProxyMutex> _mutex, RegressionTest * _test):Continuation(_mutex),
-    final_status(REGRESSION_TEST_PASSED), complete(false), test(_test), rule(NULL), db(NULL), dbsize(1024)
+  CCCongestionDBTestCont(Ptr<ProxyMutex> _mutex, RegressionTest *_test)
+    : Continuation(_mutex), final_status(REGRESSION_TEST_PASSED), complete(false), test(_test), rule(NULL), db(NULL), dbsize(1024)
   {
     SET_HANDLER(&CCCongestionDBTestCont::mainEvent);
   }
-  virtual ~ CCCongestionDBTestCont()
+  virtual ~CCCongestionDBTestCont()
   {
     if (db) {
       db->removeAllRecords();
@@ -399,16 +394,13 @@ struct CCCongestionDBTestCont: public Continuation
 };
 
 CongestionEntry *
-CCCongestionDBTestCont::gen_CongestionEntry(sockaddr const* ip, int congested)
+CCCongestionDBTestCont::gen_CongestionEntry(sockaddr const *ip, int congested)
 {
   char hostname[INET6_ADDRSTRLEN];
   uint64_t key;
   ats_ip_ntop(ip, hostname, sizeof(hostname));
   key = make_key(hostname, strlen(hostname), ip, rule->pRecord);
-  CongestionEntry *ret = new CongestionEntry(hostname,
-                                             ip,
-                                             rule->pRecord,
-                                             key);
+  CongestionEntry *ret = new CongestionEntry(hostname, ip, rule->pRecord, key);
   ret->m_congested = congested;
   ret->m_ref_count = 0;
   return ret;
@@ -417,7 +409,7 @@ CCCongestionDBTestCont::gen_CongestionEntry(sockaddr const* ip, int congested)
 void
 CCCongestionDBTestCont::init()
 {
-// create/clear db
+  // create/clear db
   if (!db)
     db = new CongestionDB(dbsize / MT_HASHTABLE_PARTITIONS);
   else
@@ -428,7 +420,6 @@ CCCongestionDBTestCont::init()
     rule->max_connection_failures = 10;
     rule->pRecord = new CongestionControlRecord(*rule);
   }
-
 }
 
 int
@@ -460,7 +451,7 @@ CCCongestionDBTestCont::mainEvent(int /* event ATS_UNUSED */, Event * /* e ATS_U
 {
   int to_add = 1 * 1024 * 1024;
   int i;
-  int items[10] = { 0 };
+  int items[10] = {0};
   init();
   rprintf(test, "Add %d records into the db", dbsize);
 
@@ -470,7 +461,7 @@ CCCongestionDBTestCont::mainEvent(int /* event ATS_UNUSED */, Event * /* e ATS_U
 
     IpEndpoint ip;
     ats_ip4_set(&ip, i + 255);
-    
+
     CongestionEntry *tmp = gen_CongestionEntry(&ip.sa);
     db->addRecord(tmp->m_key, tmp);
   }
@@ -508,7 +499,7 @@ CCCongestionDBTestCont::mainEvent(int /* event ATS_UNUSED */, Event * /* e ATS_U
 
     IpEndpoint ip;
     ats_ip4_set(&ip, i + 255);
-    
+
     CongestionEntry *tmp = gen_CongestionEntry(&ip.sa, 1);
     db->addRecord(tmp->m_key, tmp);
   }
@@ -530,7 +521,7 @@ CCCongestionDBTestCont::mainEvent(int /* event ATS_UNUSED */, Event * /* e ATS_U
   return EVENT_CONT;
 }
 
-EXCLUSIVE_REGRESSION_TEST(Congestion_CongestionDB) (RegressionTest * t, int /* atype ATS_UNUSED */, int *pstatus)
+EXCLUSIVE_REGRESSION_TEST(Congestion_CongestionDB)(RegressionTest *t, int /* atype ATS_UNUSED */, int *pstatus)
 {
   CCCongestionDBTestCont *test = new CCCongestionDBTestCont(make_ptr(new_ProxyMutex()), t);
   eventProcessor.schedule_in(test, HRTIME_SECONDS(1));
@@ -547,7 +538,7 @@ EXCLUSIVE_REGRESSION_TEST(Congestion_CongestionDB) (RegressionTest * t, int /* a
 void
 init_CongestionRegressionTest()
 {
-  (void) regressionTest_Congestion_HashTable;
-  (void) regressionTest_Congestion_FailHistory;
-  (void) regressionTest_Congestion_CongestionDB;
+  (void)regressionTest_Congestion_HashTable;
+  (void)regressionTest_Congestion_FailHistory;
+  (void)regressionTest_Congestion_CongestionDB;
 }
