@@ -34,17 +34,17 @@
 #include "libts.h"
 #include "HdrUtils.h"
 
-#define GETNEXT() {      \
-    cur += 1;            \
-    if (cur >= end) {    \
-        goto done;       \
-    }                    \
-}
+#define GETNEXT()     \
+  {                   \
+    cur += 1;         \
+    if (cur >= end) { \
+      goto done;      \
+    }                 \
+  }
 
 void
 HdrCsvIter::find_csv()
 {
-
   const char *cur, *end, *last_data, *csv_start;
 
 RETRY:
@@ -67,7 +67,7 @@ parse_value:
   // ink_assert((',' > '"') && (',' > ' ') && (',' > '\t'));
   // Cookie/Set-Cookie use ';' as the separator
   if (m_separator == ',')
-    while ((cur<end - 1) && (*cur> ',')) {
+    while ((cur < end - 1) && (*cur > ',')) {
       last_data = cur;
       cur++;
     }
@@ -102,7 +102,7 @@ done:
   m_csv_start = csv_start;
 
   if (last_data) {
-    m_csv_len = (int) (last_data - csv_start) + 1;
+    m_csv_len = (int)(last_data - csv_start) + 1;
   } else {
     // Nothing found.  See if there is another
     //    field in the dup list
@@ -116,7 +116,7 @@ done:
 }
 
 const char *
-HdrCsvIter::get_nth(MIMEField * field, int *len, int n, bool follow_dups)
+HdrCsvIter::get_nth(MIMEField *field, int *len, int n, bool follow_dups)
 {
   const char *s;
   int i, l;
@@ -124,28 +124,28 @@ HdrCsvIter::get_nth(MIMEField * field, int *len, int n, bool follow_dups)
   ink_assert(n >= 0);
   i = 0;
 
-  s = get_first(field, &l, follow_dups);        // get index 0
+  s = get_first(field, &l, follow_dups); // get index 0
   while (s && (n > i)) {
     s = get_next(&l);
     i++;
-  }                             // if had index i, but want n > i, get next
-  *len = (s ? l : 0);           // length is zero if NULL string
+  }                   // if had index i, but want n > i, get next
+  *len = (s ? l : 0); // length is zero if NULL string
   return (s);
 }
 
 
 int
-HdrCsvIter::count_values(MIMEField * field, bool follow_dups)
+HdrCsvIter::count_values(MIMEField *field, bool follow_dups)
 {
   const char *s;
   int count, l;
 
   count = 0;
-  s = get_first(field, &l, follow_dups);        // get index 0
+  s = get_first(field, &l, follow_dups); // get index 0
   while (s) {
     s = get_next(&l);
     ++count;
-  }                             // get next
+  } // get next
   return (count);
 }
 
@@ -154,27 +154,27 @@ HdrCsvIter::count_values(MIMEField * field, bool follow_dups)
 int main() {
 
     char* tests[] = {"\"I\", \"hate\", \"strings\"",
-		     "This, is a , test",
-		     "a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p",
-		     "\"This is,\" a test"
+                     "This, is a , test",
+                     "a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p",
+                     "\"This is,\" a test"
     };
 
     for (int i = 0; i < 4; i++) {
-	printf ("Testing: %s\n", tests[i]);
+        printf ("Testing: %s\n", tests[i]);
 
-	HdrCsvIter iter;
-	int len;
-	const char* v = iter.get_first(tests[i], strlen(tests[i]), &len);
+        HdrCsvIter iter;
+        int len;
+        const char* v = iter.get_first(tests[i], strlen(tests[i]), &len);
 
-	while (v) {
-	    char* str_v = (char*)ats_malloc(len+1);
-	    memcpy(str_v, v, len);
-	    str_v[len] = '\0';
-	    printf ("%s|", str_v);
-	    v = iter.get_next(&len);
-	}
+        while (v) {
+            char* str_v = (char*)ats_malloc(len+1);
+            memcpy(str_v, v, len);
+            str_v[len] = '\0';
+            printf ("%s|", str_v);
+            v = iter.get_next(&len);
+        }
 
-	printf("\n\n");
+        printf("\n\n");
     }
 
 }
