@@ -28,19 +28,18 @@
 #include "HdrToken.h"
 #include "HdrHeap.h"
 #include "INK_MD5.h"
+#include "MMH.h"
 #include "MIME.h"
 
 #include "ink_apidefs.h"
 
-enum URLType
-{
+enum URLType {
   URL_TYPE_NONE,
   URL_TYPE_HTTP,
-  URL_TYPE_HTTPS
+  URL_TYPE_HTTPS,
 };
 
-struct URLImpl:public HdrHeapObjImpl
-{
+struct URLImpl : public HdrHeapObjImpl {
   // HdrHeapObjImpl is 4 bytes
   uint16_t m_len_scheme;
   uint16_t m_len_user;
@@ -69,11 +68,11 @@ struct URLImpl:public HdrHeapObjImpl
   // Tokenized values
   int16_t m_scheme_wks_idx;
   uint16_t m_port;
-  uint8_t m_url_type;             // e.g. HTTP
-  uint8_t m_type_code;            // RFC 1738 limits type code to 1 char
+  uint8_t m_url_type;  // e.g. HTTP
+  uint8_t m_type_code; // RFC 1738 limits type code to 1 char
   // 6 bytes
 
-  uint32_t m_clean:1;
+  uint32_t m_clean : 1;
   // 8 bytes + 1 bit, will result in padding
 
   // Marshaling Functions
@@ -86,6 +85,44 @@ struct URLImpl:public HdrHeapObjImpl
   void check_strings(HeapCheck *heaps, int num_heaps);
 };
 
+/// Crypto Hash context for URLs.
+/// @internal This just forwards on to another specific context but avoids
+/// putting that switch logic in multiple places. The working context is put
+/// in to class local storage (@a _obj) via placement @a new.
+class URLHashContext : public CryptoContext
+{
+public:
+  URLHashContext();
+  /// Update the hash with @a data of @a length bytes.
+  virtual bool update(void const *data, int length);
+  /// Finalize and extract the @a hash.
+  virtual bool finalize(CryptoHash &hash);
+
+  enum HashType {
+    UNSPECIFIED,
+    MD5,
+    MMH,
+  }; ///< What type of hash we really are.
+  static HashType Setting;
+
+  /// Size of storage for placement @c new of hashing context.
+  static size_t const OBJ_SIZE = 256;
+
+protected:
+  char _obj[OBJ_SIZE]; ///< Raw storage for instantiated context.
+};
+
+inline bool
+URLHashContext::update(void const *data, int length)
+{
+  return reinterpret_cast<CryptoContext *>(_obj)->update(data, length);
+}
+
+inline bool
+URLHashContext::finalize(CryptoHash &hash)
+{
+  return reinterpret_cast<CryptoContext *>(_obj)->finalize(hash);
+}
 
 extern const char *URL_SCHEME_FILE;
 extern const char *URL_SCHEME_FTP;
@@ -162,8 +199,7 @@ void url_nuke_proxy_stuff(URLImpl *d_url);
 
 URLImpl *url_copy(URLImpl *s_url, HdrHeap *s_heap, HdrHeap *d_heap, bool inherit_strs = true);
 void url_copy_onto(URLImpl *s_url, HdrHeap *s_heap, URLImpl *d_url, HdrHeap *d_heap, bool inherit_strs = true);
-void url_copy_onto_as_server_url(URLImpl *s_url, HdrHeap *s_heap,
-                                 URLImpl *d_url, HdrHeap *d_heap, bool inherit_strs = true);
+void url_copy_onto_as_server_url(URLImpl *s_url, HdrHeap *s_heap, URLImpl *d_url, HdrHeap *d_heap, bool inherit_strs = true);
 
 int url_print(URLImpl *u, char *buf, int bufsize, int *bufindex, int *dumpoffset);
 void url_describe(HdrHeapObjImpl *raw, bool recurse);
@@ -176,10 +212,9 @@ void url_called_set(URLImpl *url);
 char *url_string_get_buf(URLImpl *url, char *dstbuf, int dstbuf_size, int *length);
 
 const char *url_scheme_get(URLImpl *url, int *length);
-void url_MD5_get(URLImpl *url, INK_MD5 *md5);
-void url_host_MD5_get(URLImpl *url, INK_MD5 *md5);
-const char *url_scheme_set(HdrHeap *heap, URLImpl *url,
-                           const char *value, int value_wks_idx, int length, bool copy_string);
+void url_MD5_get(URLImpl *url, CryptoHash *md5);
+void url_host_MD5_get(URLImpl *url, CryptoHash *md5);
+const char *url_scheme_set(HdrHeap *heap, URLImpl *url, const char *value, int value_wks_idx, int length, bool copy_string);
 
 /* Internet specific */
 void url_user_set(HdrHeap *heap, URLImpl *url, const char *value, int length, bool copy_string);
@@ -198,13 +233,12 @@ void url_query_set(HdrHeap *heap, URLImpl *url, const char *value, int length, b
 void url_fragment_set(HdrHeap *heap, URLImpl *url, const char *value, int length, bool copy_string);
 
 MIMEParseResult url_parse(HdrHeap *heap, URLImpl *url, const char **start, const char *end, bool copy_strings);
-MIMEParseResult url_parse_no_path_component_breakdown(HdrHeap *heap, URLImpl *url,
-                                                      const char **start, const char *end, bool copy_strings);
-MIMEParseResult url_parse_internet(HdrHeap *heap, URLImpl *url,
-                                   const char **start, const char *end, bool copy_strings);
+MIMEParseResult url_parse_no_path_component_breakdown(HdrHeap *heap, URLImpl *url, const char **start, const char *end,
+                                                      bool copy_strings);
+MIMEParseResult url_parse_internet(HdrHeap *heap, URLImpl *url, const char **start, const char *end, bool copy_strings);
 MIMEParseResult url_parse_http(HdrHeap *heap, URLImpl *url, const char **start, const char *end, bool copy_strings);
-MIMEParseResult url_parse_http_no_path_component_breakdown(HdrHeap *heap, URLImpl *url,
-                                                           const char **start, const char *end, bool copy_strings);
+MIMEParseResult url_parse_http_no_path_component_breakdown(HdrHeap *heap, URLImpl *url, const char **start, const char *end,
+                                                           bool copy_strings);
 
 char *url_unescapify(Arena *arena, const char *str, int length);
 
@@ -224,7 +258,7 @@ url_canonicalize_port(int type, int port)
   return (port);
 }
 
-class URL:public HdrHeapSDKHandle
+class URL : public HdrHeapSDKHandle
 {
 public:
   URLImpl *m_url_impl;
@@ -249,8 +283,8 @@ public:
   char *string_get(Arena *arena, int *length = NULL);
   char *string_get_ref(int *length = NULL);
   char *string_get_buf(char *dstbuf, int dsbuf_size, int *length = NULL);
-  void MD5_get(INK_MD5 *md5);
-  void host_MD5_get(INK_MD5 *md5);
+  void hash_get(CryptoHash *md5);
+  void host_hash_get(CryptoHash *md5);
 
   const char *scheme_get(int *length);
   int scheme_get_wksidx();
@@ -287,27 +321,23 @@ public:
   static char *unescapify(Arena *arena, const char *str, int length);
 
 private:
-
   // No gratuitous copies!
-    URL(const URL & u);
-    URL & operator =(const URL & u);
+  URL(const URL &u);
+  URL &operator=(const URL &u);
 };
 
 
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
 
-inline
-URL::URL()
-  : m_url_impl(NULL)
+inline URL::URL() : m_url_impl(NULL)
 {
 }
 
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
 
-inline
-URL::~URL()
+inline URL::~URL()
 {
 }
 
@@ -440,7 +470,7 @@ URL::string_get_buf(char *dstbuf, int dsbuf_size, int *length)
   -------------------------------------------------------------------------*/
 
 inline void
-URL::MD5_get(INK_MD5 *md5)
+URL::hash_get(CryptoHash *md5)
 {
   ink_assert(valid());
   url_MD5_get(m_url_impl, md5);
@@ -450,7 +480,7 @@ URL::MD5_get(INK_MD5 *md5)
   -------------------------------------------------------------------------*/
 
 inline void
-URL::host_MD5_get(INK_MD5 *md5)
+URL::host_hash_get(CryptoHash *md5)
 {
   ink_assert(valid());
   url_host_MD5_get(m_url_impl, md5);
@@ -704,7 +734,7 @@ URL::parse(const char *str, int length)
 {
   ink_assert(valid());
   if (length < 0)
-    length = (int) strlen(str);
+    length = (int)strlen(str);
   return parse(&str, str + length);
 }
 
@@ -718,7 +748,7 @@ URL::parse_no_path_component_breakdown(const char *str, int length)
 {
   ink_assert(valid());
   if (length < 0)
-    length = (int) strlen(str);
+    length = (int)strlen(str);
   ink_assert(valid());
   return url_parse_no_path_component_breakdown(m_heap, m_url_impl, &str, str + length, true);
 }
@@ -733,4 +763,3 @@ URL::unescapify(Arena *arena, const char *str, int length)
 }
 
 #endif /* __URL_H__ */
-
