@@ -57,8 +57,8 @@
  */
 #define LAZY_BUF_ALLOC
 
-#define HTTP_API_CONTINUE   (INK_API_EVENT_EVENTS_START + 0)
-#define HTTP_API_ERROR      (INK_API_EVENT_EVENTS_START + 1)
+#define HTTP_API_CONTINUE (INK_API_EVENT_EVENTS_START + 0)
+#define HTTP_API_ERROR (INK_API_EVENT_EVENTS_START + 1)
 
 // The default size for http header buffers when we don't
 //   need to include extra space for the document
@@ -75,26 +75,28 @@ class HttpServerSession;
 class AuthHttpAdapter;
 
 class HttpSM;
-typedef int (HttpSM::*HttpSMHandler) (int event, void *data);
+typedef int (HttpSM::*HttpSMHandler)(int event, void *data);
 
-enum HttpVC_t
-{ HTTP_UNKNOWN = 0, HTTP_UA_VC, HTTP_SERVER_VC,
-  HTTP_TRANSFORM_VC, HTTP_CACHE_READ_VC,
-  HTTP_CACHE_WRITE_VC, HTTP_RAW_SERVER_VC
+enum HttpVC_t {
+  HTTP_UNKNOWN = 0,
+  HTTP_UA_VC,
+  HTTP_SERVER_VC,
+  HTTP_TRANSFORM_VC,
+  HTTP_CACHE_READ_VC,
+  HTTP_CACHE_WRITE_VC,
+  HTTP_RAW_SERVER_VC
 };
 
-enum BackgroundFill_t
-{
+enum BackgroundFill_t {
   BACKGROUND_FILL_NONE = 0,
   BACKGROUND_FILL_STARTED,
   BACKGROUND_FILL_ABORTED,
-  BACKGROUND_FILL_COMPLETED
+  BACKGROUND_FILL_COMPLETED,
 };
 
 extern ink_mutex debug_sm_list_mutex;
 
-struct HttpVCTableEntry
-{
+struct HttpVCTableEntry {
   VConnection *vc;
   MIOBuffer *read_buffer;
   MIOBuffer *write_buffer;
@@ -106,8 +108,7 @@ struct HttpVCTableEntry
   bool in_tunnel;
 };
 
-struct HttpVCTable
-{
+struct HttpVCTable {
   static const int vc_table_max_entries = 4;
   HttpVCTable();
 
@@ -134,80 +135,81 @@ HttpVCTable::is_table_clear() const
   return true;
 }
 
-struct HttpTransformInfo
-{
+struct HttpTransformInfo {
   HttpVCTableEntry *entry;
   VConnection *vc;
 
-    HttpTransformInfo():entry(NULL), vc(NULL)
-  {
-  }
+  HttpTransformInfo() : entry(NULL), vc(NULL) {}
 };
-#define HISTORY_SIZE  64
+#define HISTORY_SIZE 64
 
-enum
-{
+enum {
   HTTP_SM_MAGIC_ALIVE = 0x0000FEED,
-  HTTP_SM_MAGIC_DEAD = 0xDEADFEED
+  HTTP_SM_MAGIC_DEAD = 0xDEADFEED,
 };
 
-enum
-{
+enum {
   HTTP_SM_POST_UNKNOWN = 0,
   HTTP_SM_POST_UA_FAIL = 1,
   HTTP_SM_POST_SERVER_FAIL = 2,
-  HTTP_SM_POST_SUCCESS = 3
+  HTTP_SM_POST_SUCCESS = 3,
 };
 
-enum
-{
+enum {
   HTTP_SM_TRANSFORM_OPEN = 0,
   HTTP_SM_TRANSFORM_CLOSED = 1,
-  HTTP_SM_TRANSFORM_FAIL = 2
+  HTTP_SM_TRANSFORM_FAIL = 2,
 };
 
-enum HttpApiState_t
-{
+enum HttpApiState_t {
   HTTP_API_NO_CALLOUT,
   HTTP_API_IN_CALLOUT,
   HTTP_API_DEFERED_CLOSE,
-  HTTP_API_DEFERED_SERVER_ERROR
+  HTTP_API_DEFERED_SERVER_ERROR,
 };
 
 
-enum HttpPluginTunnel_t
-{
+enum HttpPluginTunnel_t {
   HTTP_NO_PLUGIN_TUNNEL = 0,
   HTTP_PLUGIN_AS_SERVER,
-  HTTP_PLUGIN_AS_INTERCEPT
+  HTTP_PLUGIN_AS_INTERCEPT,
 };
 
 class CoreUtils;
 class PluginVCCore;
 
-class HttpSM: public Continuation
+class HttpSM : public Continuation
 {
   friend class HttpPagesHandler;
   friend class CoreUtils;
+
 public:
   HttpSM();
   void cleanup();
   virtual void destroy();
 
   static HttpSM *allocate();
-  HttpCacheSM & get_cache_sm();       //Added to get the object of CacheSM YTS Team, yamsat
-  HttpVCTableEntry *get_ua_entry();     //Added to get the ua_entry pointer  - YTS-TEAM
-  static void _instantiate_func(HttpSM * prototype, HttpSM * new_instance);
-  static void _make_scatter_list(HttpSM * prototype);
+  HttpCacheSM &get_cache_sm();      // Added to get the object of CacheSM YTS Team, yamsat
+  HttpVCTableEntry *get_ua_entry(); // Added to get the ua_entry pointer  - YTS-TEAM
+  static void _instantiate_func(HttpSM *prototype, HttpSM *new_instance);
+  static void _make_scatter_list(HttpSM *prototype);
 
   void init();
 
-  void attach_client_session(HttpClientSession * client_vc_arg, IOBufferReader * buffer_reader);
+  void attach_client_session(HttpClientSession *client_vc_arg, IOBufferReader *buffer_reader);
 
   // Called by httpSessionManager so that we can reset
   //  the session timeouts and initiate a read while
   //  holding the lock for the server session
-  void attach_server_session(HttpServerSession * s);
+  void attach_server_session(HttpServerSession *s);
+
+  // Used to read attributes of
+  // the current active server session
+  HttpServerSession *
+  get_server_session()
+  {
+    return server_session;
+  }
 
   // Called by transact.  Updates are fire and forget
   //  so there are no callbacks and are safe to do
@@ -218,11 +220,11 @@ public:
   // setup Range transfomration if so.
   // return true when the Range is unsatisfiable
   void do_range_setup_if_necessary();
-  
+
   void do_range_parse(MIMEField *range_field);
   void calculate_output_cl(int64_t, int64_t);
-  void parse_range_and_compare(MIMEField*, int64_t);
-  
+  void parse_range_and_compare(MIMEField *, int64_t);
+
   // Called by transact to prevent reset problems
   //  failed PUSH requests
   void set_ua_half_close_flag();
@@ -232,8 +234,8 @@ public:
   // Handles the setting of all state necessary before
   //   calling transact to process the hostdb lookup
   // A NULL 'r' argument indicates the hostdb lookup failed
-  void process_hostdb_info(HostDBInfo * r);
-  void process_srv_info(HostDBInfo * r);
+  void process_hostdb_info(HostDBInfo *r);
+  void process_srv_info(HostDBInfo *r);
 
   // Called by transact.  Synchronous.
   VConnection *do_transform_open();
@@ -245,7 +247,8 @@ public:
   int state_api_callout(int event, void *data);
 
   // Used for Http Stat Pages
-  HttpTunnel *get_tunnel()
+  HttpTunnel *
+  get_tunnel()
   {
     return &tunnel;
   };
@@ -255,8 +258,8 @@ public:
   void dump_state_hdr(HTTPHdr *h, const char *s);
 
   // Functions for manipulating api hooks
-  void txn_hook_append(TSHttpHookID id, INKContInternal * cont);
-  void txn_hook_prepend(TSHttpHookID id, INKContInternal * cont);
+  void txn_hook_append(TSHttpHookID id, INKContInternal *cont);
+  void txn_hook_prepend(TSHttpHookID id, INKContInternal *cont);
   APIHook *txn_hook_get(TSHttpHookID id);
 
   void add_history_entry(const char *fileline, int event, int reentrant);
@@ -267,14 +270,14 @@ public:
   int64_t sm_id;
   unsigned int magic;
 
-  //YTS Team, yamsat Plugin
-  bool enable_redirection;      //To check if redirection is enabled
-  char *redirect_url;     //url for force redirect (provide users a functionality to redirect to another url when needed)
+  // YTS Team, yamsat Plugin
+  bool enable_redirection; // To check if redirection is enabled
+  char *redirect_url;      // url for force redirect (provide users a functionality to redirect to another url when needed)
   int redirect_url_len;
-  int redirection_tries;        //To monitor number of redirections
-  int64_t transfered_bytes;     //Added to calculate POST data
-  bool post_failed;             //Added to identify post failure
-  bool debug_on;               //Transaction specific debug flag
+  int redirection_tries;    // To monitor number of redirections
+  int64_t transfered_bytes; // Added to calculate POST data
+  bool post_failed;         // Added to identify post failure
+  bool debug_on;            // Transaction specific debug flag
 
   // Tunneling request to plugin
   HttpPluginTunnel_t plugin_tunnel_type;
@@ -285,8 +288,7 @@ public:
 protected:
   int reentrancy_count;
 
-  struct History
-  {
+  struct History {
     const char *fileline;
     unsigned short event;
     short reentrancy;
@@ -304,16 +306,23 @@ protected:
 public:
   HttpClientSession *ua_session;
   BackgroundFill_t background_fill;
-  //AuthHttpAdapter authAdapter;
+  // AuthHttpAdapter authAdapter;
   void set_http_schedule(Continuation *);
   int get_http_schedule(int event, void *data);
 
 protected:
-  IOBufferReader * ua_buffer_reader;
-  IOBufferReader * ua_raw_buffer_reader;
+  IOBufferReader *ua_buffer_reader;
+  IOBufferReader *ua_raw_buffer_reader;
 
   HttpVCTableEntry *server_entry;
   HttpServerSession *server_session;
+
+  /* Because we don't want to take a session from a shared pool if we know that it will be private,
+   * but we cannot set it to private until we have an attached server session.
+   * So we use this variable to indicate that
+   * we should create a new connection and then once we attach the session we'll mark it as private.
+   */
+  bool will_be_private_ss;
   int shared_session_retries;
   IOBufferReader *server_buffer_reader;
   void remove_server_entry();
@@ -341,10 +350,10 @@ protected:
   int tunnel_handler_push(int event, void *data);
   int tunnel_handler_post(int event, void *data);
 
-  //YTS Team, yamsat Plugin
+  // YTS Team, yamsat Plugin
   int tunnel_handler_for_partial_post(int event, void *data);
 
-  void tunnel_handler_post_or_put(HttpTunnelProducer * p);
+  void tunnel_handler_post_or_put(HttpTunnelProducer *p);
 
   int tunnel_handler_100_continue(int event, void *data);
   int tunnel_handler_cache_fill(int event, void *data);
@@ -365,7 +374,7 @@ protected:
   int state_remove_from_list(int event, void *data);
   int state_congestion_control_lookup(int event, void *data);
 
-//Y! ebalsa: remap handlers
+  // Y! ebalsa: remap handlers
   int state_remap_request(int event, void *data);
   void do_remap_request(bool);
 
@@ -383,22 +392,22 @@ protected:
   // API
   int state_request_wait_for_transform_read(int event, void *data);
   int state_response_wait_for_transform_read(int event, void *data);
-  int state_common_wait_for_transform_read(HttpTransformInfo * t_info, HttpSMHandler tunnel_handler, int event, void *data);
+  int state_common_wait_for_transform_read(HttpTransformInfo *t_info, HttpSMHandler tunnel_handler, int event, void *data);
 
   // Tunnel event handlers
-  int tunnel_handler_server(int event, HttpTunnelProducer * p);
-  int tunnel_handler_ua(int event, HttpTunnelConsumer * c);
-  int tunnel_handler_ua_push(int event, HttpTunnelProducer * p);
-  int tunnel_handler_100_continue_ua(int event, HttpTunnelConsumer * c);
-  int tunnel_handler_cache_write(int event, HttpTunnelConsumer * c);
-  int tunnel_handler_cache_read(int event, HttpTunnelProducer * p);
-  int tunnel_handler_post_ua(int event, HttpTunnelProducer * c);
-  int tunnel_handler_post_server(int event, HttpTunnelConsumer * c);
-  int tunnel_handler_ssl_producer(int event, HttpTunnelProducer * p);
-  int tunnel_handler_ssl_consumer(int event, HttpTunnelConsumer * p);
-  int tunnel_handler_transform_write(int event, HttpTunnelConsumer * c);
-  int tunnel_handler_transform_read(int event, HttpTunnelProducer * p);
-  int tunnel_handler_plugin_agent(int event, HttpTunnelConsumer * c);
+  int tunnel_handler_server(int event, HttpTunnelProducer *p);
+  int tunnel_handler_ua(int event, HttpTunnelConsumer *c);
+  int tunnel_handler_ua_push(int event, HttpTunnelProducer *p);
+  int tunnel_handler_100_continue_ua(int event, HttpTunnelConsumer *c);
+  int tunnel_handler_cache_write(int event, HttpTunnelConsumer *c);
+  int tunnel_handler_cache_read(int event, HttpTunnelProducer *p);
+  int tunnel_handler_post_ua(int event, HttpTunnelProducer *c);
+  int tunnel_handler_post_server(int event, HttpTunnelConsumer *c);
+  int tunnel_handler_ssl_producer(int event, HttpTunnelProducer *p);
+  int tunnel_handler_ssl_consumer(int event, HttpTunnelConsumer *p);
+  int tunnel_handler_transform_write(int event, HttpTunnelConsumer *c);
+  int tunnel_handler_transform_read(int event, HttpTunnelProducer *p);
+  int tunnel_handler_plugin_agent(int event, HttpTunnelConsumer *c);
 
   void do_hostdb_lookup();
   void do_hostdb_reverse_lookup();
@@ -408,9 +417,8 @@ protected:
   void do_cache_prepare_write();
   void do_cache_prepare_write_transform();
   void do_cache_prepare_update();
-  void do_cache_prepare_action(HttpCacheSM * c_sm,
-                               CacheHTTPInfo * object_read_info, bool retry, bool allow_multiple = false);
-  void do_cache_delete_all_alts(Continuation * cont);
+  void do_cache_prepare_action(HttpCacheSM *c_sm, CacheHTTPInfo *object_read_info, bool retry, bool allow_multiple = false);
+  void do_cache_delete_all_alts(Continuation *cont);
   void do_icp_lookup();
   void do_auth_callout();
   void do_api_callout();
@@ -427,12 +435,12 @@ protected:
   void handle_server_setup_error(int event, void *data);
   void handle_http_server_open();
   void handle_post_failure();
-  void mark_host_failure(HostDBInfo * info, time_t time_down);
+  void mark_host_failure(HostDBInfo *info, time_t time_down);
   void mark_server_down_on_client_abort();
   void release_server_session(bool serve_from_cache = false);
   void set_ua_abort(HttpTransact::AbortState_t ua_abort, int event);
-  int write_header_into_buffer(HTTPHdr * h, MIOBuffer * b);
-  int write_response_header_into_buffer(HTTPHdr * h, MIOBuffer * b);
+  int write_header_into_buffer(HTTPHdr *h, MIOBuffer *b);
+  int write_response_header_into_buffer(HTTPHdr *h, MIOBuffer *b);
   void setup_blind_tunnel_port();
   void setup_client_header_nca();
   void setup_client_read_request_header();
@@ -441,16 +449,16 @@ protected:
   void setup_cache_lookup_complete_api();
   void setup_server_send_request();
   void setup_server_send_request_api();
-  void setup_server_transfer();
+  HttpTunnelProducer *setup_server_transfer();
   void setup_server_transfer_to_cache_only();
-  void setup_cache_read_transfer();
+  HttpTunnelProducer *setup_cache_read_transfer();
   void setup_internal_transfer(HttpSMHandler handler);
   void setup_error_transfer();
   void setup_100_continue_transfer();
-  void setup_push_transfer_to_cache();
+  HttpTunnelProducer *setup_push_transfer_to_cache();
   void setup_transform_to_server_transfer();
-  void setup_cache_write_transfer(HttpCacheSM * c_sm,
-                                  VConnection * source_vc, HTTPInfo * store_info, int64_t skip_bytes, const char *name);
+  void setup_cache_write_transfer(HttpCacheSM *c_sm, VConnection *source_vc, HTTPInfo *store_info, int64_t skip_bytes,
+                                  const char *name);
   void issue_cache_update();
   void perform_cache_write_action();
   void perform_transform_cache_write_action();
@@ -460,18 +468,18 @@ protected:
   HttpTunnelProducer *setup_transfer_from_transform();
   HttpTunnelProducer *setup_cache_transfer_to_transform();
   HttpTunnelProducer *setup_transfer_from_transform_to_cache_only();
-  void setup_plugin_agents(HttpTunnelProducer* p);
+  void setup_plugin_agents(HttpTunnelProducer *p);
 
   HttpTransact::StateMachineAction_t last_action;
-  int (HttpSM::*m_last_state) (int event, void *data);
+  int (HttpSM::*m_last_state)(int event, void *data);
   virtual void set_next_state();
   void call_transact_and_set_next_state(TransactEntryFunc_t f);
 
   bool is_http_server_eos_truncation(HttpTunnelProducer *);
-  bool is_bg_fill_necessary(HttpTunnelConsumer * c);
+  bool is_bg_fill_necessary(HttpTunnelConsumer *c);
   int find_server_buffer_size();
   int find_http_resp_buffer_size(int64_t cl);
-  int64_t server_transfer_init(MIOBuffer * buf, int hdr_size);
+  int64_t server_transfer_init(MIOBuffer *buf, int hdr_size);
 
 public:
   // Stats & Logging Info
@@ -491,13 +499,13 @@ public:
   // The next two enable plugins to tag the state machine for
   // the purposes of logging so the instances can be correlated
   // with the source plugin.
-  char const* plugin_tag;
+  char const *plugin_tag;
   int64_t plugin_id;
 
   // hooks_set records whether there are any hooks relevant
   //  to this transaction.  Used to avoid costly calls
   //  do_api_callout_internal()
-  int hooks_set;
+  bool hooks_set;
 
 protected:
   TSHttpHookID cur_hook_id;
@@ -520,10 +528,11 @@ protected:
   //   when the flag is set
   bool terminate_sm;
   bool kill_this_async_done;
+  bool parse_range_done;
   virtual int kill_this_async_hook(int event, void *data);
   void kill_this();
   void update_stats();
-  void transform_cleanup(TSHttpHookID hook, HttpTransformInfo * info);
+  void transform_cleanup(TSHttpHookID hook, HttpTransformInfo *info);
   bool is_transparent_passthrough_allowed();
   void plugin_agents_cleanup();
 
@@ -534,14 +543,14 @@ public:
   bool set_server_session_private(bool private_session);
 };
 
-//Function to get the cache_sm object - YTS Team, yamsat
+// Function to get the cache_sm object - YTS Team, yamsat
 inline HttpCacheSM &
 HttpSM::get_cache_sm()
 {
   return cache_sm;
 }
 
-//Function to get the ua_entry pointer - YTS Team, yamsat
+// Function to get the ua_entry pointer - YTS Team, yamsat
 inline HttpVCTableEntry *
 HttpSM::get_ua_entry()
 {
@@ -572,7 +581,7 @@ HttpSM::remove_server_entry()
 }
 
 inline int
-HttpSM::write_response_header_into_buffer(HTTPHdr * h, MIOBuffer * b)
+HttpSM::write_response_header_into_buffer(HTTPHdr *h, MIOBuffer *b)
 {
   if (t_state.client_info.http_version == HTTPVersion(0, 9)) {
     return 0;
@@ -586,8 +595,8 @@ HttpSM::add_history_entry(const char *fileline, int event, int reentrant)
 {
   int pos = history_pos++ % HISTORY_SIZE;
   history[pos].fileline = fileline;
-  history[pos].event = (unsigned short) event;
-  history[pos].reentrancy = (short) reentrant;
+  history[pos].event = (unsigned short)event;
+  history[pos].reentrancy = (short)reentrant;
 }
 
 inline int
@@ -597,14 +606,14 @@ HttpSM::find_server_buffer_size()
 }
 
 inline void
-HttpSM::txn_hook_append(TSHttpHookID id, INKContInternal * cont)
+HttpSM::txn_hook_append(TSHttpHookID id, INKContInternal *cont)
 {
   api_hooks.append(id, cont);
   hooks_set = 1;
 }
 
 inline void
-HttpSM::txn_hook_prepend(TSHttpHookID id, INKContInternal * cont)
+HttpSM::txn_hook_prepend(TSHttpHookID id, INKContInternal *cont)
 {
   api_hooks.prepend(id, cont);
   hooks_set = 1;
@@ -636,9 +645,7 @@ HttpSM::add_cache_sm()
 inline bool
 HttpSM::is_transparent_passthrough_allowed()
 {
-  return (t_state.client_info.is_transparent &&
-          ua_session->f_transparent_passthrough &&
-          ua_session->get_transact_count() == 1);
+  return (t_state.client_info.is_transparent && ua_session->f_transparent_passthrough && ua_session->get_transact_count() == 1);
 }
 
 #endif
