@@ -43,49 +43,46 @@
 #ifdef MAX_CONSUMERS
 #undef MAX_CONSUMERS
 #endif
-#define MAX_PRODUCERS   2
-#define MAX_CONSUMERS   4
+#define MAX_PRODUCERS 2
+#define MAX_CONSUMERS 4
 
-#define HTTP_TUNNEL_EVENT_DONE             (HTTP_TUNNEL_EVENTS_START + 1)
-#define HTTP_TUNNEL_EVENT_PRECOMPLETE      (HTTP_TUNNEL_EVENTS_START + 2)
-#define HTTP_TUNNEL_EVENT_CONSUMER_DETACH  (HTTP_TUNNEL_EVENTS_START + 3)
+#define HTTP_TUNNEL_EVENT_DONE (HTTP_TUNNEL_EVENTS_START + 1)
+#define HTTP_TUNNEL_EVENT_PRECOMPLETE (HTTP_TUNNEL_EVENTS_START + 2)
+#define HTTP_TUNNEL_EVENT_CONSUMER_DETACH (HTTP_TUNNEL_EVENTS_START + 3)
 
-#define HTTP_TUNNEL_STATIC_PRODUCER  (VConnection*)!0
+#define HTTP_TUNNEL_STATIC_PRODUCER (VConnection *) !0
 
-//YTS Team, yamsat Plugin
+// YTS Team, yamsat Plugin
 #define ALLOCATE_AND_WRITE_TO_BUF 1
 #define WRITE_TO_BUF 2
 
 struct HttpTunnelProducer;
 class HttpSM;
 class HttpPagesHandler;
-typedef int (HttpSM::*HttpSMHandler) (int event, void *data);
+typedef int (HttpSM::*HttpSMHandler)(int event, void *data);
 
 struct HttpTunnelConsumer;
 struct HttpTunnelProducer;
-typedef int (HttpSM::*HttpProducerHandler) (int event, HttpTunnelProducer * p);
-typedef int (HttpSM::*HttpConsumerHandler) (int event, HttpTunnelConsumer * c);
+typedef int (HttpSM::*HttpProducerHandler)(int event, HttpTunnelProducer *p);
+typedef int (HttpSM::*HttpConsumerHandler)(int event, HttpTunnelConsumer *c);
 
-enum HttpTunnelType_t
-{
+enum HttpTunnelType_t {
   HT_HTTP_SERVER,
   HT_HTTP_CLIENT,
   HT_CACHE_READ,
   HT_CACHE_WRITE,
   HT_TRANSFORM,
-  HT_STATIC
+  HT_STATIC,
 };
 
-enum TunnelChunkingAction_t
-{
+enum TunnelChunkingAction_t {
   TCA_CHUNK_CONTENT,
   TCA_DECHUNK_CONTENT,
   TCA_PASSTHRU_CHUNKED_CONTENT,
   TCA_PASSTHRU_DECHUNKED_CONTENT
 };
 
-struct ChunkedHandler
-{
+struct ChunkedHandler {
   enum ChunkedState {
     CHUNK_READ_CHUNK = 0,
     CHUNK_READ_SIZE_START,
@@ -163,8 +160,7 @@ private:
   int64_t transfer_bytes();
 };
 
-struct HttpTunnelConsumer
-{
+struct HttpTunnelConsumer {
   HttpTunnelConsumer();
 
   LINK(HttpTunnelConsumer, link);
@@ -177,9 +173,9 @@ struct HttpTunnelConsumer
   HttpConsumerHandler vc_handler;
   VIO *write_vio;
 
-  int64_t skip_bytes;               // bytes to skip at beginning of stream
-  int64_t bytes_written;            // total bytes written to the vc
-  int handler_state;              // state used the handlers
+  int64_t skip_bytes;    // bytes to skip at beginning of stream
+  int64_t bytes_written; // total bytes written to the vc
+  int handler_state;     // state used the handlers
 
   bool alive;
   bool write_success;
@@ -189,15 +185,14 @@ struct HttpTunnelConsumer
       @return @c true if any producer in the tunnel eventually feeds
       data to this consumer.
   */
-  bool is_downstream_from(VConnection* vc);
+  bool is_downstream_from(VConnection *vc);
   /** Check if this is a sink (final data destination).
       @return @c true if data exits the ATS process at this consumer.
   */
   bool is_sink() const;
 };
 
-struct HttpTunnelProducer
-{
+struct HttpTunnelProducer {
   HttpTunnelProducer();
 
   DLL<HttpTunnelConsumer> consumer_list;
@@ -216,12 +211,12 @@ struct HttpTunnelProducer
   bool do_dechunking;
   bool do_chunked_passthru;
 
-  int64_t init_bytes_done;          // bytes passed in buffer
-  int64_t nbytes;                   // total bytes (client's perspective)
-  int64_t ntodo;                    // what this vc needs to do
-  int64_t bytes_read;               // total bytes read from the vc
-  int handler_state;              // state used the handlers
-  int last_event;                   ///< Tracking for flow control restarts.
+  int64_t init_bytes_done; // bytes passed in buffer
+  int64_t nbytes;          // total bytes (client's perspective)
+  int64_t ntodo;           // what this vc needs to do
+  int64_t bytes_read;      // total bytes read from the vc
+  int handler_state;       // state used the handlers
+  int last_event;          ///< Tracking for flow control restarts.
 
   int num_consumers;
 
@@ -230,16 +225,15 @@ struct HttpTunnelProducer
   /// Flag and pointer for active flow control throttling.
   /// If this is set, it points at the source producer that is under flow control.
   /// If @c NULL then data flow is not being throttled.
-  HttpTunnelProducer* flow_control_source;
+  HttpTunnelProducer *flow_control_source;
   const char *name;
 
   /** Get the largest number of bytes any consumer has not consumed.
       Use @a limit if you only need to check if the backlog is at least @a limit.
       @return The actual backlog or a number at least @a limit.
    */
-  uint64_t backlog(
-		   uint64_t limit = INTU64_MAX ///< More than this is irrelevant
-		   );
+  uint64_t backlog(uint64_t limit = UINT64_MAX ///< More than this is irrelevant
+                   );
   /// Check if producer is original (to ATS) source of data.
   /// @return @c true if this producer is the source of bytes from outside ATS.
   bool is_source() const;
@@ -250,24 +244,28 @@ struct HttpTunnelProducer
   /// Check throttled state.
   bool is_throttled() const;
 
+  /// Update the handler_state member if it is still 0
+  void update_state_if_not_set(int new_handler_state);
+
   /** Set the flow control source producer for the flow.
       This sets the value for this producer and all downstream producers.
       @note This is the implementation for @c throttle and @c unthrottle.
       @see throttle
       @see unthrottle
   */
-  void set_throttle_src(
-			HttpTunnelProducer* srcp ///< Source producer of flow.
-			);
+  void set_throttle_src(HttpTunnelProducer *srcp ///< Source producer of flow.
+                        );
 };
 
 class PostDataBuffers
 {
 public:
   PostDataBuffers()
-    : postdata_producer_buffer(NULL), postdata_copy_buffer(NULL), postdata_producer_reader(NULL),
-      postdata_copy_buffer_start(NULL), ua_buffer_reader(NULL)
-  { Debug("http_redirect", "[PostDataBuffers::PostDataBuffers]");  }
+    : postdata_producer_buffer(NULL), postdata_copy_buffer(NULL), postdata_producer_reader(NULL), postdata_copy_buffer_start(NULL),
+      ua_buffer_reader(NULL)
+  {
+    Debug("http_redirect", "[PostDataBuffers::PostDataBuffers]");
+  }
 
   MIOBuffer *postdata_producer_buffer;
   MIOBuffer *postdata_copy_buffer;
@@ -276,7 +274,7 @@ public:
   IOBufferReader *ua_buffer_reader;
 };
 
-class HttpTunnel:public Continuation
+class HttpTunnel : public Continuation
 {
   friend class HttpPagesHandler;
   friend class CoreUtils;
@@ -290,11 +288,11 @@ class HttpTunnel:public Continuation
   */
   struct FlowControl {
     // Default value for high and low water marks.
-    static uint64_t const DEFAULT_WATER_MARK = 1<<16;
+    static uint64_t const DEFAULT_WATER_MARK = 1 << 16;
 
     uint64_t high_water; ///< Buffered data limit - throttle if more than this.
-    uint64_t low_water; ///< Unthrottle if less than this buffered.
-    bool enabled_p; ///< Flow control state (@c false means disabled).
+    uint64_t low_water;  ///< Unthrottle if less than this buffered.
+    bool enabled_p;      ///< Flow control state (@c false means disabled).
 
     /// Default constructor.
     FlowControl();
@@ -303,51 +301,51 @@ class HttpTunnel:public Continuation
 public:
   HttpTunnel();
 
-  void init(HttpSM * sm_arg, ProxyMutex * amutex);
+  void init(HttpSM *sm_arg, ProxyMutex *amutex);
   void reset();
   void kill_tunnel();
-  bool is_tunnel_active() const { return active; }
+  bool
+  is_tunnel_active() const
+  {
+    return active;
+  }
   bool is_tunnel_alive() const;
   bool has_cache_writer() const;
 
   // YTS Team, yamsat Plugin
   void copy_partial_post_data();
   void allocate_redirect_postdata_producer_buffer();
-  void allocate_redirect_postdata_buffers(IOBufferReader * ua_reader);
+  void allocate_redirect_postdata_buffers(IOBufferReader *ua_reader);
   void deallocate_redirect_postdata_buffers();
 
-  HttpTunnelProducer *add_producer(VConnection * vc,
-                                   int64_t nbytes,
-                                   IOBufferReader * reader_start,
-                                   HttpProducerHandler sm_handler, HttpTunnelType_t vc_type, const char *name);
+  HttpTunnelProducer *add_producer(VConnection *vc, int64_t nbytes, IOBufferReader *reader_start, HttpProducerHandler sm_handler,
+                                   HttpTunnelType_t vc_type, const char *name);
 
-  void set_producer_chunking_action(HttpTunnelProducer * p, int64_t skip_bytes, TunnelChunkingAction_t action);
+  void set_producer_chunking_action(HttpTunnelProducer *p, int64_t skip_bytes, TunnelChunkingAction_t action);
   /// Set the maximum (preferred) chunk @a size of chunked output for @a producer.
-  void set_producer_chunking_size(HttpTunnelProducer* producer, int64_t size);
+  void set_producer_chunking_size(HttpTunnelProducer *producer, int64_t size);
 
-  HttpTunnelConsumer *add_consumer(VConnection * vc,
-                                   VConnection * producer,
-                                   HttpConsumerHandler sm_handler,
-                                   HttpTunnelType_t vc_type, const char *name, int64_t skip_bytes = 0);
+  HttpTunnelConsumer *add_consumer(VConnection *vc, VConnection *producer, HttpConsumerHandler sm_handler, HttpTunnelType_t vc_type,
+                                   const char *name, int64_t skip_bytes = 0);
 
   int deallocate_buffers();
-  DLL<HttpTunnelConsumer> *get_consumers(VConnection * vc);
-  HttpTunnelProducer *get_producer(VConnection * vc);
-  HttpTunnelConsumer *get_consumer(VConnection * vc);
-  void tunnel_run(HttpTunnelProducer * p = NULL);
+  DLL<HttpTunnelConsumer> *get_consumers(VConnection *vc);
+  HttpTunnelProducer *get_producer(VConnection *vc);
+  HttpTunnelConsumer *get_consumer(VConnection *vc);
+  void tunnel_run(HttpTunnelProducer *p = NULL);
 
   int main_handler(int event, void *data);
-  bool consumer_reenable(HttpTunnelConsumer* c);
-  bool consumer_handler(int event, HttpTunnelConsumer * c);
-  bool producer_handler(int event, HttpTunnelProducer * p);
-  int producer_handler_dechunked(int event, HttpTunnelProducer * p);
-  int producer_handler_chunked(int event, HttpTunnelProducer * p);
-  void local_finish_all(HttpTunnelProducer * p);
-  void chain_finish_all(HttpTunnelProducer * p);
-  void chain_abort_cache_write(HttpTunnelProducer * p);
-  void chain_abort_all(HttpTunnelProducer * p);
-  void abort_cache_write_finish_others(HttpTunnelProducer * p);
-  void append_message_to_producer_buffer(HttpTunnelProducer * p, const char *msg, int64_t msg_len);
+  void consumer_reenable(HttpTunnelConsumer *c);
+  bool consumer_handler(int event, HttpTunnelConsumer *c);
+  bool producer_handler(int event, HttpTunnelProducer *p);
+  int producer_handler_dechunked(int event, HttpTunnelProducer *p);
+  int producer_handler_chunked(int event, HttpTunnelProducer *p);
+  void local_finish_all(HttpTunnelProducer *p);
+  void chain_finish_all(HttpTunnelProducer *p);
+  void chain_abort_cache_write(HttpTunnelProducer *p);
+  void chain_abort_all(HttpTunnelProducer *p);
+  void abort_cache_write_finish_others(HttpTunnelProducer *p);
+  void append_message_to_producer_buffer(HttpTunnelProducer *p, const char *msg, int64_t msg_len);
 
   /** Mark a producer and consumer as the same underlying object.
 
@@ -356,23 +354,21 @@ public:
       example is a transform which serves as a consumer on the server
       side and a producer on the cache/client side.
   */
-  void chain(
-	     HttpTunnelConsumer* c,  ///< Flow goes in here
-	     HttpTunnelProducer* p   ///< Flow comes back out here
-	     );
+  void chain(HttpTunnelConsumer *c, ///< Flow goes in here
+             HttpTunnelProducer *p  ///< Flow comes back out here
+             );
 
-  void close_vc(HttpTunnelProducer * p);
-  void close_vc(HttpTunnelConsumer * c);
+  void close_vc(HttpTunnelProducer *p);
+  void close_vc(HttpTunnelConsumer *c);
 
 private:
-
   void internal_error();
-  void finish_all_internal(HttpTunnelProducer * p, bool chain);
+  void finish_all_internal(HttpTunnelProducer *p, bool chain);
   void update_stats_after_abort(HttpTunnelType_t t);
-  void producer_run(HttpTunnelProducer * p);
+  void producer_run(HttpTunnelProducer *p);
 
-  HttpTunnelProducer *get_producer(VIO * vio);
-  HttpTunnelConsumer *get_consumer(VIO * vio);
+  HttpTunnelProducer *get_producer(VIO *vio);
+  HttpTunnelConsumer *get_consumer(VIO *vio);
 
   HttpTunnelProducer *alloc_producer();
   HttpTunnelConsumer *alloc_consumer();
@@ -389,7 +385,7 @@ private:
   FlowControl flow_state;
 
 public:
-  PostDataBuffers * postbuf;
+  PostDataBuffers *postbuf;
 };
 
 // void HttpTunnel::abort_cache_write_finish_others
@@ -398,7 +394,7 @@ public:
 //      all other local consumers
 //
 inline void
-HttpTunnel::abort_cache_write_finish_others(HttpTunnelProducer * p)
+HttpTunnel::abort_cache_write_finish_others(HttpTunnelProducer *p)
 {
   chain_abort_cache_write(p);
   local_finish_all(p);
@@ -410,7 +406,7 @@ HttpTunnel::abort_cache_write_finish_others(HttpTunnelProducer * p)
 //      to finish their writes
 //
 inline void
-HttpTunnel::local_finish_all(HttpTunnelProducer * p)
+HttpTunnel::local_finish_all(HttpTunnelProducer *p)
 {
   finish_all_internal(p, false);
 }
@@ -422,7 +418,7 @@ HttpTunnel::local_finish_all(HttpTunnelProducer * p)
 //    that producer has placed in the buffer
 //
 inline void
-HttpTunnel::chain_finish_all(HttpTunnelProducer * p)
+HttpTunnel::chain_finish_all(HttpTunnelProducer *p)
 {
   finish_all_internal(p, true);
 }
@@ -445,14 +441,13 @@ HttpTunnel::is_tunnel_alive() const
         break;
       }
     }
-
   }
 
   return tunnel_alive;
 }
 
 inline HttpTunnelProducer *
-HttpTunnel::get_producer(VConnection * vc)
+HttpTunnel::get_producer(VConnection *vc)
 {
   for (int i = 0; i < MAX_PRODUCERS; i++) {
     if (producers[i].vc == vc) {
@@ -463,7 +458,7 @@ HttpTunnel::get_producer(VConnection * vc)
 }
 
 inline HttpTunnelConsumer *
-HttpTunnel::get_consumer(VConnection * vc)
+HttpTunnel::get_consumer(VConnection *vc)
 {
   for (int i = 0; i < MAX_CONSUMERS; i++) {
     if (consumers[i].vc == vc) {
@@ -474,7 +469,7 @@ HttpTunnel::get_consumer(VConnection * vc)
 }
 
 inline HttpTunnelProducer *
-HttpTunnel::get_producer(VIO * vio)
+HttpTunnel::get_producer(VIO *vio)
 {
   for (int i = 0; i < MAX_PRODUCERS; i++) {
     if (producers[i].read_vio == vio) {
@@ -485,7 +480,7 @@ HttpTunnel::get_producer(VIO * vio)
 }
 
 inline HttpTunnelConsumer *
-HttpTunnel::get_consumer(VIO * vio)
+HttpTunnel::get_consumer(VIO *vio)
 {
   for (int i = 0; i < MAX_CONSUMERS; i++) {
     if (consumers[i].write_vio == vio) {
@@ -496,7 +491,7 @@ HttpTunnel::get_consumer(VIO * vio)
 }
 
 inline void
-HttpTunnel::append_message_to_producer_buffer(HttpTunnelProducer * p, const char *msg, int64_t msg_len)
+HttpTunnel::append_message_to_producer_buffer(HttpTunnelProducer *p, const char *msg, int64_t msg_len)
 {
   if (p == NULL || p->read_buffer == NULL)
     return;
@@ -520,10 +515,11 @@ HttpTunnel::has_cache_writer() const
 inline bool
 HttpTunnelConsumer::is_downstream_from(VConnection *vc)
 {
-  HttpTunnelProducer* p = producer;
-  HttpTunnelConsumer* c;
+  HttpTunnelProducer *p = producer;
+  HttpTunnelConsumer *c;
   while (p) {
-    if (p->vc == vc) return true;
+    if (p->vc == vc)
+      return true;
     // The producer / consumer chain can contain a cycle in the case
     // of a blind tunnel so give up if we find ourself (the original
     // consumer).
@@ -547,6 +543,14 @@ HttpTunnelProducer::is_source() const
   return HT_HTTP_SERVER == vc_type || HT_CACHE_READ == vc_type || HT_HTTP_CLIENT == vc_type;
 }
 
+inline void
+HttpTunnelProducer::update_state_if_not_set(int new_handler_state)
+{
+  if (this->handler_state == 0) {
+    this->handler_state = new_handler_state;
+  }
+}
+
 inline bool
 HttpTunnelProducer::is_throttled() const
 {
@@ -567,11 +571,7 @@ HttpTunnelProducer::unthrottle()
     this->set_throttle_src(0);
 }
 
-inline
-HttpTunnel::FlowControl::FlowControl()
-	  : high_water(DEFAULT_WATER_MARK)
-	  , low_water(DEFAULT_WATER_MARK)
-	  , enabled_p(false)
+inline HttpTunnel::FlowControl::FlowControl() : high_water(DEFAULT_WATER_MARK), low_water(DEFAULT_WATER_MARK), enabled_p(false)
 {
 }
 
