@@ -31,7 +31,7 @@
 
 #define modulePrefix "[ReverseProxy]"
 
-static bool remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti);
+static bool remap_parse_config_bti(const char *path, BUILD_TABLE_INFO *bti);
 
 /**
   Returns the length of the URL.
@@ -72,8 +72,7 @@ clear_xstr_array(char *v[], size_t vsize)
   }
 }
 
-BUILD_TABLE_INFO::BUILD_TABLE_INFO()
-  : remap_optflg(0), paramc(0), argc(0), rules_list(NULL), rewrite(NULL)
+BUILD_TABLE_INFO::BUILD_TABLE_INFO() : remap_optflg(0), paramc(0), argc(0), rules_list(NULL), rewrite(NULL)
 {
   memset(this->paramv, 0, sizeof(this->paramv));
   memset(this->argv, 0, sizeof(this->argv));
@@ -93,34 +92,36 @@ BUILD_TABLE_INFO::reset()
 }
 
 static const char *
-process_filter_opt(url_mapping * mp, const BUILD_TABLE_INFO * bti, char * errStrBuf, int errStrBufSize)
+process_filter_opt(url_mapping *mp, const BUILD_TABLE_INFO *bti, char *errStrBuf, int errStrBufSize)
 {
   acl_filter_rule *rp, **rpp;
   const char *errStr = NULL;
 
   if (unlikely(!mp || !bti || !errStrBuf || errStrBufSize <= 0)) {
     Debug("url_rewrite", "[process_filter_opt] Invalid argument(s)");
-    return (const char *) "[process_filter_opt] Invalid argument(s)";
+    return (const char *)"[process_filter_opt] Invalid argument(s)";
   }
   for (rp = bti->rules_list; rp; rp = rp->next) {
     if (rp->active_queue_flag) {
       Debug("url_rewrite", "[process_filter_opt] Add active main filter \"%s\" (argc=%d)",
             rp->filter_name ? rp->filter_name : "<NULL>", rp->argc);
-      for (rpp = &mp->filter; *rpp; rpp = &((*rpp)->next));
+      for (rpp = &mp->filter; *rpp; rpp = &((*rpp)->next))
+        ;
       if ((errStr = remap_validate_filter_args(rpp, (const char **)rp->argv, rp->argc, errStrBuf, errStrBufSize)) != NULL)
         break;
     }
   }
   if (!errStr && (bti->remap_optflg & REMAP_OPTFLG_ALL_FILTERS) != 0) {
     Debug("url_rewrite", "[process_filter_opt] Add per remap filter");
-    for (rpp = &mp->filter; *rpp; rpp = &((*rpp)->next));
+    for (rpp = &mp->filter; *rpp; rpp = &((*rpp)->next))
+      ;
     errStr = remap_validate_filter_args(rpp, (const char **)bti->argv, bti->argc, errStrBuf, errStrBufSize);
   }
   return errStr;
 }
 
 static bool
-is_inkeylist(const char * key, ...)
+is_inkeylist(const char *key, ...)
 {
   va_list ap;
 
@@ -145,67 +146,68 @@ is_inkeylist(const char * key, ...)
 }
 
 static const char *
-parse_define_directive(const char * directive, BUILD_TABLE_INFO * bti, char * errbuf, size_t errbufsize)
+parse_define_directive(const char *directive, BUILD_TABLE_INFO *bti, char *errbuf, size_t errbufsize)
 {
   bool flg;
-  acl_filter_rule * rp;
-  acl_filter_rule ** rpp;
-  const char * cstr = NULL;
+  acl_filter_rule *rp;
+  acl_filter_rule **rpp;
+  const char *cstr = NULL;
 
   if (bti->paramc < 2) {
     snprintf(errbuf, errbufsize, "Directive \"%s\" must have name argument", directive);
     Debug("url_rewrite", "[parse_directive] %s", errbuf);
-    return (const char *) errbuf;
+    return (const char *)errbuf;
   }
   if (bti->argc < 1) {
     snprintf(errbuf, errbufsize, "Directive \"%s\" must have filter parameter(s)", directive);
     Debug("url_rewrite", "[parse_directive] %s", errbuf);
-    return (const char *) errbuf;
+    return (const char *)errbuf;
   }
 
-  flg = ((rp = acl_filter_rule::find_byname(bti->rules_list, (const char *) bti->paramv[1])) == NULL) ? true : false;
+  flg = ((rp = acl_filter_rule::find_byname(bti->rules_list, (const char *)bti->paramv[1])) == NULL) ? true : false;
   // coverity[alloc_arg]
   if ((cstr = remap_validate_filter_args(&rp, (const char **)bti->argv, bti->argc, errbuf, errbufsize)) == NULL && rp) {
-    if (flg) {                  // new filter - add to list
+    if (flg) { // new filter - add to list
       Debug("url_rewrite", "[parse_directive] new rule \"%s\" was created", bti->paramv[1]);
-      for (rpp = &bti->rules_list; *rpp; rpp = &((*rpp)->next));
+      for (rpp = &bti->rules_list; *rpp; rpp = &((*rpp)->next))
+        ;
       (*rpp = rp)->name(bti->paramv[1]);
     }
     Debug("url_rewrite", "[parse_directive] %d argument(s) were added to rule \"%s\"", bti->argc, bti->paramv[1]);
-    rp->add_argv(bti->argc, bti->argv);       // store string arguments for future processing
+    rp->add_argv(bti->argc, bti->argv); // store string arguments for future processing
   }
 
   return cstr;
 }
 
 static const char *
-parse_delete_directive(const char * directive, BUILD_TABLE_INFO * bti, char * errbuf, size_t errbufsize)
+parse_delete_directive(const char *directive, BUILD_TABLE_INFO *bti, char *errbuf, size_t errbufsize)
 {
   if (bti->paramc < 2) {
     snprintf(errbuf, errbufsize, "Directive \"%s\" must have name argument", directive);
     Debug("url_rewrite", "[parse_directive] %s", errbuf);
-    return (const char *) errbuf;
+    return (const char *)errbuf;
   }
 
-  acl_filter_rule::delete_byname(&bti->rules_list, (const char *) bti->paramv[1]);
+  acl_filter_rule::delete_byname(&bti->rules_list, (const char *)bti->paramv[1]);
   return NULL;
 }
 
 static const char *
-parse_activate_directive(const char * directive, BUILD_TABLE_INFO * bti, char * errbuf, size_t errbufsize)
+parse_activate_directive(const char *directive, BUILD_TABLE_INFO *bti, char *errbuf, size_t errbufsize)
 {
-  acl_filter_rule * rp;
+  acl_filter_rule *rp;
 
   if (bti->paramc < 2) {
     snprintf(errbuf, errbufsize, "Directive \"%s\" must have name argument", directive);
     Debug("url_rewrite", "[parse_directive] %s", errbuf);
-    return (const char *) errbuf;
+    return (const char *)errbuf;
   }
 
-  if ((rp = acl_filter_rule::find_byname(bti->rules_list, (const char *) bti->paramv[1])) == NULL) {
+  if ((rp = acl_filter_rule::find_byname(bti->rules_list, (const char *)bti->paramv[1])) == NULL) {
     snprintf(errbuf, errbufsize, "Undefined filter \"%s\" in directive \"%s\"", bti->paramv[1], directive);
     Debug("url_rewrite", "[parse_directive] %s", errbuf);
-    return (const char *) errbuf;
+    return (const char *)errbuf;
   }
 
   acl_filter_rule::requeue_in_active_list(&bti->rules_list, rp);
@@ -213,20 +215,20 @@ parse_activate_directive(const char * directive, BUILD_TABLE_INFO * bti, char *
 }
 
 static const char *
-parse_deactivate_directive(const char * directive, BUILD_TABLE_INFO * bti, char * errbuf, size_t errbufsize)
+parse_deactivate_directive(const char *directive, BUILD_TABLE_INFO *bti, char *errbuf, size_t errbufsize)
 {
-  acl_filter_rule * rp;
+  acl_filter_rule *rp;
 
   if (bti->paramc < 2) {
     snprintf(errbuf, errbufsize, "Directive \"%s\" must have name argument", directive);
     Debug("url_rewrite", "[parse_directive] %s", errbuf);
-    return (const char *) errbuf;
+    return (const char *)errbuf;
   }
 
-  if ((rp = acl_filter_rule::find_byname(bti->rules_list, (const char *) bti->paramv[1])) == NULL) {
+  if ((rp = acl_filter_rule::find_byname(bti->rules_list, (const char *)bti->paramv[1])) == NULL) {
     snprintf(errbuf, errbufsize, "Undefined filter \"%s\" in directive \"%s\"", bti->paramv[1], directive);
     Debug("url_rewrite", "[parse_directive] %s", errbuf);
-    return (const char *) errbuf;
+    return (const char *)errbuf;
   }
 
   acl_filter_rule::requeue_in_passive_list(&bti->rules_list, rp);
@@ -234,25 +236,24 @@ parse_deactivate_directive(const char * directive, BUILD_TABLE_INFO * bti, char
 }
 
 static const char *
-parse_include_directive(const char * directive, BUILD_TABLE_INFO * bti, char * errbuf, size_t errbufsize)
+parse_include_directive(const char *directive, BUILD_TABLE_INFO *bti, char *errbuf, size_t errbufsize)
 {
-
   if (bti->paramc < 2) {
     snprintf(errbuf, errbufsize, "Directive \"%s\" must have a path argument", directive);
     Debug("url_rewrite", "[%s] %s", __func__, errbuf);
-    return (const char *) errbuf;
+    return (const char *)errbuf;
   }
 
-  for (unsigned i = 1; i < (unsigned) bti->paramc; ++i) {
+  for (unsigned i = 1; i < (unsigned)bti->paramc; ++i) {
     // We need to create a new bti so that we don't clobber any state in the parent parse, but we want
     // to keep the ACL rules from the parent because ACLs must be global across the full set of config
     // files.
-    BUILD_TABLE_INFO  nbti;
-    xptr<char>        path;
-    bool              success;
+    BUILD_TABLE_INFO nbti;
+    ats_scoped_str path;
+    bool success;
 
     // The included path is relative to SYSCONFDIR, just like remap.config is.
-    path = Layout::relative_to(Layout::get()->sysconfdir, bti->paramv[i]);
+    path = RecConfigReadConfigPath(NULL, bti->paramv[i]);
 
     // XXX including directories is not supported (yet!).
     if (ink_file_is_directory(path)) {
@@ -282,40 +283,39 @@ parse_include_directive(const char * directive, BUILD_TABLE_INFO * bti, char * e
   return NULL;
 }
 
-struct remap_directive
-{
-  const char * name;
-  const char * (*parser)(const char *, BUILD_TABLE_INFO *, char *, size_t);
+struct remap_directive {
+  const char *name;
+  const char *(*parser)(const char *, BUILD_TABLE_INFO *, char *, size_t);
 };
 
 static const remap_directive directives[] = {
 
-  { ".definefilter", parse_define_directive},
-  { ".deffilter", parse_define_directive},
-  { ".defflt", parse_define_directive},
+  {".definefilter", parse_define_directive},
+  {".deffilter", parse_define_directive},
+  {".defflt", parse_define_directive},
 
-  { ".deletefilter", parse_delete_directive},
-  { ".delfilter", parse_delete_directive},
-  { ".delflt", parse_delete_directive},
+  {".deletefilter", parse_delete_directive},
+  {".delfilter", parse_delete_directive},
+  {".delflt", parse_delete_directive},
 
-  { ".usefilter", parse_activate_directive},
-  { ".activefilter", parse_activate_directive},
-  { ".activatefilter", parse_activate_directive},
-  { ".useflt", parse_activate_directive},
+  {".usefilter", parse_activate_directive},
+  {".activefilter", parse_activate_directive},
+  {".activatefilter", parse_activate_directive},
+  {".useflt", parse_activate_directive},
 
-  { ".unusefilter", parse_deactivate_directive},
-  { ".deactivatefilter", parse_deactivate_directive},
-  { ".unactivefilter", parse_deactivate_directive},
-  { ".deuseflt", parse_deactivate_directive},
-  { ".unuseflt", parse_deactivate_directive},
+  {".unusefilter", parse_deactivate_directive},
+  {".deactivatefilter", parse_deactivate_directive},
+  {".unactivefilter", parse_deactivate_directive},
+  {".deuseflt", parse_deactivate_directive},
+  {".unuseflt", parse_deactivate_directive},
 
-  { ".include", parse_include_directive },
+  {".include", parse_include_directive},
 };
 
 const char *
-remap_parse_directive(BUILD_TABLE_INFO *bti, char * errbuf, size_t errbufsize)
+remap_parse_directive(BUILD_TABLE_INFO *bti, char *errbuf, size_t errbufsize)
 {
-  const char * directive = NULL;
+  const char *directive = NULL;
 
   // Check arguments
   if (unlikely(!bti || !errbuf || errbufsize <= 0 || !bti->paramc || (directive = bti->paramv[0]) == NULL)) {
@@ -331,11 +331,11 @@ remap_parse_directive(BUILD_TABLE_INFO *bti, char * errbuf, size_t errbufsize)
 
   snprintf(errbuf, errbufsize, "Unknown directive \"%s\"", directive);
   Debug("url_rewrite", "[parse_directive] %s", errbuf);
-  return (const char *) errbuf;
+  return (const char *)errbuf;
 }
 
 const char *
-remap_validate_filter_args(acl_filter_rule ** rule_pp, const char ** argv, int argc, char * errStrBuf, size_t errStrBufSize)
+remap_validate_filter_args(acl_filter_rule **rule_pp, const char **argv, int argc, char *errStrBuf, size_t errStrBufSize)
 {
   acl_filter_rule *rule;
   unsigned long ul;
@@ -347,7 +347,7 @@ remap_validate_filter_args(acl_filter_rule ** rule_pp, const char ** argv, int a
 
   if (!rule_pp) {
     Debug("url_rewrite", "[validate_filter_args] Invalid argument(s)");
-    return (const char *) "Invalid argument(s)";
+    return (const char *)"Invalid argument(s)";
   }
 
   if (is_debug_tag_set("url_rewrite")) {
@@ -361,24 +361,30 @@ remap_validate_filter_args(acl_filter_rule ** rule_pp, const char ** argv, int a
     rule = new acl_filter_rule();
     if (unlikely((*rule_pp = rule) == NULL)) {
       Debug("url_rewrite", "[validate_filter_args] Memory allocation error");
-      return (const char *) "Memory allocation Error";
+      return (const char *)"Memory allocation Error";
     }
     new_rule_flg = true;
     Debug("url_rewrite", "[validate_filter_args] new acl_filter_rule class was created during remap rule processing");
   }
 
   for (i = 0; i < argc; i++) {
+    bool hasarg;
+
     if ((ul = remap_check_option((const char **)&argv[i], 1, 0, NULL, &argptr)) == 0) {
-      Debug("url_rewrite", "[validate_filter_args] Unknow remap option - %s", argv[i]);
+      Debug("url_rewrite", "[validate_filter_args] Unknown remap option - %s", argv[i]);
       snprintf(errStrBuf, errStrBufSize, "Unknown option - \"%s\"", argv[i]);
       errStrBuf[errStrBufSize - 1] = 0;
       if (new_rule_flg) {
         delete rule;
         *rule_pp = NULL;
       }
-      return (const char *) errStrBuf;
+      return (const char *)errStrBuf;
     }
-    if (!argptr || !argptr[0]) {
+
+    // Every filter operator requires an argument except @internal.
+    hasarg = !(ul & REMAP_OPTFLG_INTERNAL);
+
+    if (hasarg && (!argptr || !argptr[0])) {
       Debug("url_rewrite", "[validate_filter_args] Empty argument in %s", argv[i]);
       snprintf(errStrBuf, errStrBufSize, "Empty argument in \"%s\"", argv[i]);
       errStrBuf[errStrBufSize - 1] = 0;
@@ -386,10 +392,10 @@ remap_validate_filter_args(acl_filter_rule ** rule_pp, const char ** argv, int a
         delete rule;
         *rule_pp = NULL;
       }
-      return (const char *) errStrBuf;
+      return (const char *)errStrBuf;
     }
 
-    if (ul & REMAP_OPTFLG_METHOD) {     /* "method=" option */
+    if (ul & REMAP_OPTFLG_METHOD) { /* "method=" option */
       // Please remember that the order of hash idx creation is very important and it is defined
       // in HTTP.cc file
       m = -1;
@@ -416,14 +422,16 @@ remap_validate_filter_args(acl_filter_rule ** rule_pp, const char ** argv, int a
       else if (!strcasecmp(argptr, "PUSH"))
         m = HTTP_WKSIDX_PUSH;
       if (m != -1) {
-        m = m - HTTP_WKSIDX_CONNECT;    // get method index
+        m = m - HTTP_WKSIDX_CONNECT; // get method index
         rule->standard_method_lookup[m] = true;
       } else {
         Debug("url_rewrite", "[validate_filter_args] Using nonstandard method [%s]", argptr);
         rule->nonstandard_methods.insert(argptr);
       }
       rule->method_restriction_enabled = true;
-    } else if (ul & REMAP_OPTFLG_SRC_IP) {      /* "src_ip=" option */
+    }
+
+    if (ul & REMAP_OPTFLG_SRC_IP) { /* "src_ip=" option */
       if (rule->src_ip_cnt >= ACL_FILTER_MAX_SRC_IP) {
         Debug("url_rewrite", "[validate_filter_args] Too many \"src_ip=\" filters");
         snprintf(errStrBuf, errStrBufSize, "Defined more than %d \"src_ip=\" filters!", ACL_FILTER_MAX_SRC_IP);
@@ -432,7 +440,7 @@ remap_validate_filter_args(acl_filter_rule ** rule_pp, const char ** argv, int a
           delete rule;
           *rule_pp = NULL;
         }
-        return (const char *) errStrBuf;
+        return (const char *)errStrBuf;
       }
       ipi = &rule->src_ip_array[rule->src_ip_cnt];
       if (ul & REMAP_OPTFLG_INVERT)
@@ -447,20 +455,22 @@ remap_validate_filter_args(acl_filter_rule ** rule_pp, const char ** argv, int a
           delete rule;
           *rule_pp = NULL;
         }
-        return (const char*) errStrBuf;
+        return (const char *)errStrBuf;
       }
       for (j = 0; j < rule->src_ip_cnt; j++) {
         if (rule->src_ip_array[j].start == ipi->start && rule->src_ip_array[j].end == ipi->end) {
           ipi->reset();
           ipi = NULL;
-          break;                /* we have the same src_ip in the list */
+          break; /* we have the same src_ip in the list */
         }
       }
       if (ipi) {
         rule->src_ip_cnt++;
         rule->src_ip_valid = 1;
       }
-    } else if (ul & REMAP_OPTFLG_ACTION) {      /* "action=" option */
+    }
+
+    if (ul & REMAP_OPTFLG_ACTION) { /* "action=" option */
       if (is_inkeylist(argptr, "0", "off", "deny", "disable", NULL)) {
         rule->allow_flag = 0;
       } else if (is_inkeylist(argptr, "1", "on", "allow", "enable", NULL)) {
@@ -473,19 +483,23 @@ remap_validate_filter_args(acl_filter_rule ** rule_pp, const char ** argv, int a
           delete rule;
           *rule_pp = NULL;
         }
-        return (const char *) errStrBuf;
+        return (const char *)errStrBuf;
       }
     }
+
+    if (ul & REMAP_OPTFLG_INTERNAL) {
+      rule->internal = 1;
+    }
   }
 
   if (is_debug_tag_set("url_rewrite"))
     rule->print();
 
-  return NULL;                  /* success */
+  return NULL; /* success */
 }
 
 unsigned long
-remap_check_option(const char ** argv, int argc, unsigned long findmode, int *_ret_idx, const char **argptr)
+remap_check_option(const char **argv, int argc, unsigned long findmode, int *_ret_idx, const char **argptr)
 {
   unsigned long ret_flags = 0;
   int idx = 0;
@@ -540,6 +554,11 @@ remap_check_option(const char ** argv, int argc, unsigned long findmode, int *_r
         if (argptr)
           *argptr = &argv[i][6];
         ret_flags |= REMAP_OPTFLG_MAP_ID;
+      } else if (!strncasecmp(argv[i], "internal", 8)) {
+        if ((findmode & REMAP_OPTFLG_INTERNAL) != 0) {
+          idx = i;
+        }
+        ret_flags |= REMAP_OPTFLG_INTERNAL;
       }
 
       if ((findmode & ret_flags) && !argptr) {
@@ -547,7 +566,6 @@ remap_check_option(const char ** argv, int argc, unsigned long findmode, int *_r
           *_ret_idx = idx;
         return ret_flags;
       }
-
     }
   }
   if (_ret_idx)
@@ -556,15 +574,15 @@ remap_check_option(const char ** argv, int argc, unsigned long findmode, int *_r
 }
 
 int
-remap_load_plugin(const char ** argv, int argc, url_mapping *mp, char *errbuf, int errbufsize,
-    int jump_to_argc, int *plugin_found_at)
+remap_load_plugin(const char **argv, int argc, url_mapping *mp, char *errbuf, int errbufsize, int jump_to_argc,
+                  int *plugin_found_at)
 {
   TSRemapInterface ri;
   struct stat stat_buf;
   remap_plugin_info *pi;
   char *c, *err, tmpbuf[2048], default_path[PATH_NAME_MAX];
   const char *new_argv[1024];
-  char * parv[1024];
+  char *parv[1024];
   int idx = 0, retcode = 0;
   int parc = 0;
 
@@ -574,7 +592,7 @@ remap_load_plugin(const char ** argv, int argc, url_mapping *mp, char *errbuf, i
   memset(new_argv, 0, sizeof(new_argv));
   tmpbuf[0] = 0;
 
-  ink_assert((unsigned) argc < countof(new_argv));
+  ink_assert((unsigned)argc < countof(new_argv));
 
   if (jump_to_argc != 0) {
     argc -= jump_to_argc;
@@ -590,13 +608,13 @@ remap_load_plugin(const char ** argv, int argc, url_mapping *mp, char *errbuf, i
   } else {
     if (unlikely(!mp || (remap_check_option(argv, argc, REMAP_OPTFLG_PLUGIN, &idx) & REMAP_OPTFLG_PLUGIN) == 0)) {
       snprintf(errbuf, errbufsize, "Can't find remap plugin keyword or \"url_mapping\" is NULL");
-      return -1;                /* incorrect input data - almost impossible case */
+      return -1; /* incorrect input data - almost impossible case */
     }
   }
 
-  if (unlikely((c = (char *) strchr(argv[idx], (int) '=')) == NULL || !(*(++c)))) {
+  if (unlikely((c = (char *)strchr(argv[idx], (int)'=')) == NULL || !(*(++c)))) {
     snprintf(errbuf, errbufsize, "Can't find remap plugin file name in \"@%s\"", argv[idx]);
-    return -2;                  /* incorrect input data */
+    return -2; /* incorrect input data */
   }
 
   if (stat(c, &stat_buf) != 0) {
@@ -631,12 +649,12 @@ remap_load_plugin(const char ** argv, int argc, url_mapping *mp, char *errbuf, i
     }
     Debug("remap_plugin", "New remap plugin info created for \"%s\"", c);
 
-    // elevate the access to read files as root if compiled with capabilities, if not
-    // change the effective user to root
     {
+#if TS_USE_POSIX_CAP
       uint32_t elevate_access = 0;
       REC_ReadConfigInteger(elevate_access, "proxy.config.plugin.load_elevated");
       ElevateAccess access(elevate_access != 0);
+#endif /* TS_USE_POSIX_CAP */
 
       if ((pi->dlh = dlopen(c, RTLD_NOW)) == NULL) {
 #if defined(freebsd) || defined(openbsd)
@@ -647,19 +665,19 @@ remap_load_plugin(const char ** argv, int argc, url_mapping *mp, char *errbuf, i
         snprintf(errbuf, errbufsize, "Can't load plugin \"%s\" - %s", c, err ? err : "Unknown dlopen() error");
         return -4;
       }
-      pi->fp_tsremap_init = (remap_plugin_info::_tsremap_init *) dlsym(pi->dlh, TSREMAP_FUNCNAME_INIT);
-      pi->fp_tsremap_done = (remap_plugin_info::_tsremap_done *) dlsym(pi->dlh, TSREMAP_FUNCNAME_DONE);
-      pi->fp_tsremap_new_instance = (remap_plugin_info::_tsremap_new_instance *) dlsym(pi->dlh, TSREMAP_FUNCNAME_NEW_INSTANCE);
-      pi->fp_tsremap_delete_instance = (remap_plugin_info::_tsremap_delete_instance *) dlsym(pi->dlh, TSREMAP_FUNCNAME_DELETE_INSTANCE);
-      pi->fp_tsremap_do_remap = (remap_plugin_info::_tsremap_do_remap *) dlsym(pi->dlh, TSREMAP_FUNCNAME_DO_REMAP);
-      pi->fp_tsremap_os_response = (remap_plugin_info::_tsremap_os_response *) dlsym(pi->dlh, TSREMAP_FUNCNAME_OS_RESPONSE);
+      pi->fp_tsremap_init = (remap_plugin_info::_tsremap_init *)dlsym(pi->dlh, TSREMAP_FUNCNAME_INIT);
+      pi->fp_tsremap_done = (remap_plugin_info::_tsremap_done *)dlsym(pi->dlh, TSREMAP_FUNCNAME_DONE);
+      pi->fp_tsremap_new_instance = (remap_plugin_info::_tsremap_new_instance *)dlsym(pi->dlh, TSREMAP_FUNCNAME_NEW_INSTANCE);
+      pi->fp_tsremap_delete_instance =
+        (remap_plugin_info::_tsremap_delete_instance *)dlsym(pi->dlh, TSREMAP_FUNCNAME_DELETE_INSTANCE);
+      pi->fp_tsremap_do_remap = (remap_plugin_info::_tsremap_do_remap *)dlsym(pi->dlh, TSREMAP_FUNCNAME_DO_REMAP);
+      pi->fp_tsremap_os_response = (remap_plugin_info::_tsremap_os_response *)dlsym(pi->dlh, TSREMAP_FUNCNAME_OS_RESPONSE);
 
       if (!pi->fp_tsremap_init) {
         snprintf(errbuf, errbufsize, "Can't find \"%s\" function in remap plugin \"%s\"", TSREMAP_FUNCNAME_INIT, c);
         retcode = -10;
       } else if (!pi->fp_tsremap_new_instance) {
-        snprintf(errbuf, errbufsize, "Can't find \"%s\" function in remap plugin \"%s\"",
-            TSREMAP_FUNCNAME_NEW_INSTANCE, c);
+        snprintf(errbuf, errbufsize, "Can't find \"%s\" function in remap plugin \"%s\"", TSREMAP_FUNCNAME_NEW_INSTANCE, c);
         retcode = -11;
       } else if (!pi->fp_tsremap_do_remap) {
         snprintf(errbuf, errbufsize, "Can't find \"%s\" function in remap plugin \"%s\"", TSREMAP_FUNCNAME_DO_REMAP, c);
@@ -705,11 +723,10 @@ remap_load_plugin(const char ** argv, int argc, url_mapping *mp, char *errbuf, i
 
   bool plugin_encountered = false;
   // how many plugin parameters we have for this remapping
-  for (idx = 0; idx < argc && parc < (int) (countof(parv) - 1); idx++) {
-
+  for (idx = 0; idx < argc && parc < (int)(countof(parv) - 1); idx++) {
     if (plugin_encountered && !strncasecmp("plugin=", argv[idx], 7) && argv[idx][7]) {
       *plugin_found_at = idx;
-      break;                    //if there is another plugin, lets deal with that later
+      break; // if there is another plugin, lets deal with that later
     }
 
     if (!strncasecmp("plugin=", argv[idx], 7)) {
@@ -731,7 +748,7 @@ remap_load_plugin(const char ** argv, int argc, url_mapping *mp, char *errbuf, i
     Debug("url_rewrite", "Argument %d: %s", k, parv[k]);
   }
 
-  void* ih;
+  void *ih;
 
   Debug("remap_plugin", "creating new plugin instance");
 
@@ -740,12 +757,12 @@ remap_load_plugin(const char ** argv, int argc, url_mapping *mp, char *errbuf, i
 
   Debug("remap_plugin", "done creating new plugin instance");
 
-  ats_free(parv[0]);               // fromURL
-  ats_free(parv[1]);               // toURL
+  ats_free(parv[0]); // fromURL
+  ats_free(parv[1]); // toURL
 
   if (res != TS_SUCCESS) {
     snprintf(errbuf, errbufsize, "Can't create new remap instance for plugin \"%s\" - %s", c,
-                 tmpbuf[0] ? tmpbuf : "Unknown plugin error");
+             tmpbuf[0] ? tmpbuf : "Unknown plugin error");
     Warning("Failed to create new instance for plugin %s (not a TS_SUCCESS return)", pi->path);
     return -8;
   }
@@ -796,8 +813,8 @@ process_regex_mapping_config(const char *from_host_lower, url_mapping *new_mappi
     goto lFail;
   }
   if (n_captures >= UrlRewrite::MAX_REGEX_SUBS) { // off by one for $0 (implicit capture)
-    Warning("Regex has %d capturing subpatterns (including entire regex); Max allowed: %d",
-            n_captures + 1, UrlRewrite::MAX_REGEX_SUBS);
+    Warning("Regex has %d capturing subpatterns (including entire regex); Max allowed: %d", n_captures + 1,
+            UrlRewrite::MAX_REGEX_SUBS);
     goto lFail;
   }
 
@@ -805,14 +822,12 @@ process_regex_mapping_config(const char *from_host_lower, url_mapping *new_mappi
   for (int i = 0; i < (to_host_len - 1); ++i) {
     if (to_host[i] == '$') {
       if (substitution_count > UrlRewrite::MAX_REGEX_SUBS) {
-        Warning("Cannot have more than %d substitutions in mapping with host [%s]",
-                UrlRewrite::MAX_REGEX_SUBS, from_host_lower);
+        Warning("Cannot have more than %d substitutions in mapping with host [%s]", UrlRewrite::MAX_REGEX_SUBS, from_host_lower);
         goto lFail;
       }
       substitution_id = to_host[i + 1] - '0';
       if ((substitution_id < 0) || (substitution_id > n_captures)) {
-        Warning("Substitution id [%c] has no corresponding capture pattern in regex [%s]",
-              to_host[i + 1], from_host_lower);
+        Warning("Substitution id [%c] has no corresponding capture pattern in regex [%s]", to_host[i + 1], from_host_lower);
         goto lFail;
       }
       reg_map->substitution_markers[reg_map->n_substitutions] = i;
@@ -831,7 +846,7 @@ process_regex_mapping_config(const char *from_host_lower, url_mapping *new_mappi
 
   return true;
 
- lFail:
+lFail:
   if (reg_map->re) {
     pcre_free(reg_map->re);
     reg_map->re = NULL;
@@ -849,9 +864,8 @@ process_regex_mapping_config(const char *from_host_lower, url_mapping *new_mappi
 }
 
 static bool
-remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
+remap_parse_config_bti(const char *path, BUILD_TABLE_INFO *bti)
 {
-
   char errBuf[1024], errStrBuf[1024];
   Tokenizer whiteTok(" \t");
   bool alarm_already = false;
@@ -859,7 +873,7 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
 
   // Vars to parse line in file
   char *tok_state, *cur_line, *cur_line_tmp;
-  int rparse, cur_line_size, cln = 0;        // Our current line number
+  int rparse, cur_line_size, cln = 0; // Our current line number
 
   // Vars to build the mapping
   const char *fromScheme, *toScheme;
@@ -868,7 +882,7 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
   int fromHostLen, toHostLen;
   char *map_from, *map_from_start;
   char *map_to, *map_to_start;
-  const char *tmp;              // Appease the DEC compiler
+  const char *tmp; // Appease the DEC compiler
   char *fromHost_lower = NULL;
   char *fromHost_lower_ptr = NULL;
   char fromHost_lower_buf[1024];
@@ -879,11 +893,11 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
   int length;
   int tok_count;
 
-  UrlRewrite::RegexMapping* reg_map;
+  UrlRewrite::RegexMapping *reg_map;
   bool is_cur_mapping_regex;
   const char *type_id_str;
 
-  xptr<char> file_buf(readIntoBuffer(path, modulePrefix, NULL));
+  ats_scoped_str file_buf(readIntoBuffer(path, modulePrefix, NULL));
   if (!file_buf) {
     Warning("can't load remapping configuration file %s", path);
     return false;
@@ -892,6 +906,8 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
   Debug("url_rewrite", "[BuildTable] UrlRewrite::BuildTable()");
 
   for (cur_line = tokLine(file_buf, &tok_state, '\\'); cur_line != NULL;) {
+    reg_map = NULL;
+    new_mapping = NULL;
     errStrBuf[0] = 0;
     bti->reset();
 
@@ -899,7 +915,7 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
     while (*cur_line && isascii(*cur_line) && isspace(*cur_line))
       ++cur_line;
 
-    if ((cur_line_size = strlen((char *) cur_line)) <= 0) {
+    if ((cur_line_size = strlen((char *)cur_line)) <= 0) {
       cur_line = tokLine(NULL, &tok_state, '\\');
       ++cln;
       continue;
@@ -912,7 +928,7 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
       --cur_line_tmp;
     }
 
-    if ((cur_line_size = strlen((char *) cur_line)) <= 0 || *cur_line == '#' || *cur_line == '\0') {
+    if ((cur_line_size = strlen((char *)cur_line)) <= 0 || *cur_line == '#' || *cur_line == '\0') {
       cur_line = tokLine(NULL, &tok_state, '\\');
       ++cln;
       continue;
@@ -920,19 +936,19 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
 
     Debug("url_rewrite", "[BuildTable] Parsing: \"%s\"", cur_line);
 
-    tok_count = whiteTok.Initialize(cur_line, SHARE_TOKS);
+    tok_count = whiteTok.Initialize(cur_line, (SHARE_TOKS | ALLOW_SPACES));
 
     for (int j = 0; j < tok_count; j++) {
-      if (((char *) whiteTok[j])[0] == '@') {
-        if (((char *) whiteTok[j])[1])
-          bti->argv[bti->argc++] = ats_strdup(&(((char *) whiteTok[j])[1]));
+      if (((char *)whiteTok[j])[0] == '@') {
+        if (((char *)whiteTok[j])[1])
+          bti->argv[bti->argc++] = ats_strdup(&(((char *)whiteTok[j])[1]));
       } else {
-        bti->paramv[bti->paramc++] = ats_strdup((char *) whiteTok[j]);
+        bti->paramv[bti->paramc++] = ats_strdup((char *)whiteTok[j]);
       }
     }
 
     // Initial verification for number of arguments
-    if (bti->paramc<1 || (bti->paramc < 3 && bti->paramv[0][0] != '.') || bti->paramc> BUILD_TABLE_MAX_ARGS) {
+    if (bti->paramc < 1 || (bti->paramc < 3 && bti->paramv[0][0] != '.') || bti->paramc > BUILD_TABLE_MAX_ARGS) {
       snprintf(errBuf, sizeof(errBuf), "%s Malformed line %d in file %s", modulePrefix, cln + 1, path);
       errStr = errStrBuf;
       goto MAP_ERROR;
@@ -982,7 +998,7 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
       goto MAP_ERROR;
     }
 
-    new_mapping = new url_mapping(cln);  // use line # for rank for now
+    new_mapping = new url_mapping();
 
     // apply filter rules if we have to
     if ((errStr = process_filter_opt(new_mapping, bti, errStrBuf, sizeof(errStrBuf))) != NULL) {
@@ -995,8 +1011,8 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
       char *c;
       int ret = remap_check_option((const char **)bti->argv, bti->argc, REMAP_OPTFLG_MAP_ID, &idx);
       if (ret & REMAP_OPTFLG_MAP_ID) {
-        c = strchr(bti->argv[idx], (int) '=');
-        new_mapping->map_id = (unsigned int) atoi(++c);
+        c = strchr(bti->argv[idx], (int)'=');
+        new_mapping->map_id = (unsigned int)atoi(++c);
       }
     }
 
@@ -1015,7 +1031,7 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
     new_mapping->fromURL.create(NULL);
     rparse = new_mapping->fromURL.parse_no_path_component_breakdown(tmp, length);
 
-    map_from_start[origLength] = '\0';  // Unwhack
+    map_from_start[origLength] = '\0'; // Unwhack
 
     if (rparse != PARSE_DONE) {
       errStr = "Malformed From URL";
@@ -1029,7 +1045,7 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
 
     new_mapping->toUrl.create(NULL);
     rparse = new_mapping->toUrl.parse_no_path_component_breakdown(tmp, length);
-    map_to_start[origLength] = '\0';    // Unwhack
+    map_to_start[origLength] = '\0'; // Unwhack
 
     if (rparse != PARSE_DONE) {
       errStr = "Malformed To URL";
@@ -1048,21 +1064,17 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
 
     // Include support for HTTPS scheme
     // includes support for FILE scheme
-    if ((fromScheme != URL_SCHEME_HTTP && fromScheme != URL_SCHEME_HTTPS &&
-         fromScheme != URL_SCHEME_FILE &&
-         fromScheme != URL_SCHEME_TUNNEL &&
-         fromScheme != URL_SCHEME_WS &&
-         fromScheme != URL_SCHEME_WSS) ||
-        (toScheme != URL_SCHEME_HTTP && toScheme != URL_SCHEME_HTTPS &&
-         toScheme != URL_SCHEME_TUNNEL && toScheme != URL_SCHEME_WS &&
-         toScheme != URL_SCHEME_WSS)) {
+    if ((fromScheme != URL_SCHEME_HTTP && fromScheme != URL_SCHEME_HTTPS && fromScheme != URL_SCHEME_FILE &&
+         fromScheme != URL_SCHEME_TUNNEL && fromScheme != URL_SCHEME_WS && fromScheme != URL_SCHEME_WSS) ||
+        (toScheme != URL_SCHEME_HTTP && toScheme != URL_SCHEME_HTTPS && toScheme != URL_SCHEME_TUNNEL &&
+         toScheme != URL_SCHEME_WS && toScheme != URL_SCHEME_WSS)) {
       errStr = "Only http, https, ws, wss, and tunnel remappings are supported";
       goto MAP_ERROR;
     }
 
     // If mapping from WS or WSS we must map out to WS or WSS
-    if ( (fromScheme == URL_SCHEME_WSS || fromScheme == URL_SCHEME_WS) &&
-         (toScheme != URL_SCHEME_WSS && toScheme != URL_SCHEME_WS)) {
+    if ((fromScheme == URL_SCHEME_WSS || fromScheme == URL_SCHEME_WS) &&
+        (toScheme != URL_SCHEME_WSS && toScheme != URL_SCHEME_WS)) {
       errStr = "WS or WSS can only be mapped out to WS or WSS.";
       goto MAP_ERROR;
     }
@@ -1080,11 +1092,10 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
             char refinfo_error_buf[1024];
             bool refinfo_error = false;
 
-            ri = new referer_info((char *)bti->paramv[j - 1], &refinfo_error, refinfo_error_buf,
-                                      sizeof(refinfo_error_buf));
+            ri = new referer_info((char *)bti->paramv[j - 1], &refinfo_error, refinfo_error_buf, sizeof(refinfo_error_buf));
             if (refinfo_error) {
-              snprintf(errBuf, sizeof(errBuf), "%s Incorrect Referer regular expression \"%s\" at line %d - %s",
-                           modulePrefix, bti->paramv[j - 1], cln + 1, refinfo_error_buf);
+              snprintf(errBuf, sizeof(errBuf), "%s Incorrect Referer regular expression \"%s\" at line %d - %s", modulePrefix,
+                       bti->paramv[j - 1], cln + 1, refinfo_error_buf);
               SignalError(errBuf, alarm_already);
               delete ri;
               ri = 0;
@@ -1092,11 +1103,11 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
 
             if (ri && ri->negative) {
               if (ri->any) {
-                new_mapping->optional_referer = true;   /* referer header is optional */
+                new_mapping->optional_referer = true; /* referer header is optional */
                 delete ri;
                 ri = 0;
               } else {
-                new_mapping->negative_referer = true;   /* we have negative referer in list */
+                new_mapping->negative_referer = true; /* we have negative referer in list */
               }
             }
             if (ri) {
@@ -1140,7 +1151,7 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
     // the rest of the system assumes that trailing slashes have
     // been removed.
 
-    if (unlikely(fromHostLen >= (int) sizeof(fromHost_lower_buf))) {
+    if (unlikely(fromHostLen >= (int)sizeof(fromHost_lower_buf))) {
       fromHost_lower = (fromHost_lower_ptr = (char *)ats_malloc(fromHostLen + 1));
     } else {
       fromHost_lower = &fromHost_lower_buf[0];
@@ -1172,11 +1183,11 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
     // in remap.config, we also needs to convert hostname to its IPv4 addr
     // and gives a new remap rule with the IPv4 addr.
     if ((maptype == FORWARD_MAP || maptype == FORWARD_MAP_REFERER || maptype == FORWARD_MAP_WITH_RECV_PORT) &&
-        fromScheme == URL_SCHEME_TUNNEL && (fromHost_lower[0]<'0' || fromHost_lower[0]> '9')) {
-      addrinfo* ai_records; // returned records.
-      ip_text_buffer ipb; // buffer for address string conversion.
+        fromScheme == URL_SCHEME_TUNNEL && (fromHost_lower[0] < '0' || fromHost_lower[0] > '9')) {
+      addrinfo *ai_records; // returned records.
+      ip_text_buffer ipb;   // buffer for address string conversion.
       if (0 == getaddrinfo(fromHost_lower, 0, 0, &ai_records)) {
-        for ( addrinfo* ai_spot = ai_records ; ai_spot ; ai_spot = ai_spot->ai_next) {
+        for (addrinfo *ai_spot = ai_records; ai_spot; ai_spot = ai_spot->ai_next) {
           if (ats_is_ip(ai_spot->ai_addr) && !ats_is_ip_any(ai_spot->ai_addr)) {
             url_mapping *u_mapping;
 
@@ -1205,22 +1216,24 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
     }
 
     // Check "remap" plugin options and load .so object
-    if ((bti->remap_optflg & REMAP_OPTFLG_PLUGIN) != 0 && (maptype == FORWARD_MAP || maptype == FORWARD_MAP_REFERER ||
-                                                          maptype == FORWARD_MAP_WITH_RECV_PORT)) {
+    if ((bti->remap_optflg & REMAP_OPTFLG_PLUGIN) != 0 &&
+        (maptype == FORWARD_MAP || maptype == FORWARD_MAP_REFERER || maptype == FORWARD_MAP_WITH_RECV_PORT)) {
       if ((remap_check_option((const char **)bti->argv, bti->argc, REMAP_OPTFLG_PLUGIN, &tok_count) & REMAP_OPTFLG_PLUGIN) != 0) {
         int plugin_found_at = 0;
         int jump_to_argc = 0;
 
         // this loads the first plugin
-        if (remap_load_plugin((const char **)bti->argv, bti->argc, new_mapping, errStrBuf, sizeof(errStrBuf), 0, &plugin_found_at)) {
+        if (remap_load_plugin((const char **)bti->argv, bti->argc, new_mapping, errStrBuf, sizeof(errStrBuf), 0,
+                              &plugin_found_at)) {
           Debug("remap_plugin", "Remap plugin load error - %s", errStrBuf[0] ? errStrBuf : "Unknown error");
           errStr = errStrBuf;
           goto MAP_ERROR;
         }
-        //this loads any subsequent plugins (if present)
+        // this loads any subsequent plugins (if present)
         while (plugin_found_at) {
           jump_to_argc += plugin_found_at;
-          if (remap_load_plugin((const char **)bti->argv, bti->argc, new_mapping, errStrBuf, sizeof(errStrBuf), jump_to_argc, &plugin_found_at)) {
+          if (remap_load_plugin((const char **)bti->argv, bti->argc, new_mapping, errStrBuf, sizeof(errStrBuf), jump_to_argc,
+                                &plugin_found_at)) {
             Debug("remap_plugin", "Remap plugin load error - %s", errStrBuf[0] ? errStrBuf : "Unknown error");
             errStr = errStrBuf;
             goto MAP_ERROR;
@@ -1241,22 +1254,24 @@ remap_parse_config_bti(const char * path, BUILD_TABLE_INFO * bti)
     ++cln;
     continue;
 
-    // Deal with error / warning scenarios
+  // Deal with error / warning scenarios
   MAP_ERROR:
     Warning("Could not add rule at line #%d; Aborting!", cln + 1);
     snprintf(errBuf, sizeof(errBuf), "%s %s at line %d", modulePrefix, errStr, cln + 1);
     SignalError(errBuf, alarm_already);
+    delete reg_map;
+    delete new_mapping;
     return false;
-  }                             /* end of while(cur_line != NULL) */
+  } /* end of while(cur_line != NULL) */
 
   return true;
 }
 
 bool
-remap_parse_config(const char * path, UrlRewrite * rewrite)
+remap_parse_config(const char *path, UrlRewrite *rewrite)
 {
-    BUILD_TABLE_INFO bti;
+  BUILD_TABLE_INFO bti;
 
-    bti.rewrite = rewrite;
-    return remap_parse_config_bti(path, &bti);
+  bti.rewrite = rewrite;
+  return remap_parse_config_bti(path, &bti);
 }
