@@ -30,7 +30,7 @@ int
 RemapProcessor::start(int num_threads, size_t stacksize)
 {
   if (_use_separate_remap_thread)
-    ET_REMAP = eventProcessor.spawn_event_threads(num_threads, "ET_REMAP", stacksize);  // ET_REMAP is a class member
+    ET_REMAP = eventProcessor.spawn_event_threads(num_threads, "ET_REMAP", stacksize); // ET_REMAP is a class member
 
   return 0;
 }
@@ -60,10 +60,8 @@ RemapProcessor::setup_for_remap(HttpTransact::State *s)
 
   ink_assert(redirect_url != NULL);
 
-  if (unlikely((rewrite_table->num_rules_forward == 0) &&
-               (rewrite_table->num_rules_forward_with_recv_port == 0))) {
-    ink_assert(rewrite_table->forward_mappings.empty() &&
-               rewrite_table->forward_mappings_with_recv_port.empty());
+  if (unlikely((rewrite_table->num_rules_forward == 0) && (rewrite_table->num_rules_forward_with_recv_port == 0))) {
+    ink_assert(rewrite_table->forward_mappings.empty() && rewrite_table->forward_mappings_with_recv_port.empty());
     Debug("url_rewrite", "[lookup] No forward mappings found; Skipping...");
     return false;
   }
@@ -78,7 +76,7 @@ RemapProcessor::setup_for_remap(HttpTransact::State *s)
 
   request_host = request_header->host_get(&request_host_len);
   request_port = request_header->port_get();
-  proxy_request = request_header->is_target_in_url() || ! s->reverse_proxy;
+  proxy_request = request_header->is_target_in_url() || !s->reverse_proxy;
 
   // Default to empty host.
   if (!request_host) {
@@ -89,10 +87,9 @@ RemapProcessor::setup_for_remap(HttpTransact::State *s)
   Debug("url_rewrite", "[lookup] attempting %s lookup", proxy_request ? "proxy" : "normal");
 
   if (rewrite_table->num_rules_forward_with_recv_port) {
-    Debug("url_rewrite", "[lookup] forward mappings with recv port found; Using recv port %d",
-          s->client_info.port);
-    if (rewrite_table->forwardMappingWithRecvPortLookup(request_url, s->client_info.port,
-                                                         request_host, request_host_len, s->url_map)) {
+    Debug("url_rewrite", "[lookup] forward mappings with recv port found; Using recv port %d", s->client_info.port);
+    if (rewrite_table->forwardMappingWithRecvPortLookup(request_url, s->client_info.port, request_host, request_host_len,
+                                                        s->url_map)) {
       Debug("url_rewrite", "Found forward mapping with recv port");
       mapping_found = true;
     } else if (rewrite_table->num_rules_forward == 0) {
@@ -169,8 +166,8 @@ RemapProcessor::finish_remap(HttpTransact::State *s)
 
     if (request_header->presence(MIME_PRESENCE_REFERER) &&
         (referer_hdr = request_header->value_get(MIME_FIELD_REFERER, MIME_LEN_REFERER, &referer_len)) != NULL) {
-      if (referer_len >= (int) sizeof(tmp_referer_buf))
-        referer_len = (int) (sizeof(tmp_referer_buf) - 1);
+      if (referer_len >= (int)sizeof(tmp_referer_buf))
+        referer_len = (int)(sizeof(tmp_referer_buf) - 1);
       memcpy(tmp_referer_buf, referer_hdr, referer_len);
       tmp_referer_buf[referer_len] = 0;
       for (enabled_flag = false; ri; ri = ri->next) {
@@ -202,8 +199,8 @@ RemapProcessor::finish_remap(HttpTransact::State *s)
             case 'f':
             case 't':
               remapped_host = (rc->type == 'f') ?
-                map->fromURL.string_get_buf(tmp_buf, (int) sizeof(tmp_buf), &from_len) :
-                ((s->url_map).getToURL())->string_get_buf(tmp_buf, (int)sizeof(tmp_buf), &from_len);
+                                map->fromURL.string_get_buf(tmp_buf, (int)sizeof(tmp_buf), &from_len) :
+                                ((s->url_map).getToURL())->string_get_buf(tmp_buf, (int)sizeof(tmp_buf), &from_len);
               if (remapped_host && from_len > 0) {
                 c = &tmp_buf[0];
               }
@@ -213,7 +210,7 @@ RemapProcessor::finish_remap(HttpTransact::State *s)
               break;
             };
 
-            if (c && tmp < (int) (sizeof(tmp_redirect_buf) - 1)) {
+            if (c && tmp < (int)(sizeof(tmp_redirect_buf) - 1)) {
               tmp += snprintf(&tmp_redirect_buf[tmp], sizeof(tmp_redirect_buf) - tmp, "%s", c);
             }
           }
@@ -225,8 +222,7 @@ RemapProcessor::finish_remap(HttpTransact::State *s)
       }
 
       if (*redirect_url == NULL) {
-        *redirect_url = ats_strdup(map->filter_redirect_url ? map->filter_redirect_url :
-                                   rewrite_table->http_default_redirect_url);
+        *redirect_url = ats_strdup(map->filter_redirect_url ? map->filter_redirect_url : rewrite_table->http_default_redirect_url);
       }
 
       return false;
@@ -246,7 +242,7 @@ RemapProcessor::finish_remap(HttpTransact::State *s)
     //  termination for the Debug() call
     if (is_debug_tag_set("url_rewrite")) {
       int old_host_hdr_len;
-      char *old_host_hdr = (char *) request_header->value_get(MIME_FIELD_HOST, MIME_LEN_HOST, &old_host_hdr_len);
+      char *old_host_hdr = (char *)request_header->value_get(MIME_FIELD_HOST, MIME_LEN_HOST, &old_host_hdr_len);
 
       if (old_host_hdr) {
         old_host_hdr = ats_strndup(old_host_hdr, old_host_hdr_len);
@@ -265,9 +261,8 @@ RemapProcessor::finish_remap(HttpTransact::State *s)
       tmp = remapped_host_len;
       memcpy(host_hdr_buf, remapped_host, remapped_host_len);
       if (remapped_port) {
-        tmp += snprintf(host_hdr_buf + remapped_host_len, TS_MAX_HOST_NAME_LEN - remapped_host_len - 1,
-                        ":%d", remapped_port);
-    }
+        tmp += snprintf(host_hdr_buf + remapped_host_len, TS_MAX_HOST_NAME_LEN - remapped_host_len - 1, ":%d", remapped_port);
+      }
     } else {
       tmp = TS_MAX_HOST_NAME_LEN;
     }
@@ -285,6 +280,8 @@ RemapProcessor::finish_remap(HttpTransact::State *s)
     }
   }
 
+  request_header->mark_target_dirty();
+
   return remap_found;
 }
 
