@@ -24,36 +24,31 @@
 #ifndef _URL_MAPPING_H_
 #define _URL_MAPPING_H_
 
+#include "ink_config.h"
 #include "AclFiltering.h"
 #include "Main.h"
 #include "Error.h"
 #include "URL.h"
 #include "RemapPluginInfo.h"
-
-#ifdef HAVE_PCRE_PCRE_H
-#include <pcre/pcre.h>
-#else
-#include <pcre.h>
-#endif
+#include "Regex.h"
 
 static const unsigned int MAX_REMAP_PLUGIN_CHAIN = 10;
 
-
 /**
  * Used to store http referer strings (and/or regexp)
 **/
 class referer_info
 {
 public:
-  referer_info(char *_ref, bool * error_flag = NULL, char *errmsgbuf = NULL, int errmsgbuf_size = 0);
-   ~referer_info();
+  referer_info(char *_ref, bool *error_flag = NULL, char *errmsgbuf = NULL, int errmsgbuf_size = 0);
+  ~referer_info();
   referer_info *next;
   char *referer;
   int referer_size;
-  bool any;                     /* any flag '*' */
-  bool negative;                /* negative referer '~' */
+  bool any;      /* any flag '*' */
+  bool negative; /* negative referer '~' */
   bool regx_valid;
-  pcre* regx;
+  pcre *regx;
 };
 
 /**
@@ -62,9 +57,7 @@ public:
 class redirect_tag_str
 {
 public:
-   redirect_tag_str()
-     : next(0), chunk_str(NULL), type(0)
-    { }
+  redirect_tag_str() : next(0), chunk_str(NULL), type(0) {}
 
   ~redirect_tag_str()
   {
@@ -77,7 +70,7 @@ public:
 
   redirect_tag_str *next;
   char *chunk_str;
-  char type;                    /* s - string, r - referer, t - url_to, f - url_from, o - origin url */
+  char type; /* s - string, r - referer, t - url_to, f - url_from, o - origin url */
   static redirect_tag_str *parse_format_redirect_url(char *url);
 };
 
@@ -90,10 +83,14 @@ public:
   url_mapping(int rank = 0);
   ~url_mapping();
 
-  bool add_plugin(remap_plugin_info *i, void* ih);
+  bool add_plugin(remap_plugin_info *i, void *ih);
   remap_plugin_info *get_plugin(unsigned int) const;
 
-  void* get_instance(unsigned int index) const { return _instance_data[index]; };
+  void *
+  get_instance(unsigned int index) const
+  {
+    return _instance_data[index];
+  };
   void delete_instance(unsigned int index);
   void Print();
 
@@ -101,25 +98,34 @@ public:
   URL fromURL;
   URL toUrl; // Default TO-URL (from remap.config)
   bool homePageRedirect;
-  bool unique;                  // INKqa11970 - unique mapping
+  bool unique; // INKqa11970 - unique mapping
   bool default_redirect_url;
   bool optional_referer;
   bool negative_referer;
-  bool wildcard_from_scheme;    // from url is '/foo', only http or https for now
-  char *tag;                    // tag
-  char *filter_redirect_url;    // redirect url when referer filtering enabled
+  bool wildcard_from_scheme; // from url is '/foo', only http or https for now
+  char *tag;                 // tag
+  char *filter_redirect_url; // redirect url when referer filtering enabled
   unsigned int map_id;
   referer_info *referer_list;
   redirect_tag_str *redir_chunk_list;
-  acl_filter_rule *filter;      // acl filtering (list of rules)
+  acl_filter_rule *filter; // acl filtering (list of rules)
   unsigned int _plugin_count;
   LINK(url_mapping, link); // For use with the main Queue linked list holding all the mapping
 
-  int getRank() const { return _rank; };
+  int
+  getRank() const
+  {
+    return _rank;
+  };
+  void
+  setRank(int rank)
+  {
+    _rank = rank;
+  };
 
 private:
-  remap_plugin_info* _plugin_list[MAX_REMAP_PLUGIN_CHAIN];
-  void* _instance_data[MAX_REMAP_PLUGIN_CHAIN];
+  remap_plugin_info *_plugin_list[MAX_REMAP_PLUGIN_CHAIN];
+  void *_instance_data[MAX_REMAP_PLUGIN_CHAIN];
   int _rank;
 };
 
@@ -128,48 +134,67 @@ private:
  * UrlMappingContainer wraps a url_mapping object and allows a caller to rewrite the target URL.
  * This is used while evaluating remap rules.
 **/
-class UrlMappingContainer {
+class UrlMappingContainer
+{
 public:
- UrlMappingContainer()
-   : _mapping(NULL), _toURLPtr(NULL), _heap(NULL)
-    { }
+  UrlMappingContainer() : _mapping(NULL), _toURLPtr(NULL), _heap(NULL) {}
 
-  explicit UrlMappingContainer(HdrHeap *heap)
-    : _mapping(NULL), _toURLPtr(NULL), _heap(heap)
-  { }
+  explicit UrlMappingContainer(HdrHeap *heap) : _mapping(NULL), _toURLPtr(NULL), _heap(heap) {}
 
   ~UrlMappingContainer() { deleteToURL(); }
-  
-  URL * getToURL() const { return _toURLPtr; };
-  URL * getFromURL() const { return _mapping ? &(_mapping->fromURL) : NULL; };
 
-  url_mapping *getMapping() const { return _mapping; };
+  URL *
+  getToURL() const
+  {
+    return _toURLPtr;
+  };
+  URL *
+  getFromURL() const
+  {
+    return _mapping ? &(_mapping->fromURL) : NULL;
+  };
 
-  void set(url_mapping *m) { 
+  url_mapping *
+  getMapping() const
+  {
+    return _mapping;
+  };
+
+  void
+  set(url_mapping *m)
+  {
     deleteToURL();
     _mapping = m;
     _toURLPtr = m ? &(m->toUrl) : NULL;
   }
 
-  void set(HdrHeap *heap) {
+  void
+  set(HdrHeap *heap)
+  {
     _heap = heap;
   }
 
-  URL *createNewToURL() {
+  URL *
+  createNewToURL()
+  {
     ink_assert(_heap != NULL);
     deleteToURL();
     _toURL.create(_heap);
     _toURLPtr = &_toURL;
-    return _toURLPtr; 
+    return _toURLPtr;
   }
 
-  void deleteToURL() {
+  void
+  deleteToURL()
+  {
     if (_toURLPtr == &_toURL) {
       _toURL.clear();
     }
   }
 
-  void clear() {
+  void
+  clear()
+  {
     deleteToURL();
     _mapping = NULL;
     _toURLPtr = NULL;
@@ -181,10 +206,10 @@ private:
   URL *_toURLPtr;
   URL _toURL;
   HdrHeap *_heap;
-  
+
   // non-copyable, non-assignable
   UrlMappingContainer(const UrlMappingContainer &orig);
-  UrlMappingContainer &operator =(const UrlMappingContainer &rhs);
+  UrlMappingContainer &operator=(const UrlMappingContainer &rhs);
 };
 
 #endif
