@@ -20,13 +20,12 @@
   See the License for the specific language governing permissions and
   limitations under the License.
  */
-#include "ink_config.h"
-#include "ink_file.h"
-#include "I_Layout.h"
-#include "I_Version.h"
 
-#define PROGRAM_NAME        "traffic_logcat"
-#define MAX_LOGBUFFER_SIZE  65536
+#include "libts.h"
+#include "I_Layout.h"
+
+#define PROGRAM_NAME "traffic_logcat"
+#define MAX_LOGBUFFER_SIZE 65536
 
 #include <poll.h>
 
@@ -47,8 +46,6 @@
 #include "Log.h"
 
 // logcat-specific command-line flags
-static int version_flag = 0;
-static int help = 0;
 static int squid_flag = 0;
 static int follow_flag = 0;
 static int clf_flag = 0;
@@ -62,28 +59,16 @@ int auto_clear_cache_flag = 0;
 static const ArgumentDescription argument_descriptions[] = {
 
   {"output_file", 'o', "Specify output file", "S1023", &output_file, NULL, NULL},
-  {"auto_filenames", 'a', "Automatically generate output names",
-   "T", &auto_filenames, NULL, NULL},
+  {"auto_filenames", 'a', "Automatically generate output names", "T", &auto_filenames, NULL, NULL},
   {"follow", 'f', "Follow the log file as it grows", "T", &follow_flag, NULL, NULL},
   {"clf", 'C', "Convert to Common Logging Format", "T", &clf_flag, NULL, NULL},
   {"elf", 'E', "Convert to Extended Logging Format", "T", &elf_flag, NULL, NULL},
-  {"help", 'h', "Give this help", "T", &help, NULL, NULL},
   {"squid", 'S', "Convert to Squid Logging Format", "T", &squid_flag, NULL, NULL},
   {"debug_tags", 'T', "Colon-Separated Debug Tags", "S1023", error_tags, NULL, NULL},
-  {"version", 'V', "Print Version Id", "T", &version_flag, NULL, NULL},
-  {"overwrite_output", 'w', "Overwrite existing output file(s)", "T",
-   &overwrite_existing_file, NULL, NULL},
-  {"elf2", '2', "Convert to Extended2 Logging Format", "T", &elf2_flag, NULL,
-   NULL}
-};
-
-static const char *USAGE_LINE = "Usage: " PROGRAM_NAME " [-o output-file | -a] [-CEhS"
-#ifdef DEBUG
-  "T"
-#endif
-  "Vw2] [input-file ...]";
-
-
+  {"overwrite_output", 'w', "Overwrite existing output file(s)", "T", &overwrite_existing_file, NULL, NULL},
+  {"elf2", '2', "Convert to Extended2 Logging Format", "T", &elf2_flag, NULL, NULL},
+  HELP_ARGUMENT_DESCRIPTION(),
+  VERSION_ARGUMENT_DESCRIPTION()};
 
 static int
 process_file(int in_fd, int out_fd)
@@ -103,7 +88,7 @@ process_file(int in_fd, int out_fd)
     //
     unsigned first_read_size = sizeof(uint32_t) + sizeof(uint32_t);
     unsigned header_size = sizeof(LogBufferHeader);
-    LogBufferHeader *header = (LogBufferHeader *) & buffer[0];
+    LogBufferHeader *header = (LogBufferHeader *)&buffer[0];
 
     nread = read(in_fd, buffer, first_read_size);
     if (!nread || nread == EOF)
@@ -163,7 +148,7 @@ process_file(int in_fd, int out_fd)
     // see if there is an alternate format request from the command
     // line
     //
-    const char * alt_format = NULL;
+    const char *alt_format = NULL;
     if (squid_flag)
       alt_format = PreDefinedFormatInfo::squid;
     if (clf_flag)
@@ -196,7 +181,8 @@ open_output_file(char *output_file)
         file_desc = -1;
       }
     } else {
-      fprintf(stderr, "Error, output file %s already exists.\n" "Select a different filename or use the -w flag\n",
+      fprintf(stderr, "Error, output file %s already exists.\n"
+                      "Select a different filename or use the -w flag\n",
               output_file);
       file_desc = -1;
     }
@@ -220,39 +206,25 @@ open_output_file(char *output_file)
   -------------------------------------------------------------------------*/
 
 int
-main(int /* argc ATS_UNUSED */, char *argv[])
+main(int /* argc ATS_UNUSED */, const char *argv[])
 {
-  enum
-  {
+  enum {
     NO_ERROR = 0,
     CMD_LINE_OPTION_ERROR = 1,
-    DATA_PROCESSING_ERROR = 2
+    DATA_PROCESSING_ERROR = 2,
   };
 
   // build the application information structure
   //
-  appVersionInfo.setup(PACKAGE_NAME,PROGRAM_NAME, PACKAGE_VERSION, __DATE__,
-                       __TIME__, BUILD_MACHINE, BUILD_PERSON, "");
+  appVersionInfo.setup(PACKAGE_NAME, PROGRAM_NAME, PACKAGE_VERSION, __DATE__, __TIME__, BUILD_MACHINE, BUILD_PERSON, "");
 
   // Before accessing file system initialize Layout engine
   Layout::create();
   // process command-line arguments
   //
   output_file[0] = 0;
-  process_args(argument_descriptions, countof(argument_descriptions), argv, USAGE_LINE);
+  process_args(&appVersionInfo, argument_descriptions, countof(argument_descriptions), argv);
 
-  // check for the version number request
-  //
-  if (version_flag) {
-    fprintf(stderr, "%s\n", appVersionInfo.FullVersionInfoStr);
-    _exit(NO_ERROR);
-  }
-  // check for help request
-  //
-  if (help) {
-    usage(argument_descriptions, countof(argument_descriptions), USAGE_LINE);
-    _exit(NO_ERROR);
-  }
   // check that only one of the -o and -a options was specified
   //
   if (output_file[0] != 0 && auto_filenames) {
@@ -299,9 +271,10 @@ main(int /* argc ATS_UNUSED */, char *argv[])
           // change .blog to .log
           //
           int n = strlen(file_arguments[i]);
-          int copy_len = (n >= bin_ext_len ? (strcmp(&file_arguments[i][n - bin_ext_len],
-                                                     LOG_FILE_BINARY_OBJECT_FILENAME_EXTENSION) ==
-                                              0 ? n - bin_ext_len : n) : n);
+          int copy_len =
+            (n >= bin_ext_len ?
+               (strcmp(&file_arguments[i][n - bin_ext_len], LOG_FILE_BINARY_OBJECT_FILENAME_EXTENSION) == 0 ? n - bin_ext_len : n) :
+               n);
 
           char *out_filename = (char *)ats_malloc(copy_len + ascii_ext_len + 1);
 
@@ -328,7 +301,7 @@ main(int /* argc ATS_UNUSED */, char *argv[])
           if (!follow_flag)
             break;
           else
-            usleep(10000);      // This avoids burning CPU, using poll() would have been nice, but doesn't work I think.
+            usleep(10000); // This avoids burning CPU, using poll() would have been nice, but doesn't work I think.
         }
       }
     }
