@@ -48,12 +48,11 @@
   machine pointer.
   -------------------------------------------------------------------------*/
 
-LogAccessHttp::LogAccessHttp(HttpSM * sm)
-  : m_http_sm(sm), m_arena(), m_client_request(NULL), m_proxy_response(NULL), m_proxy_request(NULL),
-    m_server_response(NULL), m_cache_response(NULL), m_client_req_url_str(NULL), m_client_req_url_len(0),
-    m_client_req_url_canon_str(NULL), m_client_req_url_canon_len(0), m_client_req_unmapped_url_canon_str(NULL),
-    m_client_req_unmapped_url_canon_len(-1), m_client_req_unmapped_url_path_str(NULL),
-    m_client_req_unmapped_url_path_len(-1), m_client_req_unmapped_url_host_str(NULL),
+LogAccessHttp::LogAccessHttp(HttpSM *sm)
+  : m_http_sm(sm), m_arena(), m_client_request(NULL), m_proxy_response(NULL), m_proxy_request(NULL), m_server_response(NULL),
+    m_cache_response(NULL), m_client_req_url_str(NULL), m_client_req_url_len(0), m_client_req_url_canon_str(NULL),
+    m_client_req_url_canon_len(0), m_client_req_unmapped_url_canon_str(NULL), m_client_req_unmapped_url_canon_len(-1),
+    m_client_req_unmapped_url_path_str(NULL), m_client_req_unmapped_url_path_len(-1), m_client_req_unmapped_url_host_str(NULL),
     m_client_req_unmapped_url_host_len(-1), m_client_req_url_path_str(NULL), m_client_req_url_path_len(0),
     m_proxy_resp_content_type_str(NULL), m_proxy_resp_content_type_len(0)
 {
@@ -87,7 +86,7 @@ LogAccessHttp::~LogAccessHttp()
 void
 LogAccessHttp::init()
 {
-  HttpTransact::HeaderInfo * hdr = &(m_http_sm->t_state.hdr_info);
+  HttpTransact::HeaderInfo *hdr = &(m_http_sm->t_state.hdr_info);
 
   if (hdr->client_request.valid()) {
     m_client_request = &(hdr->client_request);
@@ -98,8 +97,8 @@ LogAccessHttp::init()
     memcpy(m_client_req_url_str, url_string_ref, m_client_req_url_len);
     m_client_req_url_str[m_client_req_url_len] = '\0';
 
-    m_client_req_url_canon_str = LogUtils::escapify_url(&m_arena, m_client_req_url_str, m_client_req_url_len,
-                                                        &m_client_req_url_canon_len);
+    m_client_req_url_canon_str =
+      LogUtils::escapify_url(&m_arena, m_client_req_url_str, m_client_req_url_len, &m_client_req_url_canon_len);
     m_client_req_url_path_str = m_client_request->path_get(&m_client_req_url_path_len);
   }
 
@@ -107,17 +106,17 @@ LogAccessHttp::init()
     m_proxy_response = &(hdr->client_response);
     MIMEField *field = m_proxy_response->field_find(MIME_FIELD_CONTENT_TYPE, MIME_LEN_CONTENT_TYPE);
     if (field) {
-      m_proxy_resp_content_type_str = (char *) field->value_get(&m_proxy_resp_content_type_len);
+      m_proxy_resp_content_type_str = (char *)field->value_get(&m_proxy_resp_content_type_len);
       //
       // here is the assert
       //
-      //assert (m_proxy_resp_content_type_str[0] >= 'A' && m_proxy_resp_content_type_str[0] <= 'z');
+      // assert (m_proxy_resp_content_type_str[0] >= 'A' && m_proxy_resp_content_type_str[0] <= 'z');
       LogUtils::remove_content_type_attributes(m_proxy_resp_content_type_str, &m_proxy_resp_content_type_len);
     } else {
       // If Content-Type field is missing, check for @Content-Type
       field = m_proxy_response->field_find(HIDDEN_CONTENT_TYPE, HIDDEN_CONTENT_TYPE_LEN);
       if (field) {
-        m_proxy_resp_content_type_str = (char *) field->value_get(&m_proxy_resp_content_type_len);
+        m_proxy_resp_content_type_str = (char *)field->value_get(&m_proxy_resp_content_type_len);
         LogUtils::remove_content_type_attributes(m_proxy_resp_content_type_str, &m_proxy_resp_content_type_len);
       }
     }
@@ -209,7 +208,8 @@ LogAccessHttp::set_client_req_url_path(char *buf, int len)
 int
 LogAccessHttp::marshal_plugin_identity_id(char *buf)
 {
-  if (buf) marshal_int(buf, m_http_sm->plugin_id);
+  if (buf)
+    marshal_int(buf, m_http_sm->plugin_id);
   return INK_MIN_ALIGN;
 }
 
@@ -217,12 +217,15 @@ int
 LogAccessHttp::marshal_plugin_identity_tag(char *buf)
 {
   int len = INK_MIN_ALIGN;
-  char const* tag = m_http_sm->plugin_tag;
+  char const *tag = m_http_sm->plugin_tag;
 
-  if (!tag) tag = "*";
-  else len = LogAccess::strlen(tag);
+  if (!tag)
+    tag = "*";
+  else
+    len = LogAccess::strlen(tag);
 
-  if (buf) marshal_str(buf, tag, len);
+  if (buf)
+    marshal_str(buf, tag, len);
 
   return len;
 }
@@ -285,7 +288,7 @@ LogAccessHttp::validate_unmapped_url(void)
 
       if (unmapped_url && unmapped_url[0] != 0) {
         m_client_req_unmapped_url_canon_str =
-        LogUtils::escapify_url(&m_arena, unmapped_url, unmapped_url_len, &m_client_req_unmapped_url_canon_len);
+          LogUtils::escapify_url(&m_arena, unmapped_url, unmapped_url_len, &m_client_req_unmapped_url_canon_len);
       }
     } else {
       m_client_req_unmapped_url_canon_len = 0;
@@ -309,19 +312,17 @@ LogAccessHttp::validate_unmapped_url_path(void)
     m_client_req_unmapped_url_path_str = m_client_req_unmapped_url_canon_str;
     m_client_req_unmapped_url_path_len = m_client_req_unmapped_url_canon_len;
 
-    if (m_client_req_unmapped_url_path_len >= 6) {      // xxx:// - minimum schema size
-      c = (char *) memchr((void *) m_client_req_unmapped_url_path_str, ':', m_client_req_unmapped_url_path_len - 1);
-      if (c && (len = (int) (c - m_client_req_unmapped_url_path_str)) <= 5) {   // 5 - max schema size
+    if (m_client_req_unmapped_url_path_len >= 6) { // xxx:// - minimum schema size
+      c = (char *)memchr((void *)m_client_req_unmapped_url_path_str, ':', m_client_req_unmapped_url_path_len - 1);
+      if (c && (len = (int)(c - m_client_req_unmapped_url_path_str)) <= 5) { // 5 - max schema size
         if (len + 2 <= m_client_req_unmapped_url_canon_len && c[1] == '/' && c[2] == '/') {
-          len += 3;             // Skip "://"
+          len += 3; // Skip "://"
           m_client_req_unmapped_url_host_str = &m_client_req_unmapped_url_canon_str[len];
           m_client_req_unmapped_url_host_len = m_client_req_unmapped_url_path_len - len;
           // Attempt to find first '/' in the path
           if (m_client_req_unmapped_url_host_len > 0 &&
-              (c =
-               (char *) memchr((void *) m_client_req_unmapped_url_host_str, '/',
-                               m_client_req_unmapped_url_path_len)) != 0) {
-            m_client_req_unmapped_url_host_len = (int) (c - m_client_req_unmapped_url_host_str);
+              (c = (char *)memchr((void *)m_client_req_unmapped_url_host_str, '/', m_client_req_unmapped_url_path_len)) != 0) {
+            m_client_req_unmapped_url_host_len = (int)(c - m_client_req_unmapped_url_host_str);
             m_client_req_unmapped_url_path_str = &m_client_req_unmapped_url_host_str[m_client_req_unmapped_url_host_len];
             m_client_req_unmapped_url_path_len = m_client_req_unmapped_url_path_len - len - m_client_req_unmapped_url_host_len;
           }
@@ -363,7 +364,7 @@ LogAccessHttp::marshal_client_req_http_method(char *buf)
   int plen = INK_MIN_ALIGN;
 
   if (m_client_request) {
-    str = (char *) m_client_request->method_get(&alen);
+    str = (char *)m_client_request->method_get(&alen);
 
     // calculate the the padded length only if the actual length
     // is not zero. We don't want the padded length to be zero
@@ -371,7 +372,7 @@ LogAccessHttp::marshal_client_req_http_method(char *buf)
     // buffer if str is nil, and we need room for this.
     //
     if (alen) {
-      plen = round_strlen(alen + 1);    // +1 for trailing 0
+      plen = round_strlen(alen + 1); // +1 for trailing 0
     }
   }
 
@@ -386,7 +387,7 @@ LogAccessHttp::marshal_client_req_http_method(char *buf)
 int
 LogAccessHttp::marshal_client_req_url(char *buf)
 {
-  int len = round_strlen(m_client_req_url_len + 1);     // +1 for trailing 0
+  int len = round_strlen(m_client_req_url_len + 1); // +1 for trailing 0
 
   if (buf) {
     marshal_mem(buf, m_client_req_url_str, m_client_req_url_len, len);
@@ -418,13 +419,13 @@ LogAccessHttp::marshal_client_req_unmapped_url_canon(char *buf)
   int len = INK_MIN_ALIGN;
 
   validate_unmapped_url();
-  if (0 == m_client_req_unmapped_url_canon_len) {
+  if (0 >= m_client_req_unmapped_url_canon_len) {
     // If the unmapped URL isn't populated, we'll fall back to the original
     // client URL. This helps for example server intercepts to continue to
     // log the requests, even when there is no remap rule for it.
     len = marshal_client_req_url_canon(buf);
   } else {
-    len = round_strlen(m_client_req_unmapped_url_canon_len + 1);      // +1 for eos
+    len = round_strlen(m_client_req_unmapped_url_canon_len + 1); // +1 for eos
     if (buf) {
       marshal_mem(buf, m_client_req_unmapped_url_canon_str, m_client_req_unmapped_url_canon_len, len);
     }
@@ -444,10 +445,10 @@ LogAccessHttp::marshal_client_req_unmapped_url_path(char *buf)
   validate_unmapped_url();
   validate_unmapped_url_path();
 
-  if (0 == m_client_req_unmapped_url_path_len) {
+  if (0 >= m_client_req_unmapped_url_path_len) {
     len = marshal_client_req_url_path(buf);
   } else {
-    len = round_strlen(m_client_req_unmapped_url_path_len + 1);   // +1 for eos
+    len = round_strlen(m_client_req_unmapped_url_path_len + 1); // +1 for eos
     if (buf) {
       marshal_mem(buf, m_client_req_unmapped_url_path_str, m_client_req_unmapped_url_path_len, len);
     }
@@ -466,7 +467,7 @@ LogAccessHttp::marshal_client_req_unmapped_url_host(char *buf)
   validate_unmapped_url();
   validate_unmapped_url_path();
 
-  len = round_strlen(m_client_req_unmapped_url_host_len + 1);      // +1 for eos
+  len = round_strlen(m_client_req_unmapped_url_host_len + 1); // +1 for eos
   if (buf) {
     marshal_mem(buf, m_client_req_unmapped_url_host_str, m_client_req_unmapped_url_host_len, len);
   }
@@ -490,7 +491,7 @@ LogAccessHttp::marshal_client_req_url_scheme(char *buf)
   int alen = 0;
   int plen = INK_MIN_ALIGN;
 
-  str = (char *) m_client_request->scheme_get(&alen);
+  str = (char *)m_client_request->scheme_get(&alen);
 
   // calculate the the padded length only if the actual length
   // is not zero. We don't want the padded length to be zero
@@ -498,7 +499,7 @@ LogAccessHttp::marshal_client_req_url_scheme(char *buf)
   // buffer if str is nil, and we need room for this.
   //
   if (alen) {
-    plen = round_strlen(alen + 1);    // +1 for trailing 0
+    plen = round_strlen(alen + 1); // +1 for trailing 0
   }
 
   if (buf) {
@@ -569,7 +570,6 @@ LogAccessHttp::marshal_client_finish_status_code(char *buf)
     int code = LOG_FINISH_FIN;
     HttpTransact::AbortState_t cl_abort_state = m_http_sm->t_state.client_info.abort;
     if (cl_abort_state == HttpTransact::ABORTED) {
-
       // Check to see if the abort is due to a timeout
       if (m_http_sm->t_state.client_info.state == HttpTransact::ACTIVE_TIMEOUT ||
           m_http_sm->t_state.client_info.state == HttpTransact::INACTIVE_TIMEOUT) {
@@ -646,7 +646,7 @@ LogAccessHttp::marshal_proxy_resp_status_code(char *buf)
     } else {
       status = HTTP_STATUS_NONE;
     }
-    marshal_int(buf, (int64_t) status);
+    marshal_int(buf, (int64_t)status);
   }
   return INK_MIN_ALIGN;
 }
@@ -695,6 +695,18 @@ LogAccessHttp::marshal_proxy_finish_status_code(char *buf)
   return INK_MIN_ALIGN;
 }
 
+/*-------------------------------------------------------------------------
+-------------------------------------------------------------------------*/
+int
+LogAccessHttp::marshal_proxy_host_port(char *buf)
+{
+  if (buf) {
+    uint16_t port = m_http_sm->t_state.request_data.incoming_port;
+    marshal_int(buf, port);
+  }
+  return INK_MIN_ALIGN;
+}
+
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
 
@@ -703,7 +715,20 @@ LogAccessHttp::marshal_cache_result_code(char *buf)
 {
   if (buf) {
     SquidLogCode code = m_http_sm->t_state.squid_codes.log_code;
-    marshal_int(buf, (int64_t) code);
+    marshal_int(buf, (int64_t)code);
+  }
+  return INK_MIN_ALIGN;
+}
+
+/*-------------------------------------------------------------------------
+  -------------------------------------------------------------------------*/
+
+int
+LogAccessHttp::marshal_cache_hit_miss(char *buf)
+{
+  if (buf) {
+    SquidHitMissCode code = m_http_sm->t_state.squid_codes.hit_miss_code;
+    marshal_int(buf, (int64_t)code);
   }
   return INK_MIN_ALIGN;
 }
@@ -772,7 +797,7 @@ LogAccessHttp::marshal_proxy_hierarchy_route(char *buf)
 {
   if (buf) {
     SquidHierarchyCode code = m_http_sm->t_state.squid_codes.hier_code;
-    marshal_int(buf, (int64_t) code);
+    marshal_int(buf, (int64_t)code);
   }
   return INK_MIN_ALIGN;
 }
@@ -784,12 +809,13 @@ LogAccessHttp::marshal_proxy_hierarchy_route(char *buf)
 int
 LogAccessHttp::marshal_server_host_ip(char *buf)
 {
-  sockaddr const* ip = 0;
+  sockaddr const *ip = 0;
   ip = &m_http_sm->t_state.server_info.addr.sa;
-  if (! ats_is_ip(ip)) {
+  if (!ats_is_ip(ip)) {
     if (m_http_sm->t_state.current.server) {
       ip = &m_http_sm->t_state.current.server->addr.sa;
-      if (! ats_is_ip(ip)) ip = 0;
+      if (!ats_is_ip(ip))
+        ip = 0;
     } else {
       ip = 0;
     }
@@ -804,7 +830,7 @@ LogAccessHttp::marshal_server_host_ip(char *buf)
 int
 LogAccessHttp::marshal_server_host_name(char *buf)
 {
-  char const* str = NULL;
+  char const *str = NULL;
   int padded_len = INK_MIN_ALIGN;
   int actual_len = 0;
 
@@ -812,7 +838,7 @@ LogAccessHttp::marshal_server_host_name(char *buf)
     str = m_client_request->host_get(&actual_len);
 
     if (str)
-      padded_len = round_strlen(actual_len + 1);        // +1 for trailing 0
+      padded_len = round_strlen(actual_len + 1); // +1 for trailing 0
   }
   if (buf) {
     marshal_mem(buf, str, actual_len, padded_len);
@@ -834,7 +860,7 @@ LogAccessHttp::marshal_server_resp_status_code(char *buf)
     } else {
       status = HTTP_STATUS_NONE;
     }
-    marshal_int(buf, (int64_t) status);
+    marshal_int(buf, (int64_t)status);
   }
   return INK_MIN_ALIGN;
 }
@@ -887,6 +913,30 @@ LogAccessHttp::marshal_server_resp_http_version(char *buf)
   return (2 * INK_MIN_ALIGN);
 }
 
+/*-------------------------------------------------------------------------
+-------------------------------------------------------------------------*/
+int
+LogAccessHttp::marshal_server_resp_time_ms(char *buf)
+{
+  if (buf) {
+    ink_hrtime elapsed = m_http_sm->milestones.server_close - m_http_sm->milestones.server_connect;
+    int64_t val = (int64_t)ink_hrtime_to_msec(elapsed);
+    marshal_int(buf, val);
+  }
+  return INK_MIN_ALIGN;
+}
+
+int
+LogAccessHttp::marshal_server_resp_time_s(char *buf)
+{
+  if (buf) {
+    ink_hrtime elapsed = m_http_sm->milestones.server_close - m_http_sm->milestones.server_connect;
+    int64_t val = (int64_t)ink_hrtime_to_sec(elapsed);
+    marshal_int(buf, val);
+  }
+  return INK_MIN_ALIGN;
+}
+
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
 
@@ -900,7 +950,7 @@ LogAccessHttp::marshal_cache_resp_status_code(char *buf)
     } else {
       status = HTTP_STATUS_NONE;
     }
-    marshal_int(buf, (int64_t) status);
+    marshal_int(buf, (int64_t)status);
   }
   return INK_MIN_ALIGN;
 }
@@ -967,7 +1017,6 @@ LogAccessHttp::marshal_client_retry_after_time(char *buf)
 static LogCacheWriteCodeType
 convert_cache_write_code(HttpTransact::CacheWriteStatus_t t)
 {
-
   LogCacheWriteCodeType code;
   switch (t) {
   case HttpTransact::NO_CACHE_WRITE:
@@ -1002,7 +1051,6 @@ convert_cache_write_code(HttpTransact::CacheWriteStatus_t t)
 int
 LogAccessHttp::marshal_cache_write_code(char *buf)
 {
-
   if (buf) {
     int code = convert_cache_write_code(m_http_sm->t_state.cache_info.write_status);
     marshal_int(buf, code);
@@ -1014,7 +1062,6 @@ LogAccessHttp::marshal_cache_write_code(char *buf)
 int
 LogAccessHttp::marshal_cache_write_transform_code(char *buf)
 {
-
   if (buf) {
     int code = convert_cache_write_code(m_http_sm->t_state.cache_info.transform_write_status);
     marshal_int(buf, code);
@@ -1032,8 +1079,7 @@ LogAccessHttp::marshal_transfer_time_ms(char *buf)
 {
   if (buf) {
     ink_hrtime elapsed = m_http_sm->milestones.sm_finish - m_http_sm->milestones.sm_start;
-    elapsed /= HRTIME_MSECOND;
-    int64_t val = (int64_t) elapsed;
+    int64_t val = (int64_t)ink_hrtime_to_msec(elapsed);
     marshal_int(buf, val);
   }
   return INK_MIN_ALIGN;
@@ -1044,8 +1090,7 @@ LogAccessHttp::marshal_transfer_time_s(char *buf)
 {
   if (buf) {
     ink_hrtime elapsed = m_http_sm->milestones.sm_finish - m_http_sm->milestones.sm_start;
-    elapsed /= HRTIME_SECOND;
-    int64_t val = (int64_t) elapsed;
+    int64_t val = (int64_t)ink_hrtime_to_sec(elapsed);
     marshal_int(buf, val);
   }
   return INK_MIN_ALIGN;
@@ -1064,12 +1109,12 @@ LogAccessHttp::marshal_file_size(char *buf)
 
     if (hdr && (fld = hdr->field_find(MIME_FIELD_CONTENT_RANGE, MIME_LEN_CONTENT_RANGE))) {
       int len;
-      char *str = (char*)fld->value_get(&len);
-      char *pos = (char*)memchr(str, '/', len); // Find the /
+      char *str = (char *)fld->value_get(&len);
+      char *pos = (char *)memchr(str, '/', len); // Find the /
 
       // If the size is not /* (which means unknown) use it as the file_size.
-      if (pos && !memchr(pos+1, '*', len - (pos + 1 - str))) {
-        marshal_int(buf, ink_atoi64(pos+1, len - (pos + 1 - str)));
+      if (pos && !memchr(pos + 1, '*', len - (pos + 1 - str))) {
+        marshal_int(buf, ink_atoi64(pos + 1, len - (pos + 1 - str)));
       }
     } else {
       // This is semi-broken when we serveq zero length objects. See TS-2213
@@ -1132,7 +1177,7 @@ LogAccessHttp::marshal_http_header_field(LogField::Container container, char *fi
       //
       int running_len = 0;
       while (fld) {
-        str = (char *) fld->value_get(&actual_len);
+        str = (char *)fld->value_get(&actual_len);
         if (buf) {
           memcpy(buf, str, actual_len);
           buf += actual_len;
@@ -1162,10 +1207,10 @@ LogAccessHttp::marshal_http_header_field(LogField::Container container, char *fi
       running_len += 1;
       padded_len = round_strlen(running_len);
 
-      // Note: marshal_string fills the padding to
-      //  prevent purify UMRs so we do it here too
-      //  since we always pass the unpadded length on
-      //  our calls to marshal string
+// Note: marshal_string fills the padding to
+//  prevent purify UMRs so we do it here too
+//  since we always pass the unpadded length on
+//  our calls to marshal string
 #ifdef DEBUG
       if (buf) {
         int pad_len = padded_len - running_len;
@@ -1233,7 +1278,7 @@ LogAccessHttp::marshal_http_header_field_escapify(LogField::Container container,
       //
       int running_len = 0;
       while (fld) {
-        str = (char *) fld->value_get(&actual_len);
+        str = (char *)fld->value_get(&actual_len);
         new_str = LogUtils::escapify_url(&m_arena, str, actual_len, &new_len);
         if (buf) {
           memcpy(buf, new_str, new_len);
@@ -1264,10 +1309,10 @@ LogAccessHttp::marshal_http_header_field_escapify(LogField::Container container,
       running_len += 1;
       padded_len = round_strlen(running_len);
 
-      // Note: marshal_string fills the padding to
-      //  prevent purify UMRs so we do it here too
-      //  since we always pass the unpadded length on
-      //  our calls to marshal string
+// Note: marshal_string fills the padding to
+//  prevent purify UMRs so we do it here too
+//  since we always pass the unpadded length on
+//  our calls to marshal string
 #ifdef DEBUG
       if (buf) {
         int pad_len = padded_len - running_len;
