@@ -42,8 +42,8 @@
 //#include "ink_ctype.h"
 #include "SimpleTokenizer.h"
 
-const char *LogFilter::OPERATOR_NAME[] = { "MATCH", "CASE_INSENSITIVE_MATCH","CONTAIN", "CASE_INSENSITIVE_CONTAIN" };
-const char *LogFilter::ACTION_NAME[] = { "REJECT", "ACCEPT", "WIPE_FIELD_VALUE" };
+const char *LogFilter::OPERATOR_NAME[] = {"MATCH", "CASE_INSENSITIVE_MATCH", "CONTAIN", "CASE_INSENSITIVE_CONTAIN"};
+const char *LogFilter::ACTION_NAME[] = {"REJECT", "ACCEPT", "WIPE_FIELD_VALUE"};
 
 /*-------------------------------------------------------------------------
   LogFilter::LogFilter
@@ -52,8 +52,8 @@ const char *LogFilter::ACTION_NAME[] = { "REJECT", "ACCEPT", "WIPE_FIELD_VALUE"
   global_field_list to get the log field, but this is an unnecessary dependency
   between the classes and I think should be removed.     ltavera
   -------------------------------------------------------------------------*/
-LogFilter::LogFilter(const char *name, LogField * field, LogFilter::Action action, LogFilter::Operator oper)
-  : m_name(ats_strdup(name)), m_field(NULL) , m_action(action), m_operator(oper), m_type(INT_FILTER), m_num_values(0)
+LogFilter::LogFilter(const char *name, LogField *field, LogFilter::Action action, LogFilter::Operator oper)
+  : m_name(ats_strdup(name)), m_field(NULL), m_action(action), m_operator(oper), m_type(INT_FILTER), m_num_values(0)
 {
   m_field = new LogField(*field);
   ink_assert(m_field);
@@ -85,7 +85,7 @@ LogFilterString::_setValues(size_t n, char **value)
     for (size_t i = 0; i < n; ++i) {
       m_value[i] = ats_strdup(value[i]);
       m_length[i] = strlen(value[i]);
-      m_value_uppercase[i] = (char *)ats_malloc((unsigned int) m_length[i] + 1);
+      m_value_uppercase[i] = (char *)ats_malloc((unsigned int)m_length[i] + 1);
       size_t j;
       for (j = 0; j < m_length[i]; ++j) {
         m_value_uppercase[i][j] = ParseRules::ink_toupper(m_value[i][j]);
@@ -96,8 +96,8 @@ LogFilterString::_setValues(size_t n, char **value)
 }
 
 
-LogFilterString::LogFilterString(const char *name, LogField * field,
-                                 LogFilter::Action action, LogFilter::Operator oper, char *values)
+LogFilterString::LogFilterString(const char *name, LogField *field, LogFilter::Action action, LogFilter::Operator oper,
+                                 char *values)
   : LogFilter(name, field, action, oper)
 {
   // parse the comma-separated list of values and construct array
@@ -114,22 +114,22 @@ LogFilterString::LogFilterString(const char *name, LogField * field,
     }
     if (i < n) {
       Warning("There were invalid values in the definition of filter %s"
-              "only %zu out of %zu values will be used", name, i, n);
+              "only %zu out of %zu values will be used",
+              name, i, n);
     }
   }
   _setValues(i, val_array);
-  delete[]val_array;
+  delete[] val_array;
 }
 
-LogFilterString::LogFilterString(const char *name, LogField * field,
-                                 LogFilter::Action action, LogFilter::Operator oper, size_t num_values, char **value)
+LogFilterString::LogFilterString(const char *name, LogField *field, LogFilter::Action action, LogFilter::Operator oper,
+                                 size_t num_values, char **value)
   : LogFilter(name, field, action, oper)
 {
   _setValues(num_values, value);
 }
 
-LogFilterString::LogFilterString(const LogFilterString & rhs)
-  : LogFilter(rhs.m_name, rhs.m_field, rhs.m_action, rhs.m_operator)
+LogFilterString::LogFilterString(const LogFilterString &rhs) : LogFilter(rhs.m_name, rhs.m_field, rhs.m_action, rhs.m_operator)
 {
   _setValues(rhs.m_num_values, rhs.m_value);
 }
@@ -145,9 +145,9 @@ LogFilterString::~LogFilterString()
       ats_free(m_value[i]);
       ats_free(m_value_uppercase[i]);
     }
-    delete[]m_value;
-    delete[]m_value_uppercase;
-    delete[]m_length;
+    delete[] m_value;
+    delete[] m_value_uppercase;
+    delete[] m_length;
   }
 }
 
@@ -161,17 +161,12 @@ LogFilterString::~LogFilterString()
 
   -------------------------------------------------------------------------*/
 
-bool
-LogFilterString::operator==(LogFilterString & rhs)
+bool LogFilterString::operator==(LogFilterString &rhs)
 {
-  if (m_type == rhs.m_type &&
-      *m_field == *rhs.m_field &&
-      m_action == rhs.m_action &&
-      m_operator == rhs.m_operator &&
+  if (m_type == rhs.m_type && *m_field == *rhs.m_field && m_action == rhs.m_action && m_operator == rhs.m_operator &&
       m_num_values == rhs.m_num_values) {
     for (size_t i = 0; i < m_num_values; i++) {
-      if (m_length[i] != rhs.m_length[i] ||
-          strncmp(m_value[i], rhs.m_value[i], m_length[i])) {
+      if (m_length[i] != rhs.m_length[i] || strncmp(m_value[i], rhs.m_value[i], m_length[i])) {
         return false;
       }
     }
@@ -193,7 +188,7 @@ LogFilterString::operator==(LogFilterString & rhs)
   -------------------------------------------------------------------------*/
 
 bool
-LogFilterString::wipe_this_entry(LogAccess * lad)
+LogFilterString::wipe_this_entry(LogAccess *lad)
 {
   if (m_num_values == 0 || m_field == NULL || lad == NULL || m_action != WIPE_FIELD_VALUE) {
     return false;
@@ -201,20 +196,21 @@ LogFilterString::wipe_this_entry(LogAccess * lad)
 
   static const unsigned BUFSIZE = 1024;
   char small_buf[BUFSIZE];
-  char small_buf_upper[BUFSIZE];
   char *big_buf = NULL;
-  char *big_buf_upper = NULL;
   char *buf = small_buf;
-  char *buf_upper = small_buf_upper;
-  size_t marsh_len = m_field->marshal_len(lad);      // includes null termination
+  size_t marsh_len = m_field->marshal_len(lad); // includes null termination
 
   if (marsh_len > BUFSIZE) {
-    big_buf = (char *)ats_malloc((unsigned int) marsh_len);
+    big_buf = (char *)ats_malloc(marsh_len);
+    ink_assert(big_buf != NULL);
     buf = big_buf;
   }
 
+  ink_assert(buf != NULL);
   m_field->marshal(lad, buf);
 
+  ink_assert(buf != NULL);
+
   bool cond_satisfied = false;
   switch (m_operator) {
   case MATCH:
@@ -235,26 +231,18 @@ LogFilterString::wipe_this_entry(LogAccess * lad)
     cond_satisfied = _checkConditionAndWipe(&_isSubstring, &buf, marsh_len, m_value, DATA_LENGTH_LARGER);
     break;
   case CASE_INSENSITIVE_CONTAIN:
-    {
-      if (big_buf) {
-        big_buf_upper = (char *)ats_malloc((unsigned int) marsh_len);
-        buf_upper = big_buf_upper;
-      }
-      for (size_t i = 0; i < marsh_len; i++) {
-        buf_upper[i] = ParseRules::ink_toupper(buf[i]);
-      }
-      cond_satisfied = _checkConditionAndWipe(&_isSubstring, &buf_upper, marsh_len, m_value_uppercase, DATA_LENGTH_LARGER);
-      strcpy(buf, buf_upper);
-      break;
+    for (size_t i = 0; i < marsh_len; i++) {
+      buf[i] = ParseRules::ink_toupper(buf[i]);
     }
+    cond_satisfied = _checkConditionAndWipe(&_isSubstring, &buf, marsh_len, m_value_uppercase, DATA_LENGTH_LARGER);
+    break;
   default:
     ink_assert(!"INVALID FILTER OPERATOR");
   }
 
-  ats_free(big_buf);
-  ats_free(big_buf_upper);
-
   m_field->updateField(lad, buf, strlen(buf));
+
+  ats_free(big_buf);
   return cond_satisfied;
 }
 
@@ -271,7 +259,8 @@ LogFilterString::wipe_this_entry(LogAccess * lad)
   whether we should compare the entire string.
   -------------------------------------------------------------------------*/
 
-bool LogFilterString::toss_this_entry(LogAccess * lad)
+bool
+LogFilterString::toss_this_entry(LogAccess *lad)
 {
   if (m_num_values == 0 || m_field == NULL || lad == NULL) {
     return false;
@@ -284,17 +273,17 @@ bool LogFilterString::toss_this_entry(LogAccess * lad)
   char *big_buf_upper = NULL;
   char *buf = small_buf;
   char *buf_upper = small_buf_upper;
-  size_t marsh_len = m_field->marshal_len(lad);      // includes null termination
+  size_t marsh_len = m_field->marshal_len(lad); // includes null termination
 
   if (marsh_len > BUFSIZE) {
-    big_buf = (char *)ats_malloc((unsigned int) marsh_len);
+    big_buf = (char *)ats_malloc((unsigned int)marsh_len);
+    ink_assert(big_buf != NULL);
     buf = big_buf;
   }
 
   m_field->marshal(lad, buf);
 
-  bool
-    cond_satisfied = false;
+  bool cond_satisfied = false;
   switch (m_operator) {
   case MATCH:
     // marsh_len is an upper bound on the length of the marshalled string
@@ -313,18 +302,19 @@ bool LogFilterString::toss_this_entry(LogAccess * lad)
   case CONTAIN:
     cond_satisfied = _checkCondition(&_isSubstring, buf, marsh_len, m_value, DATA_LENGTH_LARGER);
     break;
-  case CASE_INSENSITIVE_CONTAIN:
-    {
-      if (big_buf) {
-        big_buf_upper = (char *)ats_malloc((unsigned int) marsh_len);
-        buf_upper = big_buf_upper;
-      }
-      for (size_t i = 0; i < marsh_len; i++) {
-        buf_upper[i] = ParseRules::ink_toupper(buf[i]);
-      }
-      cond_satisfied = _checkCondition(&_isSubstring, buf_upper, marsh_len, m_value_uppercase, DATA_LENGTH_LARGER);
-      break;
+  case CASE_INSENSITIVE_CONTAIN: {
+    if (big_buf) {
+      big_buf_upper = (char *)ats_malloc((unsigned int)marsh_len);
+      buf_upper = big_buf_upper;
+    } else {
+      buf = small_buf; // make clang happy
     }
+    for (size_t i = 0; i < marsh_len; i++) {
+      buf_upper[i] = ParseRules::ink_toupper(buf[i]);
+    }
+    cond_satisfied = _checkCondition(&_isSubstring, buf_upper, marsh_len, m_value_uppercase, DATA_LENGTH_LARGER);
+    break;
+  }
   default:
     ink_assert(!"INVALID FILTER OPERATOR");
   }
@@ -340,14 +330,13 @@ bool LogFilterString::toss_this_entry(LogAccess * lad)
   -------------------------------------------------------------------------*/
 
 void
-LogFilterString::display(FILE * fd)
+LogFilterString::display(FILE *fd)
 {
   ink_assert(fd != NULL);
   if (m_num_values == 0) {
     fprintf(fd, "Filter \"%s\" is inactive, no values specified\n", m_name);
   } else {
-    fprintf(fd, "Filter \"%s\" %sS records if %s %s ", m_name,
-            ACTION_NAME[m_action], m_field->symbol(), OPERATOR_NAME[m_operator]);
+    fprintf(fd, "Filter \"%s\" %sS records if %s %s ", m_name, ACTION_NAME[m_action], m_field->symbol(), OPERATOR_NAME[m_operator]);
     fprintf(fd, "%s", m_value[0]);
     for (size_t i = 1; i < m_num_values; ++i) {
       fprintf(fd, ", %s", m_value[i]);
@@ -357,14 +346,14 @@ LogFilterString::display(FILE * fd)
 }
 
 void
-LogFilterString::display_as_XML(FILE * fd)
+LogFilterString::display_as_XML(FILE *fd)
 {
   ink_assert(fd != NULL);
-  fprintf(fd,
-          "<LogFilter>\n"
-          "  <Name      = \"%s\"/>\n"
-          "  <Action    = \"%s\"/>\n"
-          "  <Condition = \"%s %s ", m_name, ACTION_NAME[m_action], m_field->symbol(), OPERATOR_NAME[m_operator]);
+  fprintf(fd, "<LogFilter>\n"
+              "  <Name      = \"%s\"/>\n"
+              "  <Action    = \"%s\"/>\n"
+              "  <Condition = \"%s %s ",
+          m_name, ACTION_NAME[m_action], m_field->symbol(), OPERATOR_NAME[m_operator]);
 
   if (m_num_values == 0) {
     fprintf(fd, "<no values>\"\n");
@@ -395,10 +384,11 @@ LogFilterInt::_setValues(size_t n, int64_t *value)
 
 // TODO: ival should be int64_t
 int
-LogFilterInt::_convertStringToInt(char *value, int64_t *ival, LogFieldAliasMap * map)
+LogFilterInt::_convertStringToInt(char *value, int64_t *ival, LogFieldAliasMap *map)
 {
   size_t i, l = strlen(value);
-  for (i = 0; i < l && ParseRules::is_digit(value[i]); i++);
+  for (i = 0; i < l && ParseRules::is_digit(value[i]); i++)
+    ;
 
   if (i < l) {
     // not all characters of value are digits, assume that
@@ -406,7 +396,7 @@ LogFilterInt::_convertStringToInt(char *value, int64_t *ival, LogFieldAliasMap *
     // from the log field alias map if field has one
     //
     if (map == NULL || map->asInt(value, ival) != LogFieldAliasMap::ALL_OK) {
-      return -1;                // error
+      return -1; // error
     };
   } else {
     // all characters of value are digits, simply convert
@@ -414,27 +404,25 @@ LogFilterInt::_convertStringToInt(char *value, int64_t *ival, LogFieldAliasMap *
     //
     *ival = ink_atoui(value);
   }
-  return 0;                     // all OK
+  return 0; // all OK
 }
 
-LogFilterInt::LogFilterInt(const char *name, LogField * field,
-                           LogFilter::Action action, LogFilter::Operator oper, int64_t value)
- : LogFilter(name, field, action, oper)
+LogFilterInt::LogFilterInt(const char *name, LogField *field, LogFilter::Action action, LogFilter::Operator oper, int64_t value)
+  : LogFilter(name, field, action, oper)
 {
   int64_t v[1];
   v[0] = value;
   _setValues(1, v);
 }
 
-LogFilterInt::LogFilterInt(const char *name, LogField * field,
-                           LogFilter::Action action, LogFilter::Operator oper, size_t num_values, int64_t *value)
+LogFilterInt::LogFilterInt(const char *name, LogField *field, LogFilter::Action action, LogFilter::Operator oper, size_t num_values,
+                           int64_t *value)
   : LogFilter(name, field, action, oper)
 {
   _setValues(num_values, value);
 }
 
-LogFilterInt::LogFilterInt(const char *name, LogField * field,
-                           LogFilter::Action action, LogFilter::Operator oper, char *values)
+LogFilterInt::LogFilterInt(const char *name, LogField *field, LogFilter::Action action, LogFilter::Operator oper, char *values)
   : LogFilter(name, field, action, oper)
 {
   // parse the comma-separated list of values and construct array
@@ -457,7 +445,8 @@ LogFilterInt::LogFilterInt(const char *name, LogField * field,
     }
     if (i < n) {
       Warning("There were invalid values in the definition of filter %s"
-              " only %zu out of %zu values will be used.", name, i, n);
+              " only %zu out of %zu values will be used.",
+              name, i, n);
     }
   } else {
     Warning("No values in the definition of filter %s.", name);
@@ -466,13 +455,11 @@ LogFilterInt::LogFilterInt(const char *name, LogField * field,
   _setValues(i, val_array);
 
   if (n) {
-    delete[]val_array;
+    delete[] val_array;
   }
 }
 
-LogFilterInt::LogFilterInt(const LogFilterInt & rhs)
-  :
-LogFilter(rhs.m_name, rhs.m_field, rhs.m_action, rhs.m_operator)
+LogFilterInt::LogFilterInt(const LogFilterInt &rhs) : LogFilter(rhs.m_name, rhs.m_field, rhs.m_action, rhs.m_operator)
 {
   _setValues(rhs.m_num_values, rhs.m_value);
 }
@@ -484,7 +471,7 @@ LogFilter(rhs.m_name, rhs.m_field, rhs.m_action, rhs.m_operator)
 LogFilterInt::~LogFilterInt()
 {
   if (m_num_values > 0) {
-    delete[]m_value;
+    delete[] m_value;
   }
 }
 
@@ -498,12 +485,9 @@ LogFilterInt::~LogFilterInt()
 
   -------------------------------------------------------------------------*/
 
-bool LogFilterInt::operator==(LogFilterInt & rhs)
+bool LogFilterInt::operator==(LogFilterInt &rhs)
 {
-  if (m_type == rhs.m_type &&
-      * m_field == * rhs.m_field &&
-      m_action == rhs.m_action &&
-      m_operator == rhs.m_operator &&
+  if (m_type == rhs.m_type && *m_field == *rhs.m_field && m_action == rhs.m_action && m_operator == rhs.m_operator &&
       m_num_values == rhs.m_num_values) {
     for (size_t i = 0; i < m_num_values; i++) {
       if (m_value[i] != rhs.m_value[i]) {
@@ -520,7 +504,7 @@ bool LogFilterInt::operator==(LogFilterInt & rhs)
   -------------------------------------------------------------------------*/
 
 bool
-LogFilterInt::wipe_this_entry(LogAccess * lad)
+LogFilterInt::wipe_this_entry(LogAccess *lad)
 {
   if (m_num_values == 0 || m_field == NULL || lad == NULL || m_action != WIPE_FIELD_VALUE) {
     return false;
@@ -529,7 +513,7 @@ LogFilterInt::wipe_this_entry(LogAccess * lad)
   bool cond_satisfied = false;
   int64_t value;
 
-  m_field->marshal(lad, (char *) &value);
+  m_field->marshal(lad, (char *)&value);
   // This used to do an ntohl() on value, but that breaks various filters.
   // Long term we should move IPs to their own log type.
 
@@ -557,7 +541,8 @@ LogFilterInt::wipe_this_entry(LogAccess * lad)
   LogFilterInt::toss_this_entry
   -------------------------------------------------------------------------*/
 
-bool LogFilterInt::toss_this_entry(LogAccess * lad)
+bool
+LogFilterInt::toss_this_entry(LogAccess *lad)
 {
   if (m_num_values == 0 || m_field == NULL || lad == NULL) {
     return false;
@@ -566,7 +551,7 @@ bool LogFilterInt::toss_this_entry(LogAccess * lad)
   bool cond_satisfied = false;
   int64_t value;
 
-  m_field->marshal(lad, (char *) &value);
+  m_field->marshal(lad, (char *)&value);
   // This used to do an ntohl() on value, but that breaks various filters.
   // Long term we should move IPs to their own log type.
 
@@ -595,14 +580,13 @@ bool LogFilterInt::toss_this_entry(LogAccess * lad)
   -------------------------------------------------------------------------*/
 
 void
-LogFilterInt::display(FILE * fd)
+LogFilterInt::display(FILE *fd)
 {
   ink_assert(fd != NULL);
   if (m_num_values == 0) {
     fprintf(fd, "Filter \"%s\" is inactive, no values specified\n", m_name);
   } else {
-    fprintf(fd, "Filter \"%s\" %sS records if %s %s ", m_name,
-            ACTION_NAME[m_action], m_field->symbol(), OPERATOR_NAME[m_operator]);
+    fprintf(fd, "Filter \"%s\" %sS records if %s %s ", m_name, ACTION_NAME[m_action], m_field->symbol(), OPERATOR_NAME[m_operator]);
     fprintf(fd, "%" PRId64 "", m_value[0]);
     for (size_t i = 1; i < m_num_values; ++i) {
       fprintf(fd, ", %" PRId64 "", m_value[i]);
@@ -612,14 +596,14 @@ LogFilterInt::display(FILE * fd)
 }
 
 void
-LogFilterInt::display_as_XML(FILE * fd)
+LogFilterInt::display_as_XML(FILE *fd)
 {
   ink_assert(fd != NULL);
-  fprintf(fd,
-          "<LogFilter>\n"
-          "  <Name      = \"%s\"/>\n"
-          "  <Action    = \"%s\"/>\n"
-          "  <Condition = \"%s %s ", m_name, ACTION_NAME[m_action], m_field->symbol(), OPERATOR_NAME[m_operator]);
+  fprintf(fd, "<LogFilter>\n"
+              "  <Name      = \"%s\"/>\n"
+              "  <Action    = \"%s\"/>\n"
+              "  <Condition = \"%s %s ",
+          m_name, ACTION_NAME[m_action], m_field->symbol(), OPERATOR_NAME[m_operator]);
 
   if (m_num_values == 0) {
     fprintf(fd, "<no values>\"\n");
@@ -633,8 +617,228 @@ LogFilterInt::display_as_XML(FILE * fd)
   fprintf(fd, "</LogFilter>\n");
 }
 
+/*-------------------------------------------------------------------------
+  LogFilterIP::LogFilterIP
+  -------------------------------------------------------------------------*/
+LogFilterIP::LogFilterIP(const char *name, LogField *field, LogFilter::Action action, LogFilter::Operator oper, IpAddr value)
+  : LogFilter(name, field, action, oper)
+{
+  m_map.mark(value, value);
+  this->init();
+}
+
+LogFilterIP::LogFilterIP(const char *name, LogField *field, LogFilter::Action action, LogFilter::Operator oper, size_t num_values,
+                         IpAddr *value)
+  : LogFilter(name, field, action, oper)
+{
+  for (IpAddr *limit = value + num_values; value != limit; ++value)
+    m_map.mark(*value, *value);
+  this->init();
+}
+
+LogFilterIP::LogFilterIP(const char *name, LogField *field, LogFilter::Action action, LogFilter::Operator oper, char *values)
+  : LogFilter(name, field, action, oper)
+{
+  // parse the comma-separated list of values and construct array
+  //
+  size_t i = 0;
+  SimpleTokenizer tok(values, ',');
+  size_t n = tok.getNumTokensRemaining();
+  char *t; // temp token pointer.
+
+  if (n) {
+    while (t = tok.getNext(), t != NULL) {
+      IpAddr min, max;
+      char *x = strchr(t, '-');
+      if (x)
+        *x++ = 0;
+      if (0 == min.load(t)) {
+        if (x) {
+          if (0 != max.load(x)) {
+            Warning("LogFilterIP Configuration: '%s-%s' looks like a range but the second address was ill formed", t, x);
+            continue;
+          }
+        } else {
+          max = min;
+        }
+        m_map.mark(min, max);
+        ++i;
+      } else {
+        Warning("LogFilterIP Configuration:  '%s' is ill formed", t);
+      }
+    }
+    if (i < n) {
+      Warning("There were invalid IP values in the definition of filter %s"
+              " only %zu out of %zu values will be used.",
+              name, i, n);
+    }
+  } else {
+    Warning("No values in the definition of filter %s.", name);
+  }
+  this->init();
+}
+
+LogFilterIP::LogFilterIP(const LogFilterIP &rhs) : LogFilter(rhs.m_name, rhs.m_field, rhs.m_action, rhs.m_operator)
+{
+  for (IpMap::iterator spot(rhs.m_map.begin()), limit(rhs.m_map.end()); spot != limit; ++spot) {
+    m_map.mark(spot->min(), spot->max(), spot->data());
+  }
+  this->init();
+}
+
+void
+LogFilterIP::init()
+{
+  m_type = IP_FILTER;
+  m_num_values = m_map.getCount();
+}
+
+/*-------------------------------------------------------------------------
+  LogFilterIP::~LogFilterIP
+  -------------------------------------------------------------------------*/
+
+LogFilterIP::~LogFilterIP()
+{
+}
+
+/*-------------------------------------------------------------------------
+  LogFilterIP::operator==
+
+  This operator is not very intelligent and expects the objects being
+  compared to have the same values specified *in the same order*.
+  Filters with the same values specified in different order are considered
+  to be different.
+
+  -------------------------------------------------------------------------*/
+
+bool LogFilterIP::operator==(LogFilterIP &rhs)
+{
+  if (m_type == rhs.m_type && *m_field == *rhs.m_field && m_action == rhs.m_action && m_operator == rhs.m_operator &&
+      m_num_values == rhs.m_num_values) {
+    IpMap::iterator left_spot(m_map.begin());
+    IpMap::iterator left_limit(m_map.end());
+    IpMap::iterator right_spot(rhs.m_map.begin());
+    IpMap::iterator right_limit(rhs.m_map.end());
+
+    while (left_spot != left_limit && right_spot != right_limit) {
+      if (!ats_ip_addr_eq(left_spot->min(), right_spot->min()) || !ats_ip_addr_eq(left_spot->max(), right_spot->max()))
+        break;
+      ++left_spot;
+      ++right_spot;
+    }
+
+    return left_spot == left_limit && right_spot == right_limit;
+  }
+  return false;
+}
+
+/*-------------------------------------------------------------------------
+  LogFilterIP::toss_this_entry
+  -------------------------------------------------------------------------*/
+
 bool
-filters_are_equal(LogFilter * filt1, LogFilter * filt2)
+LogFilterIP::is_match(LogAccess *lad)
+{
+  bool zret = false;
+
+  if (m_field && lad) {
+    LogFieldIpStorage value;
+    m_field->marshal(lad, reinterpret_cast<char *>(&value));
+    // This is bad, we abuse the fact that the initial layout of LogFieldIpStorage and IpAddr
+    // are identical. We should look at converting the log stuff to use IpAddr directly.
+    zret = m_map.contains(reinterpret_cast<IpAddr &>(value));
+  }
+
+  return zret;
+}
+
+bool
+LogFilterIP::toss_this_entry(LogAccess *lad)
+{
+  bool cond_satisfied = this->is_match(lad);
+  return (m_action == REJECT && cond_satisfied) || (m_action == ACCEPT && !cond_satisfied);
+}
+
+bool
+LogFilterIP::wipe_this_entry(LogAccess *)
+{
+#if 0
+  bool zret = WIPE_FIELD_VALUE == m_action && this->is_match(lad);
+  if (zret) {
+    // set to ADDR_ANY.
+  }
+  return zret;
+#else
+  return false;
+#endif
+}
+
+/*-------------------------------------------------------------------------
+  LogFilterIP::display
+  -------------------------------------------------------------------------*/
+
+void
+LogFilterIP::displayRange(FILE *fd, IpMap::iterator const &iter)
+{
+  ip_text_buffer ipb;
+
+  fprintf(fd, "%s", ats_ip_ntop(iter->min(), ipb, sizeof(ipb)));
+
+  if (!ats_ip_addr_eq(iter->min(), iter->max()))
+    fprintf(fd, "-%s", ats_ip_ntop(iter->max(), ipb, sizeof(ipb)));
+}
+
+void
+LogFilterIP::displayRanges(FILE *fd)
+{
+  IpMap::iterator spot(m_map.begin()), limit(m_map.end());
+  ink_assert(spot != limit);
+
+  this->displayRange(fd, spot);
+  for (++spot; spot != limit; ++spot) {
+    for (size_t i = 1; i < m_num_values; ++i) {
+      fprintf(fd, ",");
+      this->displayRange(fd, spot);
+    }
+  }
+}
+
+void
+LogFilterIP::display(FILE *fd)
+{
+  ink_assert(fd != NULL);
+
+  if (0 == m_map.getCount()) {
+    fprintf(fd, "Filter \"%s\" is inactive, no values specified\n", m_name);
+  } else {
+    fprintf(fd, "Filter \"%s\" %sS records if %s %s ", m_name, ACTION_NAME[m_action], m_field->symbol(), OPERATOR_NAME[m_operator]);
+    this->displayRanges(fd);
+    fprintf(fd, "\n");
+  }
+}
+
+
+void
+LogFilterIP::display_as_XML(FILE *fd)
+{
+  ink_assert(fd != NULL);
+  fprintf(fd, "<LogFilter>\n"
+              "  <Name      = \"%s\"/>\n"
+              "  <Action    = \"%s\"/>\n"
+              "  <Condition = \"%s %s ",
+          m_name, ACTION_NAME[m_action], m_field->symbol(), OPERATOR_NAME[m_operator]);
+
+  if (m_map.getCount() == 0) {
+    fprintf(fd, "<no values>");
+  } else {
+    this->displayRanges(fd);
+  }
+  fprintf(fd, "\"/>\n");
+  fprintf(fd, "</LogFilter>\n");
+}
+
+bool
+filters_are_equal(LogFilter *filt1, LogFilter *filt2)
 {
   bool ret = false;
 
@@ -642,9 +846,11 @@ filters_are_equal(LogFilter * filt1, LogFilter * filt2)
   if (filt1->type() == filt2->type()) {
     if (filt1->type() == LogFilter::INT_FILTER) {
       Debug("log-filter-compare", "int compare");
-      ret = (*((LogFilterInt *) filt1) == *((LogFilterInt *) filt2));
+      ret = (*((LogFilterInt *)filt1) == *((LogFilterInt *)filt2));
+    } else if (filt1->type() == LogFilter::IP_FILTER) {
+      ret = (*((LogFilterIP *)filt1) == *((LogFilterIP *)filt2));
     } else if (filt1->type() == LogFilter::STRING_FILTER) {
-      ret = (*((LogFilterString *) filt1) == *((LogFilterString *) filt2));
+      ret = (*((LogFilterString *)filt1) == *((LogFilterString *)filt2));
     } else {
       ink_assert(!"invalid filter type");
     }
@@ -663,7 +869,7 @@ filters_are_equal(LogFilter * filt1, LogFilter * filt2)
   add() function is overloaded for each sub-type of LogFilter.
   -------------------------------------------------------------------------*/
 
-LogFilterList::LogFilterList():m_does_conjunction(true)
+LogFilterList::LogFilterList() : m_does_conjunction(true)
 {
 }
 
@@ -678,7 +884,7 @@ LogFilterList::~LogFilterList()
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
 
-bool LogFilterList::operator==(LogFilterList & rhs)
+bool LogFilterList::operator==(LogFilterList &rhs)
 {
   if (m_does_conjunction == rhs.does_conjunction()) {
     LogFilter *f = first();
@@ -709,7 +915,7 @@ LogFilterList::clear()
 {
   LogFilter *f;
   while ((f = m_filter_list.dequeue())) {
-    delete f;                   // safe given the semantics stated above
+    delete f; // safe given the semantics stated above
   }
 }
 
@@ -717,15 +923,18 @@ LogFilterList::clear()
   -------------------------------------------------------------------------*/
 
 void
-LogFilterList::add(LogFilter * filter, bool copy)
+LogFilterList::add(LogFilter *filter, bool copy)
 {
   ink_assert(filter != NULL);
   if (copy) {
     if (filter->type() == LogFilter::INT_FILTER) {
-      LogFilterInt *f = new LogFilterInt(*((LogFilterInt *) filter));
+      LogFilterInt *f = new LogFilterInt(*((LogFilterInt *)filter));
+      m_filter_list.enqueue(f);
+    } else if (filter->type() == LogFilter::IP_FILTER) {
+      LogFilterIP *f = new LogFilterIP(*((LogFilterIP *)filter));
       m_filter_list.enqueue(f);
     } else {
-      LogFilterString *f = new LogFilterString(*((LogFilterString *) filter));
+      LogFilterString *f = new LogFilterString(*((LogFilterString *)filter));
       m_filter_list.enqueue(f);
     }
   } else {
@@ -737,27 +946,28 @@ LogFilterList::add(LogFilter * filter, bool copy)
   -------------------------------------------------------------------------*/
 
 bool
-LogFilterList::wipe_this_entry(LogAccess * lad)
+LogFilterList::wipe_this_entry(LogAccess *lad)
 {
   bool wipeFlag = false;
-    for (LogFilter * f = first(); f; f = next(f)) {
-      if (f->wipe_this_entry(lad)) {
-        wipeFlag = true;
-      }
+  for (LogFilter *f = first(); f; f = next(f)) {
+    if (f->wipe_this_entry(lad)) {
+      wipeFlag = true;
     }
-    return wipeFlag;
+  }
+  return wipeFlag;
 }
 
 
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
 
-bool LogFilterList::toss_this_entry(LogAccess * lad)
+bool
+LogFilterList::toss_this_entry(LogAccess *lad)
 {
   if (m_does_conjunction) {
     // toss if any filter rejects the entry (all filters should accept)
     //
-    for (LogFilter * f = first(); f; f = next(f)) {
+    for (LogFilter *f = first(); f; f = next(f)) {
       if (f->toss_this_entry(lad)) {
         return true;
       }
@@ -766,7 +976,7 @@ bool LogFilterList::toss_this_entry(LogAccess * lad)
   } else {
     // toss if all filters reject the entry (any filter accepts)
     //
-    for (LogFilter * f = first(); f; f = next(f)) {
+    for (LogFilter *f = first(); f; f = next(f)) {
       if (!f->toss_this_entry(lad)) {
         return false;
       }
@@ -781,7 +991,7 @@ bool LogFilterList::toss_this_entry(LogAccess * lad)
 LogFilter *
 LogFilterList::find_by_name(char *name)
 {
-  for (LogFilter * f = first(); f; f = next(f)) {
+  for (LogFilter *f = first(); f; f = next(f)) {
     if (strcmp(f->name(), name) == 0) {
       return f;
     }
@@ -798,24 +1008,24 @@ LogFilterList::count()
 {
   unsigned cnt = 0;
 
-  for (LogFilter * f = first(); f; f = next(f)) {
+  for (LogFilter *f = first(); f; f = next(f)) {
     cnt++;
   }
   return cnt;
 }
 
 void
-LogFilterList::display(FILE * fd)
+LogFilterList::display(FILE *fd)
 {
-  for (LogFilter * f = first(); f; f = next(f)) {
+  for (LogFilter *f = first(); f; f = next(f)) {
     f->display(fd);
   }
 }
 
 void
-LogFilterList::display_as_XML(FILE * fd)
+LogFilterList::display_as_XML(FILE *fd)
 {
-  for (LogFilter * f = first(); f; f = next(f)) {
+  for (LogFilter *f = first(); f; f = next(f)) {
     f->display_as_XML(fd);
   }
 }
