@@ -43,39 +43,25 @@
 
 #include "LogCollationClientSM.h"
 
-#define PING 	true
-#define NOPING 	false
+#define PING true
+#define NOPING false
 
 /*-------------------------------------------------------------------------
   LogHost
   -------------------------------------------------------------------------*/
 
 LogHost::LogHost(const char *object_filename, uint64_t object_signature)
-  : m_object_filename(ats_strdup(object_filename)),
-    m_object_signature(object_signature),
-    m_port(0),
-    m_name(NULL),
-    m_sock(NULL),
-    m_sock_fd(-1),
-    m_connected(false),
-    m_orphan_file(NULL)
-  , m_log_collation_client_sm(NULL)
+  : m_object_filename(ats_strdup(object_filename)), m_object_signature(object_signature), m_port(0), m_name(NULL), m_sock(NULL),
+    m_sock_fd(-1), m_connected(false), m_orphan_file(NULL), m_log_collation_client_sm(NULL)
 {
   ink_zero(m_ip);
   ink_zero(m_ipstr);
 }
 
-LogHost::LogHost(const LogHost & rhs)
-  : m_object_filename(ats_strdup(rhs.m_object_filename)),
-    m_object_signature(rhs.m_object_signature),
-    m_ip(rhs.m_ip),
-    m_port(0),
-    m_name(ats_strdup(rhs.m_name)),
-    m_sock(NULL),
-    m_sock_fd(-1),
-    m_connected(false),
-    m_orphan_file(NULL)
-  , m_log_collation_client_sm(NULL)
+LogHost::LogHost(const LogHost &rhs)
+  : m_object_filename(ats_strdup(rhs.m_object_filename)), m_object_signature(rhs.m_object_signature), m_ip(rhs.m_ip), m_port(0),
+    m_name(ats_strdup(rhs.m_name)), m_sock(NULL), m_sock_fd(-1), m_connected(false), m_orphan_file(NULL),
+    m_log_collation_client_sm(NULL)
 {
   memcpy(m_ipstr, rhs.m_ipstr, sizeof(m_ipstr));
   create_orphan_LogFile_object();
@@ -102,7 +88,7 @@ LogHost::set_name_port(char *hostname, unsigned int pt)
     return 1;
   }
 
-  clear();                      // remove all previous state for this LogHost
+  clear(); // remove all previous state for this LogHost
 
   m_name = ats_strdup(hostname);
   m_port = pt;
@@ -121,7 +107,7 @@ LogHost::set_ipstr_port(char *ipstr, unsigned int pt)
     return 1;
   }
 
-  clear();                      // remove all previous state for this LogHost
+  clear(); // remove all previous state for this LogHost
 
   if (0 != m_ip.load(ipstr))
     Note("Log host failed to parse IP address %s", ipstr);
@@ -142,9 +128,9 @@ LogHost::set_name_or_ipstr(char *name_or_ip)
 
   if (name_or_ip && name_or_ip[0] != 0) {
     ts::ConstBuffer addr, port;
-    if (ats_ip_parse(ts::ConstBuffer(name_or_ip, strlen(name_or_ip)), &addr, &port)==0) {
+    if (ats_ip_parse(ts::ConstBuffer(name_or_ip, strlen(name_or_ip)), &addr, &port) == 0) {
       uint16_t p = port ? atoi(port.data()) : Log::config->collation_port;
-      char* n = const_cast<char*>(addr.data());
+      char *n = const_cast<char *>(addr.data());
       // Force termination. We know we can do this because the address
       // string is followed by either a nul or a colon.
       n[addr.size()] = 0;
@@ -158,7 +144,8 @@ LogHost::set_name_or_ipstr(char *name_or_ip)
   return retVal;
 }
 
-bool LogHost::connected(bool ping)
+bool
+LogHost::connected(bool ping)
 {
   if (m_connected && m_sock && m_sock_fd >= 0) {
     if (m_sock->is_connected(m_sock_fd, ping)) {
@@ -168,9 +155,10 @@ bool LogHost::connected(bool ping)
   return false;
 }
 
-bool LogHost::connect()
+bool
+LogHost::connect()
 {
-  if (! m_ip.isValid()) {
+  if (!m_ip.isValid()) {
     Note("Cannot connect to LogHost; host IP has not been established");
     return false;
   }
@@ -187,7 +175,7 @@ bool LogHost::connect()
     Debug("log-host", "Connecting to LogHost %s", ats_ip_nptop(&target, ipb, sizeof ipb));
   }
 
-  disconnect();                 // make sure connection members are initialized
+  disconnect(); // make sure connection members are initialized
 
   if (m_sock == NULL) {
     m_sock = new LogSock();
@@ -230,13 +218,12 @@ LogHost::create_orphan_LogFile_object()
   delete m_orphan_file;
 
   const char *orphan_ext = "orphan";
-  unsigned name_len = (unsigned) (strlen(m_object_filename) + strlen(name()) + strlen(orphan_ext) + 16);
+  unsigned name_len = (unsigned)(strlen(m_object_filename) + strlen(name()) + strlen(orphan_ext) + 16);
   char *name_buf = (char *)ats_malloc(name_len);
 
   // NT: replace ':'s with '-'s.  This change is necessary because
   // NT doesn't like filenames with ':'s in them.  ^_^
-  snprintf(name_buf, name_len, "%s%s%s-%u.%s",
-               m_object_filename, LOGFILE_SEPARATOR_STRING, name(), port(), orphan_ext);
+  snprintf(name_buf, name_len, "%s%s%s-%u.%s", m_object_filename, LOGFILE_SEPARATOR_STRING, name(), port(), orphan_ext);
 
   // should check for conflicts with orphan filename
   //
@@ -250,7 +237,7 @@ LogHost::create_orphan_LogFile_object()
 // and try to delete it when its reference become zero.
 //
 int
-LogHost::preproc_and_try_delete (LogBuffer *lb)
+LogHost::preproc_and_try_delete(LogBuffer *lb)
 {
   int ret = -1;
 
@@ -260,8 +247,7 @@ LogHost::preproc_and_try_delete (LogBuffer *lb)
   }
   LogBufferHeader *buffer_header = lb->header();
   if (buffer_header == NULL) {
-    Note("Cannot write LogBuffer to LogHost %s; LogBufferHeader is NULL",
-        name());
+    Note("Cannot write LogBuffer to LogHost %s; LogBufferHeader is NULL", name());
     goto done;
   }
   if (buffer_header->entry_count == 0) {
@@ -291,28 +277,25 @@ done:
 // try to delete it when its reference become zero.
 //
 void
-LogHost::orphan_write_and_try_delete(LogBuffer * lb)
+LogHost::orphan_write_and_try_delete(LogBuffer *lb)
 {
-  RecIncrRawStat(log_rsb, this_thread()->mutex->thread_holding,
-                 log_stat_num_lost_before_sent_to_network_stat,
+  RecIncrRawStat(log_rsb, this_thread()->mutex->thread_holding, log_stat_num_lost_before_sent_to_network_stat,
                  lb->header()->entry_count);
 
-  RecIncrRawStat(log_rsb, this_thread()->mutex->thread_holding,
-                 log_stat_bytes_lost_before_sent_to_network_stat,
+  RecIncrRawStat(log_rsb, this_thread()->mutex->thread_holding, log_stat_bytes_lost_before_sent_to_network_stat,
                  lb->header()->byte_count);
 
   if (!Log::config->logging_space_exhausted) {
     Debug("log-host", "Sending LogBuffer to orphan file %s", m_orphan_file->get_name());
     m_orphan_file->preproc_and_try_delete(lb);
   } else {
-    Debug("log-host", "logging space exhausted, failed to write orphan file, drop(%" PRIu32 ") bytes",
-         lb->header()->byte_count);
+    Debug("log-host", "logging space exhausted, failed to write orphan file, drop(%" PRIu32 ") bytes", lb->header()->byte_count);
     LogBuffer::destroy(lb);
   }
 }
 
 void
-LogHost::display(FILE * fd)
+LogHost::display(FILE *fd)
 {
   fprintf(fd, "LogHost: %s:%u, %s\n", name(), port(), (connected(NOPING)) ? "connected" : "not connected");
 }
@@ -337,7 +320,8 @@ LogHost::clear()
   m_connected = false;
 }
 
-bool LogHost::authenticated()
+bool
+LogHost::authenticated()
 {
   if (!connected(NOPING)) {
     Note("Cannot authenticate LogHost %s; not connected", name());
@@ -345,13 +329,10 @@ bool LogHost::authenticated()
   }
 
   Debug("log-host", "Authenticating LogHost %s ...", name());
-  char *
-    auth_key = Log::config->collation_secret;
-  unsigned
-    auth_key_len = (unsigned)::strlen(auth_key) + 1;    // incl null
-  int
-    bytes = m_sock->write(m_sock_fd, auth_key, auth_key_len);
-  if ((unsigned) bytes != auth_key_len) {
+  char *auth_key = Log::config->collation_secret;
+  unsigned auth_key_len = (unsigned)::strlen(auth_key) + 1; // incl null
+  int bytes = m_sock->write(m_sock_fd, auth_key, auth_key_len);
+  if ((unsigned)bytes != auth_key_len) {
     Debug("log-host", "... bad write on authenticate");
     return false;
   }
@@ -374,7 +355,7 @@ LogHostList::~LogHostList()
 }
 
 void
-LogHostList::add(LogHost * object, bool copy)
+LogHostList::add(LogHost *object, bool copy)
 {
   ink_assert(object != NULL);
   if (copy) {
@@ -388,7 +369,7 @@ unsigned
 LogHostList::count()
 {
   unsigned cnt = 0;
-  for (LogHost * host = first(); host; host = next(host)) {
+  for (LogHost *host = first(); host; host = next(host)) {
     cnt++;
   }
   return cnt;
@@ -404,7 +385,7 @@ LogHostList::clear()
 }
 
 int
-LogHostList::preproc_and_try_delete(LogBuffer * lb)
+LogHostList::preproc_and_try_delete(LogBuffer *lb)
 {
   int ret;
   unsigned nr_host, nr;
@@ -416,7 +397,7 @@ LogHostList::preproc_and_try_delete(LogBuffer * lb)
   nr_host = nr = count();
   ink_atomic_increment(&lb->m_references, nr_host);
 
-  for (LogHost * host = first(); host && nr; host = next(host)) {
+  for (LogHost *host = first(); host && nr; host = next(host)) {
     LogHost *lh = host;
     available_host = lh;
 
@@ -439,24 +420,22 @@ LogHostList::preproc_and_try_delete(LogBuffer * lb)
 }
 
 void
-LogHostList::display(FILE * fd)
+LogHostList::display(FILE *fd)
 {
-  for (LogHost * host = first(); host; host = next(host)) {
+  for (LogHost *host = first(); host; host = next(host)) {
     host->display(fd);
   }
 }
 
-bool LogHostList::operator==(LogHostList & rhs)
+bool LogHostList::operator==(LogHostList &rhs)
 {
-  LogHost *
-    host;
+  LogHost *host;
   for (host = first(); host; host = next(host)) {
-    LogHost* rhs_host;
+    LogHost *rhs_host;
     for (rhs_host = rhs.first(); rhs_host; rhs_host = next(host)) {
       if ((host->port() == rhs_host->port() && host->ip_addr().isValid() && host->ip_addr() == rhs_host->ip_addr()) ||
-        (host->name() && rhs_host->name() && (strcmp(host->name(), rhs_host->name()) == 0)) ||
-        (*(host->ipstr()) && *(rhs_host->ipstr()) && (strcmp(host->ipstr(), rhs_host->ipstr()) == 0))
-      ) {
+          (host->name() && rhs_host->name() && (strcmp(host->name(), rhs_host->name()) == 0)) ||
+          (*(host->ipstr()) && *(rhs_host->ipstr()) && (strcmp(host->ipstr(), rhs_host->ipstr()) == 0))) {
         break;
       }
     }
@@ -470,7 +449,7 @@ bool LogHostList::operator==(LogHostList & rhs)
 int
 LogHostList::do_filesystem_checks()
 {
-  for (LogHost * host = first(); host; host = next(host)) {
+  for (LogHost *host = first(); host; host = next(host)) {
     if (host->do_filesystem_checks() < 0) {
       return -1;
     }
