@@ -40,17 +40,20 @@
 #include "ts/TestBox.h"
 
 static bool
-should_roll_on_time(Log::RollingEnabledValues roll) {
+should_roll_on_time(Log::RollingEnabledValues roll)
+{
   return roll == Log::ROLL_ON_TIME_ONLY || roll == Log::ROLL_ON_TIME_OR_SIZE;
 }
 
 static bool
-should_roll_on_size(Log::RollingEnabledValues roll) {
+should_roll_on_size(Log::RollingEnabledValues roll)
+{
   return roll == Log::ROLL_ON_SIZE_ONLY || roll == Log::ROLL_ON_TIME_OR_SIZE;
 }
 
 size_t
-LogBufferManager::preproc_buffers(LogBufferSink *sink) {
+LogBufferManager::preproc_buffers(LogBufferSink *sink)
+{
   SList(LogBuffer, write_link) q(write_list.popall()), new_q;
   LogBuffer *b = NULL;
   while ((b = q.pop())) {
@@ -60,8 +63,7 @@ LogBufferManager::preproc_buffers(LogBufferSink *sink) {
     } else if (_num_flush_buffers > FLUSH_ARRAY_SIZE) {
       ink_atomic_increment(&_num_flush_buffers, -1);
       Warning("Dropping log buffer, can't keep up.");
-      RecIncrRawStat(log_rsb, this_thread()->mutex->thread_holding,
-                     log_stat_bytes_lost_before_preproc_stat,
+      RecIncrRawStat(log_rsb, this_thread()->mutex->thread_holding, log_stat_bytes_lost_before_preproc_stat,
                      b->header()->byte_count);
       delete b;
     } else {
@@ -85,95 +87,75 @@ LogBufferManager::preproc_buffers(LogBufferSink *sink) {
   LogObject
   -------------------------------------------------------------------------*/
 
-LogObject::LogObject(const LogFormat *format, const char *log_dir,
-                     const char *basename, LogFileFormat file_format,
-                     const char *header, Log::RollingEnabledValues rolling_enabled,
-                     int flush_threads, int rolling_interval_sec,
-                     int rolling_offset_hr, int rolling_size_mb,
-                     bool auto_created):
-      m_auto_created(auto_created),
-      m_alt_filename (NULL),
-      m_flags (0),
-      m_signature (0),
-      m_flush_threads (flush_threads),
-      m_rolling_interval_sec (rolling_interval_sec),
-      m_rolling_offset_hr (rolling_offset_hr),
-      m_rolling_size_mb (rolling_size_mb),
-      m_last_roll_time(0),
-      m_buffer_manager_idx(0)
+LogObject::LogObject(const LogFormat *format, const char *log_dir, const char *basename, LogFileFormat file_format,
+                     const char *header, Log::RollingEnabledValues rolling_enabled, int flush_threads, int rolling_interval_sec,
+                     int rolling_offset_hr, int rolling_size_mb, bool auto_created)
+  : m_auto_created(auto_created), m_alt_filename(NULL), m_flags(0), m_signature(0), m_flush_threads(flush_threads),
+    m_rolling_interval_sec(rolling_interval_sec), m_rolling_offset_hr(rolling_offset_hr), m_rolling_size_mb(rolling_size_mb),
+    m_last_roll_time(0), m_buffer_manager_idx(0)
 {
-    ink_assert (format != NULL);
-    m_format = new LogFormat(*format);
-    m_buffer_manager = new LogBufferManager[m_flush_threads];
+  ink_release_assert(format);
+  m_format = new LogFormat(*format);
+  m_buffer_manager = new LogBufferManager[m_flush_threads];
 
-    if (file_format == LOG_FILE_BINARY) {
-        m_flags |= BINARY;
-    } else if (file_format == LOG_FILE_PIPE) {
-        m_flags |= WRITES_TO_PIPE;
-    }
+  if (file_format == LOG_FILE_BINARY) {
+    m_flags |= BINARY;
+  } else if (file_format == LOG_FILE_PIPE) {
+    m_flags |= WRITES_TO_PIPE;
+  }
 
-    generate_filenames(log_dir, basename, file_format);
+  generate_filenames(log_dir, basename, file_format);
 
-    // compute_signature is a static function
-    m_signature = compute_signature(m_format, m_basename, m_flags);
+  // compute_signature is a static function
+  m_signature = compute_signature(m_format, m_basename, m_flags);
 
-    // by default, create a LogFile for this object, if a loghost is
-    // later specified, then we will delete the LogFile object
-    //
-    m_logFile = new LogFile(m_filename, header, file_format,
-                            m_signature,
-                            Log::config->ascii_buffer_size,
-                            Log::config->max_line_size);
+  // by default, create a LogFile for this object, if a loghost is
+  // later specified, then we will delete the LogFile object
+  //
+  m_logFile = new LogFile(m_filename, header, file_format, m_signature, Log::config->ascii_buffer_size, Log::config->max_line_size);
 
-    LogBuffer *b = new LogBuffer (this, Log::config->log_buffer_size);
-    ink_assert(b);
-    SET_FREELIST_POINTER_VERSION(m_log_buffer, b, 0);
+  LogBuffer *b = new LogBuffer(this, Log::config->log_buffer_size);
+  ink_assert(b);
+  SET_FREELIST_POINTER_VERSION(m_log_buffer, b, 0);
 
-    _setup_rolling(rolling_enabled, rolling_interval_sec, rolling_offset_hr, rolling_size_mb);
+  _setup_rolling(rolling_enabled, rolling_interval_sec, rolling_offset_hr, rolling_size_mb);
 
-    Debug("log-config", "exiting LogObject constructor, filename=%s this=%p",
-          m_filename, this);
+  Debug("log-config", "exiting LogObject constructor, filename=%s this=%p", m_filename, this);
 }
 
-LogObject::LogObject(LogObject& rhs)
-  : m_basename(ats_strdup(rhs.m_basename)),
-    m_filename(ats_strdup(rhs.m_filename)),
-    m_alt_filename(ats_strdup(rhs.m_alt_filename)),
-    m_flags(rhs.m_flags),
-    m_signature(rhs.m_signature),
-    m_flush_threads(rhs.m_flush_threads),
-    m_rolling_interval_sec(rhs.m_rolling_interval_sec),
-    m_last_roll_time(rhs.m_last_roll_time)
+LogObject::LogObject(LogObject &rhs)
+  : m_basename(ats_strdup(rhs.m_basename)), m_filename(ats_strdup(rhs.m_filename)), m_alt_filename(ats_strdup(rhs.m_alt_filename)),
+    m_flags(rhs.m_flags), m_signature(rhs.m_signature), m_flush_threads(rhs.m_flush_threads),
+    m_rolling_interval_sec(rhs.m_rolling_interval_sec), m_last_roll_time(rhs.m_last_roll_time)
 {
-    m_format = new LogFormat(*(rhs.m_format));
-    m_buffer_manager = new LogBufferManager[m_flush_threads];
+  m_format = new LogFormat(*(rhs.m_format));
+  m_buffer_manager = new LogBufferManager[m_flush_threads];
 
-    if (rhs.m_logFile) {
-        m_logFile = new LogFile(*(rhs.m_logFile));
-    } else {
-        m_logFile = NULL;
-    }
+  if (rhs.m_logFile) {
+    m_logFile = new LogFile(*(rhs.m_logFile));
+  } else {
+    m_logFile = NULL;
+  }
 
-    LogFilter *filter;
-    for (filter = rhs.m_filter_list.first(); filter;
-            filter = rhs.m_filter_list.next (filter)) {
-        add_filter (filter);
-    }
+  LogFilter *filter;
+  for (filter = rhs.m_filter_list.first(); filter; filter = rhs.m_filter_list.next(filter)) {
+    add_filter(filter);
+  }
 
-    LogHost *host;
-    for (host = rhs.m_host_list.first(); host;
-            host = rhs.m_host_list.next (host)) {
-        add_loghost (host);
-    }
+  LogHost *host;
+  for (host = rhs.m_host_list.first(); host; host = rhs.m_host_list.next(host)) {
+    add_loghost(host);
+  }
 
-    // copy gets a fresh log buffer
-    //
-    LogBuffer *b = new LogBuffer (this, Log::config->log_buffer_size);
-    ink_assert(b);
-    SET_FREELIST_POINTER_VERSION(m_log_buffer, b, 0);
+  // copy gets a fresh log buffer
+  //
+  LogBuffer *b = new LogBuffer(this, Log::config->log_buffer_size);
+  ink_assert(b);
+  SET_FREELIST_POINTER_VERSION(m_log_buffer, b, 0);
 
-    Debug("log-config", "exiting LogObject copy constructor, "
-          "filename=%s this=%p", m_filename, this);
+  Debug("log-config", "exiting LogObject copy constructor, "
+                      "filename=%s this=%p",
+        m_filename, this);
 }
 
 LogObject::~LogObject()
@@ -193,7 +175,7 @@ LogObject::~LogObject()
   ats_free(m_alt_filename);
   delete m_format;
   delete[] m_buffer_manager;
-  delete (LogBuffer*)FREELIST_POINTER(m_log_buffer);
+  delete (LogBuffer *)FREELIST_POINTER(m_log_buffer);
 }
 
 //-----------------------------------------------------------------------------
@@ -223,11 +205,11 @@ LogObject::generate_filenames(const char *log_dir, const char *basename, LogFile
   }
   if (i == len - 1) {
     --len;
-  };                            // remove dot at end of name
+  }; // remove dot at end of name
 
   const char *ext = 0;
   int ext_len = 0;
-  if (i < 0) {                  // no extension, add one
+  if (i < 0) { // no extension, add one
     switch (file_format) {
     case LOG_FILE_ASCII:
       ext = LOG_FILE_ASCII_OBJECT_FILENAME_EXTENSION;
@@ -246,9 +228,9 @@ LogObject::generate_filenames(const char *log_dir, const char *basename, LogFile
     }
   }
 
-  int dir_len = (int) strlen(log_dir);
-  int basename_len = len + ext_len + 1; // include null terminator
-  int total_len = dir_len + 1 + basename_len;   // include '/'
+  int dir_len = (int)strlen(log_dir);
+  int basename_len = len + ext_len + 1;       // include null terminator
+  int total_len = dir_len + 1 + basename_len; // include '/'
 
   m_filename = (char *)ats_malloc(total_len);
   m_basename = (char *)ats_malloc(basename_len);
@@ -267,7 +249,6 @@ LogObject::generate_filenames(const char *log_dir, const char *basename, LogFile
 }
 
 
-
 void
 LogObject::rename(char *new_name)
 {
@@ -282,7 +263,7 @@ LogObject::rename(char *new_name)
 
 
 void
-LogObject::add_filter(LogFilter * filter, bool copy)
+LogObject::add_filter(LogFilter *filter, bool copy)
 {
   if (!filter) {
     return;
@@ -292,7 +273,7 @@ LogObject::add_filter(LogFilter * filter, bool copy)
 
 
 void
-LogObject::set_filter_list(const LogFilterList & list, bool copy)
+LogObject::set_filter_list(const LogFilterList &list, bool copy)
 {
   LogFilter *f;
 
@@ -305,7 +286,7 @@ LogObject::set_filter_list(const LogFilterList & list, bool copy)
 
 
 void
-LogObject::add_loghost(LogHost * host, bool copy)
+LogObject::add_loghost(LogHost *host, bool copy)
 {
   if (!host) {
     return;
@@ -324,7 +305,8 @@ LogObject::add_loghost(LogHost * host, bool copy)
 // of the LogFormat rather than from the format_str because the format_str
 // is not part of a LogBuffer header
 //
-uint64_t LogObject::compute_signature(LogFormat * format, char *filename, unsigned int flags)
+uint64_t
+LogObject::compute_signature(LogFormat *format, char *filename, unsigned int flags)
 {
   char *fl = format->fieldlist();
   char *ps = format->printf_str();
@@ -334,13 +316,12 @@ uint64_t LogObject::compute_signature(LogFormat * format, char *filename, unsign
     int buf_size = strlen(fl) + strlen(ps) + strlen(filename) + 2;
     char *buffer = (char *)ats_malloc(buf_size);
 
-    ink_string_concatenate_strings(buffer, fl, ps, filename, flags & LogObject::BINARY ? "B" :
-                                   (flags & LogObject::WRITES_TO_PIPE ? "P" : "A"), NULL);
+    ink_string_concatenate_strings(buffer, fl, ps, filename,
+                                   flags & LogObject::BINARY ? "B" : (flags & LogObject::WRITES_TO_PIPE ? "P" : "A"), NULL);
 
-    INK_MD5 md5s;
-
-    md5s.encodeBuffer(buffer, buf_size - 1);
-    signature = md5s.fold();
+    CryptoHash hash;
+    MD5Context().hash_immediate(hash, buffer, buf_size - 1);
+    signature = hash.fold();
 
     ats_free(buffer);
   }
@@ -349,11 +330,12 @@ uint64_t LogObject::compute_signature(LogFormat * format, char *filename, unsign
 
 
 void
-LogObject::display(FILE * fd)
+LogObject::display(FILE *fd)
 {
   fprintf(fd, "++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n");
-  fprintf(fd, "LogObject [%p]: format = %s (%p)\nbasename = %s\n" "flags = %u\n"
-          "signature = %" PRIu64 "\n",
+  fprintf(fd, "LogObject [%p]: format = %s (%p)\nbasename = %s\n"
+              "flags = %u\n"
+              "signature = %" PRIu64 "\n",
           this, m_format->name(), m_format, m_basename, m_flags, m_signature);
   if (is_collation_client()) {
     m_host_list.display(fd);
@@ -366,7 +348,7 @@ LogObject::display(FILE * fd)
 
 
 void
-LogObject::displayAsXML(FILE * fd, bool extended)
+LogObject::displayAsXML(FILE *fd, bool extended)
 {
   if (extended) {
     // display format and filter objects
@@ -374,11 +356,11 @@ LogObject::displayAsXML(FILE * fd, bool extended)
     m_filter_list.display_as_XML(fd);
   }
 
-  fprintf(fd,
-          "<LogObject>\n"
-          "  <Mode        = \"%s\"/>\n"
-          "  <Format      = \"%s\"/>\n"
-          "  <Filename    = \"%s\"/>\n", (m_flags & BINARY ? "binary" : "ascii"), m_format->name(), m_filename);
+  fprintf(fd, "<LogObject>\n"
+              "  <Mode        = \"%s\"/>\n"
+              "  <Format      = \"%s\"/>\n"
+              "  <Filename    = \"%s\"/>\n",
+          (m_flags & BINARY ? "binary" : "ascii"), m_format->name(), m_filename);
 
   LogFilter *filter;
   for (filter = m_filter_list.first(); filter != NULL; filter = m_filter_list.next(filter)) {
@@ -395,7 +377,8 @@ LogObject::displayAsXML(FILE * fd, bool extended)
 
 
 LogBuffer *
-LogObject::_checkout_write(size_t * write_offset, size_t bytes_needed) {
+LogObject::_checkout_write(size_t *write_offset, size_t bytes_needed)
+{
   LogBuffer::LB_ResultCode result_code;
   LogBuffer *buffer;
   LogBuffer *new_buffer;
@@ -411,12 +394,12 @@ LogObject::_checkout_write(size_t * write_offset, size_t bytes_needed) {
       head_p new_h;
       SET_FREELIST_POINTER_VERSION(new_h, FREELIST_POINTER(h), FREELIST_VERSION(h) + 1);
 #if TS_HAS_128BIT_CAS
-       result = ink_atomic_cas((__int128_t*) &m_log_buffer.data, h.data, new_h.data);
+      result = ink_atomic_cas((__int128_t *)&m_log_buffer.data, h.data, new_h.data);
 #else
-       result = ink_atomic_cas((int64_t *) &m_log_buffer.data, h.data, new_h.data);
+      result = ink_atomic_cas((int64_t *)&m_log_buffer.data, h.data, new_h.data);
 #endif
     } while (!result);
-    buffer = (LogBuffer*)FREELIST_POINTER(h);
+    buffer = (LogBuffer *)FREELIST_POINTER(h);
     result_code = buffer->checkout_write(write_offset, bytes_needed);
     bool decremented = false;
 
@@ -448,9 +431,9 @@ LogObject::_checkout_write(size_t * write_offset, size_t bytes_needed) {
         head_p tmp_h;
         SET_FREELIST_POINTER_VERSION(tmp_h, new_buffer, 0);
 #if TS_HAS_128BIT_CAS
-       result = ink_atomic_cas((__int128_t*) &m_log_buffer.data, old_h.data, tmp_h.data);
+        result = ink_atomic_cas((__int128_t *)&m_log_buffer.data, old_h.data, tmp_h.data);
 #else
-       result = ink_atomic_cas((int64_t *) &m_log_buffer.data, old_h.data, tmp_h.data);
+        result = ink_atomic_cas((int64_t *)&m_log_buffer.data, old_h.data, tmp_h.data);
 #endif
       } while (!result);
       if (FREELIST_POINTER(old_h) == FREELIST_POINTER(h)) {
@@ -460,7 +443,6 @@ LogObject::_checkout_write(size_t * write_offset, size_t bytes_needed) {
         Debug("log-logbuffer", "adding buffer %d to flush list after checkout", buffer->get_id());
         m_buffer_manager[idx].add_to_flush_queue(buffer);
         Log::preproc_notify[idx].signal();
-
       }
       decremented = true;
       break;
@@ -477,7 +459,6 @@ LogObject::_checkout_write(size_t * write_offset, size_t bytes_needed) {
       // transaction cannot be logged
       //
       retry = false;
-      buffer = NULL;
       break;
 
     default:
@@ -492,25 +473,27 @@ LogObject::_checkout_write(size_t * write_offset, size_t bytes_needed) {
         head_p tmp_h;
         SET_FREELIST_POINTER_VERSION(tmp_h, FREELIST_POINTER(h), FREELIST_VERSION(old_h) - 1);
 #if TS_HAS_128BIT_CAS
-       result = ink_atomic_cas((__int128_t*) &m_log_buffer.data, old_h.data, tmp_h.data);
+        result = ink_atomic_cas((__int128_t *)&m_log_buffer.data, old_h.data, tmp_h.data);
 #else
-       result = ink_atomic_cas((int64_t *) &m_log_buffer.data, old_h.data, tmp_h.data);
+        result = ink_atomic_cas((int64_t *)&m_log_buffer.data, old_h.data, tmp_h.data);
 #endif
       } while (!result);
       if (FREELIST_POINTER(old_h) != FREELIST_POINTER(h))
         ink_atomic_increment(&buffer->m_references, -1);
     }
-  } while (retry && write_offset);      // if write_offset is null, we do
+  } while (retry && write_offset); // if write_offset is null, we do
   // not retry because we really do
   // not want to write to the buffer
   // only to set it as full
-
+  if (result_code == LogBuffer::LB_BUFFER_TOO_SMALL) {
+    buffer = NULL;
+  }
   return buffer;
 }
 
 
 int
-LogObject::va_log(LogAccess * lad, const char * fmt, va_list ap)
+LogObject::va_log(LogAccess *lad, const char *fmt, va_list ap)
 {
   static const unsigned MAX_ENTRY = 16 * LOG_KILOBYTE; // 16K? Really?
   char entry[MAX_ENTRY];
@@ -533,7 +516,7 @@ LogObject::va_log(LogAccess * lad, const char * fmt, va_list ap)
     }
   }
 
-  len += vsnprintf(&entry[len], MAX_ENTRY - len, fmt, ap);
+  vsnprintf(&entry[len], MAX_ENTRY - len, fmt, ap);
 
   // Now that we have an entry and it's length (len), we can place it
   // into the associated logbuffer.
@@ -541,10 +524,10 @@ LogObject::va_log(LogAccess * lad, const char * fmt, va_list ap)
 }
 
 int
-LogObject::log(LogAccess * lad, const char *text_entry)
+LogObject::log(LogAccess *lad, const char *text_entry)
 {
   LogBuffer *buffer;
-  size_t offset = 0;            // prevent warning
+  size_t offset = 0; // prevent warning
   size_t bytes_needed = 0, bytes_used = 0;
 
   // log to a pipe even if space is exhausted since pipe uses no space
@@ -588,16 +571,16 @@ LogObject::log(LogAccess * lad, const char *text_entry)
     LogField *f;
     int64_t val;
     for (f = fl->first(); f; f = fl->next(f)) {
-
       // convert to host order to do computations
-      val = (f->is_time_field())? time_now : *((int64_t *) data_ptr);
+      val = (f->is_time_field()) ? time_now : *((int64_t *)data_ptr);
       f->update_aggregate(val);
       data_ptr += INK_MIN_ALIGN;
     }
 
     if (time_now < m_format->m_interval_next) {
       Debug("log-agg", "Time now = %ld, next agg = %ld; not time "
-            "for aggregate entry", time_now, m_format->m_interval_next);
+                       "for aggregate entry",
+            time_now, m_format->m_interval_next);
       return Log::AGGR;
     }
     // can easily compute bytes_needed because all fields are INTs
@@ -619,7 +602,8 @@ LogObject::log(LogAccess * lad, const char *text_entry)
 
   if (!buffer) {
     Note("Skipping the current log entry for %s because its size (%zu) exceeds "
-         "the maximum payload space in a log buffer", m_basename, bytes_needed);
+         "the maximum payload space in a log buffer",
+         m_basename, bytes_needed);
     return Log::FAIL;
   }
   //
@@ -649,7 +633,8 @@ LogObject::log(LogAccess * lad, const char *text_entry)
 
 
 void
-LogObject::_setup_rolling(Log::RollingEnabledValues rolling_enabled, int rolling_interval_sec, int rolling_offset_hr, int rolling_size_mb)
+LogObject::_setup_rolling(Log::RollingEnabledValues rolling_enabled, int rolling_interval_sec, int rolling_offset_hr,
+                          int rolling_size_mb)
 {
   if (!LogRollingEnabledIsValid((int)rolling_enabled)) {
     m_rolling_enabled = Log::NO_ROLLING;
@@ -666,8 +651,8 @@ LogObject::_setup_rolling(Log::RollingEnabledValues rolling_enabled, int rolling
   } else {
     // do checks for rolling based on time
     //
-    if (rolling_enabled == Log::ROLL_ON_TIME_ONLY ||
-        rolling_enabled == Log::ROLL_ON_TIME_OR_SIZE || rolling_enabled == Log::ROLL_ON_TIME_AND_SIZE) {
+    if (rolling_enabled == Log::ROLL_ON_TIME_ONLY || rolling_enabled == Log::ROLL_ON_TIME_OR_SIZE ||
+        rolling_enabled == Log::ROLL_ON_TIME_AND_SIZE) {
       if (rolling_interval_sec < Log::MIN_ROLLING_INTERVAL_SEC) {
         // check minimum
         m_rolling_interval_sec = Log::MIN_ROLLING_INTERVAL_SEC;
@@ -680,15 +665,15 @@ LogObject::_setup_rolling(Log::RollingEnabledValues rolling_enabled, int rolling
       } else {
         m_rolling_interval_sec = rolling_interval_sec;
         // increase so it divides day evenly
-        while (Log::MAX_ROLLING_INTERVAL_SEC % ++m_rolling_interval_sec);
+        while (Log::MAX_ROLLING_INTERVAL_SEC % ++m_rolling_interval_sec)
+          ;
       }
 
       if (m_rolling_interval_sec != rolling_interval_sec) {
-        Note("Rolling interval adjusted from %d sec to %d sec for %s",
-             rolling_interval_sec, m_rolling_interval_sec, m_filename);
+        Note("Rolling interval adjusted from %d sec to %d sec for %s", rolling_interval_sec, m_rolling_interval_sec, m_filename);
       }
 
-      if (rolling_offset_hr<0 || rolling_offset_hr> 23) {
+      if (rolling_offset_hr < 0 || rolling_offset_hr > 23) {
         rolling_offset_hr = 0;
         Note("Rolling offset out of bounds for %s, setting it to %d", m_filename, rolling_offset_hr);
       }
@@ -698,8 +683,8 @@ LogObject::_setup_rolling(Log::RollingEnabledValues rolling_enabled, int rolling
                              // it will be updated later
     }
 
-    if (rolling_enabled == Log::ROLL_ON_SIZE_ONLY ||
-        rolling_enabled == Log::ROLL_ON_TIME_OR_SIZE || rolling_enabled == Log::ROLL_ON_TIME_AND_SIZE) {
+    if (rolling_enabled == Log::ROLL_ON_SIZE_ONLY || rolling_enabled == Log::ROLL_ON_TIME_OR_SIZE ||
+        rolling_enabled == Log::ROLL_ON_TIME_AND_SIZE) {
       if (rolling_size_mb < 10) {
         m_rolling_size_mb = 10;
         Note("Rolling size invalid(%d) for %s, setting it to 10 MB", rolling_size_mb, m_filename);
@@ -752,8 +737,7 @@ LogObject::roll_files(long time_now)
       const int missed_window = 10;
 
       roll_on_time =
-        ((secs_to_next == 0 ||
-          secs_to_next >= m_rolling_interval_sec - missed_window) && secs_since_last > missed_window);
+        ((secs_to_next == 0 || secs_to_next >= m_rolling_interval_sec - missed_window) && secs_since_last > missed_window);
     }
   }
 
@@ -765,8 +749,7 @@ LogObject::roll_files(long time_now)
     }
   }
 
-  if ((roll_on_time && should_roll_on_time(m_rolling_enabled)) ||
-      (roll_on_size && should_roll_on_size(m_rolling_enabled)) ||
+  if ((roll_on_time && should_roll_on_time(m_rolling_enabled)) || (roll_on_size && should_roll_on_size(m_rolling_enabled)) ||
       (roll_on_time && roll_on_size && m_rolling_enabled == Log::ROLL_ON_TIME_AND_SIZE)) {
     num_rolled = _roll_files(m_last_roll_time, time_now ? time_now : LogUtils::timestamp());
   }
@@ -802,7 +785,7 @@ LogObject::_roll_files(long last_roll_time, long time_now)
 void
 LogObject::check_buffer_expiration(long time_now)
 {
-  LogBuffer *b = (LogBuffer*)FREELIST_POINTER(m_log_buffer);
+  LogBuffer *b = (LogBuffer *)FREELIST_POINTER(m_log_buffer);
   if (b && time_now > b->expiration_time()) {
     force_new_buffer();
   }
@@ -825,15 +808,12 @@ LogObject::do_filesystem_checks()
 /*-------------------------------------------------------------------------
   TextLogObject::TextLogObject
   -------------------------------------------------------------------------*/
-const LogFormat * TextLogObject::textfmt = MakeTextLogFormat();
+const LogFormat *TextLogObject::textfmt = MakeTextLogFormat();
 
-TextLogObject::TextLogObject(const char *name, const char *log_dir,
-                             bool timestamps, const char *header,
-                             Log::RollingEnabledValues rolling_enabled, int flush_threads,
-                             int rolling_interval_sec, int rolling_offset_hr,
-                             int rolling_size_mb)
-  : LogObject(TextLogObject::textfmt, log_dir, name, LOG_FILE_ASCII, header,
-              rolling_enabled, flush_threads, rolling_interval_sec,
+TextLogObject::TextLogObject(const char *name, const char *log_dir, bool timestamps, const char *header,
+                             Log::RollingEnabledValues rolling_enabled, int flush_threads, int rolling_interval_sec,
+                             int rolling_offset_hr, int rolling_size_mb)
+  : LogObject(TextLogObject::textfmt, log_dir, name, LOG_FILE_ASCII, header, rolling_enabled, flush_threads, rolling_interval_sec,
               rolling_offset_hr, rolling_size_mb)
 {
   if (timestamps) {
@@ -910,7 +890,7 @@ LogObjectManager::~LogObjectManager()
 }
 
 int
-LogObjectManager::_manage_object(LogObject * log_object, bool is_api_object, int maxConflicts)
+LogObjectManager::_manage_object(LogObject *log_object, bool is_api_object, int maxConflicts)
 {
   if (is_api_object) {
     ACQUIRE_API_MUTEX("A LogObjectManager::_manage_object");
@@ -924,17 +904,16 @@ LogObjectManager::_manage_object(LogObject * log_object, bool is_api_object, int
     // client
     //
     if (col_client || (retVal = _solve_filename_conflicts(log_object, maxConflicts), retVal == NO_FILENAME_CONFLICTS)) {
-
       // do filesystem checks
       //
       if (log_object->do_filesystem_checks() < 0) {
-        const char *msg = "The log file %s did not pass filesystem checks. " "No output will be produced for this log";
+        const char *msg = "The log file %s did not pass filesystem checks. "
+                          "No output will be produced for this log";
         Error(msg, log_object->get_full_filename());
         LogUtils::manager_alarm(LogUtils::LOG_ALARM_ERROR, msg, log_object->get_full_filename());
         retVal = ERROR_DOING_FILESYSTEM_CHECKS;
 
       } else {
-
         // no conflicts, add object to the list of managed objects
         //
         REF_COUNT_OBJ_REFCOUNT_INC(log_object);
@@ -947,18 +926,16 @@ LogObjectManager::_manage_object(LogObject * log_object, bool is_api_object, int
         ink_release_assert(retVal == NO_FILENAME_CONFLICTS);
 
         Debug("log", "LogObjectManager managing object %s (%s) "
-              "[signature = %" PRIu64 ", address = %p]",
-              log_object->get_base_filename(),
-              col_client ? "collation client" :
-              log_object->get_full_filename(), log_object->get_signature(), log_object);
+                     "[signature = %" PRIu64 ", address = %p]",
+              log_object->get_base_filename(), col_client ? "collation client" : log_object->get_full_filename(),
+              log_object->get_signature(), log_object);
 
         if (log_object->has_alternate_name()) {
           Warning("The full path for the (%s) LogObject %s "
                   "with signature %" PRIu64 " "
                   "has been set to %s rather than %s because the latter "
                   "is being used by another LogObject",
-                  log_object->receives_remote_data()? "remote" : "local",
-                  log_object->get_base_filename(),
+                  log_object->receives_remote_data() ? "remote" : "local", log_object->get_base_filename(),
                   log_object->get_signature(), log_object->get_full_filename(), log_object->get_original_filename());
         }
       }
@@ -974,7 +951,7 @@ LogObjectManager::_manage_object(LogObject * log_object, bool is_api_object, int
 
 
 int
-LogObjectManager::_solve_filename_conflicts(LogObject * log_object, int maxConflicts)
+LogObjectManager::_solve_filename_conflicts(LogObject *log_object, int maxConflicts)
 {
   int retVal = NO_FILENAME_CONFLICTS;
 
@@ -1004,9 +981,11 @@ LogObjectManager::_solve_filename_conflicts(LogObject * log_object, int maxConfl
         conflicts = false;
       }
       Debug("log", "LogObjectManager::_solve_filename_conflicts\n"
-            "\tfilename = %s\n"
-            "\tmeta file signature = %" PRIu64 "\n"
-            "\tlog object signature = %" PRIu64 "\n" "\tconflicts = %d", filename, signature, obj_sig, conflicts);
+                   "\tfilename = %s\n"
+                   "\tmeta file signature = %" PRIu64 "\n"
+                   "\tlog object signature = %" PRIu64 "\n"
+                   "\tconflicts = %d",
+            filename, signature, obj_sig, conflicts);
     }
 
     if (conflicts) {
@@ -1045,7 +1024,7 @@ LogObjectManager::_solve_filename_conflicts(LogObject * log_object, int maxConfl
             retVal = ERROR_DETERMINING_FILE_INFO;
             roll_file = false;
           } else {
-            if (s.st_mode == S_IFIFO) {
+            if (S_ISFIFO(s.st_mode)) {
               unlink(filename);
               roll_file = false;
             }
@@ -1053,19 +1032,21 @@ LogObjectManager::_solve_filename_conflicts(LogObject * log_object, int maxConfl
         }
         if (roll_file) {
           Warning("File %s will be rolled because a LogObject with "
-                  "different format is requesting the same " "filename", filename);
+                  "different format is requesting the same "
+                  "filename",
+                  filename);
           LogFile logfile(filename, NULL, LOG_FILE_ASCII, 0);
           long time_now = LogUtils::timestamp();
 
           if (logfile.roll(time_now - log_object->get_rolling_interval(), time_now) == 0) {
             // an error happened while trying to roll the file
             //
-            const char *msg = "Cannot roll log file %s to fix log " "filename conflicts";
+            const char *msg = "Cannot roll log file %s to fix log "
+                              "filename conflicts";
 
             Error(msg, filename);
             LogUtils::manager_alarm(LogUtils::LOG_ALARM_ERROR, msg, filename);
             retVal = CANNOT_SOLVE_FILENAME_CONFLICTS;
-
           }
         }
       }
@@ -1076,10 +1057,9 @@ LogObjectManager::_solve_filename_conflicts(LogObject * log_object, int maxConfl
 
 
 bool
-LogObjectManager::_has_internal_filename_conflict(const char *filename, LogObjectList& objects)
+LogObjectManager::_has_internal_filename_conflict(const char *filename, LogObjectList &objects)
 {
   for (unsigned i = 0; i < objects.length(); i++) {
-
     if (!objects[i]->is_collation_client()) {
       // an internal conflict exists if two objects request the
       // same filename, regardless of the object signatures, since
@@ -1100,13 +1080,11 @@ LogObjectManager::_solve_internal_filename_conflicts(LogObject *log_object, int
   int retVal = NO_FILENAME_CONFLICTS;
   const char *filename = log_object->get_full_filename();
 
-  if (_has_internal_filename_conflict(filename, _objects) ||
-      _has_internal_filename_conflict(filename, _APIobjects)) {
+  if (_has_internal_filename_conflict(filename, _objects) || _has_internal_filename_conflict(filename, _APIobjects)) {
     if (fileNum < maxConflicts) {
       char new_name[MAXPATHLEN];
 
-      snprintf(new_name, sizeof(new_name), "%s%s%d",
-               log_object->get_original_filename(), LOGFILE_SEPARATOR_STRING, ++fileNum);
+      snprintf(new_name, sizeof(new_name), "%s%s%d", log_object->get_original_filename(), LOGFILE_SEPARATOR_STRING, ++fileNum);
       log_object->rename(new_name);
       retVal = _solve_internal_filename_conflicts(log_object, maxConflicts, fileNum);
     } else {
@@ -1125,7 +1103,7 @@ LogObject *
 LogObjectManager::get_object_with_signature(uint64_t signature)
 {
   for (unsigned i = 0; i < this->_objects.length(); i++) {
-    LogObject * obj = this->_objects[i];
+    LogObject *obj = this->_objects[i];
 
     if (obj->get_signature() == signature) {
       return obj;
@@ -1173,7 +1151,7 @@ LogObjectManager::preproc_buffers(int idx)
 
 
 bool
-LogObjectManager::unmanage_api_object(LogObject * logObject)
+LogObjectManager::unmanage_api_object(LogObject *logObject)
 {
   ACQUIRE_API_MUTEX("A LogObjectManager::unmanage_api_object");
 
@@ -1194,7 +1172,7 @@ LogObjectManager::unmanage_api_object(LogObject * logObject)
 
 
 void
-LogObjectManager::add_filter_to_all(LogFilter * filter)
+LogObjectManager::add_filter_to_all(LogFilter *filter)
 {
   for (unsigned i = 0; i < this->_objects.length(); i++) {
     _objects[i]->add_filter(filter);
@@ -1218,7 +1196,7 @@ LogObjectManager::open_local_pipes()
 
 
 void
-LogObjectManager::transfer_objects(LogObjectManager & old_mgr)
+LogObjectManager::transfer_objects(LogObjectManager &old_mgr)
 {
   unsigned num_kept_objects = 0;
 
@@ -1242,8 +1220,8 @@ LogObjectManager::transfer_objects(LogObjectManager & old_mgr)
   }
 
   for (unsigned i = 0; i < old_mgr._objects.length(); ++i) {
-    LogObject * old_obj = old_mgr._objects[i];
-    LogObject * new_obj;
+    LogObject *old_obj = old_mgr._objects[i];
+    LogObject *new_obj;
 
     Debug("log-config-transfer", "examining existing object %s", old_obj->get_base_filename());
 
@@ -1253,8 +1231,8 @@ LogObjectManager::transfer_objects(LogObjectManager & old_mgr)
     for (unsigned j = 0; j < _objects.length(); j++) {
       new_obj = _objects[j];
 
-      Debug("log-config-transfer",
-            "comparing existing object %s to new object %s", old_obj->get_base_filename(), new_obj->get_base_filename());
+      Debug("log-config-transfer", "comparing existing object %s to new object %s", old_obj->get_base_filename(),
+            new_obj->get_base_filename());
 
       if (*new_obj == *old_obj) {
         Debug("log-config-transfer", "keeping existing object %s", old_obj->get_base_filename());
@@ -1298,7 +1276,7 @@ LogObjectManager::roll_files(long time_now)
 }
 
 void
-LogObjectManager::display(FILE * str)
+LogObjectManager::display(FILE *str)
 {
   for (unsigned i = 0; i < this->_objects.length(); i++) {
     _objects[i]->display(str);
@@ -1336,7 +1314,7 @@ LogObjectManager::get_num_collation_clients() const
 }
 
 int
-LogObjectManager::log(LogAccess * lad)
+LogObjectManager::log(LogAccess *lad)
 {
   int ret = Log::SKIP;
   ProxyMutex *mutex = this_thread()->mutex;
@@ -1359,20 +1337,15 @@ LogObjectManager::log(LogAccess * lad)
   // The if-statement should keep step with the priority order.
   //
   if (unlikely(ret & Log::FAIL)) {
-    RecIncrRawStat(log_rsb, mutex->thread_holding,
-                   log_stat_event_log_access_fail_stat, 1);
+    RecIncrRawStat(log_rsb, mutex->thread_holding, log_stat_event_log_access_fail_stat, 1);
   } else if (unlikely(ret & Log::FULL)) {
-    RecIncrRawStat(log_rsb, mutex->thread_holding,
-                   log_stat_event_log_access_full_stat, 1);
+    RecIncrRawStat(log_rsb, mutex->thread_holding, log_stat_event_log_access_full_stat, 1);
   } else if (likely(ret & Log::LOG_OK)) {
-    RecIncrRawStat(log_rsb, mutex->thread_holding,
-                   log_stat_event_log_access_ok_stat, 1);
+    RecIncrRawStat(log_rsb, mutex->thread_holding, log_stat_event_log_access_ok_stat, 1);
   } else if (unlikely(ret & Log::AGGR)) {
-    RecIncrRawStat(log_rsb, mutex->thread_holding,
-                   log_stat_event_log_access_aggr_stat, 1);
+    RecIncrRawStat(log_rsb, mutex->thread_holding, log_stat_event_log_access_aggr_stat, 1);
   } else if (likely(ret & Log::SKIP)) {
-    RecIncrRawStat(log_rsb, mutex->thread_holding,
-                   log_stat_event_log_access_skip_stat, 1);
+    RecIncrRawStat(log_rsb, mutex->thread_holding, log_stat_event_log_access_skip_stat, 1);
   } else {
     ink_release_assert("Unexpected result");
   }
@@ -1399,21 +1372,20 @@ LogObjectManager::flush_all_objects()
 #if TS_HAS_TESTS
 
 static LogObject *
-MakeTestLogObject(const char * name)
+MakeTestLogObject(const char *name)
 {
-  const char * tmpdir = getenv("TMPDIR");
+  const char *tmpdir = getenv("TMPDIR");
   LogFormat format("testfmt", NULL);
 
   if (!tmpdir) {
     tmpdir = "/tmp";
   }
 
-  return new LogObject(&format, tmpdir, name,
-                       LOG_FILE_ASCII /* file_format */, name /* header */,
+  return new LogObject(&format, tmpdir, name, LOG_FILE_ASCII /* file_format */, name /* header */,
                        Log::ROLL_ON_TIME_ONLY /* rolling_enabled */, 1 /* flush_threads */);
 }
 
-REGRESSION_TEST(LogObjectManager_Transfer)(RegressionTest * t, int /* atype ATS_UNUSED */, int * pstatus)
+REGRESSION_TEST(LogObjectManager_Transfer)(RegressionTest *t, int /* atype ATS_UNUSED */, int *pstatus)
 {
   TestBox box(t, pstatus);
 
@@ -1431,8 +1403,7 @@ REGRESSION_TEST(LogObjectManager_Transfer)(RegressionTest * t, int /* atype ATS_
 
     mgr2.transfer_objects(mgr1);
 
-    rprintf(t, "mgr1 has %d objects, mgr2 has %d objects\n",
-        (int)mgr1.get_num_objects(), (int)mgr2.get_num_objects());
+    rprintf(t, "mgr1 has %d objects, mgr2 has %d objects\n", (int)mgr1.get_num_objects(), (int)mgr2.get_num_objects());
 
     rprintf(t, "running Log::periodoc_tasks()\n");
     Log::periodic_tasks(ink_get_hrtime() / HRTIME_SECOND);
