@@ -50,6 +50,61 @@ my %INK_EXCLUDES = (
   "INKStatCoupledGlobalAdd" => 1,
   "INKStatCoupledLocalAdd" => 1,
   "INKStatsCoupledUpdate" => 1,
+  "INKStatCreateV2" => 1,
+  "INKStatIncrementV2" => 1,
+  "INKStatIncrementByNameV2" => 1,
+  "INKStatDecrementV2" => 1,
+  "INKStatDecrementByNameV2" => 1,
+  "INKStatGetCurrentV2" => 1,
+  "INKStatGetCurrentByNameV2" => 1,
+  "INKStatGetV2" => 1,
+  "INKStatGetByNameV2" => 1,
+  "INKMimeFieldCreate" => 1,
+  "INKMimeFieldDestroy" => 1,
+  "INKMimeFieldCopy" => 1,
+  "INKMimeFieldCopyValues" => 1,
+  "INKMimeFieldNext" => 1,
+  "INKMimeFieldLengthGet" => 1,
+  "INKMimeFieldNameGet" => 1,
+  "INKMimeFieldNameSet" => 1,
+  "INKMimeFieldValuesClear" => 1,
+  "INKMimeFieldValuesCount" => 1,
+  "INKMimeFieldValueGet" => 1,
+  "INKMimeFieldValueGetInt" => 1,
+  "INKMimeFieldValueGetUint" => 1,
+  "INKMimeFieldValueGetDate" => 1,
+  "INKMimeFieldValueSet" => 1,
+  "INKMimeFieldValueSetInt" => 1,
+  "INKMimeFieldValueSetUint" => 1,
+  "INKMimeFieldValueSetDate" => 1,
+  "INKMimeFieldValueAppend" => 1,
+  "INKMimeFieldValueInsert" => 1,
+  "INKMimeFieldValueInsertInt" => 1,
+  "INKMimeFieldValueInsertUint" => 1,
+  "INKMimeFieldValueInsertDate" => 1,
+  "INKMimeFieldValueDelete" => 1,
+  "INKMimeHdrFieldValueSet" => 1,
+  "INKMimeHdrFieldValueGet" => 1,
+  "INKMimeHdrFieldInsert" => 1,
+  "INKMimeHdrFieldDelete" => 1,
+  "INKMutexTryLock" => 1,
+  "INKMBufferDataSet" => 1,
+  "INKMBufferDataGet" => 1,
+  "INKMBufferLengthGet" => 1,
+  "INKMBufferRef" => 1,
+  "INKMBufferUnref" => 1,
+  "INKMBufferCompress" => 1,
+  "INKIOBufferDataCreate" => 1,
+  "INKIOBufferBlockCreate" => 1,
+  "INKIOBufferAppend" => 1,
+  "INKCacheHttpInfoCreate" => 1,
+  "INKCacheHttpInfoReqGet" => 1,
+  "INKCacheHttpInfoRespGet" => 1,
+  "INKCacheHttpInfoReqSet" => 1,
+  "INKCacheHttpInfoRespSet" => 1,
+  "INKCacheHttpInfoKeySet" => 1,
+  "INKCacheHttpInfoSizeSet" => 1,
+  "INKCacheHttpInfoVector" => 1,
 );
 
 sub ink2ts {
@@ -90,6 +145,7 @@ my $W_CHAR_NOT_NULL = "returns the char* pointer directly, it can never be NULL"
 my $W_TIME_T = "returns the time_t directly";
 my $W_NOT_NULL_LEN = "the length parameter can no longer be a NULL pointer";
 my $W_TSCACHEKEY = "returns a TSCacheKey directly";
+my $W_ARG_CHANGES = "the argument list or types have changes";
 my $W_TSAIOCALLBACK = "uses the new TSAIOCallback data type";
 my $W_DEPRECATED = "is deprecated, do not use (ever!)";
 my $W_NO_NULL_LENGTH = "1";
@@ -107,6 +163,46 @@ my %RENAMED = (
   "tsremap_remap" => "TSRemapDoRemap",
   "tsremap_os_response" => "TSRemapOSResponse",
   "rhandle" => "TSHttpTxn",
+  "INKStatCreateV2" => "TSStatCreate",
+  "INKStatIncrementV2" => "TSStatIntIncrement",
+  "INKStatIncrementByNameV2" => "TSStatIntIncrement",
+  "INKStatDecrementV2" => "TSStatIntDecrement",
+  "INKStatDecrementByNameV2" => "TSStatIntDecrement",
+  "INKStatGetCurrentV2" => "TSStatIntGet",
+  "INKStatGetCurrentByNameV2" => "TSStatIntGet",
+  "INKStatGetV2" => "TSStatIntGet",
+  "INKStatGetByNameV2" => "TSStatIntGet",
+  "INKMimeFieldCreate" => "TSMimeHdrFieldCreate",
+  "INKMimeFieldDestroy" => "TSMimeHdrFieldDestroy",
+  "INKMimeFieldCopy" => "TSMimeHdrFieldCopy",
+  "INKMimeFieldCopyValues" => "TSMimeHdrFieldCopyValues",
+  "INKMimeFieldNext" => "TSMimeHdrFieldNext",
+  "INKMimeFieldLengthGet" => "TSMimeHdrFieldLengthGet",
+  "INKMimeFieldNameGet" => "TSMimeHdrFieldNameGet",
+  "INKMimeFieldNameSet" => "TSMimeHdrFieldNameSet",
+  "INKMimeFieldValuesClear" => "TSMimeHdrFieldValuesClear",
+  "INKMimeFieldValuesCount" => "TSMimeHdrFieldValuesCount",
+  "INKMimeHdrFieldValueGet" => "TSMimeHdrFieldValueStringGet",
+  "INKMimeFieldValueGet" => "TSMimeHdrFieldValueStringGet",
+  "INKMimeFieldValueGetInt" => "TSMimeHdrFieldValueIntGet",
+  "INKMimeFieldValueGetUint" => "TSMimeHdrFieldValueUintGet",
+  "INKMimeFieldValueGetDate" => "TSMimeHdrFieldValueDateGet",
+  "INKMimeFieldValueSet" => "TSMimeHdrFieldValueStringSet",
+  "TSMimeHdrFieldValueSet" => "TSMimeHdrFieldValueStringSet",
+  "INKMimeFieldValueSetInt" => "TSMimeHdrFieldValueIntSet",
+  "INKMimeFieldValueSetUint" => "TSMimeHdrFieldValueUintSet",
+  "INKMimeFieldValueSetDate" => "TSMimeHdrFieldValueDateSet",
+  "INKMimeFieldValueAppend" => "TSMimeHdrFieldValueAppend",
+  "INKMimeFieldValueInsert" => "TSMimeHdrFieldValueStringInsert",
+  "INKMimeFieldValueInsertInt" => "TSMimeHdrFieldValueIntInsert",
+  "INKMimeFieldValueInsertUint" => "TSMimeHdrFieldValueUintInsert",
+  "INKMimeFieldValueInsertDate" => "TSMimeHdrFieldValueDateInsert",
+  "INKMimeFieldValueDelete" => "TSMimeHdrFieldValueDelete",
+  "INKMimeHdrFieldInsert" => "TSMimeHdrFieldAppend",
+  "INKMimeHdrFieldDelete" => "TSMimeHdrFieldDestroy",
+  "INKMutexTryLock" =>  "TSMutexLockTry",
+  "INKIOBufferDataCreate" => "TSIOBufferCreate",
+  "TSIOBufferDataCreate" => "TSIOBufferCreate",
 );
 
 my %TWO_2_THREE = (
@@ -171,7 +267,7 @@ my %TWO_2_THREE = (
   "TSHttpTxnArgGet" => [$W_VOID_PTR_RETURN],
   "TSHttpSsnArgSet" => [$W_VOID_RETURN],
   "TSHttpSsnArgGet" => [$W_VOID_PTR_RETURN],
-  "TSHttpTxnSetHttpRetBody" => [$W_VOID_RETURN],
+  "TSHttpTxnSetHttpRetBody" => [$W_DEPRECATED],
   "TSHttpTxnSetHttpRetStatus" => [$W_VOID_RETURN],
   "TSHttpTxnActiveTimeoutSet" => [$W_VOID_RETURN],
   "TSHttpTxnConnectTimeoutSet" => [$W_VOID_RETURN],
@@ -258,6 +354,15 @@ my %TWO_2_THREE = (
   "tsremap_delete_instance" =>  [$W_RENAMED],
   "tsremap_remap" =>  [$W_RENAMED, $W_TSREMAPSTATUS],
   "tsremap_os_response" => [$W_RENAMED],
+  "INKStatCreateV2" => [$W_RENAMED],
+  "INKStatIncrementV2" => [$W_RENAMED],
+  "INKStatIncrementByNameV2" => [$W_RENAMED],
+  "INKStatDecrementV2" => [$W_RENAMED],
+  "INKStatDecrementByNameV2" => [$W_RENAMED],
+  "INKStatGetCurrentV2" => [$W_RENAMED],
+  "INKStatGetCurrentByNameV2" => [$W_RENAMED],
+  "INKStatGetV2" => [$W_RENAMED],
+  "INKStatGetByNameV2" => [$W_RENAMED],
   "orig_url" => [$W_DEPRECATED],
   "orig_url_size" => [$W_DEPRECATED],
   "request_port" =>  [$W_DEPRECATED],
@@ -281,6 +386,55 @@ my %TWO_2_THREE = (
   "new_matrix" =>  [$W_DEPRECATED],
   "redirect_url" =>  [$W_DEPRECATED],
   "require_ssl" =>  [$W_DEPRECATED],
+  "INKMimeFieldCreate" => [$W_RENAMED],
+  "INKMimeFieldDestroy" => [$W_RENAMED],
+  "INKMimeFieldCopy" => [$W_RENAMED],
+  "INKMimeFieldCopyValues" => [$W_RENAMED],
+  "INKMimeFieldNext" => [$W_RENAMED],
+  "INKMimeFieldLengthGet" => [$W_RENAMED],
+  "INKMimeFieldNameGet" => [$W_RENAMED],
+  "INKMimeFieldNameSet" => [$W_RENAMED],
+  "INKMimeFieldValuesClear" => [$W_RENAMED],
+  "INKMimeFieldValuesCount" => [$W_RENAMED],
+  "INKMimeFieldValueGet" => [$W_RENAMED],
+  "INKMimeFieldValueGetInt" => [$W_RENAMED],
+  "INKMimeFieldValueGetUint" => [$W_RENAMED],
+  "INKMimeFieldValueGetDate" => [$W_RENAMED],
+  "INKMimeFieldValueSet" => [$W_RENAMED],
+  "INKMimeFieldValueSetInt" => [$W_RENAMED],
+  "INKMimeFieldValueSetUint" => [$W_RENAMED],
+  "INKMimeFieldValueSetDate" => [$W_RENAMED],
+  "INKMimeFieldValueAppend" => [$W_RENAMED],
+  "INKMimeFieldValueInsert" => [$W_RENAMED],
+  "INKMimeFieldValueInsertInt" => [$W_RENAMED],
+  "INKMimeFieldValueInsertUint" => [$W_RENAMED],
+  "INKMimeFieldValueInsertDate" => [$W_RENAMED],
+  "INKMimeFieldValueDelete" => [$W_RENAMED],
+  "INKMimeHdrFieldValueGet" => [$W_RENAMED],
+  "INKMimeHdrFieldValueSet" => [$W_RENAMED],
+  "INKMimeHdrFieldInsert" => [$W_RENAMED],
+  "INKMimeHdrFieldDelete" => [$W_RENAMED],
+  "INKMutexTryLock" => [$W_RENAMED],
+  "INKMBufferDataSet" => [$W_DEPRECATED],
+  "INKMBufferDataGet" => [$W_DEPRECATED],
+  "INKMBufferLengthGet" => [$W_DEPRECATED],
+  "INKMBufferRef" => [$W_DEPRECATED],
+  "INKMBufferUnref" => [$W_DEPRECATED],
+  "INKMBufferCompress" => [$W_DEPRECATED],
+  "INKIOBufferDataCreate" => [$W_RENAMED],
+  "TSIOBufferDataCreate" => [$W_RENAMED],
+  "INKIOBufferBlockCreate" => [$W_DEPRECATED],
+  "TSIOBufferBlockCreate" => [$W_DEPRECATED],
+  "INKIOBufferAppend" => [$W_DEPRECATED],
+  "TSIOBufferAppend" => [$W_DEPRECATED],
+  "INKCacheHttpInfoCreate" => [$W_DEPRECATED],
+  "INKCacheHttpInfoReqGet" => [$W_DEPRECATED],
+  "INKCacheHttpInfoRespGet" => [$W_DEPRECATED],
+  "INKCacheHttpInfoReqSet" => [$W_DEPRECATED],
+  "INKCacheHttpInfoRespSet" => [$W_DEPRECATED],
+  "INKCacheHttpInfoKeySet" => [$W_DEPRECATED],
+  "INKCacheHttpInfoSizeSet" => [$W_DEPRECATED],
+  "INKCacheHttpInfoVector" => [$W_DEPRECATED],
 );
 
 
@@ -348,7 +502,11 @@ sub process {
   while (<FILE>) {
     my @tokens = split(/[^a-zA-Z0-9_\.]/);
 
-    if (ink2ts(\@tokens, $_) || two2three(\@tokens, $_)) {
+    if (ink2ts(\@tokens, $_)) {
+      print "$file:$line:$_\n";
+    }
+
+    if (two2three(\@tokens, $_)) {
       print "$file:$line:$_\n";
     }
 
