@@ -35,49 +35,47 @@
 
 #define HASH_SIZE 67
 static Timer *timers[HASH_SIZE];
-static Timer *free_timers = (Timer *) 0;
+static Timer *free_timers = (Timer *)0;
 static long mstimeout_cache = -1;
 
 ClientData JunkClientData;
 
 
-
 static unsigned int
-hash(Timer * t)
+hash(Timer *t)
 {
   /* We can hash on the trigger time, even though it can change over
    ** the life of a timer via either the periodic bit or the tmr_reset()
    ** call.  This is because both of those guys call l_resort(), which
    ** recomputes the hash and moves the timer to the appropriate list.
    */
-  return ((unsigned int) t->time.tv_sec ^ (unsigned int) t->time.tv_usec) % HASH_SIZE;
+  return ((unsigned int)t->time.tv_sec ^ (unsigned int)t->time.tv_usec) % HASH_SIZE;
 }
 
 
 static void
-l_add(Timer * t)
+l_add(Timer *t)
 {
   int h = t->hash;
   Timer *t2;
   Timer *t2prev;
 
   t2 = timers[h];
-  if (t2 == (Timer *) 0) {
+  if (t2 == (Timer *)0) {
     /* The list is empty. */
     timers[h] = t;
-    t->prev = t->next = (Timer *) 0;
+    t->prev = t->next = (Timer *)0;
   } else {
     if (t->time.tv_sec < t2->time.tv_sec || (t->time.tv_sec == t2->time.tv_sec && t->time.tv_usec <= t2->time.tv_usec)) {
       /* The new timer goes at the head of the list. */
       timers[h] = t;
-      t->prev = (Timer *) 0;
+      t->prev = (Timer *)0;
       t->next = t2;
       t2->prev = t;
     } else {
       /* Walk the list to find the insertion point. */
-      for (t2prev = t2, t2 = t2->next; t2 != (Timer *) 0; t2prev = t2, t2 = t2->next) {
-        if (t->time.tv_sec < t2->time.tv_sec ||
-            (t->time.tv_sec == t2->time.tv_sec && t->time.tv_usec <= t2->time.tv_usec)) {
+      for (t2prev = t2, t2 = t2->next; t2 != (Timer *)0; t2prev = t2, t2 = t2->next) {
+        if (t->time.tv_sec < t2->time.tv_sec || (t->time.tv_sec == t2->time.tv_sec && t->time.tv_usec <= t2->time.tv_usec)) {
           /* Found it. */
           t2prev->next = t;
           t->prev = t2prev;
@@ -89,28 +87,28 @@ l_add(Timer * t)
       /* Oops, got to the end of the list.  Add to tail. */
       t2prev->next = t;
       t->prev = t2prev;
-      t->next = (Timer *) 0;
+      t->next = (Timer *)0;
     }
   }
 }
 
 
 static void
-l_remove(Timer * t)
+l_remove(Timer *t)
 {
   int h = t->hash;
 
-  if (t->prev == (Timer *) 0)
+  if (t->prev == (Timer *)0)
     timers[h] = t->next;
   else
     t->prev->next = t->next;
-  if (t->next != (Timer *) 0)
+  if (t->next != (Timer *)0)
     t->next->prev = t->prev;
 }
 
 
 static void
-l_resort(Timer * t)
+l_resort(Timer *t)
 {
   /* Remove the timer from its old list. */
   l_remove(t);
@@ -128,22 +126,22 @@ tmr_init(void)
 
   mstimeout_cache = -1;
   for (h = 0; h < HASH_SIZE; ++h)
-    timers[h] = (Timer *) 0;
+    timers[h] = (Timer *)0;
 }
 
 
 Timer *
-tmr_create(struct timeval *nowP, TimerProc * timer_proc, ClientData client_data, long msecs, int periodic)
+tmr_create(struct timeval *nowP, TimerProc *timer_proc, ClientData client_data, long msecs, int periodic)
 {
   Timer *t;
 
-  if (free_timers != (Timer *) 0) {
+  if (free_timers != (Timer *)0) {
     t = free_timers;
     free_timers = t->next;
   } else {
-    t = (Timer *) malloc(sizeof(Timer));
-    if (t == (Timer *) 0)
-      return (Timer *) 0;
+    t = (Timer *)malloc(sizeof(Timer));
+    if (t == (Timer *)0)
+      return (Timer *)0;
   }
 
   mstimeout_cache = -1;
@@ -151,10 +149,10 @@ tmr_create(struct timeval *nowP, TimerProc * timer_proc, ClientData client_data,
   t->client_data = client_data;
   t->msecs = msecs;
   t->periodic = periodic;
-  if (nowP != (struct timeval *) 0)
+  if (nowP != (struct timeval *)0)
     t->time = *nowP;
   else
-    (void) gettimeofday(&t->time, (struct timezone *) 0);
+    (void)gettimeofday(&t->time, (struct timezone *)0);
   t->time.tv_sec += msecs / 1000L;
   t->time.tv_usec += (msecs % 1000L) * 1000L;
   if (t->time.tv_usec >= 1000000L) {
@@ -177,7 +175,7 @@ tmr_timeout(struct timeval *nowP)
 
   msecs = tmr_mstimeout(nowP);
   if (msecs == INFTIM)
-    return (struct timeval *) 0;
+    return (struct timeval *)0;
   timeout.tv_sec = msecs / 1000L;
   timeout.tv_usec = (msecs % 1000L) * 1000L;
   return &timeout;
@@ -196,13 +194,13 @@ tmr_mstimeout(struct timeval *nowP)
     Timer *t;
 
     gotone = 0;
-    msecs = 0;                  /* make lint happy */
-    /* Since the lists are sorted, we only need to look at the
-     ** first timer on each one.
-     */
+    msecs = 0; /* make lint happy */
+               /* Since the lists are sorted, we only need to look at the
+                ** first timer on each one.
+                */
     for (h = 0; h < HASH_SIZE; ++h) {
       t = timers[h];
-      if (t != (Timer *) 0) {
+      if (t != (Timer *)0) {
         m = (t->time.tv_sec - nowP->tv_sec) * 1000L + (t->time.tv_usec - nowP->tv_usec) / 1000L;
         if (!gotone) {
           msecs = m;
@@ -230,7 +228,7 @@ tmr_run(struct timeval *nowP)
   Timer *next;
 
   for (h = 0; h < HASH_SIZE; ++h)
-    for (t = timers[h]; t != (Timer *) 0; t = next) {
+    for (t = timers[h]; t != (Timer *)0; t = next) {
       next = t->next;
       /* Since the lists are sorted, as soon as we find a timer
        ** that isn't ready yet, we can go on to the next list.
@@ -241,7 +239,7 @@ tmr_run(struct timeval *nowP)
       /* Invalidate mstimeout cache, since we're modifying the queue */
       mstimeout_cache = -1;
 
-      (t->timer_proc) (t->client_data, nowP);
+      (t->timer_proc)(t->client_data, nowP);
       if (t->periodic) {
         /* Reschedule. */
         t->time.tv_sec += t->msecs / 1000L;
@@ -258,7 +256,7 @@ tmr_run(struct timeval *nowP)
 
 
 void
-tmr_reset(struct timeval *nowP, Timer * t)
+tmr_reset(struct timeval *nowP, Timer *t)
 {
   mstimeout_cache = -1;
   t->time = *nowP;
@@ -273,7 +271,7 @@ tmr_reset(struct timeval *nowP, Timer * t)
 
 
 void
-tmr_cancel(Timer * t)
+tmr_cancel(Timer *t)
 {
   mstimeout_cache = -1;
   /* Remove it from its active list. */
@@ -281,7 +279,7 @@ tmr_cancel(Timer * t)
   /* And put it on the free list. */
   t->next = free_timers;
   free_timers = t;
-  t->prev = (Timer *) 0;
+  t->prev = (Timer *)0;
 }
 
 
@@ -291,10 +289,10 @@ tmr_cleanup(void)
   Timer *t;
 
   mstimeout_cache = -1;
-  while (free_timers != (Timer *) 0) {
+  while (free_timers != (Timer *)0) {
     t = free_timers;
     free_timers = t->next;
-    free((void *) t);
+    free((void *)t);
   }
 }
 
@@ -306,8 +304,7 @@ tmr_destroy(void)
 
   mstimeout_cache = -1;
   for (h = 0; h < HASH_SIZE; ++h)
-    while (timers[h] != (Timer *) 0)
+    while (timers[h] != (Timer *)0)
       tmr_cancel(timers[h]);
   tmr_cleanup();
-
 }
